@echo off
rem ============================================================================
rem mdbFuncs.bat
rem Collection of shared MDB install functions
rem
rem Functions:
rem
rem    mdbFuncs GET_LONG_DT
rem         sets variable LONG_DT with the date string in the long format.
rem
rem    mdbFuncs GET_DT
rem         sets variable DT with the date string in the short format.
rem
rem    mdbFuncs GET_PRECHECK_DT
rem         sets variable PRECHECK_DT with the PRECHECK "DATE=" string.
rem
rem    mdbFuncs GET_PRECHECK_TM
rem         sets variable PRECHECK_TM with the PRECHECK "TIME=" string.
rem
rem ============================================================================
REM History:
REM  08-aug-2008  johri05  created
REM  11-aug-2008  hopst01  enable debug
REM                        Double quote temp file
REM                        Use existence test and deletion test to determine if writing
REM                          to temp file successful as unsuccessful echo does not
REM                          modify errorlevel
REM  15-sep-2008  johri05  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG-PRECHECK
REM                        Add GET_PRECHECK_DT and GET_PRECHECK_TM
REM                           to set PRECHECK_DATE and PRECHECK_TM
REM                           with PRECHECK formats =>  yyyy-mm-dd  and  HH:mm:ss.hh
REM                        Chg SKIPDATE labels to be unique
REM

IF /I ("%DEBUGECHO%") EQU ("@ECHO ON") @ECHO ON

set tgtdir=.
if "%~2" EQU "" GOTO :TGTDIR_SET
   set tgtdir=%~2
:TGTDIR_SET

IF "%~1" NEQ "GET_LONG_DT" GOTO :SKIP_GET_LONG_DT
   call :GET_LONG_DT "%tgtdir%"
   exit /b
:SKIP_GET_LONG_DT

IF "%~1" NEQ "GET_DT"      GOTO :SKIP_GET_DT
   call :GET_DT  "%tgtdir%"
   exit /b
:SKIP_GET_DT

IF "%~1" NEQ "GET_PRECHECK_DT" GOTO :SKIP_GET_PRECHECK_DT
   call :GET_PRECHECK_DT "%tgtdir%"
   exit /b
:SKIP_GET_PRECHECK_DT

IF "%~1" NEQ "GET_PRECHECK_TM" GOTO :SKIP_GET_PRECHECK_TM
   call :GET_PRECHECK_TM "%tgtdir%"
   exit /b
:SKIP_GET_PRECHECK_TM

exit /b


:GET_LONG_DT
rem ============================================================================
rem GET_LONG_DT and GET_DT
rem Get FULL Date in invariant ISO 8601 internationally acceptable format.
rem    LONG_DT variable is set to long date format -- yyyy-mm-dd,HH:mm:ss-zzzz
rem Get DT -- Date-Time variable set to current date/time.
rem    DT variable is set to short date format -- mm-dd,HH:mm:ss
rem :GET_LONG_DT is executed once to decorate the install log header.
rem :GET_DT is repeated in all windows install scripts (i.e. pre and post).
rem Long date fmt:    yyyy-mm-dd,HH:mm:ss-zzzz
rem        example => 2007-12-25,12:34:56-0500
rem Short date fmt:        mm-dd,HH:mm:ss
rem        example =>      12-25,12:34:56
rem These formats are duplicated in compiled java via MDBTools.properties.
rem  and are also duplicated in LinuxUnix install scripts.
rem Website with date/time format function details...
rem http:
rem //www.microsoft.com/technet/scriptcenter/resources/qanda/jan05/hey0127.mspx
rem ============================================================================
set LONG_DT=
set tgtdir=%~1
set TMPVBS="%tgtdir%\mdbTools%RANDOM%.vbs"
IF EXIST %TMPVBS%  del %TMPVBS%                                      >> nul 2>&1
set SUCCESSFUL_DELETE=yes
IF EXIST %TMPVBS% set SUCCESSFUL_DELETE=no
rem
rem Get FULL Date in invariant ISO 8601 internationally acceptable format.
rem
echo Set objWMIService  =  GetObject("winmgmts:\\.\root\cimv2") >>%TMPVBS% 2>nul
IF NOT EXIST %TMPVBS%  GOTO :SKIPDATE_LONG
IF "%SUCCESSFUL_DELETE%" EQU "no"  GOTO :SKIPDATE_LONG
echo Set colItems  =  objWMIService.ExecQuery(                      _>> %TMPVBS%
echo                        "Select * From Win32_OperatingSystem")   >> %TMPVBS%
echo For Each objItem in colItems                                    >> %TMPVBS%
echo    ldt  =  objItem.LocalDateTime                                >> %TMPVBS%
echo    cYear     = Left( ldt,  4 )                                  >> %TMPVBS%
echo    cMonth    = Mid ( ldt,  5, 2 )                               >> %TMPVBS%
echo    cDay      = Mid ( ldt,  7, 2 )                               >> %TMPVBS%
echo    cHour     = Mid ( ldt,  9, 2 )                               >> %TMPVBS%
echo    cMinute   = Mid ( ldt, 11, 2 )                               >> %TMPVBS%
echo    cSecond   = Mid ( ldt, 13, 2 )                               >> %TMPVBS%
echo    tzOffMin = Right( ldt, 4 )                                   >> %TMPVBS%
echo Next                                                            >> %TMPVBS%

rem
rem Convert timezone minutes-offset to -HHmm format
rem
echo tzOffSign = "+"                                                 >> %TMPVBS%
echo If tzOffMin ^< 0                                               _>> %TMPVBS%
echo Then                                                            >> %TMPVBS%
echo    tzOffSign = "-"                                              >> %TMPVBS%
echo End If                                                          >> %TMPVBS%
echo tzOffHour = Int( Abs(tzOffMin) / 60 )                           >> %TMPVBS%
echo If tzOffHour ^< 10                                             _>> %TMPVBS%
echo Then                                                            >> %TMPVBS%
echo    tzOffHour = "0" ^& tzOffHour                                 >> %TMPVBS%
echo End If                                                          >> %TMPVBS%
echo tzOffMinRemain  =  Abs(tzOffMin)  Mod  60                       >> %TMPVBS%
echo If tzOffMinRemain ^< 10                                        _>> %TMPVBS%
echo Then                                                            >> %TMPVBS%
echo    tzOffMinRemain  =  "0" ^& tzOffMinRemain                     >> %TMPVBS%
echo End If                                                          >> %TMPVBS%

rem
rem Output formatted date,time (with "x" in place of comma)
rem
echo Wscript.StdOut.Write cYear ^& "-" ^& cMonth  ^& "-" ^& cDay    _>> %TMPVBS%
echo           ^& "x"  ^& cHour ^& ":" ^& cMinute ^& ":" ^& cSecond _>> %TMPVBS%
echo           ^&   tzOffSign ^& tzOffHour ^& tzOffMinRemain         >> %TMPVBS%

rem
rem Run vbs script and retrieve date,time output.
rem Transform "x" character(s) to comma(s).
rem
for /f "delims=," %%a in ('cscript //B %TMPVBS%') do set LONG_DT=%%a
set LONG_DT=%LONG_DT:x=,%
IF EXIST %TMPVBS%  del %TMPVBS%

:SKIPDATE_LONG

GOTO :EOF
REM  End GET_LONG_DT



:GET_DT
rem
rem Get SHORT Date in invariant ISO 8601 internationally acceptable format.
rem See header comment for :GET_LONG_DT
rem
set DT=
set tgtdir=%~1
set TMPVBS="%tgtdir%\mdbTools%RANDOM%.vbs"
IF EXIST %TMPVBS%  del %TMPVBS%                                      >> nul 2>&1
set SUCCESSFUL_DELETE=yes
IF EXIST %TMPVBS% set SUCCESSFUL_DELETE=no

echo Set objWMIService  =  GetObject("winmgmts:\\.\root\cimv2") >>%TMPVBS% 2>nul
IF NOT EXIST %TMPVBS%  GOTO :SKIPDATE
IF "%SUCCESSFUL_DELETE%" EQU "no"  GOTO :SKIPDATE
echo Set colItems  =  objWMIService.ExecQuery(                      _>> %TMPVBS%
echo                        "Select * From Win32_OperatingSystem")   >> %TMPVBS%
echo For Each objItem in colItems                                    >> %TMPVBS%
echo    ldt  =  objItem.LocalDateTime                                >> %TMPVBS%
echo    cMonth    =  Mid ( ldt,  5, 2 )                              >> %TMPVBS%
echo    cDay      =  Mid ( ldt,  7, 2 )                              >> %TMPVBS%
echo    cHour     =  Mid ( ldt,  9, 2 )                              >> %TMPVBS%
echo    cMinute   =  Mid ( ldt, 11, 2 )                              >> %TMPVBS%
echo    cSecond   =  Mid ( ldt, 13, 2 )                              >> %TMPVBS%
echo Next                                                            >> %TMPVBS%
rem
rem Output short formatted date,time (with "x" in place of comma)
rem
echo Wscript.StdOut.Write               cMonth  ^& "-" ^& cDay      _>> %TMPVBS%
echo         ^& "x"  ^& cHour ^& ":" ^& cMinute ^& ":" ^& cSecond    >> %TMPVBS%

rem
rem Run vbs script and retrieve date,time output.
rem Transform "x" character to comma.
rem
for /f "delims=," %%a in ('cscript //B %TMPVBS%') do set DT=%%a
set DT=%DT:x=,%

:SKIPDATE
IF EXIST %TMPVBS%  del %TMPVBS%
GOTO :EOF
REM  End GET_DT



:GET_PRECHECK_DT
rem ============================================================================
rem GET_PRECHECK_DT and GET_PRECHECK_TM
rem Get PRECHECK Date -- PRECHECK date variable is set.
rem    PRECHECK_DT variable is set to format -- yyyy-mm-dd
rem Get PRECHECK Time -- PRECHECK Time variable is set.
rem    PRECHECK_TM variable is set to short date format -- HH:mm:ss.hh
rem Website with date/time format function details...
rem http:
rem //www.microsoft.com/technet/scriptcenter/resources/qanda/jan05/hey0127.mspx
rem ============================================================================
set PRECHECK_DT=
set tgtdir=%~1
set TMPVBS="%tgtdir%\mdbTools%RANDOM%.vbs"
IF EXIST %TMPVBS%  del %TMPVBS%                                      >> nul 2>&1
set SUCCESSFUL_DELETE=yes
IF EXIST %TMPVBS% set SUCCESSFUL_DELETE=no
rem
rem Get FULL Date in invariant ISO 8601 internationally acceptable format.
rem
echo Set objWMIService  =  GetObject("winmgmts:\\.\root\cimv2") >>%TMPVBS% 2>nul
IF NOT EXIST %TMPVBS%  GOTO :SKIPDATE_PRECHECK
IF "%SUCCESSFUL_DELETE%" EQU "no"  GOTO :SKIPDATE_PRECHECK
echo Set colItems  =  objWMIService.ExecQuery(                      _>> %TMPVBS%
echo                        "Select * From Win32_OperatingSystem")   >> %TMPVBS%
echo For Each objItem in colItems                                    >> %TMPVBS%
echo    ldt  =  objItem.LocalDateTime                                >> %TMPVBS%
echo    cYear     = Left( ldt,  4 )                                  >> %TMPVBS%
echo    cMonth    = Mid ( ldt,  5, 2 )                               >> %TMPVBS%
echo    cDay      = Mid ( ldt,  7, 2 )                               >> %TMPVBS%
echo Next                                                            >> %TMPVBS%

rem
rem Output formatted PRECHECK date
rem
echo Wscript.StdOut.Write cYear ^& "-" ^& cMonth  ^& "-" ^& cDay     >> %TMPVBS%

rem
rem Run vbs script and retrieve date output.
rem
for /f "delims=," %%a in ('cscript //B %TMPVBS%') do set PRECHECK_DT=%%a
IF EXIST %TMPVBS%  del %TMPVBS%

:SKIPDATE_PRECHECK

GOTO :EOF
REM  End GET_PRECHECK_DT



:GET_PRECHECK_TM
rem ============================================================================
set PRECHECK_TM=
set tgtdir=%~1
set TMPVBS="%tgtdir%\mdbTools%RANDOM%.vbs"
IF EXIST %TMPVBS%  del %TMPVBS%                                      >> nul 2>&1
set SUCCESSFUL_DELETE=yes
IF EXIST %TMPVBS% set SUCCESSFUL_DELETE=no
rem
rem Get PRECHECK Time format.
rem
echo Set objWMIService  =  GetObject("winmgmts:\\.\root\cimv2") >>%TMPVBS% 2>nul
IF NOT EXIST %TMPVBS%  GOTO :SKIPTIME_PRECHECK
IF "%SUCCESSFUL_DELETE%" EQU "no"  GOTO :SKIPTIME_PRECHECK
echo Set colItems  =  objWMIService.ExecQuery(                      _>> %TMPVBS%
echo                        "Select * From Win32_OperatingSystem")   >> %TMPVBS%
echo For Each objItem in colItems                                    >> %TMPVBS%
echo    ldt  =  objItem.LocalDateTime                                >> %TMPVBS%
echo    cHour     = Mid ( ldt,  9, 2 )                               >> %TMPVBS%
echo    cMinute   = Mid ( ldt, 11, 2 )                               >> %TMPVBS%
echo    cSecond   = Mid ( ldt, 13, 2 )                               >> %TMPVBS%
echo    cHunds    = Mid ( ldt, 16, 2 )                               >> %TMPVBS%
echo Next                                                            >> %TMPVBS%

rem
rem Output PRECHECK formatted time.
rem
echo Wscript.StdOut.Write                                           _>> %TMPVBS%
echo     cHour ^& ":" ^& cMinute ^& ":" ^& cSecond ^& "." ^& cHunds  >> %TMPVBS%

rem
rem Run vbs script and retrieve time output.
rem
for /f "delims=," %%a in ('cscript //B %TMPVBS%') do set PRECHECK_TM=%%a
IF EXIST %TMPVBS%  del %TMPVBS%

:SKIPTIME_PRECHECK

GOTO :EOF
REM  End GET_PRECHECK_TM


