@echo off
IF /I ("%DEBUGECHO%") EQU ("@ECHO ON") @ECHO ON
REM       Make database MDB 1.0.4 compatible.
REM
REM Description:
REM         This script is a wrapper for setupmdb.bat.  The input parameters 
REM         are inherited from the calling script, with exception of 
REM         WORKSPACE, MANIFEST, 
REM         The the same as for setupmdb.bat except for the
REM         WORKSPACE, MANIFEST, MDB_{SOURCE,TARGET}_DIR, and MDB_COMMON parameters.
REM         The workspace and manifest are added to the install invocation, here,
REM       to specifiy the MDB_104 compatibility workspace/manifest.
REM       The source and target dirs must be the default -- currrent dir.
REM       The MDB_104 schema makes the specified MDB satisfy MDB 104 installs.
REM       The "MDB_104" schema installation includes the update of two tables 
REM       -- MDB and MDB_PATCH are set to reflect the latest versions
REM       of the MDB 1.0.4 and its cumulative patch.
REM       Any subsequent MDB 104 installs will see that there is nothing to do.
REM

REM
REM History:
REM  29-jan-2008  hopst01  created
REM  11-feb-2008  hospt01  added parsing for undocumented command line option LOG_DIR
REM                        removed response file parsing
REM  13-feb-2008  hopst01  updated to call the setupmdb in CCD. uses findcommon to determine CCD
REM                        store log file in log_dir if specified, else store in target_dir
REM                        handle precheck parameter
REM                        pass source, target, log and common dir arguments
REM  19-feb-2008  hopst01  make sure that precheck doesn't create msg log.  Ensure that empty 
REM                           log is not written
REM  20-feb-2008  hopst01  add new command line parameter MDB_PRIVATE_DIR that overrides MDB CCD
REM  21-feb-2008  hopst01  maintain debug level
REM                        ensure that CCD version of setupmdb is only called if it has a higher 
REM                           precedence than the local one
REM  22-feb-2008  hopst01  unescape the mdbadmin password
REM  07-apr-2008  hopst01  b1740 - quote oracle tablespace path when passing back to setupmdb
REM  15-apr-2008  hopst01  b1788 - MDB_COMMON s/b MDB_COMMON_DIR
REM  17-apr-2008  hopst01  b1795 - Syncup make_MDB_104_compatible.bat
REM                          - add new command line parameter '-batch'.  suppress new default 
REM                            interactive mode. when interactive, run precheck, then prompt
REM                            user if they would like to continue with listed args.
REM  18-jul-2008  hopst01  Star 17294367 DBPASSWORD WITH "," FAILED. Treat DBPASSWORD like 
REM                        MDB_ADMIN_PSWD.  Use temp variable when comparing it to an 
REM                        empty string.
REM  07-aug-2008  hopst01  STAR 17177592 - Conversion unnecessary.  If MDB 1.0.4 present only install 
REM                        MDB Base 1.5 schema. Do not install schema if already 1.0.4 upgraded MDB. 
REM  08-aug-2008  johri05  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG
REM                        Fix to use only minimal short format to prefix logged messages.
REM                        Long format is to be used once in the install log header.
REM                           long fmt:  yyyy-MMM-dd,HH:mm:ss-zzzz -ex:2008-jul-04,15:30:00-0400
REM                           short fmt:       MM-dd,HH:mm:ss      -ex:      07-04,15:30:00
REM                        Del :GET_DT function
REM                        Chg calls to :GET_DT label to be calls to mdbFuncs with GET_DT argument
REM                        Add "CALL mdbFuncs GET_LONG_DT" to display long date format in log header.
REM  11-aug-2008  hopst01  Update calls to mdbFuncs when exiting to match those in setupmdb.bat
REM  11-aug-2008  hopst01  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG. Target Directory needs to 
REM                        be quoted. Don't pipe calls to mdbFuncs to nul as it makes debug impossible.
REM  17-aug-2008  hopst01  STAR 17460124 DBHOST option not saved rerun. Unset dbhost default.
REM  17-aug-2008  hopst01  STAR 17441439 MDB_PRIVATE_DIR not working. Allow MDB_PRIVATE_DIR in interactive mode.
REM  30-oct-2008  hopst01  STAR 17623061 - When CCD precedence is higher than source_dir precedence 
REM                        precheck looks for the files in the wrong location. Use MDB_SOURCE_DIR_ORG for precheck
REM

setlocal

rem
rem Version and build for log
rem
set MK104_VERSION=1.0.1

set CURDIR=%CD%
set SAVEPATH=%PATH%

REM
REM Set the default parameters
REM
set DBVENDOR=
set DBHOST=
set DBNAME=MDB
set DBUSER=
set DBPASSWORD=
set DBDRIVER=mdb104
set WORKSPACE=MDB104
set II_MDB_SIZE=
set II_MDB_CONFIG=
set PRECHECK=no
set PRECHECK_MSGDIR=
set DBPORT=
set EXIT_SCRIPT=/B
set MDB_SOURCE_DIR=%CURDIR%
set MDB_TARGET_DIR=%CURDIR%
set MDB_PRIVATE_DIR=
set II_REINIT_CONFIG=
set JRE_DIR=
set ORA_DATA_SIZE=
set ORA_INDEX_SIZE=
set MDB_ADMIN_PSWD=
set ORA_TBLSPACE_PATH=
set ORA_SERVICE_NAME=
set RESPONSE_FILE=
set RC=999
set MDB_COMMON=
set INVALID_ARG_NAME=
set ERR_MESSAGE=
set MDB104_COMMAND=make_MDB_104_compatible
set MDB104_ARGS=
rem used to store all other command line args
set COMMAND_LINE_ARGS=
set ISDEBUG=
set MDB_COMMON_ORG=
set ORG_DIR=
set BATCH_MODE=no

set TMP_DBHOST=
set DEF_DBNAME=yes
set TMP_MDB_TARGET_DIR=
set DEBUGECHO=@ECHO OFF
SET PRECEDENCE_ARG=no
set MDB_SOURCE_DIR_SET=no
SET HAVE_DB_PSWD=no
SET HAVE_MDB_PSWD=no
SET DBPASSWORD_MAKE=
SET MDB_ADMIN_PSWD_MAKE=
set MDB_SOURCE_DIR_ORG=
set DEF_CALL=no
rem get the command line arg
rem
rem Parse the command line parameters
rem
:PARSE_ARGS

IF "%~1" == ""   GOTO NO_MORE_ARGS

IF NOT "%~1" == "-DBVENDOR" GOTO NEXT_ARG1
SHIFT
set DBVENDOR=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -DBVENDOR=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -DBVENDOR=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG1
IF NOT "%~1" == "-DBUSER" GOTO NEXT_ARG2
SHIFT
set DBUSER=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -DBUSER=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -DBUSER=%~1
IF (%DBUSER%)==(sys) GOTO USR_SYSDBA
IF (%DBUSER%)==(SYS) GOTO USR_SYSDBA
set ORA_AS_SYSDBA=
:USR_SYSDBA
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG2
IF NOT "%~1" == "-DBPASSWORD" GOTO NEXT_ARG3
SHIFT
set DBPASSWORD="%~1"
set MDB104_COMMAND=%MDB104_COMMAND% -DBPASSWORD=***
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -DBPASSWORD="%~1"
SET HAVE_DB_PSWD=yes
rem don't Escape any reserved shell characters simple quote 
rem will allow setupmdb to do this
rem set DBPASSWORD=%DBPASSWORD:^=^^%
rem set DBPASSWORD=%DBPASSWORD:<=^<%
rem set DBPASSWORD=%DBPASSWORD:>=^>%
rem set DBPASSWORD=%DBPASSWORD:|=^|%
rem set DBPASSWORD=%DBPASSWORD:&=^&%
rem set DBPASSWORD=%DBPASSWORD:(=^(%
rem set DBPASSWORD=%DBPASSWORD:)=^)%
rem set DBPASSWORD=%DBPASSWORD:"=\"%
set DBPASSWORD_DQ="%~1"
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG3
IF NOT "%~1" == "-DBHOST" GOTO NEXT_ARG4
SHIFT
set DBHOST=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -DBHOST=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -DBHOST=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG4
IF NOT "%~1" == "-DBNAME" GOTO NEXT_ARG5
SHIFT
set DBNAME=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -DBNAME=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -DBNAME=%~1
set DEF_DBNAME=no
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG5
IF NOT "%~1" == "-DBDRIVER" GOTO NEXT_ARG6
SHIFT
SHIFT
set ERR_MESSAGE=Usage: Invalid argument. "-DBDRIVER" cannot be specified.
set RC=90
GOTO USAGE_ERROR

:NEXT_ARG6
IF NOT "%~1" == "-WORKSPACE" GOTO NEXT_ARG7
SHIFT
SHIFT
set ERR_MESSAGE=Usage: Invalid argument. "-WORKSPACE" WORKSPACE cannot be specified.
set RC=90
GOTO USAGE_ERROR

:NEXT_ARG7
IF NOT "%~1" == "-MDB_EXIT_SCRIPT" GOTO NEXT_ARG8
SHIFT
set MDB104_COMMAND=%MDB104_COMMAND% -MDB_EXIT_SCRIPT=%1
IF NOT "%~1" == "yes" GOTO CHECK_NO
set EXIT_SCRIPT=/B
SHIFT
GOTO PARSE_ARGS
:CHECK_NO
IF NOT "%~1" == "no" GOTO XSCRIPT_ERR
set EXIT_SCRIPT=
SHIFT
GOTO PARSE_ARGS
:XSCRIPT_ERR
set ERR_MESSAGE=Invalid -MDB_EXIT_SCRIPT argument "%~1", expected yes or no
set RC=89
GOTO USAGE_ERROR

:NEXT_ARG8
IF NOT "%~1" == "-MDB_SOURCE_DIR" GOTO NEXT_ARG9
SHIFT
set MDB_SOURCE_DIR=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -MDB_SOURCE_DIR=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -MDB_SOURCE_DIR=%~1
set MDB_SOURCE_DIR_SET=yes
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG9
IF NOT "%~1" == "-MDB_TARGET_DIR" GOTO NEXT_ARG10
SHIFT
set MDB_TARGET_DIR=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -MDB_TARGET_DIR=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -MDB_TARGET_DIR%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG10
IF NOT "%~1" == "-debug" GOTO NEXT_ARG11
set DEBUGECHO=@ECHO ON
set MDB104_COMMAND=%MDB104_COMMAND% -debug
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -debug
set ISDEBUG=yes
%DEBUGECHO%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG11
IF NOT "%~1" == "-II_REINIT_CONFIG" GOTO NEXT_ARG12
SHIFT
set II_REINIT_CONFIG=TRUE
set MDB104_COMMAND=%MDB104_COMMAND% -II_REINIT_CONFIG
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -II_REINIT_CONFIG
GOTO PARSE_ARGS

:NEXT_ARG12
IF NOT "%~1" == "-II_MDB_SIZE" GOTO NEXT_ARG12a
SHIFT
set II_MDB_SIZE=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -II_MDB_SIZE=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -II_MDB_SIZE=%~1
SHIFT

:TRY_SMALL
IF /i NOT "%II_MDB_SIZE%" == "small" GOTO TRY_MEDIUM
set II_MDB_SIZE=small
set /a II_MDB_SIZE_NUM=2
GOTO END_ARG11

:TRY_MEDIUM
IF /i NOT "%II_MDB_SIZE%" == "medium" GOTO TRY_LARGE
set II_MDB_SIZE=medium
set /a II_MDB_SIZE_NUM=3
GOTO END_ARG11

:TRY_LARGE
IF /i NOT "%II_MDB_SIZE%" == "large" GOTO TRY_INVALID
set II_MDB_SIZE=large
set /a II_MDB_SIZE_NUM=4
GOTO END_ARG11

:TRY_INVALID
set MDB_RC=99
set ERR_MESSAGE=Invalid II_MDB_SIZE argument "%II_MDB_SIZE%"
GOTO USAGE_ERROR
:END_ARG11
GOTO PARSE_ARGS

:NEXT_ARG12a
IF NOT "%~1" == "-DBPORT" GOTO NEXT_ARG13
SHIFT
set DBPORT=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -DBPORT=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -DBPORT=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG13
IF NOT "%~1" == "-II_MDB_CONFIG" GOTO NEXT_ARG13a
SHIFT
set II_MDB_CONFIG=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -II_MDB_CONFIG=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -II_MDB_CONFIG=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG13a
IF NOT "%~1" == "-PRECHECK" GOTO NEXT_ARG13b
set PRECHECK=yes
set MDB104_COMMAND=%MDB104_COMMAND% -PRECHECK
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -PRECHECK
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG13b
IF NOT "%~1" == "-PRECHECK_MSGDIR" GOTO NEXT_ARG14
SHIFT
set PRECHECK_MSGDIR=%~f1
set MDB104_COMMAND=%MDB104_COMMAND% -PRECHECK_MSGDIR=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -PRECHECK_MSGDIR="%~f1%"
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG14
IF NOT "%~1" == "-ORA_TBLSPACE_PATH" GOTO NEXT_ARG15
SHIFT
set ORA_TBLSPACE_PATH=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -ORA_TBLSPACE_PATH=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -ORA_TBLSPACE_PATH="%~1"
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG15
IF NOT "%~1" == "-ORA_DATA_SIZE" GOTO NEXT_ARG16
SHIFT
set MDBDATA_SIZE=%~1
set ORA_DATA_SIZE=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -ORA_DATA_SIZE=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -ORA_DATA_SIZE=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG16
IF NOT "%~1" == "-ORA_INDEX_SIZE" GOTO NEXT_ARG17
SHIFT
set MDBINDEX_SIZE=%~1
set ORA_INDEX_SIZE=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -ORA_INDEX_SIZE=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -ORA_INDEX_SIZE=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG17
IF NOT "%~1" == "-ORA_DATA_TBLSPACE" GOTO NEXT_ARG18
SHIFT
set ORA_DATA_TBLSPACE_NAME="%~1"
set MDB104_COMMAND=%MDB104_COMMAND% -ORA_DATA_TBLSPACE=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -ORA_DATA_TBLSPACE=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG18
IF NOT "%~1" == "-ORA_INDEX_TBLSPACE" GOTO NEXT_ARG19
SHIFT
set ORA_INDEX_TBLSPACE_NAME="%~1"
set MDB104_COMMAND=%MDB104_COMMAND% -ORA_INDEX_TBLSPACE=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -ORA_INDEX_TBLSPACE=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG19
IF NOT "%~1" == "-MDB_ADMIN_PSWD" GOTO NEXT_ARG20
SHIFT
set MDB_ADMIN_PSWD="%~1"
set MDB104_COMMAND=%MDB104_COMMAND% -MDB_ADMIN_PSWD=***
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -MDB_ADMIN_PSWD="%~1"
SET HAVE_MDB_PSWD=yes
rem don't Escape any reserved shell characters simple quote 
rem will allow setupmdb to do this
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:^=^^%
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:<=^<%
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:>=^>%
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:|=^|%
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:&=^&%
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:(=^(%
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:)=^)%
rem set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:"=\"%
set MDB_ADMIN_PSWD_DQ="%~1"
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG20
IF NOT "%~1" == "-JRE_DIR" GOTO NEXT_ARG21
SHIFT
set JRE_DIR=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -JRE_DIR=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -JRE_DIR=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG21
IF NOT "%~1" == "-MANIFEST" GOTO NEXT_ARG22
SHIFT
SHIFT
set ERR_MESSAGE=Usage: Invalid argument. "-MANIFEST" cannot be specified.
set RC=90
GOTO USAGE_ERROR

:NEXT_ARG22
IF NOT "%~1" == "-ORA_SERVICE_NAME" GOTO NEXT_ARG23
SHIFT
set ORA_SERVICE_NAME=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -ORA_SERVICE_NAME=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -ORA_SERVICE_NAME=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG23
IF NOT "%~1" == "-COMPAT104" GOTO NEXT_ARG24
SHIFT
set ERR_MESSAGE=Usage: Invalid argument. "-COMPAT104" cannot be specified.
set RC=90
GOTO USAGE_ERROR

:NEXT_ARG24
IF NOT "%~1" == "-MDB_COMMON_DIR" GOTO NEXT_ARG26
SHIFT
set MDB_COMMON=%~1
set MDB_COMMON_ORG=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -MDB_COMMON_DIR=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -MDB_COMMON_DIR=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG26
IF NOT "%~1" == "-LOG_DIR" GOTO NEXT_ARG27
SHIFT
set LOG_DIR=%~1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -LOG_DIR=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG27
IF NOT "%~1" == "-MDB_PRIVATE_DIR" GOTO NEXT_ARG28
SHIFT
set MDB_PRIVATE_DIR=%~1
set MDB104_COMMAND=%MDB104_COMMAND% -MDB_PRIVATE_DIR=%1
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -MDB_PRIVATE_DIR%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG28
IF NOT "%~1" == "-batch" GOTO NEXT_ARG29
set BATCH_MODE=yes
set MDB104_COMMAND=%MDB104_COMMAND% -batch
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -batch
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG29
IF NOT "%~1" == "-PRECEDENCE" GOTO NEXT_ARG30
set PRECEDENCE_ARG=yes
set MDB104_COMMAND=%MDB104_COMMAND% -PRECEDENCE
set COMMAND_LINE_ARGS=%COMMAND_LINE_ARGS% -PRECEDENCE
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG30
IF NOT "%~1" == "-MDB_SOURCE_DIR_ORG" GOTO NEXT_ARG31
SHIFT
set MDB_SOURCE_DIR_ORG=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG31
:INVALID_ARG
IF ("%INVALID_ARG_NAME%") EQU ("") SET INVALID_ARG_NAME=%~1
set MDB104_COMMAND=%MDB104_COMMAND% %1
SHIFT
GOTO PARSE_ARGS

:NO_MORE_ARGS

IF ("%INVALID_ARG_NAME%") EQU ("") GOTO NO_ARG_ERROR 
set ERR_MESSAGE=Usage: Invalid argument "%INVALID_ARG_NAME%"
set RC=90
GOTO USAGE_ERROR

:NO_ARG_ERROR
rem
rem check for restricted args
rem
SET RESTRICTED_ARG=
IF "%BATCH_MODE%" EQU "yes" GOTO NO_RESTRICTED_ARG_ERR
IF ("%MDB_SOURCE_DIR_SET%") EQU ("yes") SET RESTRICTED_ARG=MDB_SOURCE_DIR&  GOTO RESTRICTED_ARG_ERR
IF ("%MDB_COMMON_DIR%")     NEQ ("")    SET RESTRICTED_ARG=MDB_COMMON_DIR&  GOTO RESTRICTED_ARG_ERR
IF ("%PRECEDENCE_ARG%")     EQU ("yes") SET RESTRICTED_ARG=PRECEDENCE&      GOTO RESTRICTED_ARG_ERR


rem Check that the source directory exists.

IF EXIST "%MDB_SOURCE_DIR%" GOTO SOURCE_DIR_EXIST
set ERR_MESSAGE=Non-existant install source directory -- "%MDB_SOURCE_DIR%"
set RC=95
GOTO USAGE_ERROR
:SOURCE_DIR_EXIST
chdir /D "%MDB_SOURCE_DIR%" >> nul 2>&1
IF EXIST make_MDB_104_compatible.bat GOTO NO_RESTRICTED_ARG_ERR
SET RC=112
SET ERR_MESSAGE=make_MDB_104_compatible must be called from inside the directory in which it resides.
GOTO FINI_ERROR
REM GOTO NO_RESTRICTED_ARG_ERR

:RESTRICTED_ARG_ERR
set ERR_MESSAGE=Usage: Invalid argument. "-%RESTRICTED_ARG%" cannot be specified.
SET RC=90
GOTO USAGE_ERROR

:NO_RESTRICTED_ARG_ERR

:DEF_INSTALL
rem
rem get MDB_COMMON
rem
IF ("%MDB_PRIVATE_DIR%") EQU ("") GOTO FIND_CCD
set MDB_COMMON=%MDB_PRIVATE_DIR%
GOTO DEF_INSTALL_CHECK

:FIND_CCD
set FIND_CCD_ARGS=MDB_COMMON
IF ("%MDB_COMMON%") NEQ ("") SET FIND_CCD_ARGS=%FIND_CCD_ARGS% "%MDB_COMMON%" 
CALL findcommon %FIND_CCD_ARGS%
set RC=%ERRORLEVEL%
IF %RC% EQU 0 IF ("%MDB_COMMON%") NEQ ("") GOTO DEF_INSTALL_CHECK
IF "%ERR_MESSAGE%" NEQ "" SET ERR_MESSAGE=Details: %ERR_MESSAGE%
SET ERR_MESSAGE=Unable to determine the Common Component Directory for the MDB. %ERR_MESSAGE%
GOTO FINI_ERROR 

:DEF_INSTALL_CHECK
IF NOT EXIST "%MDB_COMMON%\Windows\setupmdb.bat" GOTO RUN_THIS_COPY
IF ("%CD%") EQU ("%MDB_COMMON%\Windows") GOTO RUN_THIS_COPY
CALL "%MDB_COMMON%\Windows\setupmdb.bat" -PRECEDENCE
set CCD_PRECEDENCE=%ERRORLEVEL%
%DEBUGECHO%
IF %CCD_PRECEDENCE% EQU 999 GOTO RUN_THIS_COPY
CALL setupmdb -PRECEDENCE
set LOCAL_PRECEDENCE=%ERRORLEVEL%
%DEBUGECHO%
IF %LOCAL_PRECEDENCE% EQU 999 GOTO RUN_CCD_COPY
IF %CCD_PRECEDENCE% GTR %LOCAL_PRECEDENCE% GOTO RUN_CCD_COPY  
GOTO RUN_THIS_COPY

:RUN_CCD_COPY
chdir /D "%MDB_COMMON%\Windows" > nul 2>&1
set RC=%ERRORLEVEL%
IF %RC% NEQ 0 GOTO RUN_THIS_COPY

rem
rem Set the source and target to the CCD if calling CCD setupmdb
rem
:MAKE_DEF_CALL
IF "%MDB_SOURCE_DIR_ORG%" EQU "" SET MDB_SOURCE_DIR_ORG=%MDB_SOURCE_DIR%
set MDB_SOURCE_DIR=%MDB_COMMON%\Windows
IF ("%LOG_DIR%") EQU ("") set LOG_DIR=%MDB_TARGET_DIR%
SET MDB_TARGET_DIR=%MDB_COMMON%\Windows
set ORG_DIR=%CD%
set DEF_CALL=yes
GOTO INSTALL

rem 
rem run local copy
rem
:RUN_THIS_COPY

:INSTALL
REM 
REM Log the full command
REM
IF "%BATCH_MODE%" EQU "no" CALL :ESCAPE_PASSWORDS
CALL :SET_PSWD_VARS
SET MDB104_COMMAND=
CALL :GET_PRINTABLE_ARGS
IF "%BATCH_MODE%" EQU "yes" GOTO END_PROMPT
REM IF ("%MDB_COMMON%\Windows") NEQ ("%CURDIR%") GOTO BAD_RUN_DIR
CALL :READ_RESPONSE_FILE
SET PRECHECK_ARGS=%MDB104_ARGS%
IF /I NOT "%PRECHECK%" == "yes" SET PRECHECK_ARGS=%PRECHECK_ARGS% -PRECHECK
echo.
CALL setupmdb %PRECHECK_ARGS%
SET RC=%ERRORLEVEL%

IF ("%PRECHECK_MSGDIR%") NEQ ("") IF EXIST "%PRECHECK_MSGDIR%\mdb_precheck.log" type "%PRECHECK_MSGDIR%\mdb_precheck.log"
IF %RC% NEQ 0 GOTO FINI_PRECHECK
ECHO.
ECHO.
CALL :PRINT_ARGS
SET /P PROCEED=Proceed with these install options? [y/n]?  
SET PROCEED=%PROCEED:^=%
SET PROCEED=%PROCEED:<=%
SET PROCEED=%PROCEED:>=%
SET PROCEED=%PROCEED:|=%
SET PROCEED=%PROCEED:&=%
SET PROCEED=%PROCEED:(=%
SET PROCEED=%PROCEED:)=%
SET PROCEED=%PROCEED:"=%
SET PROCEED=%PROCEED:'=%
SET PROCEED=%PROCEED: =%
IF /I "%PROCEED%" EQU "Y" GOTO END_PROMPT

echo     Command Aborted 
GOTO FINI_PRECHECK

:BAD_RUN_DIR
SET ERR_MESSAGE=Current directory is expected to be the MDB Common Components directory ('%MDB_COMMON%').
SET RC=111
echo %ERR_MESSAGE%
echo make_MDB_104_compatible exit %EXIT_SCRIPT% return code=%RC%
GOTO FINI_PRECHECK

:END_PROMPT
REM
REM Copy the xml files and JRE directory if doing a CCD install
REM
IF /I "%PRECHECK%" == "yes" GOTO DONE_XML_COPY
IF "%DEF_CALL%" EQU "no" GOTO DONE_XML_COPY
IF EXIST "%MDB_SOURCE_DIR_ORG%\%WORKSPACE%_%DBVENDOR%" xcopy "%MDB_SOURCE_DIR_ORG%\%WORKSPACE%_%DBVENDOR%" "%MDB_COMMON%\Windows\%WORKSPACE%_%DBVENDOR%" /E /Q /Y /I /R > nul 2>&1
IF NOT EXIST "%MDB_COMMON%\Windows\MDB104_mssql" IF EXIST "%MDB_SOURCE_DIR_ORG%\MDB104_mssql" xcopy "%MDB_SOURCE_DIR_ORG%\MDB104_mssql" "%MDB_COMMON%\Windows\MDB104_mssql" /E /Q /Y /I /R > nul 2>&1
IF NOT EXIST "%MDB_COMMON%\Windows\MDB104_oracle" IF EXIST "%MDB_SOURCE_DIR_ORG%\MDB104_oracle" xcopy "%MDB_SOURCE_DIR_ORG%\MDB104_oracle" "%MDB_COMMON%\Windows\MDB104_oracle" /E /Q /Y /I /R > nul 2>&1

IF EXIST "%MDB_COMMON%\Windows\%DBVENDOR%" GOTO COPY_CUM_PATCH_ONLY
xcopy "%MDB_SOURCE_DIR_ORG%\%DBVENDOR%" "%MDB_COMMON%\Windows\%DBVENDOR%" /E /Q /Y /I > nul 2>&1
GOTO DONE_COPY_VENDOR_FILES
:COPY_CUM_PATCH_ONLY
xcopy "%MDB_SOURCE_DIR_ORG%\%DBVENDOR%\CumulativePatch" "%MDB_COMMON%\Windows\%DBVENDOR%\CumulativePatch" /E /Q /Y /I > nul 2>&1
:DONE_COPY_VENDOR_FILES

IF EXIST "%MDB_COMMON%\Windows\jre" GOTO DONE_XML_COPY
IF NOT EXIST "%MDB_SOURCE_ORG%\jre" GOTO DONE_XML_COPY
xcopy "%MDB_SOURCE_ORG%\jre" "%MDB_COMMON%\Windows\jre" /E /Q /Y /I > nul 2>&1
:DONE_XML_COPY


REM
REM Set the install log file
REM
set LOGFILE=%MDB_TARGET_DIR%
IF ("%LOG_DIR%") NEQ ("") SET LOGFILE=%LOG_DIR%
set LOGFILE="%LOGFILE%\install_%DBNAME%.log"

IF /I  "%PRECHECK%" == "yes"  goto SETUP

IF NOT EXIST "%MDB_TARGET_DIR%" mkdir "%MDB_TARGET_DIR%"
IF "%LOG_DIR%" NEQ "" IF NOT EXIST "%LOG_DIR%" mkdir "%LOG_DIR%" 
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% make_MDB_104_compatible log file in %LOGFILE%
echo . >> %LOGFILE% 2>&1
echo . >> %LOGFILE% 2>&1
echo . >> %LOGFILE% 2>&1
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo Install Date:  %LONG_DT%
echo %DT% ======================================================================== >> %LOGFILE% 2>&1
echo %DT% ============================= %MK104_VERSION% ====================================== >> %LOGFILE% 2>&1
echo %DT% ======================================================================== >> %LOGFILE% 2>&1
echo %DT% make_MDB_104_compatible log file in %LOGFILE% >> %LOGFILE% 2>&1


echo %DT% make_MDB_104_compatible command: %MDB104_COMMAND% >> %LOGFILE% 2>&1
echo. >> %LOGFILE% 2>&1
echo. >> %LOGFILE% 2>&1
GOTO SETUP

:SETUP

IF /I  "%PRECHECK%" == "yes" GOTO SETUP_CALL
rem
rem Perform a precheck before installing.
rem 
:SETUP_CALL
IF /I NOT "%PRECHECK%" == "yes" echo Installing MDB 1.0.4 compatible schema in database %DBNAME% >> %LOGFILE% 2>&1
IF /I NOT "%PRECHECK%" == "yes" echo CALL setupmdb %MDB104_COMMAND% >> %LOGFILE% 2>&1
CALL setupmdb %MDB104_ARGS% -rec
set RC=%ERRORLEVEL%

rem
rem if we called the setupmdb in the ccd, change back
rem
IF ("%ORG_DIR%") NEQ ("") chdir /D "%ORG_DIR%" > nul 2>&1

IF %RC% NEQ 0 GOTO FINI_ERROR
IF /I  "%PRECHECK%" == "yes" GOTO FINI_ERROR
echo MDB 1.0.4 schema successfully installed in database %DBNAME% >> %LOGFILE% 2>&1
echo MDB 1.0.4 schema successfully installed in database %DBNAME% 
GOTO FINI_ERROR

:USAGE_ERROR
echo make_MDB_104_compatible usage:
echo   ^|  make_MDB_104_compatible -DBVENDOR={ingres^|mssql^|oracle} 
echo   ^|           [-JRE_DIR=?]  [-MDB_SOURCE_DIR=?]  [-MDB_TARGET_DIR=?] 
echo   ^|           [-DBNAME=?]  [-DBHOST=?]  [-DBPORT=?]
echo   ^|           -DBUSER=? -DBPASSWORD=? 
echo   ^|           [-ORA_DATA_TBLSPACE=?]   [-ORA_DATA_SIZE=?]
echo   ^|           [-ORA_INDEX_TBLSPACE=?]  [-ORA_INDEX_SIZE=?]
echo   ^|           -ORA_TBLSPACE_PATH=?  -MDB_ADMIN_PSWD=?
echo   ^|           [-PRECHECK]  [-PRECHECK_MSGDIR=?]
echo   ^|           [-MDB_EXIT_SCRIPT={yes,no}]  [-batch]  [-debug]
echo   ^| 
echo   ^|  -DBVENDOR           dbms {mssql or oracle}           (required)
echo   ^|  -JRE_DIR            JRE directory                    (optional)
echo   ^|  -MDB_SOURCE_DIR     install media source             (def: cur dir)
echo   ^|  -MDB_TARGET_DIR     destination directory            (def: cur dir)
echo   ^|  -DBNAME             database name                    (def: mdb)
echo   ^|  -DBHOST             database server name             (def: localhost)
echo   ^|                      connection id for oracle         (required)
echo   ^|  -DBPORT             mdbtools JDBC port               (optional)
echo   ^|  -DBUSER             dbms user for mssql and ingres   (required)
echo   ^|                      SYS user for oracle              (def: SYS)
echo   ^|  -DBPASSWORD         dbms user password               (required)
echo   ^|                      SYS user password for oracle     (required)
echo   ^|  -DBDRIVER           mdbtools driver name             (required)
echo   ^|  -MANIFEST           mdbtools driver name (same as -DBDRIVER)
echo   ^|  -WORKSPACE          mdbtools workspace name          (required)
echo   ^|  -ORA_DATA_TBLSPACE  data tablespace name for oracle  (def: MDB_DATA)
echo   ^|  -ORA_DATA_SIZE      data tablespace size for oracle  (def: 400)
echo   ^|  -ORA_INDEX_TBLSPACE index tablespace name for oracle (def: MDB_INDEX)
echo   ^|  -ORA_INDEX_SIZE     index tablespace size for oracle (def: 100)
echo   ^|  -ORA_TBLSPACE_PATH  tablespace path for oracle       (required)
echo   ^|  -ORA_SERVICE_NAME   service name used for oracle     (def: DBNAME)
echo   ^|  -MDB_ADMIN_PSWD     mdbadmin password for oracle     (required)
echo   ^|  -PRECHECK           validate without doing anything  (def: unset)
echo   ^|  -PRECHECK_MSGDIR   validation status msg file       (def: console)
echo   ^|  -MDB_EXIT_SCRIPT    exit script using /B {yes,no}    (def: yes)
echo   ^|  -batch              Do not run interactively         (def: unset)
echo   ^|  -debug              Run with "echo on"               (def: unset)
echo   ^| 
echo   ^| 
echo   ^|  SQLServer example:
echo   ^|    make_MDB_104_compatible -DBVENDOR=mssql  -DBUSER=sa -DBPASSWORD=sa  
echo   ^| 
echo   ^|  Oracle example:
echo   ^|    make_MDB_104_compatible -DBVENDOR=oracle -DBNAME=ORCL -DBUSER=sys -DBPASSWORD=sys
echo   ^|             -ORA_TBLSPACE_PATH=d:\oracle\product\10.2.0\oradata\orcl
echo   ^|             -MDB_ADMIN_PSWD=mdbadmin   
echo   ^|
echo  End make_MDB_104_compatible usage

GOTO FINI_ERROR



:FINI_ERROR
REM
REM Handle precheck output
REM
IF /I  NOT "%PRECHECK%" == "yes"  goto NORM_FINI
GOTO FINI_PRECHECK 

:NORM_FINI
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% %ERR_MESSAGE%

IF (%LOGFILE%) == () goto NO_LOG
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% %ERR_MESSAGE% >> %LOGFILE% 2>&1
echo %DT% make_MDB_104_compatible exit %EXIT_SCRIPT% return code=%RC% >> %LOGFILE% 2>&1
:NO_LOG

call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% make_MDB_104_compatible exit %EXIT_SCRIPT% return code=%RC%


:FINI
set MSGFILE=%MDB_TARGET_DIR%
IF ("%LOG_DIR%") NEQ ("") SET MSGFILE=%LOG_DIR%
SET T_ERR_MESSAGE=x%ERR_MESSAGE%x
SET T_ERR_MESSAGE="%T_ERR_MESSAGE:"=%"
IF %RC% EQU 0 IF (%T_ERR_MESSAGE%) NEQ ("xx") SET ERR_MESSAGE=Installation of MDB 1.04 schema completed successfully
IF %RC% NEQ 0 IF (%T_ERR_MESSAGE%) EQU ("xx") GOTO MSGLOG_WRITTEN
echo %DT% %ERR_MESSAGE% > "%MSGFILE%\install_%DBNAME%_msg.log"
:MSGLOG_WRITTEN
:FINI_PRECHECK
SET T_SAVEPATH=%SAVEPATH:"=%
IF ("%T_SAVEPATH%") NEQ ("") set PATH=%SAVEPATH%
IF ("%CURDIR%")     NEQ ("") chdir /D "%CURDIR%"
 
endlocal & exit %EXIT_SCRIPT% %RC%


rem
rem set the parameter param to value if the param name is not blank
rem and the param does not already have a value
rem don't set workspace, driver, manifest
REM for special sets, if the tmp value is unset the the variable val
rem did not come from the command line so it's ok to overrride
rem
:SET_PARAM
set PARAM=%1%
set VALUE=%2%
set T_VALUE=%VALUE:"=%
IF ("%T_VALUE%") EQU ("")                GOTO DONE_SET
IF ("%PARAM%")   EQU ("")                GOTO DONE_SET
IF ("%PARAM%")   EQU ("WORKSPACE")       GOTO DONE_SET
IF ("%PARAM%")   EQU ("DBDRIVER")        GOTO DONE_SET
IF ("%PARAM%")   EQU ("MANIFEST")        GOTO DONE_SET
IF ("%PARAM%")   EQU ("MDB_SOURCE_DIR")  GOTO DONE_SET
IF ("%PARAM%")   EQU ("COMPAT104")       GOTO DONE_SET
IF ("%PARAM%")   EQU ("MDB_COMMON_DIR")  GOTO DONE_SET
IF ("%PARAM%")   EQU ("MDB_PRIVATE_DIR") GOTO DONE_SET
IF ("%PARAM%")   EQU ("MDB_EXIT_SCRIPT") GOTO DONE_SET

IF ("%PARAM%") EQU ("DBVENDOR")           IF ("%DBVENDOR%")           EQU ("") GOTO SET_VALUE
IF ("%PARAM%") EQU ("ORA_TBLSPACE_PATH")  IF ("%ORA_TBLSPACE_PATH%")  EQU ("") GOTO SET_VALUE_SPECIAL
IF ("%PARAM%") EQU ("ORA_DATA_SIZE")      IF ("%ORA_DATA_SIZE%")      EQU ("") GOTO SET_VALUE
IF ("%PARAM%") EQU ("ORA_INDEX_SIZE")     IF ("%ORA_INDEX_SIZE%")     EQU ("") GOTO SET_VALUE
IF ("%PARAM%") EQU ("ORA_DATA_TBLSPACE")  IF ("%ORA_DATA_TBLSPACE%")  EQU ("") GOTO SET_VALUE
IF ("%PARAM%") EQU ("ORA_INDEX_TBLSPACE") IF ("%ORA_INDEX_TBLSPACE%") EQU ("") GOTO SET_VALUE
IF ("%PARAM%") EQU ("JRE_DIR")            IF ("%JRE_DIR%")            EQU ("") GOTO SET_VALUE_SPECIAL
IF ("%PARAM%") EQU ("DBPORT")             IF ("%DBPORT%")             EQU ("") GOTO SET_VALUE

IF ("%PARAM%") EQU ("ORA_SERVICE_NAME") IF ("%ORA_SERVICE_NAME%") EQU ("") GOTO SET_VALUE
IF ("%PARAM%") EQU ("MDB_TARGET_DIR")   IF ("%MDB_TARGET_DIR%")   EQU ("") GOTO SET_VALUE_SPECIAL
IF ("%PARAM%") EQU ("DBNAME")           IF ("%DEF_DBNAME%")       EQU ("yes") GOTO SET_VALUE
IF ("%PARAM%") EQU ("DBNAME")           IF ("%DBNAME%")           EQU ("") GOTO SET_VALUE
IF ("%PARAM%") EQU ("DBHOST")           IF ("%DBHOST%")           EQU ("") GOTO SET_VALUE

GOTO DONE_SET

:SET_VALUE
SET %PARAM%=%VALUE%
GOTO DONE_SET

rem used to remove enclosing quotes
:SET_VALUE_SPECIAL
SET %PARAM%=%T_VALUE%
GOTO DONE_SET

:DONE_SET
GOTO :EOF

:READ_RESPONSE_FILE
set RESPONSE_FILE=
IF EXIST "%MDB_COMMON%\Windows\%DBVENDOR%\last_install.param"  SET RESPONSE_FILE="%MDB_COMMON%\Windows\%DBVENDOR%\last_install.param"& GOTO RSP_FOUND 
rem IF EXIST .\%DBVENDOR%\last_install.param SET RESPONSE_FILE=.\%DBVENDOR%\last_install.param & GOTO RSP_FOUND
GOTO RSP_NOT_FOUND

:RSP_FOUND
for /F "usebackq eol=# tokens=1,2* delims==" %%i in (%RESPONSE_FILE%) do CALL :SET_PARAM %%i %%j
GOTO DONE_READ_RESPONSE_FILE
:RSP_NOT_FOUND
echo.
echo WARNING:  "make_MDB_104_compatible.bat"
echo Could not read "%MDB_COMMON%\Windows\%DBVENDOR%\last_install.param"
echo Continuing without successful install parameter defaults.
:DONE_READ_RESPONSE_FILE
:EOF

rem
rem Get the printable arguments (MDB104_COMMAND) as well as  
rem the arguments for the call to setupmdb (MDB104_ARGS)
rem
:GET_PRINTABLE_ARGS
SET T_DBPASSWORD=x%DBPASSWORD%x
SET T_DBPASSWORD="%T_DBPASSWORD:"=%"
SET T_MDB_ADMIN_PSWD=x%MDB_ADMIN_PSWD%x
SET T_MDB_ADMIN_PSWD="%T_MDB_ADMIN_PSWD:"=%"

IF ("%DBVENDOR%")                NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -DBVENDOR=%DBVENDOR% &                     SET MDB104_ARGS=%MDB104_ARGS% -DBVENDOR=%DBVENDOR%
IF ("%DBUSER%")                  NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -DBUSER=%DBUSER% &                         SET MDB104_ARGS=%MDB104_ARGS% -DBUSER=%DBUSER%
IF (%T_DBPASSWORD%)            NEQ ("xx") SET MDB104_COMMAND=%MDB104_COMMAND% -DBPASSWORD=**** &                         SET MDB104_ARGS=%MDB104_ARGS% -DBPASSWORD=placeholder
IF ("%DBHOST%")                  NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -DBHOST=%DBHOST% &                         SET MDB104_ARGS=%MDB104_ARGS% -DBHOST=%DBHOST%
IF ("%DBNAME%")                  NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -DBNAME=%DBNAME% &                         SET MDB104_ARGS=%MDB104_ARGS% -DBNAME=%DBNAME%
IF ("%DBDRIVER%")                NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -DBDRIVER=%DBDRIVER% &                     SET MDB104_ARGS=%MDB104_ARGS% -DBDRIVER=%DBDRIVER%
IF ("%WORKSPACE%")               NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -WORKSPACE=%WORKSPACE% &                   SET MDB104_ARGS=%MDB104_ARGS% -WORKSPACE=%WORKSPACE%
IF ("%EXIT_SCRIPT%")             NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_EXIT_SCRIPT=yes &                     SET MDB104_ARGS=%MDB104_ARGS% -MDB_EXIT_SCRIPT=yes
IF ("%EXIT_SCRIPT%")             EQU ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_EXIT_SCRIPT=no &                      SET MDB104_ARGS=%MDB104_ARGS% -MDB_EXIT_SCRIPT=no
IF ("%II_REINIT_CONFIG%")        NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -II_REINIT_CONFIG=%II_REINIT_CONFIG% &     SET MDB104_ARGS=%MDB104_ARGS% -II_REINIT_CONFIG=%II_REINIT_CONFIG%
IF ("%II_MDB_SIZE%")             NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -II_MDB_SIZE=%II_MDB_SIZE% &               SET MDB104_ARGS=%MDB104_ARGS% -II_MDB_SIZE=%II_MDB_SIZE%
IF ("%DBPORT%")                  NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -DBPORT=%DBPORT% &                         SET MDB104_ARGS=%MDB104_ARGS% -DBPORT=%DBPORT%
IF ("%II_MDB_CONFIG%")           NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -II_MDB_CONFIG=%II_MDB_CONFIG% &           SET MDB104_ARGS=%MDB104_ARGS% -II_MDB_CONFIG=%II_MDB_CONFIG%
IF ("%ORA_TBLSPACE_PATH%")       NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -ORA_TBLSPACE_PATH=%ORA_TBLSPACE_PATH% &   SET MDB104_ARGS=%MDB104_ARGS% -ORA_TBLSPACE_PATH="%ORA_TBLSPACE_PATH%"
IF ("%ORA_DATA_TBLSPACE_NAME%")  NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -ORA_DATA_TBLSPACE=%ORA_DATA_TBLSPACE_NAME% &   SET MDB104_ARGS=%MDB104_ARGS% -ORA_DATA_TBLSPACE=%ORA_DATA_TBLSPACE_NAME%
IF ("%ORA_DATA_SIZE%")           NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -ORA_DATA_SIZE=%ORA_DATA_SIZE% &           SET MDB104_ARGS=%MDB104_ARGS% -ORA_DATA_SIZE=%ORA_DATA_SIZE%
IF ("%ORA_INDEX_TBLSPACE_NAME%") NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -ORA_INDEX_TBLSPACE=%ORA_INDEX_TBLSPACE_NAME% & SET MDB104_ARGS=%MDB104_ARGS% -ORA_INDEX_TBLSPACE=%ORA_INDEX_TBLSPACE_NAME%
IF ("%ORA_INDEX_SIZE%")          NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -ORA_INDEX_SIZE=%ORA_INDEX_SIZE% &         SET MDB104_ARGS=%MDB104_ARGS% -ORA_INDEX_SIZE=%ORA_INDEX_SIZE%
IF (%T_MDB_ADMIN_PSWD%)        NEQ ("xx") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_ADMIN_PSWD=**** &                     SET MDB104_ARGS=%MDB104_ARGS% -MDB_ADMIN_PSWD=placeholder
IF ("%JRE_DIR%")                 NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -JRE_DIR=%JRE_DIR%  &                      SET MDB104_ARGS=%MDB104_ARGS% -JRE_DIR="%JRE_DIR%"
IF ("%MANIFEST%")                NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MANIFEST=%MANIFEST% &                     SET MDB104_ARGS=%MDB104_ARGS% -MANIFEST=%MANIFEST%
IF ("%ORA_SERVICE_NAME%")        NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -ORA_SERVICE_NAME=%ORA_SERVICE_NAME% &     SET MDB104_ARGS=%MDB104_ARGS% -ORA_SERVICE_NAME=%ORA_SERVICE_NAME%
IF ("%PRECHECK%")                NEQ ("") IF /I ("%PRECHECK%") EQU ("yes") SET MDB104_COMMAND=%MDB104_COMMAND% -PRECHECK &  SET MDB104_ARGS=%MDB104_ARGS% -PRECHECK
IF ("%PRECHECK_MSGDIR%")         NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -PRECHECK_MSGDIR=%PRECHECK_MSGDIR% &       SET MDB104_ARGS=%MDB104_ARGS% -PRECHECK_MSGDIR="%PRECHECK_MSGDIR%"
IF ("%ISDEBUG%")                 NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -debug &                                   SET MDB104_ARGS=%MDB104_ARGS% -debug
IF ("%MDB_SOURCE_DIR%")          NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_SOURCE_DIR=%MDB_SOURCE_DIR%  &        SET MDB104_ARGS=%MDB104_ARGS% -MDB_SOURCE_DIR="%MDB_SOURCE_DIR%"
IF ("%MDB_TARGET_DIR%")          NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_TARGET_DIR=%MDB_TARGET_DIR%  &        SET MDB104_ARGS=%MDB104_ARGS% -MDB_TARGET_DIR="%MDB_TARGET_DIR%"
IF ("%MDB_PRIVATE_DIR%")         NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_PRIVATE_DIR="%MDB_PRIVATE_DIR%" &     SET MDB104_ARGS=%MDB104_ARGS% -MDB_PRIVATE_DIR="%MDB_PRIVATE_DIR%"     

IF ("%MDB_COMMON_ORG%")          NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_COMMON_DIR="%MDB_COMMON_ORG%"
IF ("%MDB_COMMON%")              NEQ ("") SET MDB104_ARGS=%MDB104_ARGS% -MDB_COMMON_DIR="%MDB_COMMON%"
IF ("%LOG_DIR%")                 NEQ ("") SET MDB104_ARGS=%MDB104_ARGS% -LOG_DIR="%LOG_DIR%"
IF ("%BATCH_MODE%")              EQU ("yes") SET MDB104_COMMAND=%MDB104_COMMAND% -batch
IF ("%MDB_SOURCE_DIR_ORG%")      NEQ ("") SET MDB104_COMMAND=%MDB104_COMMAND% -MDB_SOURCE_DIR_ORG="%MDB_SOURCE_DIR_ORG%" &  SET MDB104_ARGS=%MDB104_ARGS% -MDB_SOURCE_DIR_ORG="%MDB_SOURCE_DIR_ORG%"
GOTO :EOF

:PRINT_ARGS
SET T_DBPASSWORD=x%DBPASSWORD%x
SET T_DBPASSWORD="%T_DBPASSWORD:"=%"
SET T_MDB_ADMIN_PSWD=x%MDB_ADMIN_PSWD%x
SET T_MDB_ADMIN_PSWD="%T_MDB_ADMIN_PSWD:"=%"
echo setupmdb.bat will modify the given MDB to be MDB 1.0.4 compatible.
echo This will add all missing MDB 1.0.4 schema objects.
echo setupmdb.bat will be run with the following options:
IF ("%DBVENDOR%")                NEQ ("")    echo -DBVENDOR           =%DBVENDOR%
IF ("%DBUSER%")                  NEQ ("")    echo -DBUSER             =%DBUSER%
IF (%T_DBPASSWORD%)            NEQ ("xx")    echo -DBPASSWORD         =****
IF (%T_MDB_ADMIN_PSWD%)        NEQ ("xx")    echo -MDB_ADMIN_PSWD     =****
IF ("%DBHOST%")                  NEQ ("")    echo -DBHOST             =%DBHOST%
IF ("%DBNAME%")                  NEQ ("")    echo -DBNAME             =%DBNAME%
IF ("%DBDRIVER%")                NEQ ("")    echo -DBDRIVER           =%DBDRIVER%
IF ("%MANIFEST%")                NEQ ("")    echo -MANIFEST           =%MANIFEST%
IF ("%WORKSPACE%")               NEQ ("")    echo -WORKSPACE          =%WORKSPACE%
IF ("%DBPORT%")                  NEQ ("")    echo -DBPORT             =%DBPORT%
IF ("%ORA_TBLSPACE_PATH%")       NEQ ("")    echo -ORA_TBLSPACE_PATH  ="%ORA_TBLSPACE_PATH%"
IF ("%ORA_DATA_TBLSPACE_NAME%")  NEQ ("")    echo -ORA_DATA_TBLSPACE  =%ORA_DATA_TBLSPACE_NAME%
IF ("%ORA_INDEX_TBLSPACE_NAME%") NEQ ("")    echo -ORA_INDEX_TBLSPACE =%ORA_INDEX_TBLSPACE_NAME%
IF ("%ORA_INDEX_SIZE%")          NEQ ("")    echo -ORA_INDEX_SIZE     =%ORA_INDEX_SIZE%
IF ("%ORA_DATA_SIZE%")           NEQ ("")    echo -ORA_DATA_SIZE      =%ORA_DATA_SIZE%
IF ("%JRE_DIR%")                 NEQ ("")    echo -JRE_DIR            ="%JRE_DIR%"
IF ("%ORA_SERVICE_NAME%")        NEQ ("")    echo -ORA_SERVICE_NAME   =%ORA_SERVICE_NAME%
IF ("%PRECHECK%")                EQU ("yes") echo                     -PRECHECK
IF ("%PRECHECK_MSGDIR%")         NEQ ("")    echo -PRECHECK_MSGDIR    ="%PRECHECK_MSGDIR%"
IF ("%ISDEBUG%")                 NEQ ("")    echo                     -debug
IF ("%MDB_SOURCE_DIR%")          NEQ ("")    echo -MDB_SOURCE_DIR     ="%MDB_SOURCE_DIR%"
IF ("%MDB_TARGET_DIR%")          NEQ ("")    echo -MDB_TARGET_DIR     ="%MDB_TARGET_DIR%"
IF ("%EXIT_SCRIPT%")             NEQ ("")    echo -MDB_EXIT_SCRIPT    =yes
IF ("%EXIT_SCRIPT%")             EQU ("")    echo -MDB_EXIT_SCRIPT    =no
GOTO :EOF

:ESCAPE_PASSWORDS
IF ("%HAVE_DB_PSWD%") EQU ("yes") GOTO ESCAPE_DB
GOTO DONE_ESCAPE_DB
:ESCAPE_DB
set DBPASSWORD_DQ=%DBPASSWORD%
set DBPASSWORD=%DBPASSWORD:^=^^%
set DBPASSWORD=%DBPASSWORD:<=^<%
set DBPASSWORD=%DBPASSWORD:>=^>%
set DBPASSWORD=%DBPASSWORD:|=^|%
set DBPASSWORD=%DBPASSWORD:&=^&%
set DBPASSWORD=%DBPASSWORD:(=^(%
set DBPASSWORD=%DBPASSWORD:)=^)%
set DBPASSWORD=%DBPASSWORD:"=\"%
:DONE_ESCAPE_DB

IF ("%HAVE_MDB_PSWD%") EQU ("yes") GOTO ESCAPE_MDB_ADMIN
GOTO DONE_ESCAPE_MDB_ADMIN
:ESCAPE_MDB_ADMIN
set MDB_ADMIN_PSWD_DQ=%MDB_ADMIN_PSWD%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:^=^^%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:<=^<%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:>=^>%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:|=^|%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:&=^&%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:(=^(%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:)=^)%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:"=\"%
:DONE_ESCAPE_MDB_ADMIN
GOTO :EOF

:SET_PSWD_VARS
IF ("%HAVE_DB_PSWD%") EQU ("yes") GOTO SET_PSWD_VARS_DB
GOTO SET_PSWD_VARS2
:SET_PSWD_VARS_DB
SET DBPASSWORD_MAKE=%DBPASSWORD_DQ%

:SET_PSWD_VARS2
IF ("%HAVE_MDB_PSWD%") EQU ("yes") GOTO SET_PSWD_VARS_MDB
GOTO :EOF
:SET_PSWD_VARS_MDB
SET MDB_ADMIN_PSWD_MAKE=%MDB_ADMIN_PSWD_DQ%

GOTO :EOF
