REM
REM Name: InstallMDBPatchSQL.bat 
REM
REM Description:	Patch an MDB instance on SQLServer 
REM 
REM Syntax:
REM
REM 	InstallMDBPatchSQL [dbname] [patch file] [patch number]
REM
REM History:
REM	17-oct-2005 mulwi01
REM	    Created
REM	12-dec-2005	mulwi01		Star 14539001 CUMULATIVE PATCH INSTALL HANGS
REM	19-jan-2005	ricle02		Star 14599933 PATCH COLLATION HANDLING
REM	20-sep-2006	rigka01		Star 15251588 PATCH COLLATE MISMATCH BETWEEN SERVER AND DATABASE
REM	07-nov-2006	rigka01		Star 15377965 MDB 30 PATCH INSTALL ON SQL SERVER EXPRESS OR WHEN AUTO CLOSE IS ON FAILS PREMATURELY
REM 	17-nov-2006 	rigka01		Star 15441161 MDB 30 fails for SQL Server Express
REM     12-mar-2007     todjo06         Star 15215592 using UNC path 
REM     24-Apr-2007     todjo06         Star 15832202 and 15823162 adjustments
REM 	19-Nov-2007 	rigka01 Star 16528888, MDB 125, DDL script for SQL Server 2005 and higher, not 2000: ",,,2005" in manifest
REM     16-Jan-2008     rigka01 STAR 16650634, problem MDB 132, DDL script to exit immediately on encoutering error: ",,,,onErrExit" in manifest 
REM     29-Feb-2008     rigka01 STAR 16898441, problem MDB 143, Make onErrExit the default when unspecified in the manifest, add ",,,,onErrContinue" for continue
REM     05-Sep-2008	rigka01 STAR 17468006, problem MDB 172, determine SQL Server version as SQL Server 2000 or as higher by querying the SQL Server instance
REM     

set PATCH_PATH=%~dp0%

IF NOT EXIST %LOGFILE% set LOGFILE=install_%1.log

REM Star 14599933
set MDB_PATCH_FILE=%2
set MDB_PATCH_TEMP=%MDB_PATCH_FILE%_tmp

set MDB_RC_FILE=mdbpatcherr.txt
IF EXIST "%MDB_RC_FILE%" GOTO DONE_SKIP_ERROR



REM
REM Check if the patch already exists
REM
echo %date% %time% Checking if the patch already exists 
echo %date% %time% Checking if the patch already exists >> %LOGFILE%
%SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -d %1 -e -b -Q "exit(select count(*) from mdb_patch where patchnumber = %3)" >>%LOGFILE% 2>&1
IF %ERRORLEVEL% EQU 1 GOTO PATCH_EXISTS



REM Star 16528888, MDB 125 
if "%5"=="default" goto SQLSERVER_VERSION_CHECK_OK
REM Check if DDL script not intended to be run such as when
REM  DDL script is for SQL Server 2005 and above but not for
REM  SQL Server 2000 
if "%5"=="2005" goto NOT_PRE_2005
goto SQLSERVER_VERSION_CHECK_OK
:NOT_PRE_2005
REM Check version of SQL Server instance 
%SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -h-1 -s. -b /Q  "select convert(varchar(20), serverproperty('productversion'))" > version.txt
for /F "usebackq" %%a in ("version.txt") do (
  set SQLSERVER_VERSION=%%a
  goto ENDFOR
)
:ENDFOR
set SQLSERVER_VERS=%SQLSERVER_VERSION:~0,1%
del version.txt
if "%SQLSERVER_VERS%" == "7" goto SQLSERVER_2000_OR_LESS
if "%SQLSERVER_VERS%" == "8" goto SQLSERVER_2000_OR_LESS
GOTO SQLSERVER_VERSION_CHECK_OK
:SQLSERVER_2000_OR_LESS
echo %date% %time% Warning: Patch %3 does not apply to SQL Server 2000 so has NOT been installed
echo %date% %time% Warning: Patch %3 does not apply to SQL Server 2000 so has NOT been installed >>%LOGFILE%
GOTO DONE
:SQLSERVER_VERSION_CHECK_OK

echo %date% %time% Installing patch %3 in database %1  
echo %date% %time% Installing patch %3 in database %1  >> %LOGFILE%

REM Star 14599933
if "%4"=="setcollation" goto DO_SETCOLL
goto DO_CHECK_ONERREXIT

:DO_SETCOLL
echo %date% %time% Getting collation from database
echo %date% %time% Getting collation from database  >> %LOGFILE%

REM 15823162 - use -h-1, not -h -1

IF %SQL_CMD% EQU sqlcmd (
REM 	echo %SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -h-1 -s. -b /Q  "Use %1; select convert(varchar(30), databasepropertyex('%1', 'collation'))" > collation.txt
	%SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -h-1 -s. -b /Q  "Use %1; select convert(varchar(30), databasepropertyex('%1', 'collation'))" > collation.txt
) ELSE (
REM 	echo %SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -h-1 -s. -n -b /Q  "Use %1; select convert(varchar(30), databasepropertyex('%1', 'collation'))" > collation.txt
	%SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -h-1 -s. -n -b /Q  "Use %1; select convert(varchar(30), databasepropertyex('%1', 'collation'))" > collation.txt
)
IF %ERRORLEVEL% EQU 0 GOTO DB_COLLATION
echo %date% %time% Failed to determine the collation (errorlevel=%ERRORLEVEL%)
echo %date% %time% Failed to determine the collation (errorlevel=%ERRORLEVEL%) >> %LOGFILE%
GOTO DONE_ERROR

:DB_COLLATION
if exist %MDB_PATCH_TEMP% del %MDB_PATCH_TEMP%
copy %MDB_PATCH_FILE% %MDB_PATCH_TEMP%
set MDB_PATCH_FILE=%MDB_PATCH_TEMP%

echo %date% %time% Collation.txt start >>%LOGFILE%
type collation.txt >> %LOGFILE% 
echo %date% %time% Collation.txt end >>%LOGFILE%

IF %SQL_CMD% EQU sqlcmd (
"%PATCH_PATH%\LoadMDBUtil" -collation %MDB_PATCH_FILE% collation.txt 2
) ELSE (
"%PATCH_PATH%\LoadMDBUtil" -collation %MDB_PATCH_FILE% collation.txt 1
)

if exist collation.txt del collation.txt
:DO_CHECK_ONERREXIT
IF /i "%6"=="onErrExit" goto DO_PATCHMDB_B
IF /i "%6"=="onErrContinue" goto DO_PATCHMDB
goto DO_PATCHMDB_B

:DO_PATCHMDB
REM Do not use -b option otherwise some worldview patches might fail.
%SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -d %1 -e -i %MDB_PATCH_FILE% >>%LOGFILE% 2>&1
if %ERRORLEVEL% EQU 0 GOTO DONE
echo %date% %time% ***Error installing patch %3 in database %1 
echo %date% %time% ***Error installing patch %3 in database %1 >> %LOGFILE%
GOTO DONE_ERROR

:DO_PATCHMDB_B
%SQL_CMD% %AUTH_STRING% %DBMS_INSTANCE% -d %1 -e -b -i %MDB_PATCH_FILE% >>%LOGFILE% 2>&1
if %ERRORLEVEL% EQU 0 GOTO DONE
echo %date% %time% ***Error installing patch %3 in database %1 
echo %date% %time% ***Error installing patch %3 in database %1 >> %LOGFILE%
GOTO DONE_ERROR

:PATCH_EXISTS
echo %date% %time% Warning: Patch %3 already exists in database %1 
echo %date% %time% Warning: Patch %3 already exists in database %1 >> %LOGFILE%
GOTO DONE

:DONE
if exist %MDB_PATCH_TEMP% del %MDB_PATCH_TEMP%
exit /B 0

:DONE_ERROR
IF NOT EXIST "%MDB_RC_FILE%" echo %date% %time% ***Error installing patch script %3 in database %1 >> "%MDB_RC_FILE%"
exit /B 1

:DONE_SKIP_ERROR
echo %date% %time% Patch %3 was not installed in database %1 because of a previous error >> %LOGFILE%
exit /B 1
