SET LOCK_TIMEOUT 300000
GO
SET DEADLOCK_PRIORITY LOW
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION 
GO

/****************************************************************************************/
/*                                                                                      */
/* Star 15490703 Autosys: create ujo_event_state					*/
/*                                                                                      */
/****************************************************************************************/

/* lock objects...  */
 
/* Start of lines added to convert to online lock */
 
 
Select top 1 1 from mdb_patch with (tablockx)
GO
 
/* Start of locks for dependent tables */
 
Select top 1 1 from mdb_service_pack with (tablockx)
GO
 
Select top 1 1 from mdb with (tablockx)
GO
 
Select top 1 1 from mdb_checkpoint with (tablockx)
GO
 
/* End of lines added to convert to online lock */

if exists (select * from sysobjects where name = "ujo_event_state" and type = 'P')
begin
	drop procedure ujo_event_state
end
go

/* Correct problem with duplicate evt_num values */
/* 15024555 - Ensure unique evt_num values */
CREATE proc ujo_event_state
	@eoid        varchar(12),
	@que_status  int,
	@evt_num	 int
AS
/* If it's a 2 (EVENT_DONE), 3 (HDLR_ERROR), or 4 (UN_SENT), copy it to the proc_event table and delete it */
if (@que_status > 1 AND @que_status < 5)
begin
	begin tran
    update ujo_next_oid set oid = oid + 1 where field = 'evt_proc_num'
    if @@rowcount = 0
    begin
        insert into ujo_next_oid (oid, field) values (1, 'evt_proc_num')
        select @evt_num = 1
    end
    else
    begin
    	select @evt_num = oid from ujo_next_oid where field = 'evt_proc_num'
    end
    commit
    
    begin tran
    insert into ujo_proc_event (eoid, joid, job_name, box_name, AUTOSERV, priority, 
                            event, status, alarm, event_time_gmt, exit_code, machine,
                            pid, jc_pid, run_num, ntry, text, que_priority, stamp,
                            evt_num, que_status, que_status_stamp)
      select ujo_event.eoid, ujo_event.joid, ujo_event.job_name, ujo_event.box_name, 
	      ujo_event.AUTOSERV, ujo_event.priority, ujo_event.event, ujo_event.status, 
	      ujo_event.alarm, ujo_event.event_time_gmt, ujo_event.exit_code, ujo_event.machine, 
	      ujo_event.pid, ujo_event.jc_pid, ujo_event.run_num, ujo_event.ntry, ujo_event.text, 
	      ujo_event.que_priority, ujo_event.stamp, @evt_num, @que_status, getdate()
      from ujo_event
      where eoid = @eoid

    if @@rowcount = 1
    begin
        delete from ujo_event where eoid = @eoid
        commit
    end
	else 
	begin 
		rollback
	end
end
else
begin
	begin tran
	update	ujo_event
	set	que_status = @que_status, que_status_stamp = getdate(), evt_num = @evt_num + 1
		where	eoid = @eoid
	if @@rowcount !=1
	begin
		print 'event_state stored proc has a problem'
		rollback
		return 0
	end
	commit
end

return 1
GO

grant execute on ujo_event_state to ujoadmin
GO

/* 15010574 */
delete from ujo_intcodes where fld = 'alarm' and code = 528;
go
/* T348255 */
update ujo_timezones set zone = 'CST4CDT,M10.3.0/00:00:00,M3.2.0/00:00:00' where name = 'America/Santiago' and type = 'Z'
go
update ujo_timezones set zone = 'US/Eastern' where name = 'Detroit' and type = 'C'
go
update ujo_timezones set zone = 'EST3EDT,M11.1.0/00:00:00,M2.5.0/00:00:00' where name = 'America/Sao_Paulo' and type = 'Z'
go
update ujo_timezones set zone = 'EST-10EST,M10.5.0,M3.5.0/03:00:00' where name = 'Sydney-Z' and type = 'Z'
go

/* 15112496 */
drop index ujo_event0.event0_PUC
go

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                               	*/
/*                                                                                      */
/****************************************************************************************/
insert into mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 values ( 15490703, getdate(), 1, 4, 'Star 15490703 Autosys: create ujo_event_state' )
GO

COMMIT TRANSACTION 
GO

