SET LOCK_TIMEOUT 300000
GO
SET DEADLOCK_PRIORITY LOW
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION 
GO

/****************************************************************************************/
/*                                                                                      */
/* Star 16514609 UAPM r11.3.4 support and SWCM common functionality			*/
/*                                                                                      */
/****************************************************************************************/

/* lock objects...  */
 
/* Start of lines added to convert to online lock */
 
 
Select top 1 1 from mdb_patch with (tablockx)
GO
 
/* Start of locks for dependent tables */
 
Select top 1 1 from mdb_service_pack with (tablockx)
GO
 
Select top 1 1 from mdb with (tablockx)
GO
 
Select top 1 1 from mdb_checkpoint with (tablockx)
GO
 
Select top 1 1 from arg_attribute_def with (tablockx)
GO
 
Select top 1 1 from arg_class_def with (tablockx)
GO
 
/* End of lines added to convert to online lock */


/***** Create the al_applications table *****/
IF (NOT EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_applications') AND (type = 'U')))
BEGIN
  CREATE TABLE dbo.al_applications (
    application_name 		nvarchar(256)           NOT NULL ,
    lowered_application_name	nvarchar(256)           NOT NULL ,
    application_id           	uniqueidentifier        DEFAULT NEWID(),
    description             	nvarchar(256)		NULL,
    creation_user		nvarchar(255)		NULL,
    creation_date		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			DEFAULT 0

 CONSTRAINT PK_al_applications PRIMARY KEY CLUSTERED 
 (
      application_id ASC
 )
    )

END
GO

CREATE  UNIQUE  INDEX al_applications_idx_01 ON dbo.al_applications(application_name) ON [PRIMARY]
GO

CREATE  UNIQUE  INDEX al_applications_idx_02 ON dbo.al_applications(lowered_application_name) ON [PRIMARY]
GO


/***** Create al_control_type_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_control_type_def') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_control_type_def (
    control_type_id		int			NOT NULL,
    control_type		nvarchar(256)		NOT NULL,
    creation_user		nvarchar(255)		NULL,
    creation_date		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int 			DEFAULT 0,
 CONSTRAINT PK_al_control_type_def PRIMARY KEY CLUSTERED 
(
	control_type_id ASC
)
) ON [PRIMARY]

END
GO


/***** Create al_form_attribute_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_form_attribute_def') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_form_attribute_def (
    form_attribute_id		int 			NOT NULL,
    control_type_id		int  			NULL,
    form_id			int 			NULL,
    attribute_name		nvarchar(256) 		NOT NULL,
    attribute_path		nvarchar(256) 		NULL,
    class_name			nvarchar(256) 		NULL,
    search_formlet		nvarchar(256) 		NULL,
    group_in			nvarchar(256) 		NULL,
    hlf_navigate_url		nvarchar(256) 		NULL,
    hlf_text_format		nvarchar(256) 		NULL,
    hlf_navigate_url_fields	nvarchar(256)		NULL,
    is_datakey			int			NULL,
    visibility			int			NULL,
    position			int			NULL,
    raises_events		int			NULL,
    rangelow			float			NULL,
    Rangehigh			float			NULL,
    comparevalue		nvarchar(256)		NULL,
    regexp			nvarchar(256)		NULL,
    column_index		int			DEFAULT 0,
    foreign_search_keys		nvarchar(255)		NULL,
    foreign_display_type	int			NULL,
    compare_operator		nvarchar(20)		NULL,
    compare_data_type		nvarchar(20)		NULL,
    is_foreign_search_constraint int			NULL,
    creation_user		nvarchar(255)		NULL,
    creation_date		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			DEFAULT 0,
    
 CONSTRAINT al_form_attribute_def_pk01 PRIMARY KEY CLUSTERED 
(
	form_attribute_id ASC
) 
) ON [PRIMARY]

END
GO


/***** Create al_form_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_form_def') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_form_def (
    form_id			int 			NOT NULL,
    formlet_name		nvarchar(256)		NOT NULL,
    application_id		UNIQUEIDENTIFIER	NULL,
    render_type_id		int			NULL,
    pagesize			int			NOT NULL,
    bind_class			nvarchar(256)		NOT NULL,
    formlet_title		nvarchar(256)		NULL,
    dependent_params     	nvarchar(256)           NULL,
    columncount			int			DEFAULT 2,
    creation_user		nvarchar(255)		NULL,
    creation_date		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			NULL DEFAULT 0,

 CONSTRAINT al_form_def_pk01 PRIMARY KEY CLUSTERED 
(
	form_id ASC
) 
) ON [PRIMARY]

END
GO


/***** Create table al_link_form_attribute_profile *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_link_form_attribute_profile') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_link_form_attribute_profile (
    form_attribute_id	int		NOT NULL, 
    profile_id		int		NOT NULL, 
    is_readonly		int		NOT NULL,
    is_required		int		NOT NULL,
    last_update_user	nvarchar(255)	NULL,
    last_update_date	int		NULL,
    version_number	int		DEFAULT 0,
CONSTRAINT XPKlink_form_attribute_profile PRIMARY KEY  CLUSTERED 
(
	form_attribute_id, profile_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_link_page_webpart table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_link_page_webpart') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_link_page_webpart (
    page_webpart_id	int		NOT NULL, 
    page_id		int		NOT NULL, 
    webpart_id		int		NOT NULL,
    last_update_user	nvarchar(255)	NULL,
    last_update_date	int		NULL,
    version_number	int		NULL DEFAULT 0,
CONSTRAINT XPKal_link_page_webpart PRIMARY KEY  CLUSTERED 
(
	page_webpart_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_link_page_webpart_profile table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_link_page_webpart_profile') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_link_page_webpart_profile (
    page_webpart_id	int		NOT NULL, 
    profile_id		int		NOT NULL, 
    default_position	int		NULL,
    default_zone	int		NULL,
    last_update_user	nvarchar(255)	NULL,
    last_update_date	int		NULL,
    version_number	int		DEFAULT 0,
CONSTRAINT XPKlink_page_webpart_profile PRIMARY KEY  CLUSTERED 
(
	page_webpart_id, profile_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_page_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_page_def') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_page_def (
    page_id		int			NOT NULL,   
    application_id	UNIQUEIDENTIFIER    	NULL, 
    description 	nvarchar(256) 		NULL,
    page_path 		nvarchar(256) 		NOT NULL,
    creation_user	nvarchar(255)		NULL,
    creation_date 	int			NULL,
    last_update_user	nvarchar(255)		NULL,
    last_update_date	int			NULL,
    version_number	int			NULL DEFAULT 0,
CONSTRAINT XPKal_page_def PRIMARY KEY  CLUSTERED 
(
	page_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_paths table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_paths') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_paths (
    path_id			UNIQUEIDENTIFIER	NOT NULL DEFAULT NEWID(),   
    application_id		UNIQUEIDENTIFIER    	NOT NULL, 
    path 			nvarchar(256) 		NOT NULL,
    lowered_path 	 	nvarchar(256) 		NOT NULL,
    creation_user		nvarchar(255)		NULL,
    creation_date 		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			NULL DEFAULT 0,
CONSTRAINT XPKal_paths PRIMARY KEY  CLUSTERED 
(
	path_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_personalization_all_users table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_personalization_all_users') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_personalization_all_users (
    path_id			UNIQUEIDENTIFIER	NOT NULL,   
    page_settings		IMAGE		    	NOT NULL, 
    last_updated_date 		DATETIME 		NOT NULL,
    creation_user		nvarchar(255)		NULL,
    creation_date 		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			NULL DEFAULT 0,
CONSTRAINT XPKpersonalization_all_users PRIMARY KEY  CLUSTERED 
(
	path_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_personalization_per_user table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_personalization_per_user') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_personalization_per_user (
    Id				UNIQUEIDENTIFIER	NOT NULL DEFAULT NEWID(),   
    path_id			UNIQUEIDENTIFIER	NULL,   
    user_id			NVARCHAR(256)		NOT NULL, 
    page_settings		IMAGE		    	NOT NULL, 
    last_updated_date 		DATETIME 		NOT NULL,
    creation_user		nvarchar(255)		NULL,
    creation_date 		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			NULL DEFAULT 0,
CONSTRAINT XPKpersonalization_per_user PRIMARY KEY  CLUSTERED 
(
	Id
)  
) ON [PRIMARY] 

END
GO

CREATE UNIQUE INDEX al_personalization_per_user_i1 ON dbo.al_personalization_per_user(path_id,user_id)
GO

CREATE UNIQUE INDEX al_personalization_per_user_i2 ON dbo.al_personalization_per_user(user_id,path_id)
GO


/***** Create al_profile_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_profile_def') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_profile_def (
    profile_id			int			NOT NULL,   
    application_id		UNIQUEIDENTIFIER	NULL,   
    profile_name		NVARCHAR(256)		NOT NULL, 
    creation_user		nvarchar(255)		NULL,
    creation_date 		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			NULL DEFAULT 0,
CONSTRAINT XPKal_profile_def PRIMARY KEY  CLUSTERED 
(
	profile_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_render_type_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_render_type_def') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_render_type_def (
    render_type_id		int			NOT NULL,   
    render_type			nvarchar(256)		NOT NULL, 
    creation_user		nvarchar(255)		NULL,
    creation_date 		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			NULL DEFAULT 0,
CONSTRAINT XPKal_render_type_def PRIMARY KEY  CLUSTERED 
(
	render_type_id
)  
) ON [PRIMARY] 

END
GO


/***** Create al_ui_cache table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_ui_cache') AND (type = 'U')))
BEGIN

CREATE TABLE [dbo].[al_ui_cache] (
	[page_id] [varchar] (40) NOT NULL ,
	[control_id] [varchar] (500) NOT NULL ,
	[cache_action] [int] NOT NULL ,
	[cache_key] [varchar] (160) NOT NULL ,
	[cache_value] [image] NULL ,
	[class_name] [varchar] (100) NOT NULL,
	[last_update_date] [int] NULL,
CONSTRAINT [PK_al_ui_cache] PRIMARY KEY  CLUSTERED 
	(
		[page_id],
		[control_id],
		[cache_key]
	)  
) ON [PRIMARY]

END
GO


/***** Create al_webpart_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_webpart_def') AND (type = 'U')))
BEGIN

  CREATE TABLE dbo.al_webpart_def (
    webpart_id			int			NOT NULL,   
    application_id		UNIQUEIDENTIFIER    	NULL, 
    title 			nvarchar(256) 		NULL,
    image_url 		 	nvarchar(256) 		NULL,
    ascx_path 		 	nvarchar(256) 		NOT NULL,
    creation_user		nvarchar(255)		NULL,
    creation_date 		int			NULL,
    last_update_user		nvarchar(255)		NULL,
    last_update_date		int			NULL,
    version_number		int			NULL DEFAULT 0,
CONSTRAINT XPKal_webpart_def PRIMARY KEY  CLUSTERED 
(
	webpart_id
)  
) ON [PRIMARY] 

END
GO


/***** Add columns to arg_attribute_def table *****/
alter table arg_attribute_def add app_filter smallint not null default 2
GO

/***** Add columns to arg_class_def table *****/
alter table arg_class_def add cacheable smallint not null default 0
alter table arg_class_def add app_filter smallint not null default 2
GO



/***** Foreign key constraints for al_form_attribute_def *****/

ALTER TABLE dbo.al_form_attribute_def  WITH CHECK ADD  
	CONSTRAINT FK_al_form_attribute_def_fk01 FOREIGN KEY
	(
		control_type_id
	) REFERENCES dbo.al_control_type_def (
		control_type_id
	),
	CONSTRAINT FK_al_form_attribute_def_fk02 FOREIGN KEY
	(
		form_id
	) REFERENCES dbo.al_form_def (
		form_id
	)
GO

/***** Foreign key constraints for al_form_def *****/

ALTER TABLE dbo.al_form_def  WITH CHECK ADD  
	CONSTRAINT FK_al_form_def_fk01 FOREIGN KEY
	(
		application_id
	) REFERENCES dbo.al_applications (
		application_id
	),
	CONSTRAINT FK_al_form_def_fk02 FOREIGN KEY
	(
		render_type_id
	) REFERENCES dbo.al_render_type_def (
		render_type_id
	)
GO

/***** Foreign key constraints for al_link_form_attribute_profile *****/

ALTER TABLE dbo.al_link_form_attribute_profile ADD 
	CONSTRAINT al_link_form_attrib_prof_fk01 FOREIGN KEY 
	(
		form_attribute_id
	) REFERENCES dbo.al_form_attribute_def (
		form_attribute_id
	),
	CONSTRAINT al_link_form_attrib_prof_fk02 FOREIGN KEY 
	(
		profile_id
	) REFERENCES dbo.al_profile_def (
		profile_id
	)
GO

/***** Foreign key constraints for al_link_page_webpart *****/

ALTER TABLE dbo.al_link_page_webpart ADD 
	CONSTRAINT al_link_page_webpart_fk01 FOREIGN KEY 
	(
		page_id
	) REFERENCES dbo.al_page_def (
		page_id
	),
	CONSTRAINT al_link_page_webpart_fk02 FOREIGN KEY 
	(
		webpart_id
	) REFERENCES dbo.al_webpart_def (
		webpart_id
	)
GO

/***** Foreign key constraints for al_link_page_webpart *****/

ALTER TABLE dbo.al_link_page_webpart_profile ADD 
	CONSTRAINT al_link_page_webpart_prof_fk01 FOREIGN KEY 
	(
		page_webpart_id
	) REFERENCES dbo.al_link_page_webpart (
		page_webpart_id
	),
	CONSTRAINT al_link_page_webpart_prof_fk02 FOREIGN KEY 
	(
		profile_id
	) REFERENCES dbo.al_profile_def (
		profile_id
	)
GO

/***** Foreign key constraints for al_link_page_webpart *****/

ALTER TABLE dbo.al_page_def ADD 
	CONSTRAINT al_page_def_fk01 FOREIGN KEY 
	(
		application_id
	) REFERENCES dbo.al_applications (
		application_id
	)

GO

/***** Foreign key constraints for al_paths *****/

ALTER TABLE dbo.al_paths ADD 
	CONSTRAINT al_paths_fk01 FOREIGN KEY 
	(
		application_id
	) REFERENCES dbo.al_applications (
		application_id
	)

GO

/***** Foreign key constraints for al_personalization_all_users *****/

ALTER TABLE dbo.al_personalization_all_users ADD 
	CONSTRAINT personalization_all_users_fk01 FOREIGN KEY 
	(
		path_id
	) REFERENCES dbo.al_paths (
		path_id
	)

GO

/***** Foreign key constraints for al_personalization_per_user *****/

ALTER TABLE dbo.al_personalization_per_user ADD 
	CONSTRAINT personalization_per_user_fk01 FOREIGN KEY 
	(
		path_id
	) REFERENCES dbo.al_paths (
		path_id
	)

GO

/***** Foreign key constraints for al_profile_def *****/

ALTER TABLE dbo.al_profile_def ADD 
	CONSTRAINT al_profile_def_fk01 FOREIGN KEY 
	(
		application_id
	) REFERENCES dbo.al_applications (
		application_id
	)

GO

/***** Foreign key constraints for al_webpart_def *****/

ALTER TABLE dbo.al_webpart_def ADD 
	CONSTRAINT al_webpart_def_fk01 FOREIGN KEY 
	(
		application_id
	) REFERENCES dbo.al_applications (
		application_id
	)

GO


/*** [AL_PERSONALIZATION] ***/
CREATE TABLE arg_personalization(
            [ApplicationName] [nvarchar](100) COLLATE !!insensitive NOT NULL,
            [UserId] [nvarchar](50) COLLATE !!insensitive NOT NULL,
            [ObjectPrefix] [int] NOT NULL,
            [PropertyName] [nvarchar](100) COLLATE !!insensitive NOT NULL,
            [PropertyValue] [nvarchar](1000) COLLATE !!insensitive NULL,
CONSTRAINT [PK_arg_personalization_1] PRIMARY KEY CLUSTERED 
(
            [ApplicationName] ASC,
            [UserId] ASC,
            [ObjectPrefix] ASC,
            [PropertyName] ASC
) ON [PRIMARY]
)
GO

/*** [AL_PURCHASE_ORDER_STATUS] ***/
CREATE TABLE [dbo].[al_purchase_order_status](
	[id] [int] NOT NULL,
	[value] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
 CONSTRAINT
	[PK_al_purchase_order_status] PRIMARY KEY CLUSTERED 
 (
	[id]
 )
) ON [PRIMARY]
GO

/***** Create al_purchase_order table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_purchase_order') AND (type = 'U')))
BEGIN
CREATE TABLE [dbo].[al_purchase_order](
	[purchase_order_id] [int] NOT NULL,
	[purchase_order_number] [nvarchar](255) COLLATE !!insensitive NULL,
	[purchase_order_date] [datetime] NULL,
	[comments] [nvarchar](2000) COLLATE !!insensitive NULL,
	[signature] [nvarchar](255) COLLATE !!insensitive NULL,
	[ship_to_overide_flag] [int] NULL,
	[ship_to_contact_uuid] [binary](16) NULL,
	[ship_to_location_address] [nvarchar](255) COLLATE !!insensitive NULL,		
	[billing_overide_flag] [int] NULL,
	[billing_location_uuid] [binary](16) NULL,
	[billing_address] [nvarchar](255) COLLATE !!insensitive NULL,		
	[reseller_overide_flag] [int] NULL,
	[reseller_uuid] [binary](16) NULL,
	[reseller_address] [nvarchar](255) COLLATE !!insensitive NULL,		
	[total_amount] [float] NULL,
	[total_tax_amount] [float] NULL,
	[sub_total_amount] [float] NULL,
	[currency_type_id] [varchar] (3) COLLATE !!sensitive NULL,
	[assets_created] [int] NULL DEFAULT ((0)),
	[purchase_order_status_id] [int] NOT NULL,
	[creation_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
CONSTRAINT
	[PK_al_purchase_order] PRIMARY KEY CLUSTERED 
(
	[purchase_order_id]
)
) ON [PRIMARY]
ALTER TABLE [dbo].[al_purchase_order] ADD 
	CONSTRAINT
	[al_purchase_order_fk01] FOREIGN KEY
	(
		[currency_type_id]
	) REFERENCES [dbo].[ca_currency_type]
	(
		[currency_type_code]
	),
	CONSTRAINT
	[al_purchase_order_fk02] FOREIGN KEY
	(
		[purchase_order_status_id]
	) REFERENCES [dbo].[al_purchase_order_status]
	(
		[id]
	),
	CONSTRAINT [al_purchase_order_fk03] FOREIGN KEY 
	(
		[ship_to_contact_uuid]
	) REFERENCES [dbo].[ca_contact] (
		[contact_uuid]
	),
	CONSTRAINT [al_purchase_order_fk04] FOREIGN KEY 
	(
		[billing_location_uuid]
	) REFERENCES [dbo].[ca_location] (
		[location_uuid]
	),
	CONSTRAINT [al_purchase_order_fk05] FOREIGN KEY 
	(
		[reseller_uuid]
	) REFERENCES [dbo].[ca_company] (
		[company_uuid]
	)

END
GO

/***** Create al_purchase_order_item table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_purchase_order_item') AND (type = 'U')))
BEGIN

CREATE TABLE [dbo].[al_purchase_order_item](
	[purchase_order_item_id] [int] NOT NULL,
	[purchase_order_id] [int] NOT NULL,
	[request_item_id] [int] NULL,
	[request_id] [int] NULL,
	[model_uuid] [binary](16) NULL,
	[item_description] [nvarchar](255) COLLATE !!insensitive NULL,
	[item_quantity] [int] NULL,
	[item_unit_price] [float] NULL,
	[item_tax] [float] NULL,
	[item_total_amount] [float] NULL,
	[part_number] [nvarchar](255) COLLATE !!insensitive NULL,
	[sku_number] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
 CONSTRAINT
	[PK_al_purchase_order_item] PRIMARY KEY CLUSTERED 
(
	[purchase_order_item_id]
) 
)ON [PRIMARY]
ALTER TABLE [dbo].[al_purchase_order_item] ADD 
	CONSTRAINT [al_purchase_order_item_fk01] FOREIGN KEY
	(
		[purchase_order_id]
	) REFERENCES [dbo].[al_purchase_order]
	(
		[purchase_order_id]
	),
	CONSTRAINT [al_purchase_order_item_fk02] FOREIGN KEY 
	(
		[model_uuid]
	) REFERENCES [dbo].[ca_model_def] (
		[model_uuid]
	)

END
GO

/*** [AL_LINK_PO_ITEM_OWND_RSRC] ***/
CREATE TABLE [dbo].[al_link_po_item_ownd_rsrc](
	[owned_resource_uuid] [binary](16) NOT NULL,
	[purchase_order_item_id] [int] NOT NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
 CONSTRAINT [PK_al_link_po_item_ownd_rsrc] PRIMARY KEY CLUSTERED 
(
	[owned_resource_uuid] ASC,
	[purchase_order_item_id] ASC
)
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[al_link_po_item_ownd_rsrc] ADD  
	CONSTRAINT 
	[al_link_po_item_ownd_rsrc_fk01] FOREIGN KEY
	(
		[purchase_order_item_id]
	) REFERENCES [dbo].[al_purchase_order_item] 
	(
		[purchase_order_item_id]
	),
	CONSTRAINT 
	[al_link_po_item_ownd_rsrc_fk02] FOREIGN KEY
	(
		[owned_resource_uuid]
	) REFERENCES [dbo].[ca_owned_resource] 
	(
		[own_resource_uuid]
	)
GO

/*** [AL_PURCHASE_HW_ITEM] ***/
CREATE TABLE [dbo].[al_purchase_hw_item](
	[purchase_order_item_id] [int] NOT NULL,
	[model_uuid] [binary](16) NOT NULL,
	[creation_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
 CONSTRAINT [PK_al_purchase_hw_item] PRIMARY KEY CLUSTERED 
(
	[purchase_order_item_id]
)
)ON [PRIMARY]
GO

ALTER TABLE [dbo].[al_purchase_hw_item] ADD CONSTRAINT
	[al_purchase_hw_item_fk01] FOREIGN KEY
	(
		[purchase_order_item_id]
	) REFERENCES [dbo].[al_purchase_order_item]
	(
		[purchase_order_item_id]
	)
GO

/*** [AL_ATTACHMT] ***/
CREATE TABLE [dbo].[al_attachmt](
	[amid] [int] NOT NULL,
	[amurl] [nvarchar](250) COLLATE !!insensitive NULL,
	[amdesc] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_user] [nvarchar](64) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](64) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
 CONSTRAINT [PK_al_attachmt] PRIMARY KEY CLUSTERED 
(
	[amid] ASC
)
) ON [PRIMARY]
GO

/*** [AL_LINK_PURCHS_ORDR_ATTACHMT] ***/
CREATE TABLE [dbo].[al_link_purchs_ordr_attachmt] (
	[amid] [int] NOT NULL,
	[purchase_order_id] [int] NOT NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
 CONSTRAINT [PK_al_link_purchs_ordr_attachmt] PRIMARY KEY CLUSTERED 
(
	[amid],
	[purchase_order_id]
)
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[al_link_purchs_ordr_attachmt] ADD 
	CONSTRAINT
	[al_lnk_po_attachmt_fk01] FOREIGN KEY
	(
		[amid]
	) REFERENCES [dbo].[al_attachmt]
	(
		[amid]
	),CONSTRAINT
	[al_lnk_po_attachmt_fk02] FOREIGN KEY
	(
		[purchase_order_id]
	) REFERENCES [dbo].[al_purchase_order]
	(
		[purchase_order_id]
	)
GO


/***** Procedure for SWCM UI Metadata *****/

IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_get_fields_to_render') AND (type = 'P')))
DROP PROCEDURE [dbo].al_get_fields_to_render
GO
CREATE PROCEDURE [dbo].[al_get_fields_to_render] 
	@profile_names nvarchar(256), 
	@form_name nvarchar(256),
    @app_name nvarchar(256)
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	declare @select nvarchar(4000)
	declare @case nvarchar(4000)
	declare @fromjoin nvarchar(4000)
    declare @orderby nvarchar(4000)

	set @select =
		'SELECT CASE fd.data_type WHEN 10 THEN fd.data_size ELSE 0 END AS data_size, fd.field_required, fd.foreign_key,
		ad.attribute_label, ad.table_name, ad.relation_type, 
		al_fd.render_type_id,al_fd.formlet_name, al_fd.pagesize, al_fd.columncount,
        	al_fd.bind_class, al_fd.dependent_params,   
        	al_af.form_attribute_id, al_af.position, al_af.rangelow, al_af.rangehigh, al_af.visibility,
        	al_af.comparevalue,al_af.regexp, al_af.raises_events, al_af.attribute_path, 
        	al_af.hlf_navigate_url, al_af.hlf_text_format, al_af.hlf_navigate_url_fields,
        	al_af.attribute_name, al_af.is_datakey, al_af.class_name, al_af.search_formlet, al_af.group_in,
        	al_af.foreign_search_keys, al_af.column_index, al_af.foreign_display_type,
            al_af.compare_operator, al_af.compare_data_type, al_af.is_foreign_search_constraint,
			al_lfap.is_required, al_lfap.is_readonly, 
            ct.control_type '

	set @fromjoin =
		' FROM al_profile_def al_pd
		JOIN al_link_form_attribute_profile al_lfap
			on al_lfap.profile_id = al_pd.profile_id
		JOIN al_form_attribute_def al_af
			on al_af.form_attribute_id = al_lfap.form_attribute_id
		JOIN al_control_type_def ct
			on ct.control_type_id = al_af.control_type_id
		JOIN al_form_def al_fd
			on al_fd.form_id = al_af.form_id
		JOIN al_applications al_app
		    on al_app.application_id = al_fd.application_id
		JOIN arg_attribute_def ad
			on ad.attribute_name = al_af.attribute_name and LOWER(ad.class_name) = LOWER(al_af.class_name)
		LEFT OUTER JOIN arg_field_def fd
			on fd.table_name = ad.table_name and fd.field_name = ad.field_name
		where al_pd.profile_name in('+ @profile_names + ') 
          AND LOWER(al_fd.formlet_name) = LOWER(''' + @form_name + ''')
          AND al_app.lowered_application_name = LOWER(''' + @app_name +''')'
     set @orderby = ' ORDER BY al_af.position ASC '

	EXEC (@select+@case+@fromjoin+@orderby)
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_get_page_web_parts') AND (type = 'P')))
DROP PROCEDURE [dbo].al_get_page_web_parts
GO
CREATE PROCEDURE [dbo].[al_get_page_web_parts] 
	@profile_names nvarchar(256), 
	@page_name nvarchar(256),
    @app_name nvarchar(256)
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	declare @select nvarchar(4000)
	declare @fromjoin nvarchar(4000)
    declare @where nvarchar(4000)

	set @select = 'SELECT DISTINCT part_def.*, 
                                   page_part_prof_lnk.default_position, 
                                   page_part_prof_lnk.default_zone,
								   rep_def.report_id,  
                                   rep_def.name as report_name,
                                   rep_def.path as report_path,
                                   rep_def.height as report_height,
                                   rep_def.width as report_width '

	set @fromjoin = 'FROM al_Profile_Def prof_def 
				     JOIN al_Link_Page_WebPart_Profile page_part_prof_lnk 
					   ON page_part_prof_lnk.profile_id = prof_def.profile_id 
				     JOIN al_Link_Page_WebPart page_part_lnk 
					   ON page_part_lnk.page_webpart_id = page_part_prof_lnk.page_webpart_id 
				     JOIN al_WebPart_Def part_def 
					   ON part_def.webpart_id = page_part_lnk.webpart_id 
				     JOIN al_Page_Def page_def 
					   ON page_def.page_id = page_part_lnk.page_id 
					 JOIN al_applications al_app
					   ON al_app.application_id = page_def.application_id and al_app.application_id = part_def.application_id 
					 LEFT OUTER JOIN al_link_webpart_report part_rep_link
					   ON part_rep_link.webpart_id = part_def.webpart_id
					 LEFT OUTER JOIN al_report_def rep_def
                       ON rep_def.report_id = part_rep_link.report_id '

	set @where = 'WHERE prof_def.profile_name IN ('+ @profile_names + ') 
                    AND LOWER(page_def.page_path) = LOWER(''' + @page_name + ''') 
                    AND al_app.lowered_application_name = LOWER(''' + @app_name +''')'

	EXEC (@select+@fromjoin+@where)
END
GO


/***** Procedures for SWCM Personalization *****/

IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_applications_create') AND (type = 'P')))
DROP PROCEDURE [dbo].al_applications_create
GO

CREATE PROCEDURE [dbo].al_applications_create
    @in_application_name      nvarchar(256),
    @in_application_id        uniqueidentifier OUTPUT
AS
BEGIN
    SELECT  @in_application_id = application_id FROM dbo.al_applications WHERE LOWER(@in_application_name) = lowered_application_name

    IF(@in_application_id IS NULL)
    BEGIN
        DECLARE @TranStarted   bit
        SET @TranStarted = 0

        IF( @@TRANCOUNT = 0 )
        BEGIN
	        BEGIN TRANSACTION
	        SET @TranStarted = 1
        END
        ELSE
    	    SET @TranStarted = 0

        SELECT  @in_application_id = application_id
        FROM dbo.al_applications WITH (UPDLOCK, HOLDLOCK)
        WHERE LOWER(@in_application_name) = lowered_application_name

        IF(@in_application_id IS NULL)
        BEGIN
            SELECT  @in_application_id = NEWID()
            INSERT  dbo.al_applications (application_id, application_name, lowered_application_name)
            VALUES  (@in_application_id, @in_application_name, LOWER(@in_application_name))
        END


        IF( @TranStarted = 1 )
        BEGIN
            IF(@@ERROR = 0)
            BEGIN
	        SET @TranStarted = 0
	        COMMIT TRANSACTION
            END
            ELSE
            BEGIN
                SET @TranStarted = 0
                ROLLBACK TRANSACTION
            END
        END
    END
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_paths_create_path') AND (type = 'P')))
DROP PROCEDURE dbo.al_paths_create_path
GO
CREATE PROCEDURE dbo.al_paths_create_path
    @in_application_id UNIQUEIDENTIFIER,
    @in_path           NVARCHAR(256),
    @in_path_id         UNIQUEIDENTIFIER OUTPUT
AS
BEGIN
    BEGIN TRANSACTION
    IF (NOT EXISTS(SELECT * FROM dbo.al_paths WHERE lowered_path = LOWER(@in_path) AND application_id = @in_application_id))
    BEGIN
        INSERT dbo.al_paths (application_id, path, lowered_path) VALUES (@in_application_id, @in_path, LOWER(@in_path))
    END
    COMMIT TRANSACTION
    SELECT @in_path_id = path_id FROM dbo.al_paths WHERE LOWER(@in_path) = lowered_path AND application_id = @in_application_id
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_personalization_get_app_id') AND (type = 'P')))
DROP PROCEDURE dbo.al_personalization_get_app_id
GO
CREATE PROCEDURE dbo.al_personalization_get_app_id (
    @in_application_name NVARCHAR(256),
    @in_application_id UNIQUEIDENTIFIER OUT)
AS
BEGIN
    SELECT @in_application_id = application_id FROM dbo.al_applications WHERE LOWER(@in_application_name) = lowered_application_name
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_alluser_get_page_settings') AND (type = 'P')))
DROP PROCEDURE dbo.al_alluser_get_page_settings
GO
CREATE PROCEDURE dbo.al_alluser_get_page_settings (
    @in_application_name  NVARCHAR(256),
    @in_path              NVARCHAR(256))
AS
BEGIN
    DECLARE @application_id UNIQUEIDENTIFIER
    DECLARE @path_id UNIQUEIDENTIFIER

    SELECT @application_id = NULL
    SELECT @path_id = NULL

    EXEC dbo.al_personalization_get_app_id @in_application_name, @application_id OUTPUT
    IF (@application_id IS NULL)
    BEGIN
        RETURN
    END

    SELECT @path_id = u.path_id FROM dbo.al_paths u WHERE u.application_id = @application_id AND u.lowered_path = LOWER(@in_path)
    IF (@path_id IS NULL)
    BEGIN
        RETURN
    END

    SELECT p.page_settings FROM dbo.al_personalization_all_users p WHERE p.path_id = @path_id
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_alluser_reset_page_settings') AND (type = 'P')))
DROP PROCEDURE dbo.al_alluser_reset_page_settings
GO
CREATE PROCEDURE dbo.al_alluser_reset_page_settings (
    @in_application_name  NVARCHAR(256),
    @in_path              NVARCHAR(256))
AS
BEGIN
    DECLARE @application_id UNIQUEIDENTIFIER
    DECLARE @path_id UNIQUEIDENTIFIER

    SELECT @application_id = NULL
    SELECT @path_id = NULL

    EXEC dbo.al_personalization_get_app_id @in_application_name, @application_id OUTPUT
    IF (@application_id IS NULL)
    BEGIN
        RETURN
    END

    SELECT @path_id = u.path_id FROM dbo.al_paths u WHERE u.application_id = @application_id AND u.lowered_path = LOWER(@in_path)
    IF (@path_id IS NULL)
    BEGIN
        RETURN
    END

    DELETE FROM dbo.al_personalization_all_users WHERE path_id = @path_id
    RETURN 0
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_alluser_set_page_settings') AND (type = 'P')))
DROP PROCEDURE dbo.al_alluser_set_page_settings
GO
CREATE PROCEDURE dbo.al_alluser_set_page_settings (
    @in_application_name  NVARCHAR(256),
    @in_path             NVARCHAR(256),
    @in_page_settings     IMAGE,
    @in_current_time_utc   DATETIME)
AS
BEGIN
    DECLARE @application_id UNIQUEIDENTIFIER
    DECLARE @path_id UNIQUEIDENTIFIER

    SELECT @application_id = NULL
    SELECT @path_id = NULL

    EXEC dbo.al_applications_create @in_application_name, @application_id OUTPUT

    SELECT @path_id = u.path_id FROM dbo.al_paths u WHERE u.application_id = @application_id AND u.lowered_path = LOWER(@in_path)
    IF (@path_id IS NULL)
    BEGIN
        EXEC dbo.al_paths_create_path @application_id, @in_path, @path_id OUTPUT
    END

    IF (EXISTS(SELECT path_id FROM dbo.al_personalization_all_users WHERE path_id = @path_id))
        UPDATE dbo.al_personalization_all_users SET page_settings = @in_page_settings, last_updated_date = @in_current_time_utc WHERE path_id = @path_id
    ELSE
        INSERT INTO dbo.al_personalization_all_users(path_id, page_settings, last_updated_date) VALUES (@path_id, @in_page_settings, @in_current_time_utc)
    RETURN 0
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_peruser_get_page_settings') AND (type = 'P')))
DROP PROCEDURE dbo.al_peruser_get_page_settings
GO
CREATE PROCEDURE dbo.al_peruser_get_page_settings (
    @in_application_name  NVARCHAR(256),
    @in_user_id           NVARCHAR(256),
    @in_path             NVARCHAR(256),
    @in_current_time_utc   DATETIME)
AS
BEGIN
    DECLARE @application_id UNIQUEIDENTIFIER
    DECLARE @path_id UNIQUEIDENTIFIER

    SELECT @application_id = NULL
    SELECT @path_id = NULL

    EXEC dbo.al_personalization_get_app_id @in_application_name, @application_id OUTPUT
    IF (@application_id IS NULL)
    BEGIN
        RETURN
    END

    SELECT @path_id = u.path_id FROM dbo.al_paths u WHERE u.application_id = @application_id AND u.lowered_path = LOWER(@in_path)
    IF (@path_id IS NULL)
    BEGIN
        RETURN
    END


    SELECT p.page_settings FROM dbo.al_personalization_per_user p WHERE p.path_id = @path_id AND p.user_id = @in_user_id
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_peruser_reset_page_settings') AND (type = 'P')))
DROP PROCEDURE dbo.al_peruser_reset_page_settings
GO
CREATE PROCEDURE dbo.al_peruser_reset_page_settings (
    @in_application_name  NVARCHAR(256),
    @in_user_id           NVARCHAR(256),
    @in_path             NVARCHAR(256),
    @in_current_time_utc   DATETIME)
AS
BEGIN
    DECLARE @application_id UNIQUEIDENTIFIER
    DECLARE @path_id UNIQUEIDENTIFIER

    SELECT @application_id = NULL
    SELECT @path_id = NULL

    EXEC dbo.al_personalization_get_app_id @in_application_name, @application_id OUTPUT
    IF (@application_id IS NULL)
    BEGIN
        RETURN
    END

    SELECT @path_id = u.path_id FROM dbo.al_paths u WHERE u.application_id = @application_id AND u.lowered_path = LOWER(@in_path)
    IF (@path_id IS NULL)
    BEGIN
        RETURN
    END


    DELETE FROM dbo.al_personalization_per_user WHERE path_id = @path_id AND user_id = @in_user_id
    RETURN 0
END
GO


IF (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_peruser_set_page_settings') AND (type = 'P')))
DROP PROCEDURE dbo.al_peruser_set_page_settings
GO
CREATE PROCEDURE dbo.al_peruser_set_page_settings (
    @in_application_name  NVARCHAR(256),
    @in_user_id           NVARCHAR(256),
    @in_path             NVARCHAR(256),
    @in_page_settings     IMAGE,
    @in_current_time_utc   DATETIME)
AS
BEGIN
    DECLARE @application_id UNIQUEIDENTIFIER
    DECLARE @path_id UNIQUEIDENTIFIER

    SELECT @application_id = NULL
    SELECT @path_id = NULL

    EXEC dbo.al_applications_create @in_application_name, @application_id OUTPUT

    SELECT @path_id = u.path_id FROM dbo.al_paths u WHERE u.application_id = @application_id AND u.lowered_path = LOWER(@in_path)
    IF (@path_id IS NULL)
    BEGIN
        EXEC dbo.al_paths_create_path @application_id, @in_path, @path_id OUTPUT
    END


    IF (EXISTS(SELECT path_id FROM dbo.al_personalization_per_user WHERE user_id = @in_user_id AND path_id = @path_id))
        UPDATE dbo.al_personalization_per_user SET page_settings = @in_page_settings, last_updated_date = @in_current_time_utc WHERE user_id = @in_user_id AND path_id = @path_id
    ELSE
        INSERT INTO dbo.al_personalization_per_user(user_id, path_id, page_settings, last_updated_date) VALUES (@in_user_id, @path_id, @in_page_settings, @in_current_time_utc)
    RETURN 0
END
GO


/***** Create al_report_def table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_report_def') AND (type = 'U')))
BEGIN

CREATE TABLE [dbo].al_report_def(
	[report_id] [int] NOT NULL,
	[name] [nvarchar] (255) COLLATE !!insensitive NOT NULL,
	[path] [nvarchar] (500) COLLATE !!insensitive NOT NULL,
	[height] [int] NULL,
	[width] [int] NULL,
 CONSTRAINT [PK_al_report_def] PRIMARY KEY CLUSTERED 
 (
	[report_id] ASC
 )
) ON [PRIMARY]

CREATE  INDEX [al_al_report_def_index_1] ON [dbo].[al_report_def]([name]) ON [PRIMARY]

END
GO


/***** Create al_link_webpart_report table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_link_webpart_report') AND (type = 'U')))
BEGIN

CREATE TABLE [dbo].al_link_webpart_report (	
    [webpart_id] [int] NOT NULL,
	[report_id] [int] NOT NULL,
 CONSTRAINT [PK_al_link_webpart_report] PRIMARY KEY CLUSTERED 
 (
	[webpart_id] ASC,
	[report_id] ASC
 )
) ON [PRIMARY]

ALTER TABLE [dbo].[al_link_webpart_report] ADD                
 CONSTRAINT [FK_al_link_webpart_report_01] FOREIGN KEY 
 (
	[webpart_id]
 ) 
 REFERENCES [dbo].[al_webpart_def] 
 (
	[webpart_id]
 ),
 CONSTRAINT [FK_al_link_webpart_report_02] FOREIGN KEY 
 (
	[report_id]
 ) 
 REFERENCES [dbo].[al_report_def] 
 (
	[report_id]
 )
 
END
GO


/***** Create al_link_ca_arg_crncy table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_link_ca_arg_crncy') AND (type = 'U')))
BEGIN

CREATE TABLE [dbo].[al_link_ca_arg_crncy](
	[dlkey] [smallint] NOT NULL,
	[currency_type_code] [varchar](3) COLLATE !!sensitive NOT NULL,
	[creation_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)));

ALTER TABLE [dbo].[al_link_ca_arg_crncy] ADD 
	CONSTRAINT PK_al_link_ca_arg_crncy PRIMARY KEY CLUSTERED
		(dlkey, currency_type_code);

ALTER TABLE [dbo].[al_link_ca_arg_crncy] ADD 
	CONSTRAINT
	[al_link_ca_arg_crncy_fk01] FOREIGN KEY
	(
		[currency_type_code]
	) REFERENCES [dbo].[ca_currency_type]
	(
		[currency_type_code]
	)
END
GO


/***** Create al_purchase_cost_type table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_purchase_cost_type') AND (type = 'U')))
BEGIN

CREATE TABLE [dbo].[al_purchase_cost_type](
	[id] [int] NOT NULL,
	[value] [nvarchar](50) COLLATE !!insensitive NOT NULL,
	[creation_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
CONSTRAINT
	[PK_al_purchase_cost_type] PRIMARY KEY CLUSTERED 
(
	[id]
) ON [PRIMARY]
)

END
GO


/***** Create al_usm_request_item_status table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_usm_request_item_status') AND (type = 'U')))
BEGIN

CREATE TABLE [dbo].[al_usm_request_item_status] (
	[id] [int] NOT NULL,
	[status_id] [int] NOT NULL,
	[description] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[creation_date] [int] NULL,
	[last_update_user] [nvarchar](255) COLLATE !!insensitive NULL,
	[last_update_date] [int] NULL,
	[version_number] [int] NULL DEFAULT ((0)),
 CONSTRAINT
	[PK_al_usm_request_item_status] PRIMARY KEY CLUSTERED 
 (
	[id]
 )
) ON [PRIMARY]	

END
GO


/***** Create al_purchattachs trigger *****/
CREATE TRIGGER [al_purchattachs] ON [dbo].[al_link_purchs_ordr_attachmt]
INSTEAD OF DELETE
AS
BEGIN

	-- delete linked record
	DELETE al_link_purchs_ordr_attachmt
	FROM al_link_purchs_ordr_attachmt f
	INNER JOIN deleted d ON f.amid = d.amid
	AND f.purchase_order_id = d.purchase_order_id

	-- delete sibling record
	DELETE al_attachmt
	FROM al_attachmt f
	INNER JOIN deleted d ON f.amid = d.amid
END
GO

/***** Create al_prchordr_totscalc_tri *****/
CREATE TRIGGER al_prchordr_totscalc_tri ON al_purchase_order_item
AFTER INSERT
AS
BEGIN
      DECLARE @total_amount float
      DECLARE @total_tax_amount float
      DECLARE @sub_total_amount float
      DECLARE @purchaseorderid float
 
      SELECT
      @purchaseorderid = purchase_order_id
      FROM inserted
      
      SELECT      @total_tax_amount = SUM(item_tax),
            @sub_total_amount = SUM(item_total_amount) - SUM(item_tax),
            @total_amount = SUM(item_total_amount) 
      FROM al_purchase_order_item
      WHERE purchase_order_id = @purchaseorderid
 
      UPDATE      al_purchase_order
      SET   total_tax_amount = @total_tax_amount,
            sub_total_amount = @sub_total_amount,
            total_amount = @total_amount
      WHERE       purchase_order_id = @purchaseorderid
      
END
GO
 
/***** Create al_prchordr_totscalc_trd *****/
CREATE TRIGGER al_prchordr_totscalc_trd ON al_purchase_order_item
AFTER UPDATE, DELETE
AS
BEGIN
      DECLARE @total_amount float
      DECLARE @total_tax_amount float
      DECLARE @sub_total_amount float
      DECLARE @purchaseorderid float
 
      SELECT
      @purchaseorderid = purchase_order_id
      FROM deleted
      
      SELECT      @total_tax_amount = SUM(item_tax),
            @sub_total_amount = SUM(item_total_amount) - SUM(item_tax),
            @total_amount = SUM(item_total_amount) 
      FROM al_purchase_order_item
      WHERE purchase_order_id = @purchaseorderid
 
      UPDATE      al_purchase_order
      SET   total_tax_amount = @total_tax_amount,
            sub_total_amount = @sub_total_amount,
            total_amount = @total_amount
      WHERE       purchase_order_id = @purchaseorderid
      
END
GO

/***** Create al_db_scripts table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_db_scripts') AND (type = 'U')))
BEGIN

CREATE TABLE dbo.al_db_scripts(
            script_id int NOT NULL,
            script_name nvarchar(255) NOT NULL,
            script_type int NOT NULL,
            description nvarchar(255) NULL,
            creation_date int NULL,
            creation_user nvarchar(50) NULL,
            last_update_date int NULL,
            last_update_user nvarchar(50) NULL,
            version_number int NOT NULL DEFAULT 0,
            app_filter int NOT NULL
 CONSTRAINT al_db_scripts_pk01 PRIMARY KEY CLUSTERED 
(
            script_id ASC
) 
) ON [PRIMARY]

END
GO

CREATE  UNIQUE  INDEX al_db_scripts_idx01 ON dbo.al_db_scripts(script_name) ON [PRIMARY]
GO

/***** Create al_db_version table *****/
IF NOT (EXISTS (SELECT name FROM sysobjects WHERE (name = N'al_db_version') AND (type = 'U')))
BEGIN

CREATE TABLE dbo.al_db_version(
            product_code int NOT NULL,
            struct_major_ver int NULL,
            struct_minor_ver int NULL,
            struct_rev_ver int NULL,
            struct_build_ver int NULL,
            meta_major_ver int NULL,
            meta_minor_ver int NULL,
            meta_rev_ver int NULL,
            meta_build_ver int NULL
 CONSTRAINT al_db_version_pk01 PRIMARY KEY CLUSTERED 
(
            product_code ASC
) 
) ON [PRIMARY]

END
GO

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                               	*/
/*                                                                                      */
/****************************************************************************************/
insert into mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 values ( 16514609, getdate(), 1, 4, 'Star 16514609 (MODIFIED v2) UAPM r11.3.4 support and SWCM common functionality' )
GO

COMMIT TRANSACTION 
GO

