SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;

/****************************************************************************************/
/*                                                                                      */
/* Star 14813935 USD: Add t_ci_cr_prptpl, t_ci_sapolicy, t_ci_saprobtyp, t_ci_tspan, t_ci_prptpl triggers	*/
/*                                                                                      */
/****************************************************************************************/

/*******************************************/
/*******************************************/
/* Req_Property_Template */
/*******************************************/
/*******************************************/
CREATE OR REPLACE TRIGGER t_ci_cr_prptpl
BEFORE INSERT OR UPDATE ON MDBADMIN.cr_prptpl
FOR EACH ROW

/*  declare variables  */
DECLARE
	i INTEGER;   /*  integer to check for existence of duplicate index values  */

	/*  changing fields that are not part of the index causes a mutating table error (ORA-4091)  */
	/*  created an exception variable and initialized it to -4091 to trap and igonore the error  */
	mutating_table EXCEPTION;
	PRAGMA EXCEPTION_INIT (mutating_table, -4091);

/*  main logic  */
BEGIN

	/*  check for duplicate index values in the table  */
	SELECT COUNT(*) INTO i FROM MDBADMIN.cr_prptpl
		 WHERE NLS_UPPER(code) = NLS_UPPER(:new.code);

	/*  if duplicates found, raise error  */
	IF i > 0 THEN
		RAISE DUP_VAL_ON_INDEX;
	END IF;

/*  exception handler  */
EXCEPTION

	/*  Duplicate Error - raise error to calling application  */
	WHEN DUP_VAL_ON_INDEX THEN
		RAISE DUP_VAL_ON_INDEX;

	/*  Mutating Table Error - ignore  */
	WHEN mutating_table THEN
		i:= 0;

END;
/

/*******************************************/
/*******************************************/
/* SA_Policy */
/*******************************************/
/*******************************************/
CREATE OR REPLACE TRIGGER t_ci_sapolicy
BEFORE INSERT OR UPDATE ON MDBADMIN.sapolicy
FOR EACH ROW

/*  declare variables  */
DECLARE
	i INTEGER;   /*  integer to check for existence of duplicate index values  */

	/*  changing fields that are not part of the index causes a mutating table error (ORA-4091)  */
	/*  created an exception variable and initialized it to -4091 to trap and igonore the error  */
	mutating_table EXCEPTION;
	PRAGMA EXCEPTION_INIT (mutating_table, -4091);

/*  main logic  */
BEGIN

	/*  check for duplicate index values in the table  */
	SELECT COUNT(*) INTO i FROM MDBADMIN.sapolicy
		 WHERE NLS_UPPER(code) = NLS_UPPER(:new.code);

	/*  if duplicates found, raise error  */
	IF i > 0 THEN
		RAISE DUP_VAL_ON_INDEX;
	END IF;

/*  exception handler  */
EXCEPTION

	/*  Duplicate Error - raise error to calling application  */
	WHEN DUP_VAL_ON_INDEX THEN
		RAISE DUP_VAL_ON_INDEX;

	/*  Mutating Table Error - ignore  */
	WHEN mutating_table THEN
		i:= 0;

END;
/

/*******************************************/
/*******************************************/
/* SA_Prob_Type */
/*******************************************/
/*******************************************/
CREATE OR REPLACE TRIGGER t_ci_saprobtyp
BEFORE INSERT OR UPDATE ON MDBADMIN.saprobtyp
FOR EACH ROW

/*  declare variables  */
DECLARE
	i INTEGER;   /*  integer to check for existence of duplicate index values  */

	/*  changing fields that are not part of the index causes a mutating table error (ORA-4091)  */
	/*  created an exception variable and initialized it to -4091 to trap and igonore the error  */
	mutating_table EXCEPTION;
	PRAGMA EXCEPTION_INIT (mutating_table, -4091);

/*  main logic  */
BEGIN

	/*  check for duplicate index values in the table  */
	SELECT COUNT(*) INTO i FROM MDBADMIN.saprobtyp
		 WHERE NLS_UPPER(code) = NLS_UPPER(:new.code);

	/*  if duplicates found, raise error  */
	IF i > 0 THEN
		RAISE DUP_VAL_ON_INDEX;
	END IF;

/*  exception handler  */
EXCEPTION

	/*  Duplicate Error - raise error to calling application  */
	WHEN DUP_VAL_ON_INDEX THEN
		RAISE DUP_VAL_ON_INDEX;

	/*  Mutating Table Error - ignore  */
	WHEN mutating_table THEN
		i:= 0;

END;
/

/*******************************************/
/*******************************************/
/* Timespan */
/*******************************************/
/*******************************************/
CREATE OR REPLACE TRIGGER t_ci_tspan
BEFORE INSERT OR UPDATE ON MDBADMIN.tspan
FOR EACH ROW

/*  declare variables  */
DECLARE
	i INTEGER;   /*  integer to check for existence of duplicate index values  */

	/*  changing fields that are not part of the index causes a mutating table error (ORA-4091)  */
	/*  created an exception variable and initialized it to -4091 to trap and igonore the error  */
	mutating_table EXCEPTION;
	PRAGMA EXCEPTION_INIT (mutating_table, -4091);

/*  main logic  */
BEGIN

	/*  check for duplicate index values in the table  */
	SELECT COUNT(*) INTO i FROM MDBADMIN.tspan
		 WHERE NLS_UPPER(code) = NLS_UPPER(:new.code);

	/*  if duplicates found, raise error  */
	IF i > 0 THEN
		RAISE DUP_VAL_ON_INDEX;
	END IF;

/*  exception handler  */
EXCEPTION

	/*  Duplicate Error - raise error to calling application  */
	WHEN DUP_VAL_ON_INDEX THEN
		RAISE DUP_VAL_ON_INDEX;

	/*  Mutating Table Error - ignore  */
	WHEN mutating_table THEN
		i:= 0;

END;
/

/*******************************************/
/*******************************************/
/* Property_Template */
/*******************************************/
/*******************************************/
CREATE OR REPLACE TRIGGER t_ci_prptpl
BEFORE INSERT OR UPDATE ON MDBADMIN.prptpl
FOR EACH ROW

/*  declare variables  */
DECLARE
	i INTEGER;   /*  integer to check for existence of duplicate index values  */

	/*  changing fields that are not part of the index causes a mutating table error (ORA-4091)  */
	/*  created an exception variable and initialized it to -4091 to trap and igonore the error  */
	mutating_table EXCEPTION;
	PRAGMA EXCEPTION_INIT (mutating_table, -4091);

/*  main logic  */
BEGIN

	/*  check for duplicate index values in the table  */
	SELECT COUNT(*) INTO i FROM MDBADMIN.prptpl
		 WHERE NLS_UPPER(code) = NLS_UPPER(:new.code);

	/*  if duplicates found, raise error  */
	IF i > 0 THEN
		RAISE DUP_VAL_ON_INDEX;
	END IF;

/*  exception handler  */
EXCEPTION

	/*  Duplicate Error - raise error to calling application  */
	WHEN DUP_VAL_ON_INDEX THEN
		RAISE DUP_VAL_ON_INDEX;

	/*  Mutating Table Error - ignore  */
	WHEN mutating_table THEN
		i:= 0;

END;
/

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 14813935, systimestamp, 1, 4, 'Star 14813935 USD: Add t_ci_cr_prptpl, t_ci_sapolicy, t_ci_saprobtyp, t_ci_tspan, t_ci_prptpl triggers' );

COMMIT;

EXIT SUCCESS;
