SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 15395750 : CMDB : multiple data sourcing and Oracle support			*/
/*                                                                                      */
/****************************************************************************************/

CREATE TABLE ci_mdr_provider (
    id NUMBER NOT NULL,
    del NUMBER NOT NULL, 
    description NVARCHAR2(255) NULL, 
    hostname NVARCHAR2(255) NULL,
    mdr_class NVARCHAR2(50)  NULL,
    mdr_name NVARCHAR2(50) NOT NULL,
    name NVARCHAR2(16) NOT NULL, 
    owner RAW(16) NULL,
    password NVARCHAR2(255) NULL,
    encryptiontype NVARCHAR2(12) NULL,
    encryptedpassword NVARCHAR2(255) NULL,
    path NVARCHAR2(255) NULL,
    parameters NVARCHAR2(255) NULL,
    port NUMBER NULL,
    launchurl NVARCHAR2(255) NULL,
    last_mod_dt NUMBER NULL,
    last_mod_by RAW(16) NULL, 
    userid NVARCHAR2(100) NULL,
    persid NVARCHAR2(30) NULL
  );

ALTER TABLE ci_mdr_provider ADD PRIMARY KEY ( id ); 

CREATE  INDEX ci_mdr_provider_X0 ON ci_mdr_provider(mdr_name ASC) tablespace &2;
CREATE  INDEX ci_mdr_provider_X1 ON ci_mdr_provider(mdr_class ASC) tablespace &2;

CREATE TABLE ci_mdr_idmap (
    id NUMBER NOT NULL,
    federated_asset_id NVARCHAR2(255) NULL,
    mdr_provider_id NUMBER NOT NULL, 
    cmdb_asset_id RAW(16) NULL, 
    last_mod_dt NUMBER NULL,
    last_mod_by RAW(16) NULL,
    del NUMBER NOT NULL, 
    persid NVARCHAR2(30) NULL
);

ALTER TABLE ci_mdr_idmap ADD PRIMARY KEY ( id ); 

CREATE  INDEX ci_mdr_idmap_X0 ON ci_mdr_idmap(mdr_provider_id ASC) tablespace &2;
CREATE  INDEX ci_mdr_idmap_X1 ON ci_mdr_idmap(federated_asset_id ASC) tablespace &2;
CREATE  INDEX ci_mdr_idmap_X2 ON ci_mdr_idmap(cmdb_asset_id ASC) tablespace &2;

ALTER TABLE busmgt ADD ci_rel_type NUMBER NULL;

CREATE  INDEX busmgt_X3 ON busmgt(ci_rel_type ASC) tablespace &2;

CREATE TABLE ci_app_ext (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30) NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	app_id NVARCHAR2(50) NULL ,
	portfolio NVARCHAR2(50) NULL ,
	environment NVARCHAR2(255) NULL ,
	inhouse_or_vendor NVARCHAR2(15) NULL ,
	category NVARCHAR2(50) NULL ,
	type NVARCHAR2(50) NULL ,
	status NVARCHAR2(15) NULL ,
	version NVARCHAR2(255) NULL ,
	server NVARCHAR2(255) NULL ,
	install_dir NVARCHAR2(255) NULL ,
	main_process NVARCHAR2(255) NULL ,
	storage_used NVARCHAR2(15) NULL ,
	uptime NUMBER NULL ,
	response_time NUMBER NULL ,
	highly_avail NVARCHAR2(50) NULL ,
	highavail_appl_resources NVARCHAR2(255) NULL ,
	date_installed NUMBER NULL ,
	support_type NVARCHAR2(255)  NULL ,
	support_start_date NUMBER NULL ,
	support_end_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_start_date NUMBER NULL ,
	lease_end_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_app_ext ADD 
	 PRIMARY KEY
	(
		id
	) ; 

CREATE TABLE ci_app_inhouse (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	app_id NVARCHAR2(50)  NULL ,
	portfolio NVARCHAR2(50)  NULL ,
	environment NVARCHAR2(200)  NULL ,
	inhouse_or_vendor NVARCHAR2(15)  NULL ,
	category NVARCHAR2(50)  NULL ,
	type NVARCHAR2(50)  NULL ,
	status NVARCHAR2(15)  NULL ,
	version NVARCHAR2(15)  NULL ,
	server NVARCHAR2(50)  NULL ,
	install_dir NVARCHAR2(100)  NULL ,
	main_process NVARCHAR2(50)  NULL ,
	storage_used NVARCHAR2(15)  NULL ,
	uptime NUMBER NULL ,
	response_time NUMBER NULL ,
	highly_avail NVARCHAR2(50)  NULL ,
	highavail_appl_resources NVARCHAR2(50)  NULL ,
	date_installed NUMBER NULL ,
	support_type NVARCHAR2(50)  NULL ,
	support_start_date NUMBER NULL ,
	support_end_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL 
);

ALTER TABLE ci_app_inhouse ADD 
	 PRIMARY KEY
	(
		id
	) ; 

CREATE TABLE ci_contract (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	proj_code NVARCHAR2(50)  NULL ,
	con_num NVARCHAR2(50)  NULL ,
	con_ref NVARCHAR2(50)  NULL ,
	con_status NVARCHAR2(50)  NULL ,
	con_type NVARCHAR2(50)  NULL ,
	con_start_date NUMBER NULL ,
	con_end_date NUMBER NULL ,
	con_renewal_date NUMBER NULL ,
	con_comments NVARCHAR2(200)  NULL 
);

ALTER TABLE ci_contract ADD 
	 PRIMARY KEY
	(
		id
	) ; 

CREATE TABLE ci_database (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	db_id NVARCHAR2(50)  NULL ,
	portfolio NVARCHAR2(50)  NULL ,
	environment NVARCHAR2(50)  NULL ,
	type NVARCHAR2(50)  NULL ,
	status NVARCHAR2(50)  NULL ,
	version NVARCHAR2(50)  NULL ,
	support_type NVARCHAR2(50)  NULL ,
	support_start_date NUMBER NULL ,
	support_end_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(50)  NULL ,
	proj_code NVARCHAR2(50)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_start_date NUMBER NULL ,
	lease_end_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NUMBER NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(50)  NULL ,
	maintenance_period NVARCHAR2(50)  NULL ,
	mtce_contract_number NVARCHAR2(50)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_database ADD 
	 PRIMARY KEY
	(
		id
	) ; 

CREATE TABLE ci_document (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	doc_id NVARCHAR2(50)  NULL ,
	doc_category NVARCHAR2(50)  NULL ,
	doc_type NVARCHAR2(50)  NULL ,
	doc_status NVARCHAR2(50)  NULL ,
	doc_version NVARCHAR2(15)  NULL ,
	doc_start_date NUMBER NULL ,
	doc_end_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL 
);

ALTER TABLE ci_document ADD 
	 PRIMARY KEY
	(
		id
	) ; 

CREATE TABLE ci_eligible_child (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	del NUMBER NOT NULL ,
	rel_id NUMBER NOT NULL ,
	fam_id NUMBER NULL ,
	class_id NUMBER NULL ,
	sym NVARCHAR2(50)  NULL 
);

ALTER TABLE ci_eligible_child ADD 
	 PRIMARY KEY
	(
		id
	) ; 

CREATE TABLE ci_eligible_parent (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	del NUMBER NOT NULL ,
	rel_id NUMBER NOT NULL ,
	fam_id NUMBER NULL ,
	class_id NUMBER NULL ,
	sym NVARCHAR2(50)  NULL 
);

ALTER TABLE ci_eligible_parent ADD 
	 PRIMARY KEY
	(
		id
	) ; 

CREATE TABLE ci_fac_ac (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_start_date NUMBER NULL ,
	lease_end_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_fac_ac ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_fac_fire_control (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_start_date NUMBER NULL ,
	lease_end_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_fac_fire_control ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_fac_furnishings (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	warehouse_loc NVARCHAR2(50)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_start_date NUMBER NULL ,
	lease_end_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_fac_furnishings ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_fac_other (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	warehouse_loc NVARCHAR2(50)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_start_date NUMBER NULL ,
	lease_end_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_fac_other ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_fac_ups (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	warehouse_loc NVARCHAR2(50)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_start_date NUMBER NULL ,
	lease_end_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_fac_ups ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_lpar (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	phys_mem NVARCHAR2(15)  NULL ,
	mem_capacity NVARCHAR2(15)  NULL ,
	hard_drive_capacity NVARCHAR2(15)  NULL ,
	proc_type NVARCHAR2(15)  NULL ,
	proc_spd NVARCHAR2(15)  NULL ,
	disk_type NVARCHAR2(15)  NULL ,
	number_mips NVARCHAR2(15)  NULL ,
	profile NVARCHAR2(15)  NULL ,
	max_processors NUMBER NULL ,
	min_processors NUMBER NULL ,
	desired_processors NUMBER NULL ,
	max_memory NVARCHAR2(15)  NULL ,
	min_memory NVARCHAR2(15)  NULL ,
	desired_memory NVARCHAR2(15)  NULL ,
	panel_display NVARCHAR2(15)  NULL ,
	current_memory NVARCHAR2(15)  NULL ,
	current_processors NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_lpar ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_mainframe (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	phys_mem NVARCHAR2(15)  NULL ,
	mem_capacity NVARCHAR2(15)  NULL ,
	hard_drive_capacity NVARCHAR2(15)  NULL ,
	proc_type NVARCHAR2(15)  NULL ,
	proc_spd NVARCHAR2(15)  NULL ,
	disk_type NVARCHAR2(15)  NULL ,
	num_mips NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NUMBER NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(50)  NULL ,
	maintenance_period NVARCHAR2(50)  NULL ,
	mtce_contract_number NVARCHAR2(50)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_mainframe ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_monitor (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_monitor ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_other (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	phys_mem NVARCHAR2(15)  NULL ,
	mem_capacity NVARCHAR2(15)  NULL ,
	hard_drive_capacity NVARCHAR2(15)  NULL ,
	proc_type NVARCHAR2(15)  NULL ,
	proc_spd NVARCHAR2(15)  NULL ,
	disk_type NVARCHAR2(15)  NULL ,
	media_type NVARCHAR2(15)  NULL ,
	media_drive_num NVARCHAR2(15)  NULL ,
	total_capacity NVARCHAR2(15)  NULL ,
	used_space NVARCHAR2(15)  NULL ,
	array_name NVARCHAR2(50)  NULL ,
	array_serial_num NVARCHAR2(50)  NULL ,
	cd_rom_type NVARCHAR2(15)  NULL ,
	graphics_card NVARCHAR2(50)  NULL ,
	scsi_card NVARCHAR2(50)  NULL ,
	modem_type NVARCHAR2(15)  NULL ,
	modem_card NVARCHAR2(15)  NULL ,
	net_card NVARCHAR2(15)  NULL ,
	monitor NVARCHAR2(15)  NULL ,
	printer NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_slot_proc NUMBER NULL ,
	number_proc_inst NUMBER NULL ,
	mem_cache_proc NVARCHAR2(15)  NULL ,
	slot_total_mem NVARCHAR2(15)  NULL ,
	slot_mem_used NVARCHAR2(15)  NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	number_mips NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	supervision_mode NVARCHAR2(15)  NULL ,
	server_type NVARCHAR2(15)  NULL ,
	processor_count NUMBER NULL ,
	swap_size NVARCHAR2(15)  NULL ,
	security_patch_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_other ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_printer (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_printer ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_server (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	phys_mem NVARCHAR2(15)  NULL ,
	mem_capacity NVARCHAR2(15)  NULL ,
	hard_drive_capacity NVARCHAR2(15)  NULL ,
	proc_type NVARCHAR2(255)  NULL ,
	proc_speed NVARCHAR2(15)  NULL ,
	disk_type NVARCHAR2(255)  NULL ,
	cd_rom_type NVARCHAR2(255)  NULL ,
	net_card NVARCHAR2(255)  NULL ,
	monitor NVARCHAR2(255)  NULL ,
	printer NVARCHAR2(255)  NULL ,
	technology NVARCHAR2(255)  NULL ,
	number_slot_proc NUMBER NULL ,
	number_proc_inst NUMBER NULL ,
	mem_cache_proc NVARCHAR2(15)  NULL ,
	slot_total_mem NVARCHAR2(15)  NULL ,
	slot_mem_used NVARCHAR2(15)  NULL ,
	type_net_conn NVARCHAR2(255)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	number_mips NVARCHAR2(15)  NULL ,
	role NVARCHAR2(255)  NULL ,
	supervision_mode NVARCHAR2(255)  NULL ,
	server_type NVARCHAR2(255)  NULL ,
	processor_count NUMBER NULL ,
	swap_size NVARCHAR2(15)  NULL ,
	security_patch_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_server ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_storage (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	disk_type NVARCHAR2(255)  NULL ,
	media_type NVARCHAR2(255)  NULL ,
	media_drive_num NVARCHAR2(15)  NULL ,
	total_capacity NVARCHAR2(15)  NULL ,
	used_space NVARCHAR2(15)  NULL ,
	array_name NVARCHAR2(50)  NULL ,
	array_serial_num NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_storage ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_virtual (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	phys_mem NVARCHAR2(15)  NULL ,
	mem_capacity NVARCHAR2(15)  NULL ,
	hard_drive_capacity NVARCHAR2(15)  NULL ,
	proc_type NVARCHAR2(15)  NULL ,
	proc_speed NVARCHAR2(15)  NULL ,
	disk_type NVARCHAR2(15)  NULL ,
	media_type NVARCHAR2(15)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	number_mips NVARCHAR2(15)  NULL ,
	security_patch_level NVARCHAR2(50)  NULL ,
	virtual_processors NUMBER NULL ,
	processor_affinity NVARCHAR2(15)  NULL ,
	cpu_shares NVARCHAR2(15)  NULL ,
	memory_shares NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_virtual ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_hardware_workstation (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	phys_mem NVARCHAR2(15)  NULL ,
	mem_capacity NVARCHAR2(15)  NULL ,
	hard_drive_capacity NVARCHAR2(15)  NULL ,
	proc_type NVARCHAR2(15)  NULL ,
	proc_speed NVARCHAR2(15)  NULL ,
	disk_type NVARCHAR2(15)  NULL ,
	cd_rom_type NVARCHAR2(15)  NULL ,
	graphics_card NVARCHAR2(50)  NULL ,
	scsi_card NVARCHAR2(50)  NULL ,
	modem_type NVARCHAR2(15)  NULL ,
	modem_card NVARCHAR2(15)  NULL ,
	net_card NVARCHAR2(15)  NULL ,
	monitor NVARCHAR2(15)  NULL ,
	printer NVARCHAR2(50)  NULL ,
	number_slot_proc NUMBER NULL ,
	number_proc_inst NUMBER NULL ,
	slot_total_mem NVARCHAR2(15)  NULL ,
	slot_mem_used NVARCHAR2(15)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	processor_count NUMBER NULL ,
	security_patch_level NVARCHAR2(50)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_hardware_workstation ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_bridge (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_bridge ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_cluster (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	channel_address NVARCHAR2(15)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	virtual_ip NVARCHAR2(15)  NULL ,
	quorum NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	security_patch_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_cluster ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_controller (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(255)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	number_mips NVARCHAR2(15)  NULL ,
	number_smips NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_controller ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_frontend (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	number_mips NVARCHAR2(15)  NULL ,
	number_smips NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_frontend ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_gateway (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_gateway ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_hub (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_hub ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_nic (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(255)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	line_type NVARCHAR2(15)  NULL ,
	line_speed NVARCHAR2(15)  NULL ,
	protocol NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL 
);

ALTER TABLE ci_network_nic ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_other (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	bios_ver NVARCHAR2(50)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(50)  NULL ,
	proj_code NVARCHAR2(50)  NULL ,
	contract_number NVARCHAR2(50)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NUMBER NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(50)  NULL ,
	maintenance_period NVARCHAR2(50)  NULL ,
	mtce_contract_number NVARCHAR2(50)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_other ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_peripheral (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_peripheral ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_port (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	domain NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	line_type NVARCHAR2(15)  NULL ,
	line_speed NVARCHAR2(15)  NULL ,
	protocol NVARCHAR2(15)  NULL ,
	channel_address NVARCHAR2(15)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_port ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_resource (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	resource_group_type NVARCHAR2(15)  NULL ,
	resource_type NVARCHAR2(15)  NULL ,
	resource_file NVARCHAR2(15)  NULL ,
	resource_mount_point NVARCHAR2(50)  NULL ,
	resource_disk NVARCHAR2(15)  NULL 
);

ALTER TABLE ci_network_resource ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_resource_group (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	resource_group_type NVARCHAR2(15)  NULL 
);

ALTER TABLE ci_network_resource_group ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_router (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	rout_prot NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	flow NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	modem_type NVARCHAR2(15)  NULL ,
	modem_card NVARCHAR2(15)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	number_proc_inst NUMBER NULL ,
	mem_cache_proc NVARCHAR2(15)  NULL ,
	slot_total_mem NVARCHAR2(15)  NULL ,
	slot_mem_used NVARCHAR2(15)  NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	processor_count NUMBER NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	protocol NVARCHAR2(15)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_router ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_network_server (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	rout_prot NVARCHAR2(50)  NULL ,
	addr_class NVARCHAR2(50)  NULL ,
	flow NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	graphics_card NVARCHAR2(50)  NULL ,
	scsi_card NVARCHAR2(50)  NULL ,
	modem_type NVARCHAR2(15)  NULL ,
	modem_card NVARCHAR2(15)  NULL ,
	net_card NVARCHAR2(15)  NULL ,
	monitor NVARCHAR2(15)  NULL ,
	printer NVARCHAR2(50)  NULL ,
	technology NVARCHAR2(50)  NULL ,
	number_ports NUMBER NULL ,
	number_ports_used NUMBER NULL ,
	number_proc_inst NUMBER NULL ,
	mem_cache_proc NVARCHAR2(15)  NULL ,
	slot_total_mem NVARCHAR2(15)  NULL ,
	slot_mem_used NVARCHAR2(15)  NULL ,
	type_net_conn NVARCHAR2(15)  NULL ,
	number_net_port NVARCHAR2(15)  NULL ,
	number_net_port_conn NVARCHAR2(15)  NULL ,
	number_net_card NVARCHAR2(15)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	role NVARCHAR2(50)  NULL ,
	supervision_mode NVARCHAR2(15)  NULL ,
	server_type NVARCHAR2(15)  NULL ,
	processor_count NUMBER NULL ,
	swap_size NVARCHAR2(15)  NULL ,
	ip_mgmt_addr NVARCHAR2(50)  NULL ,
	usb_active_connections NVARCHAR2(15)  NULL ,
	protocol NVARCHAR2(15)  NULL ,
	channel_address NVARCHAR2(15)  NULL ,
	os_version NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	security_patch_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_network_server ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_operating_system (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	os_id NVARCHAR2(50)  NULL ,
	environment NVARCHAR2(50)  NULL ,
	type NVARCHAR2(50)  NULL ,
	status NVARCHAR2(15)  NULL ,
	version NVARCHAR2(15)  NULL ,
	date_installed NUMBER NULL ,
	support_type NVARCHAR2(50)  NULL ,
	support_start_date NUMBER NULL ,
	support_end_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_operating_system ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_rel_type (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	del NUMBER NOT NULL ,
	parenttochild NVARCHAR2(50)  NOT NULL ,
	childtoparent NVARCHAR2(50)  NOT NULL ,
	is_peer NUMBER NULL ,
	nx_desc NVARCHAR2(40)  NULL 
);

ALTER TABLE ci_rel_type ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_security (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	security_id NVARCHAR2(50)  NULL ,
	integrity_level NVARCHAR2(50)  NULL ,
	avail NVARCHAR2(50)  NULL ,
	confidentiality_level NVARCHAR2(50)  NULL ,
	appl NVARCHAR2(50)  NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL 
);

ALTER TABLE ci_security ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_service (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	service_id NVARCHAR2(50)  NULL ,
	portfolio NVARCHAR2(50)  NULL ,
	category NVARCHAR2(50)  NULL ,
	type NVARCHAR2(50)  NULL ,
	status NVARCHAR2(50)  NULL ,
	version NVARCHAR2(255)  NULL ,
	site NVARCHAR2(50)  NULL ,
	start_date NUMBER NULL ,
	end_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL 
);

ALTER TABLE ci_service ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_sla (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	sla_id NVARCHAR2(50)  NULL ,
	sla_category NVARCHAR2(50)  NULL ,
	sla_type NVARCHAR2(50)  NULL ,
	sla_status NVARCHAR2(50)  NULL ,
	sla_version NVARCHAR2(15)  NULL ,
	sla_date_active NUMBER NULL ,
	sla_start_date NUMBER NULL ,
	sla_end_date NUMBER NULL 
);

ALTER TABLE ci_sla ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_telcom_ciruit (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	carrier NVARCHAR2(15)  NULL ,
	circuit_number NVARCHAR2(15)  NULL ,
	circuit_type NVARCHAR2(15)  NULL ,
	server_id NVARCHAR2(50)  NULL ,
	bandwidth NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_telcom_ciruit ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_telcom_other (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	phone_number NVARCHAR2(50)  NULL ,
	carrier NVARCHAR2(15)  NULL ,
	circuit_number NVARCHAR2(15)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	domain NVARCHAR2(50)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	line_id NVARCHAR2(15)  NULL ,
	server_id NVARCHAR2(50)  NULL ,
	cpu_type NVARCHAR2(50)  NULL ,
	memory_available NVARCHAR2(15)  NULL ,
	memory_used NVARCHAR2(15)  NULL ,
	harddrive_capacity NVARCHAR2(15)  NULL ,
	harddrive_used NVARCHAR2(15)  NULL ,
	monitor NVARCHAR2(15)  NULL ,
	nic_card NVARCHAR2(15)  NULL ,
	bandwidth NVARCHAR2(15)  NULL ,
	frequency NVARCHAR2(15)  NULL ,
	license_number NVARCHAR2(50)  NULL ,
	license_expiration_date NUMBER NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_telcom_other ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_telcom_radio (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	domain NVARCHAR2(50)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	cpu_type NVARCHAR2(50)  NULL ,
	memory_available NVARCHAR2(15)  NULL ,
	memory_used NVARCHAR2(15)  NULL ,
	harddrive_capacity NVARCHAR2(15)  NULL ,
	harddrive_used NVARCHAR2(15)  NULL ,
	monitor NVARCHAR2(15)  NULL ,
	nic_card NVARCHAR2(15)  NULL ,
	bandwidth NVARCHAR2(15)  NULL ,
	frequency NVARCHAR2(15)  NULL ,
	license_number NVARCHAR2(50)  NULL ,
	license_expiration_date NUMBER NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_telcom_radio ADD 
	 PRIMARY KEY 
	(
		id
	) ; 
CREATE TABLE ci_telcom_voice (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	nci_network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	phone_number NVARCHAR2(50)  NULL ,
	main_extension NVARCHAR2(50)  NULL ,
	carrier NVARCHAR2(15)  NULL ,
	cpu_type NVARCHAR2(50)  NULL ,
	memory_available NVARCHAR2(15)  NULL ,
	memory_used NVARCHAR2(15)  NULL ,
	harddrive_capacity NVARCHAR2(15)  NULL ,
	harddrive_used NVARCHAR2(15)  NULL ,
	monitor NVARCHAR2(15)  NULL ,
	nic_card NVARCHAR2(15)  NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_telcom_voice ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE TABLE ci_telcom_wireless (
	id NUMBER NOT NULL ,
	persid NVARCHAR2(30)  NULL ,
	last_mod_dt NUMBER NULL ,
	last_mod_by RAW(16) NULL ,
	ext_asset RAW(16) NOT NULL ,
	network_name NVARCHAR2(50)  NULL ,
	network_address NVARCHAR2(50)  NULL ,
	phone_number NVARCHAR2(50)  NULL ,
	carrier NVARCHAR2(15)  NULL ,
	gateway_id NVARCHAR2(50)  NULL ,
	subnet_mask NVARCHAR2(50)  NULL ,
	domain NVARCHAR2(50)  NULL ,
	bios_ver NVARCHAR2(15)  NULL ,
	cpu_type NVARCHAR2(50)  NULL ,
	memory_available NVARCHAR2(15)  NULL ,
	memory_used NVARCHAR2(15)  NULL ,
	harddrive_capacity NVARCHAR2(15)  NULL ,
	harddrive_used NVARCHAR2(15)  NULL ,
	monitor NVARCHAR2(15)  NULL ,
	nic_card NVARCHAR2(15)  NULL ,
	bandwidth NVARCHAR2(15)  NULL ,
	frequency NVARCHAR2(15)  NULL ,
	license_number NVARCHAR2(50)  NULL ,
	license_expiration_date NUMBER NULL ,
	last_mtce_date NUMBER NULL ,
	mtce_level NVARCHAR2(15)  NULL ,
	active_date NUMBER NULL ,
	retire_date NUMBER NULL ,
	priority NUMBER NULL ,
	SLA NVARCHAR2(50)  NULL ,
	leased_or_owned_status NVARCHAR2(15)  NULL ,
	proj_code NVARCHAR2(15)  NULL ,
	contract_number NVARCHAR2(15)  NULL ,
	lease_effective_date NUMBER NULL ,
	lease_termination_date NUMBER NULL ,
	lease_renewal_date NUMBER NULL ,
	lease_cost_per_month NVARCHAR2(15)  NULL ,
	purchase_amount NUMBER NULL ,
	mtce_type NVARCHAR2(15)  NULL ,
	maintenance_period NVARCHAR2(15)  NULL ,
	mtce_contract_number NVARCHAR2(15)  NULL ,
	maintenance_fee NUMBER NULL 
);

ALTER TABLE ci_telcom_wireless ADD 
	 PRIMARY KEY 
	(
		id
	) ; 

CREATE  INDEX ci_eligible_child_X0 ON ci_eligible_child(rel_id ASC) tablespace &2; 
CREATE  INDEX ci_eligible_parent_X0 ON ci_eligible_parent(rel_id ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_app_ext_X0 ON ci_app_ext(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_app_inhouse_X0 ON ci_app_inhouse(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_contract_X0 ON ci_contract(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_database_X0 ON ci_database(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_document_X0 ON ci_document(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_fac_ac_X0 ON ci_fac_ac(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_fac_fire_control_X0 ON ci_fac_fire_control(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_fac_furnishings_X0 ON ci_fac_furnishings(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_fac_other_X0 ON ci_fac_other(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_fac_ups_X0 ON ci_fac_ups(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_lpar_X0 ON ci_hardware_lpar(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_mainframe_X0 ON ci_hardware_mainframe(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_monitor_X0 ON ci_hardware_monitor(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_other_X0 ON ci_hardware_other(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_printer_X0 ON ci_hardware_printer(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_server_X0 ON ci_hardware_server(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_storage_X0 ON ci_hardware_storage(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_virtual_X0 ON ci_hardware_virtual(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_hardware_workstation_X0 ON ci_hardware_workstation(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_bridge_X0 ON ci_network_bridge(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_cluster_X0 ON ci_network_cluster(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_controller_X0 ON ci_network_controller(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_frontend_X0 ON ci_network_frontend(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_gateway_X0 ON ci_network_gateway(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_hub_X0 ON ci_network_hub(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_nic_X0 ON ci_network_nic(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_other_X0 ON ci_network_other(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_peripheral_X0 ON ci_network_peripheral(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_port_X0 ON ci_network_port(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_resource_X0 ON ci_network_resource(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_resource_group_X0 ON ci_network_resource_group(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_router_X0 ON ci_network_router(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_network_server_X0 ON ci_network_server(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_operating_system_X0 ON ci_operating_system(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_security_X0 ON ci_security(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_service_X0 ON ci_service(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_sla_X0 ON ci_sla(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_telcom_ciruit_X0 ON ci_telcom_ciruit(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_telcom_other_X0 ON ci_telcom_other(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_telcom_radio_X0 ON ci_telcom_radio(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_telcom_voice_X0 ON ci_telcom_voice(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_telcom_wireless_X0 ON ci_telcom_wireless(ext_asset ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_rel_type_X0 ON ci_rel_type(parenttochild ASC) tablespace &2; 
CREATE  UNIQUE  INDEX ci_rel_type_X1 ON ci_rel_type(childtoparent ASC) tablespace &2; 

GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_mdr_provider  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_mdr_idmap  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_app_ext  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_app_inhouse  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_contract  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_database  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_document  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_eligible_child  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_eligible_parent  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_fac_ac  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_fac_fire_control  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_fac_furnishings  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_fac_other  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_fac_ups  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_lpar  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_mainframe  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_monitor  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_other  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_printer  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_server  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_storage  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_virtual  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_hardware_workstation  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_bridge  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_cluster  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_controller  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_frontend  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_gateway  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_hub  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_nic  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_other  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_peripheral  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_port  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_resource  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_resource_group  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_router  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_network_server  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_operating_system  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_rel_type  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_security  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_service  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_sla  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_telcom_ciruit  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_telcom_other  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_telcom_radio  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_telcom_voice  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON ci_telcom_wireless  TO public, service_desk_admin_group ;
GRANT  SELECT ,  UPDATE ,  INSERT ,  DELETE  ON busmgt  TO public, service_desk_admin_group ;
GRANT  SELECT ON ci_mdr_idmap  TO public, service_desk_ro_group ;
GRANT  SELECT ON ci_mdr_provider  TO public, service_desk_ro_group ;
GRANT  SELECT ON ci_app_ext  TO service_desk_ro_group ;
GRANT  SELECT ON ci_app_inhouse  TO service_desk_ro_group ;
GRANT  SELECT ON ci_contract  TO service_desk_ro_group ;
GRANT  SELECT ON ci_database  TO service_desk_ro_group ;
GRANT  SELECT ON ci_document  TO service_desk_ro_group ;
GRANT  SELECT ON ci_eligible_child  TO service_desk_ro_group ;
GRANT  SELECT ON ci_eligible_parent  TO service_desk_ro_group ;
GRANT  SELECT ON ci_fac_ac  TO service_desk_ro_group ;
GRANT  SELECT ON ci_fac_fire_control  TO service_desk_ro_group ;
GRANT  SELECT ON ci_fac_furnishings  TO service_desk_ro_group ;
GRANT  SELECT ON ci_fac_other  TO service_desk_ro_group ;
GRANT  SELECT ON ci_fac_ups  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_lpar  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_mainframe  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_monitor  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_other  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_printer  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_server  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_storage  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_virtual  TO service_desk_ro_group ;
GRANT  SELECT ON ci_hardware_workstation  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_bridge  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_cluster  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_controller  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_frontend  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_gateway  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_hub  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_nic  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_other  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_peripheral  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_port  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_resource  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_resource_group  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_router  TO service_desk_ro_group ;
GRANT  SELECT ON ci_network_server  TO service_desk_ro_group ;
GRANT  SELECT ON ci_operating_system  TO service_desk_ro_group ;
GRANT  SELECT ON ci_rel_type  TO service_desk_ro_group ;
GRANT  SELECT ON ci_security  TO service_desk_ro_group ;
GRANT  SELECT ON ci_service  TO service_desk_ro_group ;
GRANT  SELECT ON ci_sla  TO service_desk_ro_group ;
GRANT  SELECT ON ci_telcom_ciruit  TO service_desk_ro_group ;
GRANT  SELECT ON ci_telcom_other  TO service_desk_ro_group ;
GRANT  SELECT ON ci_telcom_radio  TO service_desk_ro_group ;
GRANT  SELECT ON ci_telcom_voice  TO service_desk_ro_group ;
GRANT  SELECT ON ci_telcom_wireless  TO service_desk_ro_group ;
GRANT  SELECT ON busmgt  TO service_desk_ro_group;


/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15395750, systimestamp, 1, 4, 'Star 15395750 MODIFIED: CMDB : multiple data sourcing and Oracle support' );

COMMIT;

EXIT SUCCESS;
