SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 16505478 CMDB new vis_ and ci_ tables */
/*                                                                                      */
/****************************************************************************************/
/* 16584925 MDB auto-build CRPatch */ 

/****** QC 525: Clarity content ******/
CREATE TABLE ci_investment_other
(
     id NUMBER NOT NULL  ,
     persid nvarchar2(30) NULL  ,
     del NUMBER NOT NULL  ,
     last_mod_dt NUMBER NULL  ,
     last_mod_by raw(16) NULL  ,
     ext_asset raw(16) NOT NULL  ,
     type nvarchar2(30) NULL  ,
     risk nvarchar2(30) NULL  ,
     manager nvarchar2(300) NULL  ,
     alignment NUMBER NULL  ,
     active NUMBER NULL  ,
     stage nvarchar2(2000) NULL  ,
     goal nvarchar2(2000) NULL  ,
     investment_priority NUMBER NULL  ,
     investment_status nvarchar2(240) NULL  ,
     status_indicator nvarchar2(20) NULL  ,
     status_comment nvarchar2(2000) NULL  ,
     charge_code nvarchar2(50) NULL  ,
     start_date NUMBER NULL  ,
     finish_date NUMBER NULL  ,
     progress nvarchar2(50) NULL  ,
     total_cost nvarchar2(30) NULL  ,
     total_effort nvarchar2(30) NULL  ,
     currency nvarchar2(3) NULL
);
ALTER TABLE ci_investment_other ADD PRIMARY KEY  ( id );
GRANT SELECT , UPDATE , INSERT , DELETE ON ci_investment_other TO service_desk_admin_group;
GRANT SELECT ON ci_investment_other TO service_desk_ro_group;
CREATE UNIQUE INDEX ci_investment_other_X0 ON ci_investment_other (ext_asset ASC) tablespace &2;

CREATE TABLE ci_investment_idea
(
     id NUMBER NOT NULL  ,
     persid nvarchar2(30) NULL  ,
     del NUMBER NOT NULL  ,
     last_mod_dt NUMBER NULL  ,
     last_mod_by raw(16) NULL  ,
     ext_asset raw(16) NOT NULL  ,
     target_manager nvarchar2(300) NULL  ,
     business_unit nvarchar2(90) NULL  ,
     active NUMBER NULL  ,
     est_start_date NUMBER NULL  ,
     est_finish_date NUMBER NULL  ,
     existing_initiative_impact nvarchar2(2000) NULL  ,
     dependencies nvarchar2(2000) NULL  ,
     risks nvarchar2(2000) NULL  ,
     owner nvarchar2(2000) NULL  ,
     idea_priority nvarchar2(30) NULL  ,
     subject nvarchar2(300) NULL  ,
     general_notes nvarchar2(2000) NULL
);
ALTER TABLE ci_investment_idea ADD PRIMARY KEY  ( id );
GRANT SELECT , UPDATE , INSERT , DELETE ON ci_investment_idea TO service_desk_admin_group;
GRANT SELECT ON ci_investment_idea TO service_desk_ro_group;
CREATE UNIQUE INDEX ci_investment_idea ON ci_investment_idea (ext_asset ASC) tablespace &2;


CREATE TABLE ci_investment_project
(
     id NUMBER NOT NULL  ,
     persid nvarchar2(30) NULL  ,
     del NUMBER NOT NULL  ,
     last_mod_dt NUMBER NULL  ,
     last_mod_by raw(16) NULL  ,
     ext_asset raw(16) NOT NULL  ,
     risk nvarchar2(30) NULL  ,
     manager nvarchar2(300) NULL  ,
     alignment NUMBER NULL  ,
     active NUMBER NULL  ,
     stage nvarchar2(2000) NULL  ,
     goal nvarchar2(2000) NULL  ,
     project_priority NUMBER NULL  ,
     project_status nvarchar2(240) NULL  ,
     status_indicator nvarchar2(20) NULL  ,
     status_comment nvarchar2(2000) NULL  ,
     charge_code nvarchar2(96) NULL  ,
     start_date NUMBER NULL  ,
     finish_date NUMBER NULL  ,
     progress nvarchar2(50) NULL  ,
     total_cost nvarchar2(30) NULL  ,
     total_effort nvarchar2(30) NULL  ,
     currency nvarchar2(3) NULL
);
ALTER TABLE ci_investment_project ADD PRIMARY KEY  ( id );
GRANT SELECT , UPDATE , INSERT , DELETE ON ci_investment_project TO service_desk_admin_group;
GRANT SELECT ON ci_investment_project TO service_desk_ro_group;
CREATE UNIQUE INDEX ci_investment_project ON ci_investment_project (ext_asset ASC) tablespace &2;

/****** QC 433: Baseline CI support ******/

ALTER TABLE usp_owned_resource ADD baseline_uuid raw(16) NULL;

/****** QC 400: CMDBVisualizer : table stores the metadata of a filter ******/

CREATE TABLE vis_object_store_master (
	id NUMBER NOT NULL,
	object_name nvarchar2(100) NOT NULL ,
	creation_user raw(16) NULL ,
	creation_date NUMBER NULL ,
	last_update_date NUMBER NULL ,
	last_update_user raw(16) NULL ,
	description nvarchar2(255) NULL,
	object_sub_type NUMBER NULL,
	object_type NUMBER NOT NULL,
	inactive NUMBER NOT NULL,
	derived_from_type NUMBER NULL
	);


ALTER TABLE vis_object_store_master ADD 
	 PRIMARY KEY
	(
		id
	) ;

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_object_store_master TO service_desk_admin_group;

GRANT SELECT ON vis_object_store_master TO service_desk_ro_group;


/****** QC 400: CMDBVisualizer : table stores the filter parameters in key value pair. ******/


CREATE TABLE vis_object_store_criteria (
	id NUMBER NOT NULL,
	object_id NUMBER NOT NULL ,
	object_criteria_name varchar2(32) NOT NULL,
	object_criteria_value nvarchar2(2000) NULL,
	last_update_date NUMBER NULL,
	inactive NUMBER NOT NULL
	);

ALTER TABLE vis_object_store_criteria ADD 
	 PRIMARY KEY
	(
		id
	) ;

ALTER TABLE vis_object_store_criteria
ADD CONSTRAINT vis_object_store_criteria_fk
    FOREIGN KEY (object_id)
        REFERENCES vis_object_store_master (id);

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_object_store_criteria TO service_desk_admin_group;

GRANT SELECT ON vis_object_store_criteria TO service_desk_ro_group;


/****** QC 400: CMDBVisualizer : table is used to save the graph. ******/


CREATE TABLE vis_graph_metadata (
	id NUMBER NOT NULL ,
	focus_ci_list varchar2(1024) NOT NULL ,
	graph_level NUMBER NOT NULL ,
	layout NUMBER NOT NULL ,
	filter_id NUMBER NULL ,
	hidden_ci_list varchar2(2048) NULL ,
	inactive NUMBER NOT NULL ,
	graph_name nvarchar2(100) UNIQUE NOT NULL ,
	creation_user raw(16) NULL ,
	creation_date NUMBER NULL ,
	last_update_user raw(16) NULL ,
	last_update_date NUMBER NULL
	);

ALTER TABLE vis_graph_metadata ADD 
	 PRIMARY KEY
	(
		id
	) ;

ALTER TABLE vis_graph_metadata
ADD CONSTRAINT vis_graph_metadata_fk
    FOREIGN KEY (filter_id)
        REFERENCES vis_object_store_master (id);

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_graph_metadata TO service_desk_admin_group;

GRANT SELECT ON vis_graph_metadata TO service_desk_ro_group;

/****** QC 400: CMDBVisualizer : table stores the configuration parameters in key value pair. ******/


CREATE TABLE vis_configuration (
	id NUMBER NOT NULL ,
	visconfig_criteria1 varchar2(100) UNIQUE NOT NULL,
	visconfig_criteria2 varchar2(100) NULL,
	visconfig_criteria3 varchar2(100) NULL,
	visconfig_criteria_value varchar2(100) NULL,
	creation_user raw(16) NULL ,
	creation_date NUMBER NULL ,
	last_update_user raw(16) NULL ,
	last_update_date NUMBER NULL ,
	inactive NUMBER NOT NULL
	);

ALTER TABLE vis_configuration ADD 
	 PRIMARY KEY
	(
		id
	) ;

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_configuration TO service_desk_admin_group;

GRANT SELECT ON vis_configuration TO service_desk_ro_group;

/****** QC 400: CMDBVisualizer : table is modified for the color combination to be applied on a relationship. ******/

ALTER TABLE ci_rel_type
ADD ( view_style varchar2(15) ) ;


/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 16505478, systimestamp, 1, 4, 'Star 16505478 CMDB new vis_ and ci_ tables' );

COMMIT;

EXIT SUCCESS;
