rem @Echo off

REM Name: setupmdb_post.bat 
REM
REM Description: 
REM    internal post-process script for mdb on Oracle
REM 
REM Syntax:
REM
REM    setupmdb_post
REM
REM History:
REM    31-jul-2006  mulwi01  created 
REM    01-aug-2006  mulwi01  make a signature error non-fatal
REM    03-oct-2007  johro05  chg SIGFILE to use imported MDB_TARGET_DIR
REM    29-nov-2007  johri05  b1628 Consistency of logged messages time stamps
REM                      Add :GET_DT--Get Date/Time func to fmt logged timestamp
REM                      to match Java Utilities and LinuxUnix install scripts.
REM    14-dec-2007  johri05  b1628 Consistency of logged messages time stamps
REM                      Copy fixed :GET_DT func from setupmdb.bat
REM                      Fixed :GET_DT--"Get Date/Time" func, to always use 24-hr fmt
REM                      Also fixed to use %TMPDIR% for temporary (writable) directory.
REM    07-apr-2008  hopst01  b1740 - remove quotes from around SIGFILE since value is quoted
REM    08-aug-2008  johri05  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG
REM                       Fix to use only minimal short format to prefix logged messages.
REM                       Long format is to be used once in the install log header.
REM                          long fmt:  yyyy-MMM-dd,HH:mm:ss-zzzz -ex:2008-jul-04,15:30:00-0400
REM                          short fmt:       MM-dd,HH:mm:ss      -ex:      07-04,15:30:00
REM                       Del :GET_DT function
REM                       Chg calls to :GET_DT label to be calls to mdbFuncs with GET_DT argument
REM    11-aug-2008  hopst01  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG. Target Directory needs to 
REM                          be quoted. Don't pipe calls to mdbFuncs to nul as it makes debug impossible.
REM    27-aug-2008  hopst01  b1949 - Don't inherit sigfile location
REM

set MDB_RC=2

set MDB_PATCH_DDL_DIR=.\DDL


rem
rem Get TMPDIR for general use.
rem (use tgt dir for post-script)
rem
set TMPDIR=%MDB_TARGET_DIR%



rem
rem check if Oracle is available
rem
sqlplus -V > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=sqlplus
    GOTO OSQL_FOUND
)
set MDB_RC=10
set ERR_MESSAGE=Cannot find sqlplus. Check that Oracle has been installed and in the PATH
GOTO DONE_EXIT
:OSQL_FOUND


rem
rem cleanup? 
rem
IF NOT "%1"=="cleanup" GOTO NO_CLEAN
set ERR_MESSAGE=
set MDB_RC=0
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% Cleanup resources... >>%LOGFILE%

IF (%DB_CREATED%) NEQ (true) GOTO ENDDATA
%SQL_CMD% -L "%ORA_SYS_USER%/%ORA_SYS_PSWD%@%ORA_CONNECT_ID%%ORA_AS_SYSDBA%" @.\DDL\drop_mdb_tblspace.sql %ORA_DATA_TBLSPACE_NAME% >>%LOGFILE% 2>&1
set ERR_MESSAGE=Removed the %ORA_DATA_TBLSPACE_NAME% tablespace
:ENDDATA

IF (%DB_CREATED_INDEX%) NEQ (true) GOTO ENDINDEX
%SQL_CMD% -L "%ORA_SYS_USER%/%ORA_SYS_PSWD%@%ORA_CONNECT_ID%%ORA_AS_SYSDBA%" @.\DDL\drop_mdb_tblspace.sql %ORA_INDEX_TBLSPACE_NAME% >>%LOGFILE% 2>&1
set ERR_MESSAGE=%ERR_MESSAGE% Removed the %ORA_INDEX_TBLSPACE_NAME% tablespace
:ENDINDEX

IF (%DB_CREATED_USER%) NEQ (true) GOTO ENDUSER
%SQL_CMD% -L "%ORA_SYS_USER%/%ORA_SYS_PSWD%@%ORA_CONNECT_ID%%ORA_AS_SYSDBA%" @.\DDL\drop_mdbadmin.sql >>%LOGFILE% 2>&1
set ERR_MESSAGE=%ERR_MESSAGE% Removed the mdbadmin user
:ENDUSER
GOTO DONE_EXIT

:NO_CLEAN



set SIGFILE="%MDB_TARGET_DIR%\%DBNAME%_signature.txt"


REM
REM create the signature... 
REM
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% Creating the %DBNAME% signature in %SIGFILE% 

echo MdbName=%DBNAME%> %SIGFILE%
echo DbmsType=Oracle>> %SIGFILE%
echo ConnectIdentifier=%ORA_CONNECT_ID%>> %SIGFILE%
echo DataTablespace=%MDB_DATA_TBLSPACE_NAME%>> %SIGFILE%
echo IndexTablespace=%MDB_INDEX_TBLSPACE_NAME%>> %SIGFILE%


%SQL_CMD% -L "MDBADMIN/%MDB_ADMIN_PSWD%@%ORA_CONNECT_ID%" @"%MDB_PATCH_DDL_DIR%\mdb_signature.sql" >> %LOGFILE% 2>&1
IF %ERRORLEVEL% EQU 0 GOTO SIG_CREATED
rem set MDB_RC=600
set MDB_RC=0
set ERR_MESSAGE=Failed to create the %DBNAME% signature (errorlevel=%ERRORLEVEL%)
IF EXIST %SIGFILE% del %SIGFILE%
GOTO DONE_EXIT
:SIG_CREATED


IF EXIST mdbsig.txt del mdbsig.txt
findstr /B /L /V /C:"SQL>" signature.txt > mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_SIG
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=610
set ERR_MESSAGE=Failed to create the %DBNAME% signature
IF EXIST %SIGFILE% del %SIGFILE%
GOTO DONE_EXIT

:FOUND_SIG
type mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul


set MDB_RC=0
set ERR_MESSAGE=Signature for %DBNAME% created for %ORA_CONNECT_ID%



:DONE_EXIT
IF EXIST signature.txt del signature.txt

call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% %ERR_MESSAGE%
echo %DT% %ERR_MESSAGE% >> %LOGFILE% 2>&1

echo %DT% Setupmdb_post exit /B return code=%MDB_RC% >> %LOGFILE% 2>&1

EXIT /B %MDB_RC%
