SET LOCK_TIMEOUT 300000
GO
SET DEADLOCK_PRIORITY LOW
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION 
GO

/****************************************************************************************/
/*                                                                                      */
/* Star 16255155 DSM: add ca_agent_ip_list and ip6Tohex					*/
/*                                                                                      */
/****************************************************************************************/

/* lock objects...  */
 
/* Start of lines added to convert to online lock */
 
 
Select top 1 1 from mdb_patch with (tablockx)
GO
 
/* Start of locks for dependent tables */
 
Select top 1 1 from mdb_service_pack with (tablockx)
GO
 
Select top 1 1 from mdb with (tablockx)
GO
 
Select top 1 1 from mdb_checkpoint with (tablockx)
GO
 
/* End of lines added to convert to online lock */

/**
 * Copyright (c) , 2007
 * 
 * SQl script to upgrade the DSM MDB schema to support IPv6
 *
 */ 


set ANSI_NULLS ON
set QUOTED_IDENTIFIER OFF
GO


/**
 * function to convert IP address of colon notation to a hex string
 * 
 * CAVEATS:
 *	no full support  of Zero-compression
 *	*************************************************************************** 
 */
if  exists (select * from dbo.sysobjects where name = 'ip6ColTohex' and xtype = 'FN')
    drop function  [ip6ColTohex]
GO
-- ipaddr_str can describe 16 byte=32 half bytes including 15 colons =47 chars
create function [dbo].[ip6ColTohex](@ipaddr_str char(64) )  
RETURNS binary(16) 
AS  
BEGIN 
	declare @erg_str 		varchar(64); -- ipaddr_str without colons. max length: 16 * 2 
	declare @erg_str1 		varchar(64); -- ipaddr_str without colons. max length: 16 * 2 
	declare @pos 			integer;
	declare @found 			integer;
	declare @len			integer;
	declare @len_part 		integer;
	declare @partcount		integer;
	declare @found2colons	integer;
	declare @ipaddr_part 	varchar(64); -- max 4 chars: ABCF
	declare @ipaddr_part2 	varchar(64); -- max 4 chars: ABCF

	if (@ipaddr_str = NULL)
	begin
		-- Error
		-- raiserror('Error 9009: internal error: parameter NULL not allowed in ip6ColTohex', 16,1 );		
		return NULL;
	end

	set @len=len(@ipaddr_str);
	set @pos=1;
	set @erg_str='';
	set @erg_str1='';
	set @partcount=0;
	set @found2colons=0;

	-- check for correctness: no . allowed, mixed mode not supported.
	select @found=charindex('.',@ipaddr_str);
	if (@found > 0 )
	begin
		-- Error
		-- raiserror('Error 9009: internal error: illegal input for function ip6ColTohex', 16,1 );		
		return NULL;
	end

	-- check for correctness: at least one : expected mixed mode not supported.
	select @found=charindex(':',@ipaddr_str);
	if (@found = 0 )
	begin
		-- Error
		-- raiserror('Error 9009: internal error: illegal input for function ip6ColTohex', 16,1 );		
		return NULL;
	end


	while  (@pos < @len + 1 )
	begin

		select @found = charindex( ':', @ipaddr_str,  @pos )
		-- 0: end of string found, fetch the rest
		if @found = 0
			select @found=@len + 1;

		select @ipaddr_part=rtrim(ltrim(substring(@ipaddr_str,@pos,@found-@pos)));
		select @len_part=len(@ipaddr_part);

		if @len_part != 0 
		begin
			select @ipaddr_part2=stuff('0000',4-@len_part+1,@len_part,@ipaddr_part);
			select @erg_str=@erg_str ++ @ipaddr_part2;
			set @partcount=@partcount + 1;
		end
		else
		begin
			-- support of short format ::
			-- :: is replaced by 0000... (see below)
			-- :: can only occur ones, otherwise NULL returned
			select @erg_str1=@erg_str;
			select @erg_str='';
			set @found2colons=@found2colons+1;
			-- :: at begin of string
			--if @pos = 1 and @found = 1 and substring(@rtrim(ltrim(@ipaddr_str)),@pos,2)= '::'
			--begin
			--	set @found2colons=1;
			--	set @erg_str1='0000';
			--end
			-- :: at end of string
			-- if @pos = len-1 && substring(@ipaddr_part,@pos,2)= '::'
		end

		-- pos to next part of ipaddr_str
		select @pos=@found + 1;

	end

	if @found2colons > 1 
		return NULL;
	if @found2colons = 1 
		select @erg_str=@erg_str1 ++ replicate('0000',8-@partcount) ++ @erg_str;
	if len(@erg_str) = 32
		return dbo.unhex (@erg_str);

	return NULL;
END
GO
grant execute on [dbo].ip6ColTohex to ca_itrm_group
go
grant execute on [dbo].ip6ColTohex to ca_itrm_group_ams
go 


  
/**
 * function to convert 
 *		IPv4 address - dotted notation OR 
 *		IPv6 address - colon hexadecimal OR
 * 		to 16 byte hex string
 * 
 *	*************************************************************************** 
 */
if  exists (select * from dbo.sysobjects where name = 'ip6Tohex' and xtype = 'FN')
    drop function  [ip6Tohex]
go
CREATE FUNCTION [dbo].[ip6Tohex](@ipaddr_str char(64) )  
RETURNS binary(16) 
AS  
BEGIN 
	declare @ipaddr_hex binary(16)
	declare @ipaddr float, @ipbyte int, @temp char(25), @ch char(1), @ipaddr_int int

	if (@ipaddr_str = NULL)
	begin
		select @ipaddr_hex = NULL
		return @ipaddr_hex
	end

	if ( charindex(':',@ipaddr_str) >0 )
	begin 
		-- must be an IPv6 address
		-- colon hexadecimal address
		set @ipaddr_hex = dbo.ip6ColTohex(@ipaddr_str);
		return @ipaddr_hex;
	end
	
	-- must be an IPv4 address

	if ( charindex('.',@ipaddr_str) >0 )
	begin 
		select @ipaddr_hex = convert(binary(16), convert(bigint, dbo.ip2hex(@ipaddr_str)));
		return @ipaddr_hex
	end
	return NULL

END
GO
grant execute on [dbo].ip6Tohex to ca_itrm_group
go
grant execute on [dbo].ip6Tohex to ca_itrm_group_ams
go 


/**
 * ***************************************************************************
 *  new table to  hold multiple IP addresses for an single agent
 * ***************************************************************************
 */
--if  exists (select * from dbo.sysobjects where name = 'ca_agent_ip_list' and xtype = 'U')
 --   drop table  ca_agent_ip_list
--go


CREATE TABLE ca_agent_ip_list
(
	object_uuid  binary(16)  NOT NULL ,
	ip_address  nvarchar(64)  NOT NULL ,
    auto_rep_version   timestamp  NULL 
)  ON [PRIMARY]
go

ALTER TABLE ca_agent_ip_list
	ADD CONSTRAINT  PK_ca_agent_ip_list PRIMARY KEY NONCLUSTERED (object_uuid  ASC,ip_address  ASC)
	on [PRIMARY]
go

grant select, insert, update, delete on ca_agent_ip_list to ca_itrm_group
GO
grant select on ca_agent_ip_list to ca_itrm_group_ams
GO


/*
 ****************************************************************************
 * procedure called by a trigger on delete on ca_agent
 *****************************************************************************
*/
ALTER procedure [dbo].[p_integrity_d_agent](
	@old_object_uuid binary(16) 	/* old object uuid */
	)
as

begin
  delete from ca_agent_component where object_uuid = @old_object_uuid;
  delete from ca_agent_ip_list where object_uuid = @old_object_uuid;
end
GO

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                               	*/
/*                                                                                      */
/****************************************************************************************/
insert into mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 values ( 16255155, getdate(), 1, 4, 'Star 16255155 DSM: add ca_agent_ip_list and ip6Tohex' )
GO

COMMIT TRANSACTION 
GO

