rem @Echo off
REM
REM Name: precheck_extension.bat
REM
REM Description:
REM   internal additional precheck script for mdb on SQLServer
REM
REM Syntax:
REM
REM   setupmdb_pre
REM
REM History:
REM    3-oct-2007  hopst01  created
REM   23-oct-2007  hopst01  change connection reporting.  report total count
REM                         and name of each connected user
REM   25-oct-2007  hopst01  add 'NT AUTHORITY\LOCALSERVICE', 'NT AUTHORITY\NETWORKSERVICE' 
REM                           to list of filtered accounts
REM   20-nov-2007  hopst01  Remove quotes from around pre-check values
REM   30-nov-2007  hopst01  Add standard error codes for missing dbname and
REM                           inability to connect to master database
REM   11-dec-2007  hopst01  b1675 - Remove duplicate authorization parameter -E
REM   21-dec-2007  hopst01  16587331 - Fix syntax error in ERR_EXIT
REM   14-jul-2008  hopst01  b1766 - PRECHECK FAILURE (Star 17044308).  
REM                         Fix syntax error in ERR_EXIT
REM   18-jul-2008  hopst01  Star 17294367 DBPASSWORD WITH "," FAILED. Treat DBPASSWORD like 
REM                         MDB_ADMIN_PSWD.  Use temp variable when comparing it to an 
REM                         empty string.
REM   05-aug-2008  hopst01  b1917 - STAR 17340801 Use TCP connection host,port unless 
REM                         port is 0 this replaces dbhost in the connection string 
REM  05-dec-2008  hopst01  17727007 - FOR LOOP W CMD NOT SUPPORTED. For loops that use 
REM                        a command to populate the for loop set should be replaced.
REM

set RC=9

rem
rem Check if SQLServer is available
rem
sqlcmd -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=sqlcmd
    GOTO OSQL_FOUND
)
osql -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=osql
    GOTO OSQL_FOUND
)

set RC=10
set MESSAGE_TEXT=cannot find osql or sqlcmd. Check that SQLServer has been installed and in the PATH
GOTO ERR_EXIT
:OSQL_FOUND

rem
rem check for required parameters
rem
IF "%DBNAME%" NEQ "" GOTO AUTHORIZATION 
SET RC=11
SET ERR_MESSAGE=Missing required argument: DBNAME
GOTO ERR_EXIT

rem
rem determine if using windows or sql server authentication
rem
:AUTHORIZATION
set AUTH=-E
set ECHOED_AUTH=-E
SET T_DBPASSWORD=x%DBPASSWORD%x
SET T_DBPASSWORD="%T_DBPASSWORD:"=%"
IF (%DBUSER%) NEQ () IF (%T_DBPASSWORD%) NEQ ("xx") GOTO SQL_AUTH
GOTO AUTH_SET
:SQL_AUTH
set AUTH=-U %DBUSER% -P %DBPASSWORD_DQ%
set ECHOED_AUTH=-U %DBUSER% -P ***
:AUTH_SET

REM
REM CHECK FOR THE NUMBER OF LOGINS CONNECTED TO THE DATABASE
REM

REM if database isn't there then you can't connect to it
%SQL_CMD% -S %DBMS_INSTANCE% -d master %AUTH% -e -b -Q "exit(SELECT count(*)+100000 FROM master..sysdatabases WHERE name = '%DBNAME%')"               >> %LOGFILE% 2>&1
SET RC=%ERRORLEVEL%
IF %RC% EQU 100001 GOTO MDB_FOUND
IF %RC% EQU 100000 GOTO MDB_NOT_FOUND
SET RC=100
SET ERR_MESSAGE=SQL command error, ERRORLEVEL=%RC%, unable to connect to master database
GOTO ERR_EXIT

:MDB_NOT_FOUND
SET RC=0
GOTO DONE_LOGIN_COUNT

:MDB_FOUND

rem
rem Get the number of connections to the database and a list of connect users
rem
:COUNT_CONNECTED
SET RC=0
SET LOGIN_COUNT=
SET LOGIN_LIST=
SET QUERY=SELECT 'loginname=' + loginame FROM #mdb_temp_users_tbl WHERE dbname ='%DBNAME%' AND status != 'background' AND loginame NOT IN ('NT AUTHORITY\SYSTEM', 'NT AUTHORITY\LOCALSERVICE', 'NT AUTHORITY\NETWORKSERVICE') ORDER BY loginame desc 

:POPULATE_USER_TABLE
rem
rem create temp file, use sp_who to query for connnect users
rem
IF EXIST temp.txt del temp.txt
IF EXIST temp_output.txt del temp_output.txt
type ddl\create_temp_user_tbl.sql > temp.txt
echo %QUERY% >> temp.txt
type ddl\del_temp_user_tbl.sql >> temp.txt
echo EXIT >> temp.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% %AUTH% -h-1 -s. -n -i temp.txt > temp_output.txt 2>&1
set RC=%ERRORLEVEL%
IF %RC% EQU 0 GOTO PARSE_POPULATE_RESULT

IF EXIST temp.txt del temp.txt
IF EXIST temp_output.txt del temp_output.txt
set RC=12
set MESSAGE_TEXT=Unable to determine the user connected to the database.
GOTO ERR_EXIT


REM
REM Parse the query results in the temp file and compile list of connect users
REM
:PARSE_POPULATE_RESULT
set TEMP_LOGIN_NAME=
set LOGIN_COUNT=0
for /F "tokens=1,2 delims==" %%i IN (temp_output.txt) DO IF ("%%j") NEQ ("") CALL :SET_LOGIN_LIST %%j

REM cleanup
IF EXIST temp.txt del temp.txt
IF EXIST temp_output.txt del temp_output.txt

IF "%LOGIN_COUNT%" EQU "" GOTO ERR_EXIT
IF "%LOGIN_LIST%"  EQU "" GOTO ERR_EXIT

set MESSAGE_TEXT=%LOGIN_COUNT%
SET MESSAGE_NAME=NUMBER_CONNECTIONS
CALL :PRINT_MSG

set MESSAGE_TEXT=%LOGIN_LIST%
set MESSAGE_NAME=CONNECTION_LIST
CALL :PRINT_MSG

:DONE_LOGIN_COUNT
GOTO DONE_EXIT


REM
REM FUNCTIONS
REM

rem
rem Prints out message in format message_name="message_text"
rem
:PRINT_MSG
IF (%PRECHECK_MSGFILE%) EQU ()  goto PRECHK_STDOUT
echo %MESSAGE_NAME%=%MESSAGE_TEXT%       >> %PRECHECK_MSGFILE%
GOTO :EOF
:PRECHK_STDOUT
echo %MESSAGE_NAME%=%MESSAGE_TEXT%
GOTO :EOF

rem
rem Builds up list of connected user and updates total count 
rem
:SET_LOGIN_LIST
set TEMP_LOGIN_NAME=%1%
IF "%LOGIN_LIST%" EQU "" GOTO BLANK_LOGIN_NAME
set LOGIN_LIST=%TEMP_LOGIN_NAME%,%LOGIN_LIST%
GOTO UPDATE_COUNT

:BLANK_LOGIN_NAME
set LOGIN_LIST=%TEMP_LOGIN_NAME%
GOTO UPDATE_COUNT

:UPDATE_COUNT
SET /A LOGIN_COUNT=1 + %LOGIN_COUNT%
GOTO :EOF

REM
REM Exit script
REM

:ERR_EXIT
SET MDB_RC=%RC%
IF "%MESSAGE_TEXT%" EQU "" GOTO DONE_EXIT
SET ERR_MESSAGE=%MESSAGE_TEXT%

:DONE_EXIT
EXIT /B %RC%

