@ECHO OFF

REM Name: CreateMDBSignature.bat 
REM
REM Description: 
REM		returns 1 if the signature is created, otherwise returns 0
REM 
REM Syntax:
REM
REM     CreateMDBSignature -ORA_CONNECT_ID=%ORA_CONNECT_ID% -MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD% 
REM                        -MDB_NAME=%MDB_NAME% -ORA_DATA_TBLSPACE_NAME=%ORA_DATA_TBLSPACE_NAME% 
REM                        -ORA_INDEX_TBLSPACE_NAME=%ORA_INDEX_TBLSPACE_NAME%
REM                        -MDB_TARGET_DIR=%MDB_TARGET_DIR% [-debug] [-?]
REM
REM History:
REM	17-jan-2006 mulwi01
REM	    Created.
REM  8-feb-2006 mulwi01     add tablespace names
REM  21-mar-2007 todjo06    STAR 14970798 sig file location should be in 
REM                               MDB_TARGET_DIR is specified
REM

SETLOCAL

set ORA_CONNECT_ID=
set MDB_ADMIN_PSWD=
set MDB_NAME=MDB
set EXIT_SCRIPT=/B
set MDB_RC=2
set MDB_DATA_TBLSPACE_NAME=%MDB_NAME%_DATA
set MDB_INDEX_TBLSPACE_NAME=%MDB_NAME%_INDEX

set MDB_PATCH_DDL_DIR=.\DDL


REM
REM Parse the command line parameters
REM

:PARSE_ARGS

IF "%~1"==""   GOTO NO_MORE_ARGS
IF "%~1"=="-?" GOTO USAGE


IF NOT "%~1"=="-ORA_CONNECT_ID" GOTO NEXT_ARG1
SHIFT
set ORA_CONNECT_ID=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG1
IF NOT "%~1"=="-MDB_ADMIN_PSWD" GOTO NEXT_ARG2
SHIFT
set MDB_ADMIN_PSWD="%~1"
rem undo "call" stmt
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:^^=^%
rem Escape any reserved shell characters
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:^=^^%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:<=^<%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:>=^>%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:|=^|%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:&=^&%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:(=^(%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:)=^)%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:"=\"%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG2
IF NOT "%~1"=="-MDB_NAME" GOTO NEXT_ARG3
SHIFT
set MDB_NAME=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG3
IF NOT "%~1"=="-MDB_PATCH_DDL_DIR" GOTO NEXT_ARG4
SHIFT
set MDB_PATCH_DDL_DIR=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG4
IF NOT "%~1"=="-ORA_DATA_TBLSPACE_NAME" GOTO NEXT_ARG5
SHIFT
set MDB_DATA_TBLSPACE_NAME=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG5
IF NOT "%~1"=="-ORA_INDEX_TBLSPACE_NAME" GOTO NEXT_ARG6
SHIFT
set MDB_INDEX_TBLSPACE_NAME=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG6
IF NOT "%~1"=="-MDB_TARGET_DIR" GOTO NEXT_ARG7
SHIFT
set MDB_TARGET_DIR=%~1
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG7
IF /i NOT "%~1"=="-debug" GOTO INVALID_ARG
set DEBUGECHO=@ECHO ON
%DEBUGECHO%
SHIFT
GOTO PARSE_ARGS

:INVALID_ARG
echo %date% %time% Usage: Invalid argument "%~1"
GOTO USAGE

:NO_MORE_ARGS




rem
rem check required arguments
rem

IF (%ORA_CONNECT_ID%) NEQ () GOTO REQ_ARG1
echo %date% %time% Missing required argument: ORA_CONNECT_ID 
set ERR_MESSAGE=Missing required argument: ORA_CONNECT_ID
GOTO USAGE

:REQ_ARG1
IF (%MDB_ADMIN_PSWD%) NEQ () GOTO DB_CHECK
echo %date% %time% Missing required argument: MDB_ADMIN_PSWD 
set ERR_MESSAGE=Missing required argument: MDB_ADMIN_PSWD
GOTO USAGE

:DB_CHECK


rem
rem check if Oracle is available
rem
sqlplus -V > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=sqlplus
    GOTO OSQL_FOUND
)
set MDB_RC=10
set ERR_MESSAGE=Cannot find sqlplus. Check that Oracle has been installed and in the PATH
GOTO DONE_EXIT
:OSQL_FOUND

IF (%SIGFILE%) NEQ () GOTO SIG_LOC_DONE

IF (%MDB_TARGET_DIR) NEQ () GOTO SIG_LOC_TARGET

set SIGFILE="%MDB_NAME%_signature.txt"
GOTO SIG_LOC_DONE

:SIG_LOC_TARGET
set SIGFILE="%MDB_TARGET_DIR%\%MDB_NAME%_signature.txt"

:SIG_LOC_DONE

REM
REM create the signature... 
REM

echo %date% %time% Creating the %MDB_NAME% signature in %SIGFILE% 

echo MdbName=%MDB_NAME%> %SIGFILE%
echo DbmsType=Oracle>> %SIGFILE%
echo ConnectIdentifier=%ORA_CONNECT_ID%>> %SIGFILE%
echo DataTablespace=%MDB_DATA_TBLSPACE_NAME%>> %SIGFILE%
echo IndexTablespace=%MDB_INDEX_TBLSPACE_NAME%>> %SIGFILE%


%SQL_CMD% -L "MDBADMIN/%MDB_ADMIN_PSWD%@%ORA_CONNECT_ID%" @"%MDB_PATCH_DDL_DIR%\mdb_signature.sql"
IF %ERRORLEVEL% EQU 0 GOTO SIG_CREATED
set MDB_RC=600
set ERR_MESSAGE=Failed to create the %MDB_NAME% signature (errorlevel=%ERRORLEVEL%)
IF EXIST "%SIGFILE%" del "%SIGFILE%"
GOTO DONE_EXIT
:SIG_CREATED


IF EXIST mdbsig.txt del mdbsig.txt
findstr /B /L /V /C:"SQL>" signature.txt > mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_SIG
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=610
set ERR_MESSAGE=Failed to create the %MDB_NAME% signature
IF EXIST "%SIGFILE%" del "%SIGFILE%"
GOTO DONE_EXIT

:FOUND_SIG
type mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul


set MDB_RC=0
set ERR_MESSAGE=Signature for %MDB_NAME% created for %ORA_CONNECT_ID%

goto DONE_EXIT 


:USAGE
echo %date% %time% 
echo %date% %time% Usage: CreateMDBSignature -ORA_CONNECT_ID=xxxx -MDB_ADMIN_PSWD=xxxx -MDB_NAME=xxxx 
echo %date% %time%                           -ORA_DATA_TBLSPACE_NAME=xxxx -ORA_INDEX_TBLSPACE_NAME=xxxx -MDB_TARGET_DIR=xxxx [-debug] [-?]
echo %date% %time% 
echo %date% %time%        ORA_CONNECT_ID    connection identifier                       (required)
echo %date% %time%        MDB_ADMIN_PSWD    mdbadmin user password                      (required)
echo %date% %time%        MDB_NAME          mdb name                                    (optional, default to mdb)
echo %date% %time%        ORA_DATA_TBLSPACE_NAME name of the data tablespace            (optional)
echo %date% %time%        ORA_INDEX_TBLSPACE_NAME name of the index tablespace          (optional)

echo %date% %time%        MDB_TARGET_DIR output directory
echo %date% %time%        -debug            echo output
echo %date% %time%
    
set MDB_RC=99
GOTO DONE_EXIT


:DONE_EXIT
IF EXIST signature.txt del signature.txt
echo %date% %time% %ERR_MESSAGE%
EXIT %EXIT_SCRIPT% %MDB_RC%
