-------------------------------------------------------------------------------
-- The following will cause the dependent patch to be skipped if the release 
-- of oracle is not compatible. 
-------------------------------------------------------------------------------
WHENEVER SQLERROR EXIT SUCCESS;	
SET SERVEROUTPUT ON

DECLARE
    vc_version		varchar2(255);	-- string version number
    vc_compatibility	varchar2(255);	-- string compat version number
    mstr varchar2(255);
    dotpos number;
    n_min_major_version number := 10;
    n_min_minor_version number := 2;
    n_major_version number;
    n_minor_version number;
BEGIN
	-- Get server version number
    dbms_utility.db_version( vc_version, vc_compatibility );
    
    -- Convert to numeric
    dotpos := instr(vc_version,'.',1,1);
    mstr := substr(vc_version,1,dotpos-1);
    n_major_version := TO_NUMBER(mstr);

    mstr := substr(vc_version,dotpos+1,(instr(vc_version,'.',1,2)-1)-dotpos);
    n_minor_version := TO_NUMBER(mstr);

    dbms_output.put_line( 'Oracle Version = ' || vc_version );
    
    -- Check to see if min version is satisfied

    if (n_major_version < n_min_major_version) THEN
		dbms_output.put_line( 'Patch not applied - requires Oracle Version ' || n_min_major_version || '.' || n_min_minor_version || ' or higher' );
		-- Force failure
		raise_application_error(-20000, 'Patch not applied - requires Oracle Version ' || n_min_major_version || '.' || n_min_minor_version || ' or higher' );
    END IF;
    if (n_major_version > n_min_major_version) THEN
        dbms_output.put_line( 'Patch will be applied' );
    ELSE
      if (n_minor_version >= n_min_minor_version) THEN
          dbms_output.put_line( 'Patch will be applied' );
      ELSE
		dbms_output.put_line( 'Patch not applied - requires Oracle Version ' || n_min_major_version || '.' || n_min_minor_version || ' or higher' );
		-- Force failure
		raise_application_error(-20000, 'Patch not applied - requires Oracle Version ' || n_min_major_version || '.' || n_min_minor_version || ' or higher' );
      END IF;

    END IF;
END;
/


-------------------------------------------------------------------------------
-- Below is the actual patch. It will only be applied if we have a valid 
-- Oracle release.
-------------------------------------------------------------------------------
SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 14770933 SDESK LINGUISTIC SEARCH CHGS						*/
/*                                                                                      */
/****************************************************************************************/

---------------------------------------------------------------------
-- Service Desk Change:
-- 
-- The attached changes are to improve performance for Linguistic 
-- searches and to allow for Linguistic searches for tickets
---------------------------------------------------------------------

---------------------------------------------------------------------
-- Add description search fields
---------------------------------------------------------------------

alter table call_req ADD ( desc_search NVARCHAR2(2000) ) ;
alter table chg      ADD ( desc_search NVARCHAR2(2000) ) ;
alter table issue    ADD ( desc_search NVARCHAR2(2000) ) ;


---------------------------------------------------------------------
-- Add Triggers for new fields 
-- Note: You cannot add UPDATE OF on NCLOB fields, so
--       we must do this for all updates.
---------------------------------------------------------------------

CREATE OR REPLACE TRIGGER t_iu_call_req
BEFORE INSERT OR UPDATE ON mdbadmin.call_req
REFERENCING NEW AS NEW
FOR EACH ROW
BEGIN
    :NEW.desc_search := SUBSTR(:new.description,1,2000);
END;
/

CREATE OR REPLACE TRIGGER t_iu_chg
BEFORE INSERT OR UPDATE ON mdbadmin.chg
REFERENCING NEW AS NEW
FOR EACH ROW
BEGIN
    :NEW.desc_search := SUBSTR(:new.description,1,2000);
END;
/

CREATE OR REPLACE TRIGGER t_iu_issue
BEFORE INSERT OR UPDATE ON mdbadmin.issue
REFERENCING NEW AS NEW
FOR EACH ROW
BEGIN
    :NEW.desc_search := SUBSTR(:new.description,1,2000);
END;
/

---------------------------------------------------------------------
-- Add Necessary indexes for case-insensitive (linguistic) searches
---------------------------------------------------------------------

 
CREATE INDEX act_log_x0_ci ON act_log
(
      NLSSORT(call_req_id,  'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX att_evt_x1_ci ON att_evt
(
      NLSSORT(obj_id,       'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX attached_sla_x2_ci ON attached_sla
(
      NLSSORT(mapped_cr,    'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX attached_sla_x4_ci ON attached_sla
(
      NLSSORT(mapped_iss,   'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX attmnt_lrel_x0_ci ON attmnt_lrel
(
      NLSSORT(l_persid,     'NLS_SORT=BINARY_CI'),
      NLSSORT(l_attr,       'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX attmnt_lrel_x1_ci ON attmnt_lrel
(
      NLSSORT(r_persid,     'NLS_SORT=BINARY_CI'),
      NLSSORT(r_attr,       'NLS_SORT=BINARY_CI')
) tablespace &2 ;


CREATE INDEX ca_contact_idx_02_ci ON ca_contact
(
      NLSSORT(last_name,    'NLS_SORT=BINARY_CI'),
      NLSSORT(first_name,   'NLS_SORT=BINARY_CI'),
      NLSSORT(middle_name,  'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX ca_contact_idx_03_ci ON ca_contact
(
      NLSSORT(userid, 'NLS_SORT=BINARY_CI'),
      NLSSORT(contact_uuid, 'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX ca_contact_idx_05_ci ON ca_contact
(
      NLSSORT(email_address, 'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX ca_owned_resource_idx_01_ci ON ca_owned_resource
(
      NLSSORT(resource_name, 'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE UNIQUE INDEX call_req_x3_ci ON call_req
(
      NLSSORT(ref_num,      'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX call_req_x13_ci ON call_req
(
      NLSSORT(parent,       'NLS_SORT=BINARY_CI'),
      NLSSORT(ref_num,      'NLS_SORT=BINARY_CI'),
      NLSSORT(open_date,    'NLS_SORT=BINARY_CI'),
      NLSSORT(active_flag,  'NLS_SORT=BINARY_CI'),
      NLSSORT(type,         'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE UNIQUE INDEX chg_x3_ci ON chg
(
      NLSSORT(chg_ref_num,  'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX cr_prp_x1_ci ON cr_prp
(
      NLSSORT(owning_cr,    'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX issalg_x0_ci ON issalg
(
      NLSSORT(issue_id,     'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX issprp_x1_ci ON issprp
(
      NLSSORT(owning_iss,   'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE UNIQUE INDEX issue_x3_ci ON issue
(
      NLSSORT(ref_num,      'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX issue_x11_ci ON issue
(
      NLSSORT(parent,       'NLS_SORT=BINARY_CI'),
      NLSSORT(ref_num,      'NLS_SORT=BINARY_CI'),
      NLSSORT(open_date,    'NLS_SORT=BINARY_CI'),
      NLSSORT(active_flag,  'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE UNIQUE INDEX isswf_x0_ci ON isswf
(
      NLSSORT(object_id,    'NLS_SORT=BINARY_CI'),
      NLSSORT(sequence,     'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX lrel_x0_ci ON lrel
(
      NLSSORT(l_persid,     'NLS_SORT=BINARY_CI'),
      NLSSORT(l_attr,       'NLS_SORT=BINARY_CI')
) tablespace &2 ;

CREATE INDEX lrel_x1_ci ON lrel
(
      NLSSORT(r_persid,     'NLS_SORT=BINARY_CI'),
      NLSSORT(r_attr,       'NLS_SORT=BINARY_CI')
) tablespace &2 ;


/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 14770933, systimestamp, 1, 4, 'Star 14770933 SDESK LINGUISTIC SEARCH CHGS - MODIFIED' );

COMMIT;

EXIT SUCCESS;
