SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 14938364 NSM UCM create roles and ucm tables					*/
/*                                                                                      */
/****************************************************************************************/

CREATE TABLE ucm_calendars (
	calendar_uuid 		RAW(16) NOT NULL ,
	calendar_name 		NVARCHAR2(80) NULL ,
	start_date_time 	NUMBER NULL ,
	end_date_time 		NUMBER NULL ,
	binary_days 		int NULL ,
	creation_user 		NVARCHAR2(64) NULL ,
	creation_date 		NUMBER NULL ,
	last_update_user 	NVARCHAR2(64) NULL ,
	last_update_date 	NUMBER NULL 
);

ALTER TABLE ucm_calendars
       ADD CONSTRAINT XPKucm_calendars PRIMARY KEY (calendar_uuid);


CREATE TABLE ucm_cron_triggers (
	trigger_uuid 		RAW(16) NOT NULL ,
	cron_expression 	NVARCHAR2(80)  NOT NULL ,
	time_zone_id 		NVARCHAR2(80)  NULL 
);


ALTER TABLE ucm_cron_triggers
       ADD CONSTRAINT XPKucm_cron_triggers PRIMARY KEY (trigger_uuid);


CREATE TABLE ucm_fired_triggers (
	trigger_uuid 		RAW(16) NOT NULL ,
	entry_id 		NVARCHAR2(95)  NULL ,
	is_volatile 		NVARCHAR2(1)  NULL ,
	instance_name 		NVARCHAR2(80)  NULL ,
	fired_time 		NUMBER NULL ,
	state 			NVARCHAR2(16)  NULL ,
	job_uuid 		RAW(16) NULL ,
	is_stateful 		NVARCHAR2(1)  NULL ,
	requests_recovery 	NVARCHAR2(1)  NULL 
);


ALTER TABLE ucm_fired_triggers
       ADD CONSTRAINT XPKucm_fired_triggers PRIMARY KEY (trigger_uuid);


CREATE TABLE ucm_history (
	uuid 			RAW(16) NULL ,
	config_uuid 		RAW(16) NULL ,
	asset_uuid 		RAW(16) NULL ,
	description 		NVARCHAR2(120)  NULL ,
	description1 		NVARCHAR2(120)  NULL ,
	description2 		NVARCHAR2(120)  NULL ,
	description3 		NVARCHAR2(120)  NULL ,
	description4 		NVARCHAR2(120)  NULL ,
	description5 		NVARCHAR2(120)  NULL ,
	description6 		NVARCHAR2(120)  NULL ,
	type			NUMBER NULL ,
	creation_user 		NVARCHAR2(64)  NULL ,
	creation_date 		NUMBER NULL ,
	i_delete_flag 		NUMBER NULL 
);

CREATE TABLE ucm_job_details (
	job_uuid 		RAW(16) NOT NULL ,
	job_name 		NVARCHAR2(80)  NULL ,
	job_group 		NVARCHAR2(80)  NULL ,
	description 		NVARCHAR2(120)  NULL ,
	job_class_name 		NVARCHAR2(128)  NULL ,
	is_durable 		NVARCHAR2(1)  NULL ,
	is_volatile 		NVARCHAR2(1)  NULL ,
	is_stateful 		NVARCHAR2(1)  NULL ,
	requests_recovery 	NVARCHAR2(1)  NULL ,
	creation_user 		NVARCHAR2(64)  NULL ,
	creation_date 		NUMBER NULL ,
	last_update_user 	NVARCHAR2(64)  NULL ,
	last_update_date 	NUMBER NULL 
);


ALTER TABLE ucm_job_details
       ADD CONSTRAINT XPKucm_job_details PRIMARY KEY (job_uuid);

CREATE TABLE ucm_job_listeners (
	job_uuid 		RAW(16) NOT NULL ,
	job_listener 		NVARCHAR2(80)  NOT NULL 
);

ALTER TABLE ucm_job_listeners
       ADD CONSTRAINT XPKucm_job_listeners PRIMARY KEY (job_uuid, job_listener);


CREATE TABLE ucm_link_calendar_trigger (
	calendar_uuid 		RAW(16) NOT NULL ,
	trigger_uuid 		RAW(16) NOT NULL ,
	last_update_date 	NUMBER NULL ,
	version_number 		NUMBER NULL 
);

ALTER TABLE ucm_link_calendar_trigger
       ADD CONSTRAINT XPKucm_link_calendar_trigger PRIMARY KEY (calendar_uuid, trigger_uuid);


CREATE TABLE ucm_link_config_report (
	config_uuid 		RAW(16) NOT NULL ,
	rpt_id 			NUMBER NOT NULL ,
	last_update_date 	NUMBER NULL ,
	version_number 		NUMBER NULL 
);

ALTER TABLE ucm_link_config_report
       ADD CONSTRAINT XPKucm_link_config_report PRIMARY KEY (config_uuid, rpt_id);


CREATE TABLE ucm_locks (
	lock_name 		NVARCHAR2(40)  NOT NULL 
);


ALTER TABLE ucm_locks
       ADD CONSTRAINT XPKucm_locks PRIMARY KEY (lock_name);

CREATE TABLE ucm_mib_data (
	hostname 		NVARCHAR2(255)  NOT NULL ,
	mibname 		NVARCHAR2(48)  NOT NULL ,
	instance 		NVARCHAR2(20)  NULL ,
	tablegroup 		NVARCHAR2(48)  NOT NULL ,
	"ROW" 			NVARCHAR2(255)  NULL ,
	variable 		NVARCHAR2(48)  NOT NULL ,
	varlabel 		NVARCHAR2(255)  NOT NULL 
);


CREATE TABLE ucm_mib_logreportdata (
    	hostname 		NVARCHAR2(255) NOT NULL ,
    	mibname 		NVARCHAR2(48) NOT NULL , 
    	instance 		NVARCHAR2(20) NULL ,
    	tablegroup 		NVARCHAR2(48) NOT NULL ,
    	tgdesc 			NVARCHAR2(255) NOT NULL ,
    	"ROW" 			NVARCHAR2(255) NULL ,
    	vardesc 		NVARCHAR2(255) NOT NULL ,
    	historypolicy 		NVARCHAR2(32) NULL ,
    	trapsendpolicy 		NVARCHAR2(32) NULL ,
    	matchtrappolicy 	NVARCHAR2(32) NULL ,
    	statuspolicy 		NVARCHAR2(32) NULL ,
    	monitorstatus 		NVARCHAR2(32) NULL ,
    	toggle_pos_end 		NVARCHAR2(16) NULL ,
    	toggle_pos_start 	NVARCHAR2(16) NULL ,
    	toggle_pos_pattern 	NVARCHAR2(255) NULL ,
    	toggle_neg_end 		NVARCHAR2(16) NULL ,
    	toggle_neg_start 	NVARCHAR2(16) NULL ,
    	toggle_neg_pattern 	NVARCHAR2(255) NULL ,
    	neg_pattern 		NVARCHAR2(255) NULL ,
    	neg_start 		NVARCHAR2(16) NULL ,
    	neg_end 		NVARCHAR2(16) NULL ,
    	pos_pattern 		NVARCHAR2(16) NULL ,
    	pos_start 		NVARCHAR2(16) NULL ,
    	pos_end 		NVARCHAR2(16) NULL ,
    	exist 			NVARCHAR2(32) NULL 
);

CREATE TABLE ucm_mib_miblabel (
	miblabel 		NVARCHAR2(48)  NOT NULL ,
	mibdesc 		NVARCHAR2(255)  NOT NULL ,
	miboid 			NVARCHAR2(64)  NOT NULL ,
	mibnumber 		NUMBER NOT NULL 
);

CREATE UNIQUE INDEX baseidx_ucm_mib_miblabel ON ucm_mib_miblabel
(
       miblabel                         ASC
) tablespace &2 ;

CREATE TABLE ucm_mib_reportdata (
	hostname 		NVARCHAR2(255)  NOT NULL ,
	mibname 		NVARCHAR2(48)  NOT NULL ,
	instance 		NVARCHAR2(20)  NULL ,
	tablegroup 		NVARCHAR2(48)  NOT NULL ,
	tgdesc 			NVARCHAR2(255)  NOT NULL ,
	"ROW" 			NVARCHAR2(255)  NULL ,
	vardesc 		NVARCHAR2(255)  NOT NULL ,
	warnmax 		NVARCHAR2(16)  NULL ,
	warnmin 		NVARCHAR2(16)  NULL ,
	critmax 		NVARCHAR2(16)  NULL ,
	critmin 		NVARCHAR2(16)  NULL ,
	warn 			NVARCHAR2(16)  NULL ,
	crit 			NVARCHAR2(16)  NULL ,
	max 			NVARCHAR2(16)  NULL ,
	min 			NVARCHAR2(16)  NULL ,
	monitor 		NVARCHAR2(16)  NULL ,
	lag 			NVARCHAR2(16)  NULL 
);

CREATE TABLE ucm_mib_tglabel (
	tglabel 		NVARCHAR2(48)  NOT NULL ,
	tggrouping 		NVARCHAR2(48)  NOT NULL ,
	tgdesc 			NVARCHAR2(255)  NOT NULL ,
	mibnumber 		NUMBER NOT NULL ,
	tgnumber 		NUMBER NOT NULL 
);

CREATE UNIQUE INDEX baseidx_ucm_mib_tglabel ON ucm_mib_tglabel
(
       tglabel                         ASC
) tablespace &2 ;

CREATE TABLE ucm_mib_varlabel (
	varlabel 		NVARCHAR2(48)  NOT NULL ,
	vardesc 		NVARCHAR2(255)  NOT NULL ,
	mibnumber 		NUMBER NOT NULL ,
	tgnumber 		NUMBER NOT NULL ,
	varoid 			NVARCHAR2(64)  NOT NULL ,
	vartype 		NUMBER NOT NULL 
);

CREATE UNIQUE INDEX baseidx_ucm_mib_varlabel ON ucm_mib_varlabel
(
       varlabel                         ASC
) tablespace &2 ;


CREATE TABLE ucm_paused_trigger_grps (
	trigger_group 		NVARCHAR2(80)  NOT NULL 
);

ALTER TABLE ucm_paused_trigger_grps
       ADD CONSTRAINT XPKucm_paused_trigger_grps PRIMARY KEY (trigger_group);


CREATE TABLE ucm_scheduler_state (
	instance_name 		NVARCHAR2(80)  NOT NULL ,
	last_checkin_time 	NUMBER NOT NULL ,
	checkin_interval 	NUMBER NOT NULL ,
	recoverer 		NVARCHAR2(80)  NULL 
);

ALTER TABLE ucm_scheduler_state
       ADD CONSTRAINT XPKucm_scheduler_state PRIMARY KEY (instance_name);


CREATE TABLE ucm_simple_triggers (
	trigger_uuid 		RAW(16) NOT NULL ,
	repeat_count 		NUMBER NULL ,
	repeat_interval 	NUMBER NULL ,
	repeat_unit 		int NULL ,
	times_triggered 	NUMBER NULL 
);

ALTER TABLE ucm_simple_triggers
       ADD CONSTRAINT XPKucm_simple_triggers PRIMARY KEY (trigger_uuid);

CREATE TABLE ucm_trigger_listeners (
	trigger_uuid 		RAW(16) NOT NULL ,
	trigger_listener 	NVARCHAR2(80)  NOT NULL 
);

ALTER TABLE ucm_trigger_listeners
       ADD CONSTRAINT XPKucm_trigger_listeners PRIMARY KEY (trigger_uuid, trigger_listener);


CREATE TABLE ucm_triggers (
	trigger_uuid 		RAW(16) NOT NULL ,
	trigger_name 		NVARCHAR2(80)  NULL ,
	trigger_group 		NVARCHAR2(80)  NULL ,
	job_uuid 		RAW(16) NULL ,
	is_volatile 		NVARCHAR2(1)  NULL ,
	description 		NVARCHAR2(120)  NULL ,
	next_fire_time 		NUMBER NULL ,
	prev_fire_time 		NUMBER NULL ,
	trigger_state 		NVARCHAR2(16)  NULL ,
	trigger_type 		NVARCHAR2(8)  NULL ,
	start_time 		NUMBER NULL ,
	end_time 		NUMBER NULL ,
	misfire_instr 		int NULL ,
	creation_user 		NVARCHAR2(64)  NULL ,
	creation_date 		NUMBER NULL ,
	last_update_user 	NVARCHAR2(64)  NULL ,
	last_update_date 	NUMBER NULL 
);

ALTER TABLE ucm_triggers
       ADD CONSTRAINT XPKucm_triggers PRIMARY KEY (trigger_uuid);



--
-- Generated grants from mdb_ora on Thu Jan 19 14:30:20 2006
--

grant delete on ucm_calendars to ucmadmin
;
grant insert on ucm_calendars to ucmadmin
;
grant update on ucm_calendars to ucmadmin
;
grant select on ucm_calendars to ucmadmin
;
grant select on ucm_calendars to ucmuser
;
grant delete on ucm_calendars to uniadmin
;
grant insert on ucm_calendars to uniadmin
;
grant update on ucm_calendars to uniadmin
;
grant select on ucm_calendars to uniadmin
;
grant select on ucm_calendars to uniuser
;

grant delete on ucm_cron_triggers to ucmadmin
;
grant insert on ucm_cron_triggers to ucmadmin
;
grant update on ucm_cron_triggers to ucmadmin
;
grant select on ucm_cron_triggers to ucmadmin
;
grant select on ucm_cron_triggers to ucmuser
;
grant delete on ucm_cron_triggers to uniadmin
;
grant insert on ucm_cron_triggers to uniadmin
;
grant update on ucm_cron_triggers to uniadmin
;
grant select on ucm_cron_triggers to uniadmin
;
grant select on ucm_cron_triggers to uniuser
;

grant delete on ucm_fired_triggers to ucmadmin
;
grant insert on ucm_fired_triggers to ucmadmin
;
grant update on ucm_fired_triggers to ucmadmin
;
grant select on ucm_fired_triggers to ucmadmin
;
grant select on ucm_fired_triggers to ucmuser
;
grant delete on ucm_fired_triggers to uniadmin
;
grant insert on ucm_fired_triggers to uniadmin
;
grant update on ucm_fired_triggers to uniadmin
;
grant select on ucm_fired_triggers to uniadmin
;
grant select on ucm_fired_triggers to uniuser
;

grant delete on ucm_history to ucmadmin
;
grant insert on ucm_history to ucmadmin
;
grant update on ucm_history to ucmadmin
;
grant select on ucm_history to ucmadmin
;
grant select on ucm_history to ucmuser
;
grant delete on ucm_history to uniadmin
;
grant insert on ucm_history to uniadmin
;
grant update on ucm_history to uniadmin
;
grant select on ucm_history to uniadmin
;
grant select on ucm_history to uniuser
;

grant delete on ucm_job_details to ucmadmin
;
grant insert on ucm_job_details to ucmadmin
;
grant update on ucm_job_details to ucmadmin
;
grant select on ucm_job_details to ucmadmin
;
grant select on ucm_job_details to ucmuser
;
grant delete on ucm_job_details to uniadmin
;
grant insert on ucm_job_details to uniadmin
;
grant update on ucm_job_details to uniadmin
;
grant select on ucm_job_details to uniadmin
;
grant select on ucm_job_details to uniuser
;

grant delete on ucm_job_listeners to ucmadmin
;
grant insert on ucm_job_listeners to ucmadmin
;
grant update on ucm_job_listeners to ucmadmin
;
grant select on ucm_job_listeners to ucmadmin
;
grant select on ucm_job_listeners to ucmuser
;
grant delete on ucm_job_listeners to uniadmin
;
grant insert on ucm_job_listeners to uniadmin
;
grant update on ucm_job_listeners to uniadmin
;
grant select on ucm_job_listeners to uniadmin
;
grant select on ucm_job_listeners to uniuser
;

grant delete on ucm_link_calendar_trigger to ucmadmin
;
grant insert on ucm_link_calendar_trigger to ucmadmin
;
grant update on ucm_link_calendar_trigger to ucmadmin
;
grant select on ucm_link_calendar_trigger to ucmadmin
;
grant select on ucm_link_calendar_trigger to ucmuser
;
grant delete on ucm_link_calendar_trigger to uniadmin
;
grant insert on ucm_link_calendar_trigger to uniadmin
;
grant update on ucm_link_calendar_trigger to uniadmin
;
grant select on ucm_link_calendar_trigger to uniadmin
;
grant select on ucm_link_calendar_trigger to uniuser
;

grant delete on ucm_link_config_report to ucmadmin
;
grant insert on ucm_link_config_report to ucmadmin
;
grant update on ucm_link_config_report to ucmadmin
;
grant select on ucm_link_config_report to ucmadmin
;
grant select on ucm_link_config_report to ucmuser
;
grant delete on ucm_link_config_report to uniadmin
;
grant insert on ucm_link_config_report to uniadmin
;
grant update on ucm_link_config_report to uniadmin
;
grant select on ucm_link_config_report to uniadmin
;
grant select on ucm_link_config_report to uniuser
;

grant delete on ucm_locks to ucmadmin
;
grant insert on ucm_locks to ucmadmin
;
grant update on ucm_locks to ucmadmin
;
grant select on ucm_locks to ucmadmin
;
grant select on ucm_locks to ucmuser
;
grant delete on ucm_locks to uniadmin
;
grant insert on ucm_locks to uniadmin
;
grant update on ucm_locks to uniadmin
;
grant select on ucm_locks to uniadmin
;
grant select on ucm_locks to uniuser
;

grant delete on ucm_mib_data to ucmadmin
;
grant insert on ucm_mib_data to ucmadmin
;
grant update on ucm_mib_data to ucmadmin
;
grant select on ucm_mib_data to ucmadmin
;
grant select on ucm_mib_data to ucmuser
;
grant delete on ucm_mib_data to uniadmin
;
grant insert on ucm_mib_data to uniadmin
;
grant update on ucm_mib_data to uniadmin
;
grant select on ucm_mib_data to uniadmin
;
grant select on ucm_mib_data to uniuser
;

grant delete on ucm_mib_logreportdata to ucmadmin
;
grant insert on ucm_mib_logreportdata to ucmadmin
;
grant update on ucm_mib_logreportdata to ucmadmin
;
grant select on ucm_mib_logreportdata to ucmadmin
;
grant select on ucm_mib_logreportdata to ucmuser
;
grant delete on ucm_mib_logreportdata to uniadmin
;
grant insert on ucm_mib_logreportdata to uniadmin
;
grant update on ucm_mib_logreportdata to uniadmin
;
grant select on ucm_mib_logreportdata to uniadmin
;
grant select on ucm_mib_logreportdata to uniuser
;

grant delete on ucm_mib_miblabel to ucmadmin
;
grant insert on ucm_mib_miblabel to ucmadmin
;
grant update on ucm_mib_miblabel to ucmadmin
;
grant select on ucm_mib_miblabel to ucmadmin
;
grant select on ucm_mib_miblabel to ucmuser
;
grant delete on ucm_mib_miblabel to uniadmin
;
grant insert on ucm_mib_miblabel to uniadmin
;
grant update on ucm_mib_miblabel to uniadmin
;
grant select on ucm_mib_miblabel to uniadmin
;
grant select on ucm_mib_miblabel to uniuser
;

grant delete on ucm_mib_reportdata to ucmadmin
;
grant insert on ucm_mib_reportdata to ucmadmin
;
grant update on ucm_mib_reportdata to ucmadmin
;
grant select on ucm_mib_reportdata to ucmadmin
;
grant select on ucm_mib_reportdata to ucmuser
;
grant delete on ucm_mib_reportdata to uniadmin
;
grant insert on ucm_mib_reportdata to uniadmin
;
grant update on ucm_mib_reportdata to uniadmin
;
grant select on ucm_mib_reportdata to uniadmin
;
grant select on ucm_mib_reportdata to uniuser
;

grant delete on ucm_mib_tglabel to ucmadmin
;
grant insert on ucm_mib_tglabel to ucmadmin
;
grant update on ucm_mib_tglabel to ucmadmin
;
grant select on ucm_mib_tglabel to ucmadmin
;
grant select on ucm_mib_tglabel to ucmuser
;
grant delete on ucm_mib_tglabel to uniadmin
;
grant insert on ucm_mib_tglabel to uniadmin
;
grant update on ucm_mib_tglabel to uniadmin
;
grant select on ucm_mib_tglabel to uniadmin
;
grant select on ucm_mib_tglabel to uniuser
;

grant delete on ucm_mib_varlabel to ucmadmin
;
grant insert on ucm_mib_varlabel to ucmadmin
;
grant update on ucm_mib_varlabel to ucmadmin
;
grant select on ucm_mib_varlabel to ucmadmin
;
grant select on ucm_mib_varlabel to ucmuser
;
grant delete on ucm_mib_varlabel to uniadmin
;
grant insert on ucm_mib_varlabel to uniadmin
;
grant update on ucm_mib_varlabel to uniadmin
;
grant select on ucm_mib_varlabel to uniadmin
;
grant select on ucm_mib_varlabel to uniuser
;

grant delete on ucm_paused_trigger_grps to ucmadmin
;
grant insert on ucm_paused_trigger_grps to ucmadmin
;
grant update on ucm_paused_trigger_grps to ucmadmin
;
grant select on ucm_paused_trigger_grps to ucmadmin
;
grant select on ucm_paused_trigger_grps to ucmuser
;
grant delete on ucm_paused_trigger_grps to uniadmin
;
grant insert on ucm_paused_trigger_grps to uniadmin
;
grant update on ucm_paused_trigger_grps to uniadmin
;
grant select on ucm_paused_trigger_grps to uniadmin
;
grant select on ucm_paused_trigger_grps to uniuser
;

grant delete on ucm_scheduler_state to ucmadmin
;
grant insert on ucm_scheduler_state to ucmadmin
;
grant update on ucm_scheduler_state to ucmadmin
;
grant select on ucm_scheduler_state to ucmadmin
;
grant select on ucm_scheduler_state to ucmuser
;
grant delete on ucm_scheduler_state to uniadmin
;
grant insert on ucm_scheduler_state to uniadmin
;
grant update on ucm_scheduler_state to uniadmin
;
grant select on ucm_scheduler_state to uniadmin
;
grant select on ucm_scheduler_state to uniuser
;

grant delete on ucm_simple_triggers to ucmadmin
;
grant insert on ucm_simple_triggers to ucmadmin
;
grant update on ucm_simple_triggers to ucmadmin
;
grant select on ucm_simple_triggers to ucmadmin
;
grant select on ucm_simple_triggers to ucmuser
;
grant delete on ucm_simple_triggers to uniadmin
;
grant insert on ucm_simple_triggers to uniadmin
;
grant update on ucm_simple_triggers to uniadmin
;
grant select on ucm_simple_triggers to uniadmin
;
grant select on ucm_simple_triggers to uniuser
;

grant delete on ucm_trigger_listeners to ucmadmin
;
grant insert on ucm_trigger_listeners to ucmadmin
;
grant update on ucm_trigger_listeners to ucmadmin
;
grant select on ucm_trigger_listeners to ucmadmin
;
grant select on ucm_trigger_listeners to ucmuser
;
grant delete on ucm_trigger_listeners to uniadmin
;
grant insert on ucm_trigger_listeners to uniadmin
;
grant update on ucm_trigger_listeners to uniadmin
;
grant select on ucm_trigger_listeners to uniadmin
;
grant select on ucm_trigger_listeners to uniuser
;

grant delete on ucm_triggers to ucmadmin
;
grant insert on ucm_triggers to ucmadmin
;
grant update on ucm_triggers to ucmadmin
;
grant select on ucm_triggers to ucmadmin
;
grant select on ucm_triggers to ucmuser
;
grant delete on ucm_triggers to uniadmin
;
grant insert on ucm_triggers to uniadmin
;
grant update on ucm_triggers to uniadmin
;
grant select on ucm_triggers to uniadmin
;
grant select on ucm_triggers to uniuser
;

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 14938364, systimestamp, 1, 4, 'Star 14938364 NSM UCM create roles and ucm tables' );

COMMIT;

EXIT SUCCESS;
