SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;

/****************************************************************************************/
/*                                                                                      */
/* Star 15415231 SERVICE DELIVERY SCHEMA PATCH 						*/
/*                                                                                      */
/****************************************************************************************/

alter table usm_report_profile_attrs MODIFY ( value  nvarchar2(2000) );

alter table usm_report_profile_spec MODIFY ( default_value nvarchar2(2000) );

alter table usm_report_profile_spec_values MODIFY ( value  nvarchar2(2000) );

alter table usm_report_dataview MODIFY ( dataobject_string    nvarchar2(1024) );

alter table usm_slo_template MODIFY ( comments     varchar(1024) );

alter table usm_slo_template MODIFY ( description     varchar(1024) );

alter table usm_slo_template MODIFY ( warning_text     varchar(1024) );

alter table usm_slo_template MODIFY ( violation_text    varchar(1024) );

alter table usm_slo_template MODIFY ( unit    varchar(50) );

ALTER TABLE usm_portal_template DROP ( authentication_url ) CASCADE CONSTRAINTS;
ALTER TABLE usm_portal_template ADD ( authentication_url NCLOB );

ALTER TABLE usm_portal_template DROP ( xsl_url ) CASCADE CONSTRAINTS;
ALTER TABLE usm_portal_template ADD ( xsl_url NCLOB );

ALTER TABLE usm_portal_template DROP ( content_url ) CASCADE CONSTRAINTS;
ALTER TABLE usm_portal_template ADD ( content_url	NCLOB );

alter table usm_portal_template MODIFY ( file_name nvarchar2(128) );

alter table usm_portal_template MODIFY ( params varchar(1024) );

alter table usm_schema_comp MODIFY ( name    nvarchar2(256) );

alter table usm_scope MODIFY ( unit    nvarchar2(50) );

alter table usm_cor_data MODIFY ( icon    nvarchar2(256) );

alter table usm_analysis MODIFY ( access_group    nvarchar2(255) );

/*
	added utility procedure "usm_proc_drop_idxkey" to drop index, if the index name exists
	tname:		Table Name
	idxname:	Index Name 
	oname:		Owner Name
*/
CREATE OR REPLACE PROCEDURE usm_proc_drop_idxkey (tname IN VARCHAR2, idxname IN VARCHAR2, oname IN VARCHAR2)
AS
	drop_idx_name VARCHAR2(60);
	stmt varchar(8000);

	cursor c1 IS		
		SELECT INDEX_NAME 
		FROM user_indexes 
		WHERE TABLE_NAME = UPPER(tname) AND TABLE_OWNER = UPPER(oname);
		
BEGIN
    OPEN c1;
    FETCH c1 INTO drop_idx_name;
    IF c1%FOUND THEN
	stmt := 'DROP INDEX ' || drop_idx_name;
    	DBMS_OUTPUT.PUT_LINE('Drop Index stmt: ' || stmt);
    	EXECUTE IMMEDIATE stmt;
    	COMMIT;
    END IF;
    CLOSE c1;
EXCEPTION
    WHEN OTHERS THEN
       CLOSE c1;
       DBMS_OUTPUT.PUT_LINE('Error ' || TO_CHAR(SQLCODE) || ': ' || SQLERRM);
       RAISE;	
END;
/

exec usm_proc_drop_idxkey('usm_analysis', 'usm_analysis_idx_01', 'mdbadmin');

CREATE INDEX usm_analysis_idx_01 ON usm_analysis
(
       url                            ASC,
       access_group                   ASC,
       release_status                 ASC,
       period_start                   ASC
);

exec usm_proc_drop_idxkey('usm_analysis', 'usm_analysis_idx_02', 'mdbadmin');

CREATE INDEX usm_analysis_idx_02 ON usm_analysis
(
       report_group_id				ASC,
       category						ASC,
       access_group                 ASC,
       release_status               ASC,
       period_start                 ASC,
       period_type					ASC,
       analyze_status               ASC
);

exec usm_proc_drop_idxkey('usm_analysis', 'usm_analysis_idx_03', 'mdbadmin');

CREATE INDEX usm_analysis_idx_03 ON usm_analysis
(
       access_group                 ASC,
       analyze_job_id               ASC,
       release_status               ASC,
       analyze_status				ASC,
       period_start                 ASC
);


alter table usm_slo_instance MODIFY ( operator     varchar(8) );

ALTER TABLE usm_metric_category MODIFY ( name     NVARCHAR2(256) );

ALTER TABLE usm_metric_category MODIFY ( comments    NVARCHAR2(256) );


/*
	added utility procedure "usm_proc_drop_column" to drop column, if the column exists
	tname:		Table Name
	colname:	Column Name 
	oname:		Owner Name
*/
CREATE OR REPLACE PROCEDURE usm_proc_drop_column (tname IN VARCHAR2, colname IN VARCHAR2, oname IN VARCHAR2)
AS
	drop_col_name VARCHAR2(60);
	stmt varchar(8000);

	cursor c1 IS		
		SELECT COLUMN_NAME 
		FROM ALL_TAB_COLUMNS 
			WHERE TABLE_NAME = UPPER(tname) AND 
			OWNER = UPPER(oname) AND 
			COLUMN_NAME = UPPER(colname);
		
BEGIN
    OPEN c1;
    FETCH c1 INTO drop_col_name;
    IF c1%FOUND THEN
	stmt := 'ALTER TABLE ' || tname || ' DROP (' || drop_col_name || ')';
    	DBMS_OUTPUT.PUT_LINE('Drop Column stmt: ' || stmt);
    	EXECUTE IMMEDIATE stmt;
    	COMMIT;
    END IF;
    CLOSE c1;
EXCEPTION
    WHEN OTHERS THEN
       CLOSE c1;
       DBMS_OUTPUT.PUT_LINE('Error ' || TO_CHAR(SQLCODE) || ': ' || SQLERRM);
       RAISE;	
END;
/

exec usm_proc_drop_column('usm_asset', 'object_type', 'mdbadmin');
exec usm_proc_drop_column('usm_asset', 'object_id', 'mdbadmin');
ALTER TABLE usm_asset ADD ( object_type  integer);
ALTER TABLE usm_asset ADD ( object_id  integer);

/*
	added utility procedure "usm_proc_drop_deltatable" to delta table, if the table exists
	tname:		Table Name
	oname:		Owner Name
*/
CREATE OR REPLACE PROCEDURE usm_proc_drop_deltatable(tname IN VARCHAR2, oname IN VARCHAR2)
AS
	drop_delta_tname VARCHAR2(60);
	stmt varchar(8000);

	cursor c1 IS		
		SELECT TABLE_NAME
		FROM ALL_TABLES
		WHERE TABLE_NAME = UPPER(tname) AND OWNER = UPPER(oname);
				
BEGIN
    OPEN c1;
    FETCH c1 INTO drop_delta_tname;
    IF c1%FOUND THEN
	stmt := 'DROP TABLE ' || drop_delta_tname;
    	DBMS_OUTPUT.PUT_LINE('Drop Table stmt: ' || stmt);
    	EXECUTE IMMEDIATE stmt;
    	COMMIT;
    END IF;
    CLOSE c1;
EXCEPTION
    WHEN OTHERS THEN
       CLOSE c1;
       DBMS_OUTPUT.PUT_LINE('Error ' || TO_CHAR(SQLCODE) || ': ' || SQLERRM);
       RAISE;	
END;
/

exec usm_proc_drop_deltatable('usm_link_ticket_request_item', 'mdbadmin');
CREATE TABLE usm_link_ticket_request_item (
       persid               VARCHAR2(30) NOT NULL,
       ref_num              VARCHAR2(30) NOT NULL,
       request_item_id      INTEGER NOT NULL,
       request_id           INTEGER NOT NULL
);

ALTER TABLE usm_link_ticket_request_item
	ADD CONSTRAINT XPKusm_link_ticket_request_ite PRIMARY KEY (persid, ref_num, request_item_id, request_id);

grant   select on usm_link_ticket_request_item to usmgroup;
grant   update on usm_link_ticket_request_item to usmgroup;
grant   delete on usm_link_ticket_request_item to usmgroup;
grant   insert on usm_link_ticket_request_item to usmgroup;


exec usm_proc_drop_column('usm_offering', 'sd_request_area', 'mdbadmin');
exec usm_proc_drop_column('usm_rate_plan', 'sd_request_area', 'mdbadmin');
exec usm_proc_drop_column('usm_rate_definition', 'sd_request_area', 'mdbadmin');

ALTER TABLE usm_offering ADD ( sd_request_area varchar(30) );
ALTER TABLE usm_rate_plan ADD ( sd_request_area varchar(30) );
ALTER TABLE usm_rate_definition ADD ( sd_request_area varchar(30) );


/*
      	-------------
	  	Oct 20, 2006
	  	-------------
	      1.
		      CHANGE Table usm_request
		          - Changing column order
		          - change datatype from nvarchar to long nvarchar of column comments          
		      ACTION is DROP and CREATE Table usm_request
				  - drop tables
				    usm_link_subscription_asset
					usm_request_status (this is new delta table : NO DROP)
					usm_request_value
					usm_request
		          - create all tables.
		  2. CHANGE Table usm_request_item_form
		   		form_elem_name
		   		form_elem_value	     
*/
/*
      	-------------
	  	Oct 23, 2006
	  	-------------
	  		Updated Change on the Oct 20:
	  		For MDB Backward compatibility, altering column for the Ingres ans SQLServer, but drop for Oracle.
	      1.
		     CHANGE Table usm_request
		          - change datatype from nvarchar to long nvarchar of column comments
		     ACTION:
		     	DROP child table FK constrints only;
		     	DROP table usm_request
		     	re-create table and the constraints.
*/
/*
	-------------
	Note for dropping system generated fkeys
	-------------	
	added utility procedure "usm_proc_drop_fkey" to drop foreign keys without having drop table stmt.
	using the procedure, drop keys and alter the table.
*/
CREATE OR REPLACE PROCEDURE usm_proc_drop_fkey (tname IN VARCHAR2, cname IN VARCHAR2, oname IN VARCHAR2)
AS
	drop_cons_name VARCHAR2(60);
	stmt varchar(8000);

	cursor c1 IS
      		SELECT cons.CONSTRAINT_NAME
		FROM user_constraints cons, user_cons_columns cons_col
		WHERE cons.CONSTRAINT_TYPE = 'R' AND
		cons.CONSTRAINT_NAME = cons_col.CONSTRAINT_NAME AND
		cons.TABLE_NAME = UPPER(tname) AND
		cons.OWNER = UPPER(oname) AND
		cons_col.COLUMN_NAME = UPPER(cname);
BEGIN
    OPEN c1;
    FETCH c1 INTO drop_cons_name;
    IF c1%FOUND THEN
	stmt := 'ALTER TABLE ' || tname || ' DROP CONSTRAINT ' || drop_cons_name;
    	DBMS_OUTPUT.PUT_LINE('Drop Constraint stmt: ' || stmt);
    	EXECUTE IMMEDIATE stmt;
    	COMMIT;
    END IF;
    CLOSE c1;
EXCEPTION
    WHEN OTHERS THEN
       CLOSE c1;
       DBMS_OUTPUT.PUT_LINE('Error ' || TO_CHAR(SQLCODE) || ': ' || SQLERRM);
       RAISE;	
END;
/

exec usm_proc_drop_fkey('usm_request_value', 'request_id', 'mdbadmin');

exec usm_proc_drop_fkey('usm_link_subscription_asset', 'request_id', 'mdbadmin');

exec usm_proc_drop_fkey('usm_request_status', 'request_id', 'mdbadmin');

exec usm_proc_drop_deltatable('usm_request_backup', 'mdbadmin');
CREATE TABLE usm_request_backup AS SELECT
       request_id,
       name,
       status,
       created_date,
       modified_date,
       completion_date,
       desired_date,
       priority,
       req_for_account_id,
       req_by_account_id,
       req_for_user_id,
       req_by_user_id,
       code,
       domain,
       location_uuid              
FROM usm_request;

exec usm_proc_drop_deltatable('usm_request', 'mdbadmin');
CREATE TABLE usm_request (
       request_id           NUMBER NOT NULL,
       name                 NVARCHAR2(128) NOT NULL,
       status               NUMBER NOT NULL,
       created_date         DATE DEFAULT sysdate NOT NULL,
       modified_date        DATE DEFAULT sysdate NOT NULL,
       completion_date      DATE NULL,
       desired_date         DATE NULL,
       priority             NUMBER NULL,
       req_for_account_id   VARCHAR2(50) NULL,
       req_by_account_id    VARCHAR2(50) NULL,
       req_for_user_id      NVARCHAR2(100) NULL,
       req_by_user_id       NVARCHAR2(100) NULL,
       code                 NVARCHAR2(64) NULL,
       domain               VARCHAR2(50) NULL,
       location_uuid        RAW(16) NULL ,
       comments             NCLOB NULL
);

INSERT INTO usm_request (
       request_id,
       name,
       status,
       created_date,
       modified_date,
       completion_date,
       desired_date,
       priority,
       req_for_account_id,
       req_by_account_id,
       req_for_user_id,
       req_by_user_id,
       code,
       domain,
       location_uuid)
SELECT * FROM usm_request_backup;

DROP TABLE usm_request_backup;

CREATE INDEX usm_request_idx_01 ON usm_request
(
       req_by_user_id                 ASC,
       req_for_account_id             ASC,
       status                         ASC
);

CREATE INDEX usm_request_idx_02 ON usm_request
(
       req_by_user_id                 ASC,
       req_for_user_id                ASC
);

CREATE INDEX usm_request_idx_03 ON usm_request
(
       req_by_user_id                 ASC,
       req_for_user_id                ASC,
       status                         ASC
);


ALTER TABLE usm_request
       ADD CONSTRAINT XPKusm_request PRIMARY KEY (request_id);
       
       
/**/

ALTER TABLE usm_request_value
       ADD (	FOREIGN KEY (request_id)
                             REFERENCES usm_request  (request_id)
                             ON DELETE CASCADE );

ALTER TABLE usm_link_subscription_asset
       ADD (	FOREIGN KEY (request_id)
                             REFERENCES usm_request  (request_id) );

ALTER TABLE usm_request
       ADD (	FOREIGN KEY (domain)
                             REFERENCES usm_tenant  (tenant_id)
                             ON DELETE SET NULL );
                             
/**/

grant   insert   on usm_request to usmgroup;
grant   delete   on usm_request to usmgroup;
grant   update   on usm_request to usmgroup;
grant   select   on usm_request to usmgroup;

/**/

exec usm_proc_drop_deltatable('usm_request_status', 'mdbadmin');
CREATE TABLE usm_request_status (
       request_status_id    INTEGER NOT NULL,
       request_id           INTEGER NOT NULL,
       subscription_detail_id INTEGER NULL,
       status               INTEGER NOT NULL,
       status_date          DATE NOT NULL,
       user_id              VARCHAR2(128) NULL
);

ALTER TABLE usm_request_status
	    ADD CONSTRAINT XPKusm_request_status PRIMARY KEY (request_status_id);

grant   select on usm_request_status to usmgroup;
grant   update on usm_request_status to usmgroup;
grant   delete on usm_request_status to usmgroup;
grant   insert on usm_request_status to usmgroup;


ALTER TABLE usm_request_status
	    ADD CONSTRAINT XFK01_usm_request_status
		   FOREIGN KEY (subscription_detail_id)
				  REFERENCES usm_subscription_detail  (id);

ALTER TABLE usm_request_status
	    ADD CONSTRAINT XFK02_usm_request_status
		   FOREIGN KEY (request_id)
				  REFERENCES usm_request  (request_id);

CREATE INDEX XIE1usm_asset ON usm_asset
(
       object_id                      ASC
);

exec usm_proc_drop_column('usm_contact_extension', 'data1', 'mdbadmin');
exec usm_proc_drop_column('usm_contact_extension', 'data2', 'mdbadmin');
exec usm_proc_drop_column('usm_contact_extension', 'data3', 'mdbadmin');
exec usm_proc_drop_column('usm_contact_extension', 'data4', 'mdbadmin');
exec usm_proc_drop_column('usm_contact_extension', 'data5', 'mdbadmin');
exec usm_proc_drop_column('usm_contact_extension', 'data6', 'mdbadmin');
exec usm_proc_drop_column('usm_contact_extension', 'data7', 'mdbadmin');

ALTER TABLE usm_contact_extension ADD (data1                NVARCHAR2(512) NULL);
ALTER TABLE usm_contact_extension ADD (data2                NVARCHAR2(512) NULL);
ALTER TABLE usm_contact_extension ADD (data3                NVARCHAR2(512) NULL);
ALTER TABLE usm_contact_extension ADD (data4                NVARCHAR2(512) NULL);
ALTER TABLE usm_contact_extension ADD (data5                NVARCHAR2(512) NULL);
ALTER TABLE usm_contact_extension ADD (data6                NVARCHAR2(512) NULL);
ALTER TABLE usm_contact_extension ADD (data7                NVARCHAR2(512) NULL);

exec usm_proc_drop_column('usm_offering', 'path', 'mdbadmin');
exec usm_proc_drop_column('usm_offering', 'tree_level', 'mdbadmin');

ALTER TABLE usm_offering ADD ( path varchar(128) NULL );
ALTER TABLE usm_offering ADD ( tree_level integer NULL );

exec usm_proc_drop_column('usm_dash', 'role_id', 'mdbadmin');
ALTER TABLE usm_dash ADD ( role_id VARCHAR2(50) NULL );

CREATE INDEX XIF2usm_dash ON usm_dash
(
       role_id                        ASC
);

ALTER TABLE usm_dash
		ADD CONSTRAINT XFK01_usm_dash
			FOREIGN KEY (role_id)
				REFERENCES usm_role  (role_id);


exec usm_proc_drop_deltatable('usm_cor_dynamic', 'mdbadmin');
CREATE TABLE usm_cor_dynamic (
       cor_dynamic_id       INTEGER NOT NULL,
       server_id            INTEGER NOT NULL,
       metric_id            INTEGER NOT NULL,
       class_name           VARCHAR2(255) NOT NULL,
       bpv_uuid             VARCHAR2(50) NULL
);

ALTER TABLE usm_cor_dynamic
       ADD CONSTRAINT XPKusm_cor_dynamic PRIMARY KEY (cor_dynamic_id);

grant   select on usm_cor_dynamic to usmgroup;
grant   update on usm_cor_dynamic to usmgroup;
grant   delete on usm_cor_dynamic to usmgroup;
grant   insert on usm_cor_dynamic to usmgroup;

exec usm_proc_drop_deltatable('usm_cor_dynamic_attr', 'mdbadmin');
CREATE TABLE usm_cor_dynamic_attr (
       cor_dynamic_attr_id  INTEGER NOT NULL,
       cor_dynamic_id       INTEGER NOT NULL,
       metric_attr_spec_id  INTEGER NOT NULL,
       value                VARCHAR2(511) NULL
);


ALTER TABLE usm_cor_dynamic_attr
       ADD CONSTRAINT XPKusm_cor_dynamic_attr PRIMARY KEY (cor_dynamic_attr_id);


grant   select on usm_cor_dynamic_attr to usmgroup;
grant   update on usm_cor_dynamic_attr to usmgroup;
grant   delete on usm_cor_dynamic_attr to usmgroup;
grant   insert on usm_cor_dynamic_attr to usmgroup;

exec usm_proc_drop_deltatable('usm_cor_dynamic_report_group', 'mdbadmin');
CREATE TABLE usm_cor_dynamic_report_group (
       cor_dynamic_report_group_id INTEGER NOT NULL,
       cor_dynamic_id       INTEGER NOT NULL,
       report_group_id      INTEGER NOT NULL,
       use_calendar         CHAR(1) NOT NULL
);


ALTER TABLE usm_cor_dynamic_report_group
       ADD CONSTRAINT XPKusm_cor_dynamic_report_grp PRIMARY KEY (cor_dynamic_report_group_id);

grant   select on usm_cor_dynamic_report_group to usmgroup;
grant   update on usm_cor_dynamic_report_group to usmgroup;
grant   delete on usm_cor_dynamic_report_group to usmgroup;
grant   insert on usm_cor_dynamic_report_group to usmgroup;

exec usm_proc_drop_deltatable('usm_offering_sla', 'mdbadmin');
CREATE TABLE usm_offering_sla (
       offering_id          INTEGER NOT NULL,
       item_id              INTEGER NOT NULL,
       start_status         INTEGER NOT NULL,
       end_status           INTEGER NOT NULL,
       wrn_millis           INTEGER NOT NULL,
       vio_millis           INTEGER NOT NULL
);

grant   select on usm_offering_sla to usmgroup;
grant   update on usm_offering_sla to usmgroup;
grant   delete on usm_offering_sla to usmgroup;
grant   insert on usm_offering_sla to usmgroup;


exec usm_proc_drop_idxkey('usm_offering_sla', 'XIE1usm_offering_sla', 'mdbadmin');

CREATE INDEX XIE1usm_offering_sla ON usm_offering_sla
(
       offering_id, item_id
);

exec usm_proc_drop_deltatable('usm_request_item_form', 'mdbadmin');
CREATE TABLE usm_request_item_form (
       subscription_detail_id INTEGER NOT NULL,
       form_elem_name       NVARCHAR2(64) NOT NULL,
       form_elem_value      NCLOB NULL
);


ALTER TABLE usm_request_item_form
       ADD CONSTRAINT XPKusm_request_item_form PRIMARY KEY (subscription_detail_id, form_elem_name);

grant   select on usm_request_item_form to usmgroup;
grant   update on usm_request_item_form to usmgroup;
grant   delete on usm_request_item_form to usmgroup;
grant   insert on usm_request_item_form to usmgroup;


ALTER TABLE  usm_cor_dynamic
       ADD  ( FOREIGN KEY (server_id)
                             REFERENCES usm_slm_server ) ;


ALTER TABLE  usm_cor_dynamic
       ADD  ( FOREIGN KEY (metric_id)
                             REFERENCES usm_metric ) ;


ALTER TABLE  usm_cor_dynamic_attr
       ADD  ( FOREIGN KEY (metric_attr_spec_id)
                             REFERENCES usm_metric_attr_spec ) ;


ALTER TABLE  usm_cor_dynamic_attr
       ADD  ( FOREIGN KEY (cor_dynamic_id)
                             REFERENCES usm_cor_dynamic ) ;


ALTER TABLE  usm_cor_dynamic_report_group
       ADD  ( FOREIGN KEY (report_group_id)
                             REFERENCES usm_report_group ) ;


ALTER TABLE  usm_cor_dynamic_report_group
       ADD  ( FOREIGN KEY (cor_dynamic_id)
                             REFERENCES usm_cor_dynamic ) ;


ALTER TABLE  usm_offering_sla
       ADD  ( FOREIGN KEY (item_id)
                             REFERENCES usm_rate_definition ) ;


ALTER TABLE  usm_offering_sla
       ADD  ( FOREIGN KEY (offering_id)
                             REFERENCES usm_offering ) ;


ALTER TABLE  usm_request_item_form
       ADD  ( FOREIGN KEY (subscription_detail_id)
                             REFERENCES usm_subscription_detail ) ;

exec usm_proc_drop_deltatable('usm_featured_offering', 'mdbadmin');
CREATE TABLE usm_featured_offering (
       featured_offering_id INTEGER NOT NULL,
       featured_in_offering_id INTEGER NOT NULL,
       feature_type         INTEGER NOT NULL
);

ALTER TABLE usm_featured_offering
       ADD CONSTRAINT XPKusm_featured_offering PRIMARY KEY (featured_offering_id, featured_in_offering_id);

grant   select on usm_featured_offering to usmgroup;
grant   update on usm_featured_offering to usmgroup;
grant   delete on usm_featured_offering to usmgroup;
grant   insert on usm_featured_offering to usmgroup;

exec usm_proc_drop_column('usm_request_pending_action', 'is_group', 'mdbadmin');
ALTER TABLE usm_request_pending_action ADD ( is_group INTEGER );

ALTER TABLE  usm_featured_offering
       ADD  ( FOREIGN KEY (featured_in_offering_id)
                             REFERENCES usm_offering (offering_id) ) ;

ALTER TABLE  usm_featured_offering
       ADD  ( FOREIGN KEY (featured_offering_id)
                             REFERENCES usm_offering (offering_id) ) ;

exec usm_proc_drop_deltatable('usm_rule_event_param', 'mdbadmin');
CREATE TABLE usm_rule_event_param (
       event_param_id       VARCHAR2(50) NOT NULL,
       event_type_id        VARCHAR2(50) NOT NULL,
       event_param_name     NVARCHAR2(64) NOT NULL,
       event_param_data_type INTEGER DEFAULT -1 NOT NULL
);

ALTER TABLE usm_rule_event_param
       ADD CONSTRAINT XPKusm_rule_event_param PRIMARY KEY (event_param_id);

grant   select on usm_rule_event_param to usmgroup;
grant   update on usm_rule_event_param to usmgroup;
grant   delete on usm_rule_event_param to usmgroup;
grant   insert on usm_rule_event_param to usmgroup;


ALTER TABLE usm_rule_event_param
       ADD  ( FOREIGN KEY (event_type_id)
                             REFERENCES usm_rule_event_type ) ;

exec usm_proc_drop_column('usm_rule_action', 'status', 'mdbadmin');
ALTER TABLE usm_rule_action ADD (status INTEGER DEFAULT -1 NOT NULL);

ALTER TABLE usm_rule_condition MODIFY ( condition varchar(1024) );

exec usm_proc_drop_deltatable('usm_plan_data_backup', 'mdbadmin');
CREATE TABLE usm_plan_data_backup AS SELECT
       fp_id,
       ps_id,
       cp_id,
       item_id,
       type,
       numeric_1
FROM usm_plan_data;

DROP TABLE usm_plan_data;

exec usm_proc_drop_deltatable('usm_plan_data', 'mdbadmin');
CREATE TABLE usm_plan_data (
       fp_id                NUMBER NOT NULL,
       ps_id                NUMBER NOT NULL,
       cp_id                NUMBER NOT NULL,
       item_id              NUMBER NOT NULL,
       type                 NUMBER NOT NULL,
       domain               VARCHAR2(50) NOT NULL,
       numeric_1            FLOAT NULL
);

INSERT INTO usm_plan_data (
       fp_id,
       ps_id,
       cp_id,
       item_id,
       type,
       domain,
       numeric_1
) SELECT 
       fp_id,
       ps_id,
       cp_id,
       item_id,
       type,
       '',
       numeric_1
FROM usm_plan_data_backup;

DROP TABLE usm_plan_data_backup;

ALTER TABLE usm_plan_data
			ADD CONSTRAINT XPKusm_plan_data PRIMARY KEY (fp_id, ps_id, cp_id, item_id, type, domain);

ALTER TABLE usm_plan_data
			ADD ( FOREIGN KEY (ps_id) REFERENCES usm_planning_set  (ps_id) );

ALTER TABLE usm_plan_data
			ADD ( FOREIGN KEY (fp_id) REFERENCES usm_fiscal_period  (fp_id) );

ALTER TABLE usm_plan_data
			ADD ( FOREIGN KEY (cp_id) REFERENCES usm_cost_pool  (cp_id) );

ALTER TABLE usm_plan_data
			ADD ( FOREIGN KEY (domain) REFERENCES usm_tenant  (tenant_id) );

grant   select   on usm_plan_data to usmgroup;
grant   insert   on usm_plan_data to usmgroup;
grant   delete   on usm_plan_data to usmgroup;
grant   update   on usm_plan_data to usmgroup;

exec usm_proc_drop_column('usm_offering', 'feature_sort_order_type', 'mdbadmin');
exec usm_proc_drop_column('usm_offering', 'feature_sort_order', 'mdbadmin');

ALTER TABLE usm_offering ADD (feature_sort_order_type INTEGER DEFAULT 0 NOT NULL);
ALTER TABLE usm_offering ADD (feature_sort_order INTEGER DEFAULT 0 NOT NULL);

ALTER TABLE usm_system_alert MODIFY (other_info3 nvarchar2(1024));

CREATE OR REPLACE FUNCTION usm_next_sequence_value (seq_name VARCHAR2)
    RETURN NUMBER
AS
    next_id NUMBER;
    CURSOR c_seq_generator IS
       SELECT id
         FROM usm_lastid
         WHERE name = seq_name
         FOR UPDATE;
    -- this locks current row
BEGIN
    OPEN c_seq_generator;
    FETCH c_seq_generator INTO next_id;

    IF c_seq_generator%FOUND THEN
       next_id := next_id + 1;
       UPDATE usm_lastid
          SET id = next_id
        WHERE CURRENT OF c_seq_generator;
    ELSE
       next_id := 0;
       INSERT INTO usm_lastid (name, id)
            VALUES (seq_name, next_id);
    END IF;
    CLOSE c_seq_generator;
    RETURN next_id;
EXCEPTION
    WHEN OTHERS THEN
       CLOSE c_seq_generator;
       RAISE;
END;
/

GRANT EXECUTE on usm_next_sequence_value TO usmgroup;


	/*
	  -------------
	  Sept 22, 2006
	  -------------

      CREATE Table
	       usm_das_analyzer_types
	       usm_das_analyzers
	       usm_das_analyses
	       usm_das_analysis_summaries
	       usm_das_analyzer_attributes
	       usm_das_analyzer_definitions
	       usm_report_group_attr_spec
	       usm_report_group_attr
	       usm_report_group_spec_value

      CHANGE for Table usm_metric_instance
          - Adding column report_group_id which references table usm_report_group

      CHANGE for Table usm_report_group
          - Adding column weight
          - Adding column account_id which references table usm_account
          - Adding column time_zone_code which references table ca_time_zone

      CHANGE for Table usm_snmp_config
          - Adding column privacyPassword
          - Adding column securityLevel
    */

exec usm_proc_drop_deltatable('usm_das_analyzer_types', 'mdbadmin');
CREATE TABLE usm_das_analyzer_types (
       analyzer_type_oid    INTEGER NOT NULL,
       analyzer_type_name   VARCHAR2(100) NOT NULL UNIQUE,
       description          NVARCHAR2(255) NULL,
       xml                  NCLOB NULL,
       element_category     VARCHAR2(10) NULL,
       input_value_type_oid INTEGER NOT NULL,
       output_value_type_oid INTEGER NOT NULL
);

ALTER TABLE usm_das_analyzer_types
       ADD CONSTRAINT XPKusm_das_analyzer_types PRIMARY KEY (analyzer_type_oid);

grant   select on usm_das_analyzer_types to usmgroup;
grant   update on usm_das_analyzer_types to usmgroup;
grant   delete on usm_das_analyzer_types to usmgroup;
grant   insert on usm_das_analyzer_types to usmgroup;

exec usm_proc_drop_deltatable('usm_das_analyzers', 'mdbadmin');
CREATE TABLE usm_das_analyzers (
       analyzer_oid         INTEGER NOT NULL,
       analyzer_type_oid    INTEGER NOT NULL,
       start_time           INTEGER NOT NULL,
       stop_time            INTEGER NOT NULL
);

ALTER TABLE usm_das_analyzers
       ADD CONSTRAINT XPKusm_das_analyzers PRIMARY KEY (analyzer_oid);

grant   select on usm_das_analyzers to usmgroup;
grant   update on usm_das_analyzers to usmgroup;
grant   delete on usm_das_analyzers to usmgroup;
grant   insert on usm_das_analyzers to usmgroup;

exec usm_proc_drop_deltatable('usm_das_analyses', 'mdbadmin');
CREATE TABLE usm_das_analyses (
       analysis_oid         INTEGER NOT NULL,
       analyzer_oid         INTEGER NOT NULL,
       xml                  NCLOB NOT NULL
);

ALTER TABLE usm_das_analyses
       ADD CONSTRAINT XPKusm_das_analyses PRIMARY KEY (analysis_oid);

grant   select on usm_das_analyses to usmgroup;
grant   update on usm_das_analyses to usmgroup;
grant   delete on usm_das_analyses to usmgroup;
grant   insert on usm_das_analyses to usmgroup;

exec usm_proc_drop_deltatable('usm_das_analysis_summaries', 'mdbadmin');
CREATE TABLE usm_das_analysis_summaries (
       analysis_summary_oid INTEGER NOT NULL,
       analyzer_oid         INTEGER NOT NULL,
       name                 VARCHAR2(50) NULL,
       value                VARCHAR2(255) NULL
);

ALTER TABLE usm_das_analysis_summaries
       ADD CONSTRAINT XPKusm_das_analysis_summaries PRIMARY KEY (analysis_summary_oid);

grant   select on usm_das_analysis_summaries to usmgroup;
grant   update on usm_das_analysis_summaries to usmgroup;
grant   delete on usm_das_analysis_summaries to usmgroup;
grant   insert on usm_das_analysis_summaries to usmgroup;

exec usm_proc_drop_deltatable('usm_das_analyzer_attributes', 'mdbadmin');
CREATE TABLE usm_das_analyzer_attributes (
       analyzer_attribute_oid INTEGER NOT NULL,
       analyzer_oid         INTEGER NOT NULL,
       attribute_name       VARCHAR2(50) NULL,
       attribute_value      VARCHAR2(255) NULL
);

ALTER TABLE usm_das_analyzer_attributes
       ADD CONSTRAINT XPKusm_das_analyzer_attributes PRIMARY KEY (analyzer_attribute_oid);

grant   select on usm_das_analyzer_attributes to usmgroup;
grant   update on usm_das_analyzer_attributes to usmgroup;
grant   delete on usm_das_analyzer_attributes to usmgroup;
grant   insert on usm_das_analyzer_attributes to usmgroup;

exec usm_proc_drop_deltatable('usm_das_analyzer_definitions', 'mdbadmin');
CREATE TABLE usm_das_analyzer_definitions (
       analyzer_definition_oid INTEGER NOT NULL,
       description          NVARCHAR2(255) NULL,
       xml                  NCLOB NULL
);

ALTER TABLE usm_das_analyzer_definitions
       ADD CONSTRAINT XPKusm_das_analyzer_definition PRIMARY KEY (analyzer_definition_oid);

grant   select on usm_das_analyzer_definitions to usmgroup;
grant   update on usm_das_analyzer_definitions to usmgroup;
grant   delete on usm_das_analyzer_definitions to usmgroup;
grant   insert on usm_das_analyzer_definitions to usmgroup;

exec usm_proc_drop_deltatable('usm_report_group_attr_spec', 'mdbadmin');
CREATE TABLE usm_report_group_attr_spec (
       report_group_attr_spec_id INTEGER NOT NULL,
       attribute_name       VARCHAR2(100) NULL,
       type                 VARCHAR2(20) NULL,
       form_type            VARCHAR2(20) NULL,
       label                NVARCHAR2(100) NULL,
       label_bundle_key     VARCHAR2(50) NULL,
       default_value        NVARCHAR2(255) NULL,
       default_reference_key VARCHAR2(50) NULL,
       is_required          CHAR(1) NULL,
       report_group_template_id INTEGER NOT NULL,
       attr_reference_plugin_id INTEGER NOT NULL,
       tab_order            INTEGER NULL
);

ALTER TABLE usm_report_group_attr_spec
       ADD CONSTRAINT XPKusm_report_group_attr_spec PRIMARY KEY (report_group_attr_spec_id);

grant   select on usm_report_group_attr_spec to usmgroup;
grant   update on usm_report_group_attr_spec to usmgroup;
grant   delete on usm_report_group_attr_spec to usmgroup;
grant   insert on usm_report_group_attr_spec to usmgroup;

exec usm_proc_drop_deltatable('usm_report_group_attr', 'mdbadmin');
CREATE TABLE usm_report_group_attr (
       report_group_attr_id INTEGER NOT NULL,
       report_group_id      INTEGER NOT NULL,
       report_group_attr_spec_id INTEGER NOT NULL,
       value                NVARCHAR2(512) NULL,
       reference_key        VARCHAR2(20) NULL
);

ALTER TABLE usm_report_group_attr
       ADD CONSTRAINT XPKusm_report_group_attr PRIMARY KEY (report_group_attr_id);

grant   select on usm_report_group_attr to usmgroup;
grant   update on usm_report_group_attr to usmgroup;
grant   delete on usm_report_group_attr to usmgroup;
grant   insert on usm_report_group_attr to usmgroup;

exec usm_proc_drop_deltatable('usm_report_group_spec_value', 'mdbadmin');
CREATE TABLE usm_report_group_spec_value (
       report_group_spec_value_id INTEGER NOT NULL,
       report_group_attr_spec_id INTEGER NOT NULL,
       label                NVARCHAR2(100) NULL,
       label_bundle_key     VARCHAR2(50) NULL,
       value                NVARCHAR2(100) NULL,
       value_order          INTEGER NULL,
       reference_key        VARCHAR2(50) NULL
);

ALTER TABLE usm_report_group_spec_value
       ADD CONSTRAINT XPKusm_report_group_spec_value PRIMARY KEY (report_group_spec_value_id);

grant   select on usm_report_group_spec_value to usmgroup;
grant   update on usm_report_group_spec_value to usmgroup;
grant   delete on usm_report_group_spec_value to usmgroup;
grant   insert on usm_report_group_spec_value to usmgroup;



      /*
      CHANGE for Table usm_metric_instance
          - Adding column report_group_id which references table usm_report_group

      CHANGE for Table usm_report_group
          - Adding column weight
          - Adding column account_id which references table usm_account
          - Adding column time_zone_code which references table ca_time_zone

      CHANGE for Table usm_snmp_config
          - Adding column privacyPassword
          - Adding column securityLevel
      */


exec usm_proc_drop_column('usm_report_group', 'weight', 'mdbadmin');
exec usm_proc_drop_column('usm_report_group', 'account_id', 'mdbadmin');
exec usm_proc_drop_column('usm_report_group', 'time_zone_code', 'mdbadmin');

ALTER TABLE usm_report_group ADD (weight			INTEGER NULL);
ALTER TABLE usm_report_group ADD (account_id		VARCHAR2(50) NULL);
ALTER TABLE usm_report_group ADD (time_zone_code		VARCHAR2(64) NULL);

ALTER TABLE usm_report_group
		ADD ( FOREIGN KEY (account_id) REFERENCES usm_account ON DELETE SET NULL );

ALTER TABLE usm_report_group
		ADD ( FOREIGN KEY (time_zone_code) REFERENCES ca_time_zone ON DELETE SET NULL );

exec usm_proc_drop_column('usm_metric_instance', 'analyzed_report_group_id', 'mdbadmin');
ALTER TABLE usm_metric_instance ADD (analyzed_report_group_id       INTEGER NULL);

ALTER TABLE usm_metric_instance
		ADD ( FOREIGN KEY (analyzed_report_group_id) REFERENCES usm_report_group (report_group_id) ON DELETE SET NULL );


exec usm_proc_drop_column('usm_snmp_config', 'privacyPassword', 'mdbadmin');
exec usm_proc_drop_column('usm_snmp_config', 'securityLevel', 'mdbadmin');
ALTER TABLE usm_snmp_config ADD (privacyPassword     VARCHAR2(100) NULL);
ALTER TABLE usm_snmp_config ADD (securityLevel       VARCHAR2(20) NULL);

/* */


ALTER TABLE usm_das_analyzers
       ADD  ( FOREIGN KEY (analyzer_type_oid)
                             REFERENCES usm_das_analyzer_types );

ALTER TABLE usm_das_analyses
       ADD  ( FOREIGN KEY (analyzer_oid)
                             REFERENCES usm_das_analyzers );

ALTER TABLE usm_das_analysis_summaries
       ADD  ( FOREIGN KEY (analyzer_oid)
                             REFERENCES usm_das_analyzers );

ALTER TABLE usm_das_analyzer_attributes
       ADD  ( FOREIGN KEY (analyzer_oid)
                             REFERENCES usm_das_analyzers );

ALTER TABLE usm_report_group_attr_spec
       ADD  ( FOREIGN KEY (attr_reference_plugin_id)
                             REFERENCES usm_attr_reference_plugin );

ALTER TABLE usm_report_group_attr_spec
       ADD  ( FOREIGN KEY (report_group_template_id)
                             REFERENCES usm_report_group_template );

ALTER TABLE usm_report_group_attr
       ADD  ( FOREIGN KEY (report_group_attr_spec_id)
                             REFERENCES usm_report_group_attr_spec );

ALTER TABLE usm_report_group_attr
       ADD  ( FOREIGN KEY (report_group_id)
                             REFERENCES usm_report_group );

ALTER TABLE usm_report_group_spec_value
       ADD  ( FOREIGN KEY (report_group_attr_spec_id)
                             REFERENCES usm_report_group_attr_spec );


/*
	  -------------
	  Sept 28, 2006
	  -------------
	  update on the table usm_system_change_detail, columns old_value, new_value

*/

ALTER TABLE usm_system_change_detail  MODIFY ( old_value  NVARCHAR2(1024) );
ALTER TABLE usm_system_change_detail  MODIFY ( new_value  NVARCHAR2(1024) );


/*
	  -------------
	  Oct 5, 2006
	  -------------
      CREATE Table usm_link_rateitem_model
*/
exec usm_proc_drop_deltatable('usm_link_rateitem_model', 'mdbadmin');
CREATE TABLE usm_link_rateitem_model (
       rate_item_id         INTEGER NOT NULL,
       model_uuid           RAW(16) NOT NULL,
       created_date         DATE NOT NULL,
       created_by_user_id   NVARCHAR2(100) NOT NULL
);

ALTER TABLE usm_link_rateitem_model
       ADD CONSTRAINT XPKusm_link_rateitem_model PRIMARY KEY (rate_item_id, model_uuid);

grant   select on usm_link_rateitem_model to usmgroup;
grant   update on usm_link_rateitem_model to usmgroup;
grant   delete on usm_link_rateitem_model to usmgroup;
grant   insert on usm_link_rateitem_model to usmgroup;

ALTER TABLE usm_link_rateitem_model
			ADD ( FOREIGN KEY (rate_item_id) REFERENCES usm_rate_definition  (item_id) );

/*
  -------------
  Oct 6, 2006
  -------------
  Table usm_metric_instance comments column length change
*/
ALTER TABLE usm_metric_instance  MODIFY ( comments  NVARCHAR2(256) );


/*
	  -------------
	  Oct 12, 2006
	  -------------
      Adding a column "enum_15" to the Table usm_rate_definition
      This will be applicable to items with usm_rate_definition.item_type=4 (Application Rate Items).
      The purpose is to indicate whether or not the Service Manager should create a service config for the item upon request/subscription.  If item_type=4 and enum_15=1, service config will not be created.
*/
exec usm_proc_drop_column('usm_rate_definition', 'enum_15', 'mdbadmin');
ALTER TABLE usm_rate_definition ADD (enum_15			INTEGER NULL);

/*
	  -------------
	  Oct 23, 2006
	  -------------
	  NOTE: For oracle, collation star issue has been opened.
      altering the column account_label for collation fix on below tables.
      - usm_note
      - usm_adjustment
      - usm_subscription_detail
      - usm_billing_account
      re-creating the index on the account_labe on usm_billing_account
*/
ALTER TABLE usm_note MODIFY account_label NVARCHAR2(128);
/*
	  -------------
	  Nov 8, 2006
	  -------------
      altering the column label for collation fix on the table usm_subscription_mgmt
*/
/*
	  -------------
	  Oct 30, 2006
	  -------------
      altering the column data3 for the table usm_task
*/
ALTER TABLE usm_task MODIFY data3 NVARCHAR2(256);

/**/
ALTER TABLE usm_report_layout_obj_list MODIFY layout_object_list nclob NULL;

/*
	-------------
	Nov 2, 2006
	-------------
	usm_system_alert : message, other_info1, other_info2, other_info3 are in size of 1024
*/
ALTER TABLE usm_system_alert MODIFY (message nvarchar2(1024));
ALTER TABLE usm_system_alert MODIFY (other_info1 nvarchar2(1024));
ALTER TABLE usm_system_alert MODIFY (other_info2 nvarchar2(1024));


/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15415231, systimestamp, 1, 4, 'Star 15415231 (MODIFIED v3) SERVICE DELIVERY SCHEMA PATCH' );

COMMIT;

EXIT SUCCESS;
