SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/*  Star 15755932 Service Delivery : alter report tables				*/ 						*/
/*                                                                                      */
/****************************************************************************************/
/* ********************************************************************************* */
/*
	-------------
	Dec 19, 2006
	-------------	
	usm_report_group_attr_spec:
	   2 changed fields:
	     report_group_template_id should allow NULL
	     attr_reference_plugin_id should allow NULL
 
	usm_report_group
	  1 new fields
	     sla_instance_id - FK to usm_sla_instance - allow NULL
	  1 changing field
	     contract_id - FK to usm_contract - allow NULL
 
	usm_metric_instance
	  1 changed field
	     - description - increase length from 128 to 512

	usm_note, the column note_text as nclob

	-------------
	Note for dropping system generated fkeys
	-------------	
	added utility procedure "usm_proc_drop_fkey" to drop foreign keys without having drop table stmt.
	using the procedure, drop keys and alter the table.

		usm_report_group
		usm_report_group_attr_spec

*/
CREATE OR REPLACE PROCEDURE usm_proc_drop_fkey (tname IN VARCHAR2, cname IN VARCHAR2, oname IN VARCHAR2)
AS
	drop_cons_name VARCHAR2(60);
	stmt varchar(8000);

	cursor c1 IS
      		SELECT cons.CONSTRAINT_NAME
		FROM user_constraints cons, user_cons_columns cons_col
		WHERE cons.CONSTRAINT_TYPE = 'R' AND
		cons.CONSTRAINT_NAME = cons_col.CONSTRAINT_NAME AND
		cons.TABLE_NAME = UPPER(tname) AND
		cons.OWNER = UPPER(oname) AND
		cons_col.COLUMN_NAME = UPPER(cname);
BEGIN
    OPEN c1;
    FETCH c1 INTO drop_cons_name;
    IF c1%FOUND THEN
	stmt := 'ALTER TABLE ' || tname || ' DROP CONSTRAINT ' || drop_cons_name;
    	DBMS_OUTPUT.PUT_LINE('Drop Constraint stmt: ' || stmt);
    	EXECUTE IMMEDIATE stmt;
    	COMMIT;
    END IF;
    CLOSE c1;
EXCEPTION
    WHEN OTHERS THEN
       CLOSE c1;
       DBMS_OUTPUT.PUT_LINE('Error ' || TO_CHAR(SQLCODE) || ': ' || SQLERRM);
       RAISE;	
END;
/


exec usm_proc_drop_fkey('usm_report_group_attr_spec', 'attr_reference_plugin_id', 'mdbadmin');

exec usm_proc_drop_fkey('usm_report_group_attr_spec', 'report_group_template_id', 'mdbadmin');

ALTER TABLE usm_report_group_attr_spec RENAME COLUMN report_group_template_id TO report_group_template_id0;
ALTER TABLE usm_report_group_attr_spec ADD (report_group_template_id INTEGER NULL);
UPDATE usm_report_group_attr_spec SET report_group_template_id = report_group_template_id0;
ALTER TABLE usm_report_group_attr_spec DROP COLUMN report_group_template_id0;

ALTER TABLE usm_report_group_attr_spec RENAME COLUMN attr_reference_plugin_id to attr_reference_plugin_id0;
ALTER TABLE usm_report_group_attr_spec ADD (attr_reference_plugin_id INTEGER NULL);
UPDATE usm_report_group_attr_spec SET attr_reference_plugin_id = attr_reference_plugin_id0;
ALTER TABLE usm_report_group_attr_spec DROP COLUMN attr_reference_plugin_id0;

ALTER TABLE usm_report_group_attr_spec
       ADD CONSTRAINT XFK1usm_report_group_attr_spec
              FOREIGN KEY (attr_reference_plugin_id)
                             REFERENCES usm_attr_reference_plugin;
                             
ALTER TABLE usm_report_group_attr_spec
       ADD CONSTRAINT XFK2usm_report_group_attr_spec
              FOREIGN KEY (report_group_template_id)
                             REFERENCES usm_report_group_template;

exec usm_proc_drop_fkey('usm_report_group', 'contract_id', 'mdbadmin');

ALTER TABLE usm_report_group
	ADD CONSTRAINT XFK1usm_report_group
          FOREIGN KEY (contract_id)
              REFERENCES usm_contract;

ALTER TABLE usm_report_group ADD (sla_instance_id INTEGER NULL);

ALTER TABLE usm_report_group
	ADD CONSTRAINT XFK2usm_report_group
          FOREIGN KEY (sla_instance_id)
          	REFERENCES usm_sla_instance;

ALTER TABLE usm_metric_instance MODIFY ( description NVARCHAR2(512) );


ALTER TABLE usm_note RENAME COLUMN note_text to note_text_old;
ALTER TABLE usm_note ADD (note_text nclob NULL);
UPDATE usm_note SET note_text = note_text_old;
ALTER TABLE usm_note DROP COLUMN note_text_old;


ALTER TABLE usm_exchange_rate MODIFY ( symbol_1 VARCHAR2(3) );
ALTER TABLE usm_exchange_rate MODIFY ( symbol_2 NVARCHAR2(16) );

/*
	Jan 18, 2007
	usm_user_query_history: altering column user_query and remove from the PK
*/
ALTER TABLE usm_user_query_history
       DROP CONSTRAINT XPKusm_user_query_history;

ALTER TABLE usm_user_query_history MODIFY ( user_query NVARCHAR2(512) );

ALTER TABLE usm_user_query_history
       ADD CONSTRAINT XPKusm_user_query_history PRIMARY KEY (user_id, guinode_id, name);

/*
	Jan 18, 2007
	usm_mr_itable, filter - where expression
	usm_mr_import, build_expr - agg logic
 */
ALTER TABLE usm_mr_itable MODIFY (filter NVARCHAR2(1024) );
ALTER TABLE usm_mr_import MODIFY (build_expr NVARCHAR2(1024) );

/*
	Jan 30, 2007
	offering group_id will be stored in this column if object_type=1 (indicating that object_id is an offering id). 
*/
ALTER TABLE usm_request_pending_action ADD ( object_group_id INTEGER NULL);
/*
	Feb 12, 2007
	Increasing the filter length of the table usm_mr_ifile
*/
ALTER TABLE usm_mr_ifile MODIFY (filter NVARCHAR2(1024) );

alter table usm_sla_config MODIFY ( data1  VARCHAR2(64) );
alter table usm_sla_config MODIFY ( data2  VARCHAR2(64) );
alter table usm_sla_config MODIFY ( data3  VARCHAR2(64) );
alter table usm_sla_config MODIFY ( data4  VARCHAR2(64) );

/*	Star 15755932	*/


/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15755932, systimestamp, 1, 4, ' Star 15755932 Service Delivery : alter report tables' );

COMMIT;

EXIT SUCCESS;
