SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 16319710 Autosys: replace ujo_batch_package  */
/*                                                                                      */
/****************************************************************************************/
/* 16584925 MDB auto-build CRPatch */ 

CREATE OR REPLACE PACKAGE ujo_batch_package AS

TYPE ref_cursor_type IS REF CURSOR;

FUNCTION ujo_batch_get_event (
  i_time0            IN  NUMBER,
  o_event            OUT ref_cursor_type)

RETURN INTEGER;

END ujo_batch_package;
/

CREATE OR REPLACE PACKAGE BODY ujo_batch_package AS

FUNCTION ujo_batch_get_event (
  i_time0                NUMBER,
  o_event            OUT ref_cursor_type)
RETURN INTEGER AS
  rc                     INTEGER;
  time_stamp             DATE         := SYSDATE;
  firstcount		 INTEGER;
  rcount		 INTEGER;
  errorno		 INTEGER := 0;
  my_sqlerrm		 VARCHAR2(100);
BEGIN
  BEGIN
	UPDATE UJO_EVENT
	SET que_status = -1,
		que_status_stamp = time_stamp
	WHERE event_time_gmt <= i_time0
		AND que_status = 0;

	firstcount := SQL%ROWCOUNT;
	IF (firstcount = 0) THEN	
		COMMIT WORK;		/* T346298 */
		RETURN 0;   
	END IF;
	   
	EXCEPTION
	WHEN OTHERS THEN
		my_sqlerrm := SUBSTR(SQLERRM, 1, 200);
		RAISE_APPLICATION_ERROR(-20870,'First update of ujo_batch_get_event failed - '||SQLCODE||' -ERROR- '||SUBSTR(SQLERRM, 1, 200));
		ROLLBACK WORK;
		RETURN -1;
  END;
  
  BEGIN
     OPEN o_event FOR
        SELECT eoid,
               joid,
               priority,
               event,
               status,
               alarm,
               event_time_gmt,
               exit_code,
               machine,
               pid,
               jc_pid,
               run_num,
               ntry,
               text,
               ((time_stamp - stamp) * 86400) AS stamp_diff,
               job_name,
               box_name,
               que_priority,
               AUTOSERV,
               evt_num 
        FROM   UJO_EVENT
        WHERE  event_time_gmt     <= i_time0
        AND    que_status         = -1
        AND    que_status_stamp   = time_stamp
        ORDER BY
               priority, event_time_gmt, evt_num ;

  END;
  
  /* Update que_status flag to -2. Another invocation of the same sp will not select the same rows */
  BEGIN
	UPDATE UJO_EVENT
	SET que_status       = -2
	WHERE que_status_stamp = time_stamp
		AND event_time_gmt <= i_time0
		AND que_status = -1;

	rcount     := SQL%ROWCOUNT;
	EXCEPTION
	WHEN OTHERS THEN
		errorno := SQLCODE;
		my_sqlerrm := SUBSTR(SQLERRM, 1, 200);
		RAISE_APPLICATION_ERROR(-20870,'Second Update of ujo_batch_get_event failed - '||errorno||' -ERROR- '||my_sqlerrm);
		ROLLBACK WORK;
		RETURN -1;
   END;

	/* If nothing was found log error, rollback and return */
	IF (rcount != firstcount) THEN
		RAISE_APPLICATION_ERROR(-20870,'ujo_batch_get_event failed during select. Data has been lost or modified');
		ROLLBACK ;
		RETURN -1;   
	ELSE
		COMMIT;
		RETURN 0;
	END IF; 
END;
END;
/
grant execute on ujo_batch_package to ujoadmin
/

exit

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 16319710, systimestamp, 1, 4, 'Star 16319710 Autosys: replace ujo_batch_package ' );

COMMIT;

EXIT SUCCESS;
