SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 16443159 Autosys: updated ujo_chase_state stored procedure  */
/*                                                                                      */
/****************************************************************************************/
/* 16584925 MDB auto-build CRPatch */ 
CREATE OR REPLACE FUNCTION ujo_chase_state( 
	i_starting_delay_time NUMBER, 
	i_outval OUT NUMBER)
RETURN INTEGER AS
	StoO_selcnt	INTEGER;
	StoO_error 	INTEGER;
	StoO_rowcnt	INTEGER;
	i_nstart NUMBER;
BEGIN
	BEGIN
	SELECT   MAX(nstart)
	INTO i_nstart
	FROM ujo_chase;
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN TOO_MANY_ROWS THEN
			StoO_rowcnt := 2;
		WHEN OTHERS THEN
			StoO_selcnt := 0;
			StoO_error := SQLCODE;
	END;
	IF i_nstart IS NULL THEN
		i_nstart :=  0 ;
	END IF;
	i_nstart :=  i_nstart + 1 ;
	IF i_nstart > 50 THEN
	BEGIN
		i_nstart :=  1 ;
		delete from ujo_chase ;	/* Issue 12216151 - sinpr01 */
	END;
	END IF;
	BEGIN
	DELETE  ujo_chase 
	WHERE nstart = i_nstart;
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN OTHERS THEN
			StoO_error  := SQLCODE;
	END;
  /* 14913319 - Chase is checking Cross Platform Jobs */
	BEGIN
	INSERT INTO ujo_chase (nstart, 
		joid,
		eoid, 
		job_name, 
		job_type, 
		status, 
		run_machine, 
		pid, 
		jc_pid)
	SELECT  i_nstart, j.joid,e.eoid, j.job_name, j.job_type, status, e.machine, pid, jc_pid
	FROM ujo_event e, ujo_job j, ujo_machine m
	WHERE e.joid = j.joid 
	  AND j.machine = m.name
		AND job_type IN ('c', 'f')
    AND m.type IN ('L', 'l', 'r', 'n')
		AND que_status = 0 
		AND status = 1;
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN OTHERS THEN
			StoO_error  := SQLCODE;
	END;
	
	 /* Put in the current status */
	BEGIN
	INSERT INTO ujo_chase (nstart, 
		joid,
		job_name, 
		job_type, 
		status, 
		run_machine, 
		pid, 
		jc_pid)
	SELECT  i_nstart, j.joid, j.job_name, j.job_type, status, run_machine, pid, jc_pid
	FROM ujo_job j, ujo_job_status s, ujo_machine m
	WHERE j.joid = s.joid 
	  AND j.machine = m.name
		AND status = 1 
		AND job_type IN ('c', 'f') 
    AND m.type IN ('L', 'l', 'r', 'n')
		AND j.joid NOT IN (SELECT  joid FROM ujo_chase 
	                       WHERE nstart = i_nstart);
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN OTHERS THEN
			StoO_error  := SQLCODE;
	END;
	/* STARTING */
	BEGIN
	INSERT INTO ujo_chase (nstart, 
		joid, 		
		job_name, 
		job_type, 
		status, 
		run_machine, 
		pid, 
		jc_pid)
	SELECT  i_nstart, j.joid, j.job_name, j.job_type, status, run_machine, pid, jc_pid 
	FROM ujo_job j,ujo_job_status s, ujo_machine m 
	WHERE j.joid = s.joid 
	  AND j.machine = m.name
		AND status = 3 
		AND status_time < i_starting_delay_time 
		AND job_type IN ('c', 'f') 
    AND m.type IN ('L', 'l', 'r', 'n')
		AND j.joid NOT IN
		(SELECT joid FROM ujo_event WHERE status = 3 AND event_time_gmt < i_starting_delay_time)
		AND j.joid NOT IN (SELECT  joid FROM ujo_chase WHERE nstart = i_nstart);
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN OTHERS THEN
			StoO_error  := SQLCODE;
	END;
	
	/* Now blow off the 1's that are waiting in the event and finished */
	BEGIN
	DELETE  ujo_chase 
	WHERE joid in (SELECT r.joid FROM ujo_chase r,ujo_event e 
			WHERE r.joid = e.joid
			AND e.status IN (4, 5, 6, 10)
			AND que_status = 0 
	    AND nstart = i_nstart);
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN OTHERS THEN
			StoO_error  := SQLCODE;
	END;
    
     /* Remove the rows in the ujo_chase table that are for Z/Team machines. */ 
	BEGIN
	DELETE  ujo_chase 
	WHERE run_machine IN (SELECT DISTINCT j.run_machine 
                        FROM ujo_job_status j, ujo_machine m 
	                      WHERE j.run_machine = m.name AND m.type in ('z', 't'));
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN OTHERS THEN
			StoO_error  := SQLCODE;
	END;
    
    /* Issue 12184156 - sinpr01 */
    /* Remove the rows in the ujo_chase table that have blank machine names */
    delete from ujo_chase where run_machine='' and nstart=nstart;
    
	BEGIN
	SELECT 1 INTO StoO_selcnt
	FROM DUAL
	WHERE EXISTS (SELECT * FROM ujo_chase 
	WHERE nstart = i_nstart);
	StoO_rowcnt := SQL%ROWCOUNT;
	EXCEPTION
		WHEN OTHERS THEN
			StoO_selcnt := 0;
			StoO_error := SQLCODE;
	END;
	IF StoO_selcnt != 0 THEN
		i_outval := i_nstart;
	ELSE
		i_outval := 0 ;
	END IF;
	RETURN -999;
END;
/
grant execute on ujo_chase_state to ujoadmin
/

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 16443159, systimestamp, 1, 4, 'Star 16443159 Autosys: updated ujo_chase_state stored procedure ' );

COMMIT;

EXIT SUCCESS;
