SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 16514609 UAPM r11.3.4 support and SWCM common functionality			*/
/*                                                                                      */
/****************************************************************************************/
/***** Create the al_applications table *****/
CREATE TABLE al_applications (
    application_name 		nvarchar2(256)          NOT NULL ,
    lowered_application_name	nvarchar2(256)          NOT NULL ,
    application_id           	raw(16)                 DEFAULT SYS_GUID(),
    description             	nvarchar2(256)		NULL,
    creation_user		nvarchar2(255)		NULL,
    creation_date		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0
);

ALTER TABLE al_applications ADD (
	CONSTRAINT PK_al_applications PRIMARY KEY (application_id)
);

CREATE  UNIQUE  INDEX al_applications_idx_01 ON al_applications(application_name)
;

CREATE  UNIQUE  INDEX al_applications_idx_02 ON al_applications(lowered_application_name)
;

/***** Create al_control_type_def table *****/
CREATE TABLE al_control_type_def (
    control_type_id		number			NOT NULL,
    control_type		nvarchar2(256)		NOT NULL,
    creation_user		nvarchar2(255)		NULL,
    creation_date		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number 			DEFAULT 0
);

ALTER TABLE al_control_type_def ADD (
	CONSTRAINT PK_al_control_type_def PRIMARY KEY (control_type_id)
);   

/***** Create al_form_attribute_def table *****/
CREATE TABLE al_form_attribute_def (
    form_attribute_id		number 			NOT NULL,
    control_type_id		number  		NULL,
    form_id			number 			NULL,
    attribute_name		nvarchar2(256) 		NOT NULL,
    attribute_path		nvarchar2(256) 		NULL,
    class_name			nvarchar2(256) 		NULL,
    search_formlet		nvarchar2(256) 		NULL,
    group_in			nvarchar2(256) 		NULL,
    hlf_navigate_url		nvarchar2(256) 		NULL,
    hlf_text_format		nvarchar2(256) 		NULL,
    hlf_navigate_url_fields	nvarchar2(256)		NULL,
    is_datakey			number			NULL,
    visibility			number			NULL,
    position			number			NULL,
    raises_events		number			NULL,
    rangelow			float			NULL,
    Rangehigh			float			NULL,
    comparevalue		nvarchar2(256)		NULL,
    regexp			nvarchar2(256)		NULL,
    column_index		number			DEFAULT 0,
    foreign_search_keys		nvarchar2(255)		NULL,
    foreign_display_type	number			NULL,
    compare_operator		nvarchar2(20)		NULL,
    compare_data_type		nvarchar2(20)		NULL,
    is_foreign_search_constraint number			NULL,
    creation_user		nvarchar2(255)		NULL,
    creation_date		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0
);

ALTER TABLE al_form_attribute_def ADD (
	CONSTRAINT al_form_attribute_def_pk01 PRIMARY KEY (form_attribute_id)
);   

/***** Create al_form_def table *****/
CREATE TABLE al_form_def (
    form_id			number 			NOT NULL,
    formlet_name		nvarchar2(256)		NOT NULL,
    application_id		raw(16)			NULL,
    render_type_id		number			NULL,
    pagesize			number			NOT NULL,
    bind_class			nvarchar2(256)		NOT NULL,
    formlet_title		nvarchar2(256)		NULL,
    dependent_params     	nvarchar2(256)          NULL,
    columncount			number			DEFAULT 2,
    creation_user		nvarchar2(255)		NULL,
    creation_date		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0 NULL
);

ALTER TABLE al_form_def ADD (
	CONSTRAINT al_form_def_pk01 PRIMARY KEY (form_id)
);   

/***** Create table al_link_form_attribute_profile *****/
CREATE TABLE al_link_form_attribute_profile (
    form_attribute_id	number		NOT NULL, 
    profile_id		number		NOT NULL, 
    is_readonly		number		NOT NULL,
    is_required		number		NOT NULL,
    last_update_user	nvarchar2(255)	NULL,
    last_update_date	number		NULL,
    version_number	number		DEFAULT 0
);

ALTER TABLE al_link_form_attribute_profile ADD (
	CONSTRAINT XPKlink_form_attribute_profile PRIMARY KEY (form_attribute_id, profile_id)
);   

/***** Create al_link_page_webpart table *****/
CREATE TABLE al_link_page_webpart (
    page_webpart_id	number		NOT NULL, 
    page_id		number		NOT NULL, 
    webpart_id		number		NOT NULL,
    last_update_user	nvarchar2(255)	NULL,
    last_update_date	number		NULL,
    version_number	number		DEFAULT 0 NULL
);

ALTER TABLE al_link_page_webpart ADD (
	CONSTRAINT XPKal_link_page_webpart PRIMARY KEY (page_webpart_id)
);   

/***** Create al_link_page_webpart_profile table *****/
CREATE TABLE al_link_page_webpart_profile (
    page_webpart_id	number		NOT NULL, 
    profile_id		number		NOT NULL, 
    default_position	number		NULL,
    default_zone	number		NULL,
    last_update_user	nvarchar2(255)	NULL,
    last_update_date	number		NULL,
    version_number	number		DEFAULT 0
);

ALTER TABLE al_link_page_webpart_profile ADD (
	CONSTRAINT XPKlink_page_webpart_profile PRIMARY KEY (page_webpart_id, profile_id)
);  

/***** Create al_page_def table *****/
CREATE TABLE al_page_def (
    page_id		number			NOT NULL,   
    application_id	raw(16)		    	NULL, 
    description 	nvarchar2(256) 		NULL,
    page_path 		nvarchar2(256) 		NOT NULL,
    creation_user	nvarchar2(255)		NULL,
    creation_date 	number			NULL,
    last_update_user	nvarchar2(255)		NULL,
    last_update_date	number			NULL,
    version_number	number			DEFAULT 0 NULL
);

ALTER TABLE al_page_def ADD (
	CONSTRAINT XPKal_page_def PRIMARY KEY (page_id)
);  

/***** Create al_paths table *****/
CREATE TABLE al_paths (
    path_id			raw(16)			DEFAULT SYS_GUID() NOT NULL,   
    application_id		raw(16)		    	NOT NULL, 
    path 			nvarchar2(256) 		NOT NULL,
    lowered_path 	 	nvarchar2(256) 		NOT NULL,
    creation_user		nvarchar2(255)		NULL,
    creation_date 		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0 NULL
);

ALTER TABLE al_paths ADD (
	CONSTRAINT XPKal_paths PRIMARY KEY (path_id)
); 

/***** Create al_personalization_all_users table *****/
CREATE TABLE al_personalization_all_users (
    path_id			raw(16)			NOT NULL,   
    page_settings		blob		    	NOT NULL, 
    last_updated_date 		date 			NOT NULL,
    creation_user		nvarchar2(255)		NULL,
    creation_date 		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0 NULL 
);

ALTER TABLE al_personalization_all_users ADD (
	CONSTRAINT XPKpersonalization_all_users PRIMARY KEY (path_id)
);

/***** Create al_personalization_per_user table *****/
CREATE TABLE al_personalization_per_user (
    Id				raw(16)			DEFAULT SYS_GUID() NOT NULL,   
    path_id			raw(16)			NULL,   
    user_id			nvarchar2(256)		NOT NULL, 
    page_settings		blob		    	NOT NULL, 
    last_updated_date 		date 			NOT NULL,
    creation_user		nvarchar2(255)		NULL,
    creation_date 		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0 NULL 
);

ALTER TABLE al_personalization_per_user ADD (
	CONSTRAINT XPKpersonalization_per_user PRIMARY KEY (Id)
);

CREATE UNIQUE INDEX al_personalization_per_user_i1 ON al_personalization_per_user(path_id,user_id)
;

CREATE UNIQUE INDEX al_personalization_per_user_i2 ON al_personalization_per_user(user_id,path_id)
;

/***** Create al_profile_def table *****/
CREATE TABLE al_profile_def (
    profile_id			number			NOT NULL,   
    application_id		raw(16)			NULL,   
    profile_name		nvarchar2(256)		NOT NULL, 
    creation_user		nvarchar2(255)		NULL,
    creation_date 		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0 NULL 
);

ALTER TABLE al_profile_def ADD (
	CONSTRAINT XPKal_profile_def PRIMARY KEY (profile_id)
);

/***** Create al_render_type_def table *****/
CREATE TABLE al_render_type_def (
    render_type_id		number			NOT NULL,   
    render_type			nvarchar2(256)		NOT NULL, 
    creation_user		nvarchar2(255)		NULL,
    creation_date 		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0 NULL
);

ALTER TABLE al_render_type_def ADD (
	CONSTRAINT XPKal_render_type_def PRIMARY KEY (render_type_id)
);

/***** Create al_ui_cache table *****/
CREATE TABLE al_ui_cache (
	page_id varchar2 (40) NOT NULL ,
	control_id varchar2 (500) NOT NULL ,
	cache_action number NOT NULL ,
	cache_key varchar2 (160) NOT NULL ,
	cache_value blob NULL ,
	class_name varchar2 (100) NOT NULL,
	last_update_date number NULL
);

ALTER TABLE al_ui_cache ADD (
	CONSTRAINT PK_al_ui_cache PRIMARY KEY 
(
	page_id,
        control_id,
        cache_key
)
);

/***** Create al_webpart_def table *****/
CREATE TABLE al_webpart_def (
    webpart_id			number			NOT NULL,   
    application_id		raw(16)		    	NULL, 
    title 			nvarchar2(256) 		NULL,
    image_url 		 	nvarchar2(256) 		NULL,
    ascx_path 		 	nvarchar2(256) 		NOT NULL,
    creation_user		nvarchar2(255)		NULL,
    creation_date 		number			NULL,
    last_update_user		nvarchar2(255)		NULL,
    last_update_date		number			NULL,
    version_number		number			DEFAULT 0 NULL
);

ALTER TABLE al_webpart_def ADD (
	CONSTRAINT XPKal_webpart_def PRIMARY KEY (webpart_id)
);


/***** Add columns to arg_attribute_def table *****/
alter table arg_attribute_def add app_filter number default 2 not null;

/***** Add columns to arg_class_def table *****/
alter table arg_class_def add cacheable number default 0 not null;
alter table arg_class_def add app_filter number default 2 not null;


/***** Foreign key constraints for al_form_attribute_def *****/
ALTER TABLE al_form_attribute_def ADD (
	CONSTRAINT FK_al_form_attribute_def_fk01 FOREIGN KEY (control_type_id) 
	REFERENCES al_control_type_def (control_type_id)
);

ALTER TABLE al_form_attribute_def ADD (
	CONSTRAINT FK_al_form_attribute_def_fk02 FOREIGN KEY (form_id) 
	REFERENCES al_form_def (form_id)
);

/***** Foreign key constraints for al_form_def *****/
ALTER TABLE al_form_def ADD (
	CONSTRAINT FK_al_form_def_fk01 FOREIGN KEY (application_id) 
	REFERENCES al_applications (application_id)
);

ALTER TABLE al_form_def ADD (
	CONSTRAINT FK_al_form_def_fk02 FOREIGN KEY (render_type_id) 
	REFERENCES al_render_type_def (render_type_id)
);

/***** Foreign key constraints for al_link_form_attribute_profile *****/
ALTER TABLE al_link_form_attribute_profile ADD (
	CONSTRAINT al_link_form_attrib_prof_fk01 FOREIGN KEY (form_attribute_id) 
	REFERENCES al_form_attribute_def (form_attribute_id)
);

ALTER TABLE al_link_form_attribute_profile ADD (
	CONSTRAINT al_link_form_attrib_prof_fk02 FOREIGN KEY (profile_id) 
	REFERENCES al_profile_def (profile_id)
);

/***** Foreign key constraints for al_link_page_webpart *****/
ALTER TABLE al_link_page_webpart ADD (
	CONSTRAINT al_link_page_webpart_fk01 FOREIGN KEY (page_id) 
	REFERENCES al_page_def (page_id)
);

ALTER TABLE al_link_page_webpart ADD (
	CONSTRAINT al_link_page_webpart_fk02 FOREIGN KEY (webpart_id) 
	REFERENCES al_webpart_def (webpart_id)
);

/***** Foreign key constraints for al_link_page_webpart_profile *****/
ALTER TABLE al_link_page_webpart_profile ADD (
	CONSTRAINT al_link_page_webpart_prof_fk01 FOREIGN KEY (page_webpart_id) 
	REFERENCES al_link_page_webpart (page_webpart_id)
);

ALTER TABLE al_link_page_webpart_profile ADD (
	CONSTRAINT al_link_page_webpart_prof_fk02 FOREIGN KEY (profile_id) 
	REFERENCES al_profile_def (profile_id)
);

/***** Foreign key constraints for al_page_def *****/
ALTER TABLE al_page_def ADD (
	CONSTRAINT al_page_def_fk01 FOREIGN KEY (application_id) 
	REFERENCES al_applications (application_id)
);

/***** Foreign key constraints for al_paths *****/
ALTER TABLE al_paths ADD (
	CONSTRAINT al_paths_fk01 FOREIGN KEY (application_id) 
	REFERENCES al_applications (application_id)
);

/***** Foreign key constraints for al_personalization_all_users *****/
ALTER TABLE al_personalization_all_users ADD (
	CONSTRAINT personalization_all_users_fk01 FOREIGN KEY (path_id) 
	REFERENCES al_paths (path_id)
);

/***** Foreign key constraints for al_personalization_per_user *****/
ALTER TABLE al_personalization_per_user ADD (
	CONSTRAINT personalization_per_user_fk01 FOREIGN KEY (path_id) 
	REFERENCES al_paths (path_id)
);

/***** Foreign key constraints for al_profile_def *****/
ALTER TABLE al_profile_def ADD (
	CONSTRAINT al_profile_def_fk01 FOREIGN KEY (application_id) 
	REFERENCES al_applications (application_id)
);

/***** Foreign key constraints for al_webpart_def *****/
ALTER TABLE al_webpart_def ADD (
	CONSTRAINT al_webpart_def_fk01 FOREIGN KEY (application_id) 
	REFERENCES al_applications (application_id)
);

/*** AL_PERSONALIZATION ***/
CREATE TABLE arg_personalization(
            ApplicationName nvarchar2(100) NOT NULL,
            UserId nvarchar2(50) NOT NULL,
            ObjectPrefix number NOT NULL,
            PropertyName nvarchar2(100) NOT NULL,
            PropertyValue nvarchar2(1000) NULL
);

ALTER TABLE arg_personalization ADD (
	CONSTRAINT PK_arg_personalization_1 PRIMARY KEY 
(
	ApplicationName,
        UserId,
        ObjectPrefix,
        PropertyName
)
);

/*** AL_PURCHASE_ORDER_STATUS ***/
CREATE TABLE al_purchase_order_status(
	id number NOT NULL,
	value nvarchar2(255)  NULL,
	creation_user nvarchar2(255)  NULL,
	creation_date number NULL,
	last_update_user nvarchar2(255)  NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_purchase_order_status ADD (
	CONSTRAINT PK_al_purchase_order_status PRIMARY KEY (id)
);


/*** AL_PURCHASE_ORDER ***/
CREATE TABLE al_purchase_order(
	purchase_order_id number NOT NULL,
	purchase_order_number nvarchar2(255) NULL,
	purchase_order_date date NULL,
	comments nvarchar2(2000) NULL,
	signature nvarchar2(255) NULL,
	ship_to_overide_flag number NULL,
	ship_to_contact_uuid raw(16) NULL,
	ship_to_location_address nvarchar2(255) NULL,		
	billing_overide_flag number NULL,
	billing_location_uuid raw(16) NULL,
	billing_address nvarchar2(255) NULL,		
	reseller_overide_flag number NULL,
	reseller_uuid raw(16) NULL,
	reseller_address nvarchar2(255) NULL,		
	total_amount float NULL,
	total_tax_amount float NULL,
	sub_total_amount float NULL,
	currency_type_id varchar2(3) NULL,
	assets_created number DEFAULT 0 NULL ,
	purchase_order_status_id number NOT NULL,
	creation_user nvarchar2(255) NULL,
	creation_date number NULL,
	last_update_user nvarchar2(255) NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_purchase_order ADD (
	CONSTRAINT PK_al_purchase_order PRIMARY KEY (purchase_order_id)
);

ALTER TABLE al_purchase_order ADD (
	CONSTRAINT al_purchase_order_fk01 FOREIGN KEY (currency_type_id) 
	REFERENCES ca_currency_type (currency_type_code)
);

ALTER TABLE al_purchase_order ADD (
	CONSTRAINT al_purchase_order_fk02 FOREIGN KEY (purchase_order_status_id) 
	REFERENCES al_purchase_order_status (id)
);

ALTER TABLE al_purchase_order ADD (
	CONSTRAINT al_purchase_order_fk03 FOREIGN KEY (ship_to_contact_uuid) 
	REFERENCES ca_contact (contact_uuid)
);

ALTER TABLE al_purchase_order ADD (
	CONSTRAINT al_purchase_order_fk04 FOREIGN KEY (billing_location_uuid) 
	REFERENCES ca_location (location_uuid)
);

ALTER TABLE al_purchase_order ADD (
	CONSTRAINT al_purchase_order_fk05 FOREIGN KEY (reseller_uuid) 
	REFERENCES ca_company (company_uuid)
);

/*** AL_PURCHASE_ORDER_ITEM ***/
CREATE TABLE al_purchase_order_item(
	purchase_order_item_id number NOT NULL,
	purchase_order_id number NOT NULL,
	request_item_id number NULL,
	request_id number NULL,
	model_uuid raw(16) NULL,
	item_description nvarchar2(255) NULL,
	item_quantity number NULL,
	item_unit_price float NULL,
	item_tax float NULL,
	item_total_amount float NULL,
	part_number nvarchar2(255) NULL,
	sku_number nvarchar2(255) NULL,
	creation_user nvarchar2(255) NULL,
	creation_date number NULL,
	last_update_user nvarchar2(255) NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);
	
ALTER TABLE al_purchase_order_item ADD (
	CONSTRAINT PK_al_purchase_order_item PRIMARY KEY (purchase_order_item_id)
);

ALTER TABLE al_purchase_order_item ADD (
	CONSTRAINT al_purchase_order_item_fk01 FOREIGN KEY (purchase_order_id) 
	REFERENCES al_purchase_order (purchase_order_id)
);
	 
ALTER TABLE al_purchase_order_item ADD (
	CONSTRAINT al_purchase_order_item_fk02 FOREIGN KEY (model_uuid) 
	REFERENCES ca_model_def (model_uuid)
);

/*** AL_LINK_PO_ITEM_OWND_RSRC ***/
CREATE TABLE al_link_po_item_ownd_rsrc(
	owned_resource_uuid RAW(16) NOT NULL,
	purchase_order_item_id number NOT NULL,
	last_update_user nvarchar2(255)  NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_link_po_item_ownd_rsrc ADD (
	CONSTRAINT PK_al_link_po_item_ownd_rsrc PRIMARY KEY (
	owned_resource_uuid,
	purchase_order_item_id
	)
);

ALTER TABLE al_link_po_item_ownd_rsrc ADD ( 
	CONSTRAINT al_link_po_item_ownd_rsrc_fk01 FOREIGN KEY (purchase_order_item_id)
	REFERENCES al_purchase_order_item (purchase_order_item_id)
);

ALTER TABLE al_link_po_item_ownd_rsrc ADD (  	
	CONSTRAINT al_link_po_item_ownd_rsrc_fk02 FOREIGN KEY (owned_resource_uuid)
	REFERENCES ca_owned_resource (own_resource_uuid)
);


/*** AL_PURCHASE_HW_ITEM ***/
CREATE TABLE al_purchase_hw_item(
	purchase_order_item_id number NOT NULL,
	model_uuid RAW(16) NOT NULL,
	creation_user nvarchar2(255)  NULL,
	creation_date number NULL,
	last_update_user nvarchar2(255)  NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_purchase_hw_item ADD (
	CONSTRAINT PK_al_purchase_hw_item PRIMARY KEY (purchase_order_item_id)
);

ALTER TABLE al_purchase_hw_item ADD (
	CONSTRAINT al_purchase_hw_item_fk01 FOREIGN KEY	(purchase_order_item_id)
	REFERENCES al_purchase_order_item (purchase_order_item_id)
);
	

/*** AL_ATTACHMT ***/
CREATE TABLE al_attachmt(
	amid number NOT NULL,
	amurl nvarchar2(250)  NULL,
	amdesc nvarchar2(255)  NULL,
	creation_user nvarchar2(64)  NULL,
	creation_date number NULL,
	last_update_user nvarchar2(64)  NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_attachmt ADD (
	CONSTRAINT PK_al_attachmt PRIMARY KEY (amid)
);

/*** AL_LINK_PURCHS_ORDR_ATTACHMT ***/
CREATE TABLE al_link_purchs_ordr_attachmt (
	amid number NOT NULL,
	purchase_order_id number NOT NULL,
	last_update_user nvarchar2(255)  NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_link_purchs_ordr_attachmt ADD (
	CONSTRAINT PK_al_link_purchs_ordr_attachm PRIMARY KEY (
	amid,
	purchase_order_id
	)
);

ALTER TABLE al_link_purchs_ordr_attachmt ADD (
	CONSTRAINT al_lnk_po_attachmt_fk01 FOREIGN KEY (amid)
	REFERENCES al_attachmt (amid)
); 


ALTER TABLE al_link_purchs_ordr_attachmt ADD (
	CONSTRAINT al_lnk_po_attachmt_fk02 FOREIGN KEY (purchase_order_id)
	REFERENCES al_purchase_order (purchase_order_id)
);

/***** Create al_db_scripts table *****/
CREATE TABLE al_db_scripts(
            script_id number NOT NULL,
            script_name nvarchar2(255) NOT NULL,
            script_type number NOT NULL,
            description nvarchar2(255) NULL,
            creation_date number NULL,
            creation_user nvarchar2(50) NULL,
            last_update_date number NULL,
            last_update_user nvarchar2(50) NULL,
            version_number number DEFAULT 0 NOT NULL,
            app_filter number NOT NULL
);

ALTER TABLE al_db_scripts ADD (
        CONSTRAINT al_db_scripts_pk01 PRIMARY KEY (script_id)
);

CREATE  UNIQUE  INDEX al_db_scripts_idx01 ON al_db_scripts(script_name)
;

/***** Create al_db_version table *****/
CREATE TABLE al_db_version(
            product_code number NOT NULL,
            struct_major_ver number NULL,
            struct_minor_ver number NULL,
            struct_rev_ver number NULL,
            struct_build_ver number NULL,
            meta_major_ver number NULL,
            meta_minor_ver number NULL,
            meta_rev_ver number NULL,
            meta_build_ver number NULL
);

ALTER TABLE al_db_version ADD (
        CONSTRAINT al_db_version_pk01 PRIMARY KEY (product_code)
);

/***** Create al_report_def table *****/
CREATE TABLE al_report_def(
	report_id number     NOT NULL,
	name nvarchar2 (255) NOT NULL,
	path nvarchar2 (500) NOT NULL,
	height number NULL,
	width number NULL
);

ALTER TABLE al_report_def ADD (
        CONSTRAINT PK_al_report_def PRIMARY KEY (report_id)
);

CREATE  INDEX al_al_report_def_index_1 ON al_report_def(name)
;

/***** Create al_link_webpart_report table *****/
CREATE TABLE al_link_webpart_report (	
    	webpart_id number NOT NULL,
	report_id number  NOT NULL
);

ALTER TABLE al_link_webpart_report ADD (
	CONSTRAINT PK_al_link_webpart_report PRIMARY KEY (
	webpart_id,
	report_id
	)
);

ALTER TABLE al_link_webpart_report ADD (
	CONSTRAINT FK_al_link_webpart_report_01 FOREIGN KEY (webpart_id)
	REFERENCES al_webpart_def (webpart_id)
);

ALTER TABLE al_link_webpart_report ADD (
	CONSTRAINT FK_al_link_webpart_report_02 FOREIGN KEY (report_id)
	REFERENCES al_report_def (report_id)
); 

/***** Create al_link_ca_arg_crncy table *****/
CREATE TABLE al_link_ca_arg_crncy(
	dlkey number NOT NULL,
	currency_type_code varchar2(3) NOT NULL,
	creation_user nvarchar2(255) NULL,
	creation_date number NULL,
	last_update_user nvarchar2(255) NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_link_ca_arg_crncy ADD (
	CONSTRAINT PK_al_link_ca_arg_crncy PRIMARY KEY (
	dlkey,
	currency_type_code
	)
);

ALTER TABLE al_link_ca_arg_crncy ADD (
	CONSTRAINT al_link_ca_arg_crncy_fk01 FOREIGN KEY (currency_type_code)
	REFERENCES ca_currency_type (currency_type_code)
); 

/***** Create al_purchase_cost_type table *****/
CREATE TABLE al_purchase_cost_type(
	id number NOT NULL,
	value nvarchar2(50) NOT NULL,
	creation_user nvarchar2(255) NULL,
	creation_date number NULL,
	last_update_user nvarchar2(255) NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_purchase_cost_type ADD (
	CONSTRAINT PK_al_purchase_cost_type PRIMARY KEY (id)
);

/***** Create al_usm_request_item_status table *****/
CREATE TABLE al_usm_request_item_status (
	id number NOT NULL,
	status_id number NOT NULL,
	description nvarchar2(255) NULL,
	creation_user nvarchar2(255) NULL,
	creation_date number NULL,
	last_update_user nvarchar2(255) NULL,
	last_update_date number NULL,
	version_number number DEFAULT 0 NULL
);

ALTER TABLE al_usm_request_item_status ADD (
	CONSTRAINT PK_al_usm_request_item_status PRIMARY KEY (id)
);


/***********************************************************************/
/* Create Package Just for CURSOR Definition                           */
/***********************************************************************/

CREATE OR REPLACE PACKAGE al_cursor AS 

	TYPE T_CURSOR IS REF CURSOR;       	
			
END al_cursor;
/

/***********************************************************************/
/* Create the Personalization Procedures                               */
/***********************************************************************/


-- Create al_applications_create Stored Proc.
CREATE OR REPLACE PROCEDURE al_applications_create (
		in_application_name IN VARCHAR2,
		out_application_id  OUT al_applications.application_id%TYPE) IS
	BEGIN

		SELECT application_id INTO out_application_id 
		  FROM al_applications 
		 WHERE LOWER(in_application_name) = lowered_application_name;

		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				SELECT SYS_GUID() INTO out_application_id FROM DUAL;

				INSERT INTO al_applications (application_id, application_name, lowered_application_name)
				VALUES  (out_application_id, in_application_name, LOWER(in_application_name));		
	END al_applications_create;
/

-- Create al_personalization_get_app_id Stored Proc.
CREATE OR REPLACE PROCEDURE al_personalization_get_app_id (
		in_application_name IN VARCHAR2,
		out_application_id  OUT al_applications.application_id%TYPE) IS
	BEGIN

		SELECT application_id 
		  INTO out_application_id 
		  FROM al_applications 
		 WHERE LOWER(in_application_name) = lowered_application_name;

	END al_personalization_get_app_id;
/

-- Create al_paths_create_path Stored Proc
CREATE OR REPLACE PROCEDURE al_paths_create_path (
		in_application_id IN al_paths.application_id%TYPE,
		in_path 	 IN al_paths.path%TYPE,
		out_path_id 	 OUT al_paths.path_id%TYPE) IS
	BEGIN
		SELECT path_id INTO out_path_id 
		  FROM al_paths 
		 WHERE lowered_path = LOWER(in_path)
		   AND application_id = in_application_id;

		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				SELECT SYS_GUID() INTO out_path_id FROM DUAL;

				INSERT INTO al_paths (application_id, path, lowered_path, path_id)
				VALUES(in_application_id, in_path, LOWER(in_path), out_path_id);

	END al_paths_create_path;
/		

-- Create al_peruser_get_page_settings Stored Proc
CREATE OR REPLACE PROCEDURE al_peruser_get_page_settings (
		in_application_name 	IN VARCHAR2,
		in_user_id          	IN VARCHAR2,
		in_path            	IN VARCHAR2,
		in_current_time_utc  	IN DATE,
		out_page_settings_Cursor	OUT al_cursor.T_CURSOR) IS

		var_application_id al_paths.application_id%TYPE;
		var_path_id al_personalization_per_user.path_id%TYPE;

	BEGIN
		al_personalization_get_app_id(in_application_name, var_application_id);

		SELECT path_id INTO var_path_id 
		  FROM al_paths u 
		 WHERE u.application_id = var_application_id 
		   AND u.lowered_path = LOWER(in_path);  	    	  

		OPEN out_page_settings_Cursor FOR 
		SELECT p.page_settings 
		  FROM al_personalization_per_user p 
		 WHERE p.path_id = var_path_id
		   AND p.user_id = in_user_id;  	  	   

		EXCEPTION
			WHEN NO_DATA_FOUND THEN 
				 OPEN out_page_settings_Cursor FOR 
				 SELECT NULL FROM DUAL;

	END al_peruser_get_page_settings;
/
          
-- Create al_peruser_reset_page_settings Stored Proc
CREATE OR REPLACE PROCEDURE al_peruser_reset_page_settings (
		in_application_name IN VARCHAR2,
		in_user_id          IN VARCHAR2,
		in_path            IN VARCHAR2,
		in_current_time_utc  IN DATE) IS 

		var_application_id al_paths.application_id%TYPE;
		var_path_id al_personalization_per_user.path_id%TYPE;

	BEGIN

		al_personalization_get_app_id(in_application_name, var_application_id);

		SELECT path_id INTO var_path_id 
		  FROM al_paths u 
		 WHERE u.application_id = var_application_id 
		   AND u.lowered_path = LOWER(in_path);

		DELETE FROM al_personalization_per_user 
		 WHERE path_id = var_path_id 
		   AND user_id = in_user_id;

		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				RETURN;
	END al_peruser_reset_page_settings;
/	

-- Create al_peruser_set_page_settings Stored Proc
CREATE OR REPLACE PROCEDURE al_peruser_set_page_settings (
		in_application_name IN VARCHAR2,
		in_user_id          IN VARCHAR2,
		in_path            IN VARCHAR2,
		in_page_settings    IN al_personalization_per_user.page_settings%TYPE,
		in_current_time_utc  IN DATE) IS

		var_application_id al_paths.application_id%TYPE;
		var_id al_personalization_per_user.id%TYPE;
		var_path_id al_personalization_per_user.path_id%TYPE;
		var_path_id_PerUsr al_personalization_per_user.path_id%TYPE;


	BEGIN

		al_applications_create(in_application_name, var_application_id);

		BEGIN 
			SELECT path_id INTO var_path_id 
			  FROM al_paths u 
			 WHERE u.application_id = var_application_id 
			   AND u.lowered_path = LOWER(in_path);

		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				al_paths_create_path(var_application_id, in_path, var_path_id);
		END;

		SELECT path_id 
		  INTO var_path_id_PerUsr
		  FROM al_personalization_per_user 
		 WHERE user_id = in_user_id
		   AND path_id = var_path_id;

		UPDATE al_personalization_per_user 
		   SET page_settings = in_page_settings, 
		       last_updated_date = in_current_time_utc 
		 WHERE user_id = in_user_id 
		   AND path_id = var_path_id;


		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				SELECT SYS_GUID() INTO var_id FROM DUAL;
				INSERT INTO al_personalization_per_user(id, user_id, path_id, page_settings, last_updated_date) 
				VALUES (var_id, in_user_id, var_path_id, in_page_settings, in_current_time_utc);

	END al_peruser_set_page_settings;	
/	
	
-- Create al_alluser_get_page_settings Stored Proc
CREATE OR REPLACE PROCEDURE al_alluser_get_page_settings (
		in_application_name 	IN VARCHAR2,
		in_path            	IN VARCHAR2,
		out_page_settings_Cursor	OUT al_cursor.T_CURSOR) IS

		var_application_id al_paths.application_id%TYPE;
		var_path_id al_personalization_per_user.path_id%TYPE;

	BEGIN
		al_personalization_get_app_id(in_application_name, var_application_id);

		SELECT path_id INTO var_path_id 
		  FROM al_paths u 
		 WHERE u.application_id = var_application_id 
		   AND u.lowered_path = LOWER(in_path);  	    	  

		OPEN out_page_settings_Cursor FOR 
		SELECT a.page_settings 
		  FROM al_personalization_all_users a 
		 WHERE a.path_id = var_path_id;  	  	   

		EXCEPTION
			WHEN NO_DATA_FOUND THEN 
				 OPEN out_page_settings_Cursor FOR 
				 SELECT NULL FROM DUAL;

	END al_alluser_get_page_settings;	
/

-- Create al_alluser_reset_page_settings Stored Proc
CREATE OR REPLACE PROCEDURE al_alluser_reset_page_settings (
		in_application_name IN VARCHAR2,
		in_path            IN VARCHAR2) IS 

		var_application_id al_paths.application_id%TYPE;
		var_path_id al_personalization_per_user.path_id%TYPE;

	BEGIN

		al_personalization_get_app_id(in_application_name, var_application_id);

		SELECT path_id INTO var_path_id 
		  FROM al_paths u 
		 WHERE u.application_id = var_application_id 
		   AND u.lowered_path = LOWER(in_path);

		DELETE FROM al_personalization_all_users 
		 WHERE path_id = var_path_id;

		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				RETURN;
	END al_alluser_reset_page_settings;
/	

-- Create al_alluser_set_page_settings Stored Proc
CREATE OR REPLACE PROCEDURE al_alluser_set_page_settings (
		in_application_name IN VARCHAR2,
		in_path            IN VARCHAR2,
		in_page_settings    IN al_personalization_per_user.page_settings%TYPE,
		in_current_time_utc  IN DATE) IS

		var_application_id al_paths.application_id%TYPE;
		var_id al_personalization_per_user.id%TYPE;
		var_path_id al_personalization_per_user.path_id%TYPE;
		var_path_id_PerUsr al_personalization_per_user.path_id%TYPE;


	BEGIN

		al_applications_create(in_application_name, var_application_id);

		BEGIN 
			SELECT path_id INTO var_path_id 
			  FROM al_paths u 
			 WHERE u.application_id = var_application_id 
			   AND u.lowered_path = LOWER(in_path);

		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				al_paths_create_path(var_application_id, in_path, var_path_id);
		END;

		SELECT path_id 
		  INTO var_path_id_PerUsr
		  FROM al_personalization_all_users
		 WHERE path_id = var_path_id;

		UPDATE al_personalization_all_users 
		   SET page_settings = in_page_settings
		 WHERE path_id = var_path_id;


		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				SELECT SYS_GUID() INTO var_id FROM DUAL;
				INSERT INTO al_personalization_all_users(path_id, page_settings, last_updated_date) 
				VALUES (var_path_id, in_page_settings, in_current_time_utc);

	END al_alluser_set_page_settings;	
/	



-- Create al_get_page_web_parts Stored Proc.
CREATE OR REPLACE PROCEDURE al_get_page_web_parts (
		profile_names	IN VARCHAR2,
		page_name	IN VARCHAR2,
		app_name	IN VARCHAR2,
		page_web_parts	OUT al_cursor.T_CURSOR) IS	
	BEGIN
		
		OPEN page_web_parts FOR 
			'SELECT DISTINCT part_def.*, ' ||
			'	page_part_prof_lnk.default_position, ' ||
			'	page_part_prof_lnk.default_zone, ' ||
			'	rep_def.report_id, ' ||
			'	rep_def.name as report_name, ' ||
			'	rep_def.path as report_path, ' ||
			'	rep_def.height as report_height, ' ||
			'	rep_def.width as report_width ' ||
 			'FROM al_Profile_Def prof_def ' ||
			'	JOIN al_Link_Page_WebPart_Profile page_part_prof_lnk ' ||
	  		'	  ON page_part_prof_lnk.profile_id = prof_def.profile_id ' ||
			'	JOIN al_Link_Page_WebPart page_part_lnk ' ||
	  		'	  ON page_part_lnk.page_webpart_id = page_part_prof_lnk.page_webpart_id ' ||
			'	JOIN al_WebPart_Def part_def ' ||
	  		'	  ON part_def.webpart_id = page_part_lnk.webpart_id ' ||
			'	JOIN al_Page_Def page_def ' ||
	  		'	  ON page_def.page_id = page_part_lnk.page_id ' ||
			'	JOIN al_applications al_app ' ||
	  		'	  ON al_app.application_id = page_def.application_id ' ||
	  		'	 AND al_app.application_id = part_def.application_id ' ||
			'	LEFT OUTER JOIN al_link_webpart_report part_rep_link ' ||
	  		'	  ON part_rep_link.webpart_id = part_def.webpart_id ' ||
			'	LEFT OUTER JOIN al_report_def rep_def ' ||
	  		'	  ON rep_def.report_id = part_rep_link.report_id ' ||
 			'WHERE prof_def.profile_name IN (' || profile_names ||  ') ' ||
   			'  AND LOWER(page_def.page_path) = LOWER(''' || page_name || ''')' ||
  			'  AND al_app.lowered_application_name = LOWER(''' || app_name || ''')';
	END al_get_page_web_parts;	
/

-- Create al_get_fields_to_render Stored Proc.
CREATE OR REPLACE PROCEDURE al_get_fields_to_render (
		profile_names	IN VARCHAR2,
		form_name	IN VARCHAR2,
		app_name	IN VARCHAR2,
		fields_to_render OUT al_cursor.T_CURSOR) IS
	BEGIN
		OPEN fields_to_render FOR 
			'SELECT CASE WHEN fd.data_type = 10 THEN fd.data_size ELSE 0, fd.data_size, fd.field_required, fd.foreign_key, ' ||
			'	ad.attribute_label, ad.table_name, ad.relation_type, ' ||
			'	al_fd.render_type_id,al_fd.formlet_name, al_fd.pagesize, al_fd.columncount, ' ||
			'	al_fd.bind_class, al_fd.dependent_params, ' ||
			'	al_af.form_attribute_id, al_af.position, al_af.rangelow, al_af.rangehigh, al_af.visibility, ' ||
			'	al_af.comparevalue,al_af.regexp, al_af.raises_events, al_af.attribute_path, ' ||
			'	al_af.hlf_navigate_url, al_af.hlf_text_format, al_af.hlf_navigate_url_fields, ' ||
			'	al_af.attribute_name, al_af.is_datakey, al_af.class_name, al_af.search_formlet, al_af.group_in, ' ||
			'	al_af.foreign_display_type, al_lfap.is_required, al_lfap.is_readonly, ' ||
			'   al_af.foreign_search_keys, al_af.column_index, al_af.is_foreign_search_constraint, ' ||
            '   al_af.compare_operator, al_af.compare_data_type, ' ||
			'	ct.control_type ' ||
			'FROM al_profile_def al_pd ' ||
			'JOIN al_link_form_attribute_profile al_lfap ' ||
			'  on al_lfap.profile_id = al_pd.profile_id ' ||
			'JOIN al_form_attribute_def al_af ' ||
			'  on al_af.form_attribute_id = al_lfap.form_attribute_id ' ||
			'JOIN al_control_type_def ct ' ||
			'  on ct.control_type_id = al_af.control_type_id ' ||
			'JOIN al_form_def al_fd ' ||
			'  on al_fd.form_id = al_af.form_id ' ||
			'JOIN al_applications al_app ' ||
			'  on al_app.application_id = al_fd.application_id ' ||
			'JOIN arg_attribute_def ad ' ||
			'  on ad.attribute_name = al_af.attribute_name and LOWER(ad.class_name) = LOWER(al_af.class_name) ' ||
			'LEFT OUTER JOIN arg_field_def fd ' ||
			'  on fd.table_name = ad.table_name and fd.field_name = ad.field_name ' ||
			'WHERE al_pd.profile_name in(' || profile_names || ') ' || 
			'  AND LOWER(al_fd.formlet_name) = LOWER(''' || form_name || ''')  ' ||
			'  AND al_app.lowered_application_name = LOWER(''' || app_name || ''')  ' ||
			'ORDER BY al_af.position ASC';

	END al_get_fields_to_render;
/

-- Create al_delpurchattachs Trigger
CREATE OR REPLACE TRIGGER al_delpurchattachs
AFTER DELETE ON MDBADMIN.al_link_purchs_ordr_attachmt
FOR EACH ROW
BEGIN
	/*  delete sibling record  */
	DELETE FROM al_attachmt f
	WHERE f.amid = :new.amid;
END;
/

-- Create al_prchordr_totscalc_tri Trigger
CREATE OR REPLACE TRIGGER al_prchordr_totscalc_tri
AFTER INSERT ON MDBADMIN.al_purchase_order_item  
FOR EACH ROW

/*  declare variables  */
DECLARE
	var_total_amount 	al_purchase_order.total_amount%type;
	var_total_tax_amount 	al_purchase_order.total_tax_amount%type;
	var_sub_total_amount 	al_purchase_order.sub_total_amount%type;
	
BEGIN
	SELECT	total_tax_amount,
		sub_total_amount,
		total_amount
	INTO	var_total_tax_amount,
		var_sub_total_amount,
		var_total_amount
	FROM  	al_purchase_order
	WHERE 	purchase_order_id = :new.purchase_order_id;
	
	UPDATE 	al_purchase_order
	SET	total_tax_amount = NVL(TO_CHAR(var_total_tax_amount), 0.00) + NVL(TO_CHAR(:new.item_tax), 0.00),
		sub_total_amount = NVL(TO_CHAR(var_sub_total_amount), 0.00) + (NVL(TO_CHAR(:new.item_total_amount), 0.00) - NVL(TO_CHAR(:new.item_tax), 0.00)),
		total_amount = NVL(TO_CHAR(var_total_amount), 0.00) + NVL(TO_CHAR(:new.item_total_amount), 0.00)
	WHERE 	purchase_order_id = :new.purchase_order_id;
END;
/

-- Create al_prchordr_totscalc_tru Trigger
CREATE OR REPLACE TRIGGER al_prchordr_totscalc_tru
AFTER UPDATE ON MDBADMIN.al_purchase_order_item  
FOR EACH ROW

/*  declare variables  */
DECLARE
	var_total_amount 	al_purchase_order.total_amount%type;
	var_total_tax_amount 	al_purchase_order.total_tax_amount%type;
	var_sub_total_amount 	al_purchase_order.sub_total_amount%type;	
BEGIN
	SELECT	total_tax_amount,
		sub_total_amount,
		total_amount
	INTO	var_total_tax_amount,
		var_sub_total_amount,
		var_total_amount
	FROM  	al_purchase_order
	WHERE 	purchase_order_id = :old.purchase_order_id;
	
	UPDATE 	al_purchase_order
	SET	total_tax_amount = NVL(TO_CHAR(var_total_tax_amount), 0.00) - NVL(TO_CHAR(:old.item_tax), 0.00) + NVL(TO_CHAR(:new.item_tax), 0.00),
		sub_total_amount = NVL(TO_CHAR(var_sub_total_amount), 0.00) - (NVL(TO_CHAR(:old.item_total_amount), 0.00) - NVL(TO_CHAR(:old.item_tax), 0.00)) + (NVL(TO_CHAR(:new.item_total_amount), 0.00) - NVL(TO_CHAR(:new.item_tax), 0.00)),
		total_amount = NVL(TO_CHAR(var_total_amount), 0.00) - NVL(TO_CHAR(:old.item_total_amount), 0.00) + NVL(TO_CHAR(:new.item_total_amount), 0.00)
	WHERE 	purchase_order_id = :old.purchase_order_id;
END;
/

-- Create al_prchordr_totscalc_trd Trigger
CREATE OR REPLACE TRIGGER al_prchordr_totscalc_trd
AFTER DELETE ON MDBADMIN.al_purchase_order_item  
FOR EACH ROW

/*  declare variables  */
DECLARE
	var_total_amount 	al_purchase_order.total_amount%type;
	var_total_tax_amount 	al_purchase_order.total_tax_amount%type;
	var_sub_total_amount 	al_purchase_order.sub_total_amount%type;
	
BEGIN
	SELECT	total_tax_amount,
		sub_total_amount,
		total_amount
	INTO	var_total_tax_amount,
		var_sub_total_amount,
		var_total_amount
	FROM  	al_purchase_order
	WHERE 	purchase_order_id = :old.purchase_order_id;		
	
	UPDATE 	al_purchase_order
	SET	total_tax_amount = NVL(TO_CHAR(var_total_tax_amount), 0.00) - NVL(TO_CHAR(:old.item_tax), 0.00),
		sub_total_amount = NVL(TO_CHAR(var_sub_total_amount), 0.00) - (NVL(TO_CHAR(:old.item_total_amount), 0.00) - NVL(TO_CHAR(:old.item_tax), 0.00)),
		total_amount = NVL(TO_CHAR(var_total_amount), 0.00) - NVL(TO_CHAR(:old.item_total_amount), 0.00)
	WHERE 	purchase_order_id = :old.purchase_order_id;	
END;
/

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 16514609, systimestamp, 1, 4, 'Star 16514609 (MODIFIED v1) UAPM r11.3.4 support and SWCM common functionality' );

COMMIT;

EXIT SUCCESS;
