SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;

-- copyright Ca 2007
--
-- product 
--      Desktop and server Management 
--
-- purpose
--  upgrade oracle MDB version 1.0.4 30k 
--  to the same level as MDb 1.0.4 mdb 30 on MSSQL and Ingres
--  as used in  DSM release r11.2 GA  
--  --> installing all missing tables
--      
--  Scope
--      add missing tables      
--      add missing columns in tables
--
-- FIXME
--  list of tables where tabel name does not match
--          MSSQL / INgres                      Oracle
--          -------------------------------------------------------------------
--      ca_software_def_class_def_matrix,   CA_SOFTWARE_DEF_CLASS_DEF_MATR,
--
--
--
--
-- Caveats:
--      * table name=ca_taskwiz_def will not be created 
--
--
-- ****************************************************************************


-- ****************************************************************************
-- special notes about schema mapping between Oracle and MSSQL
--
--             Datatype MSSQL              Datatype Oracle
--          -------------------------------------------------------
--              int                         NUMBER
--              nvarchar2                    nvarchar22
--              ntext                       NCLOB
--              varchar(4000)               BLOB
--              datetime                    DATE
--              tinyint                     SMALLINT
--              
--
-- Additional Differences
--          COLLATE !!sensitive             --
--
--              column name invalid chars in column names are inclosed in ""
--                                      sample  "_time"  
--              column name which are keywords in Oracle are inclosed in ""
--                                      sample "version"
--
--              keyword IDENTITY on MSSQL using ~SEQUENCE on ORACLE
--
-- ****************************************************************************




-- ****************************************************************************
-- adding tables
-- ****************************************************************************

--name=addmemo,


CREATE TABLE addmemo (
	domainid NUMBER NOT NULL ,
	adid   NUMBER NOT NULL ,
	adtype NUMBER NOT NULL ,
	part  NUMBER NOT NULL ,
	admemo NCLOB  NULL 
)
;


alter table addmemo add  PRIMARY KEY(adid, adtype, part, domainid) 
;

grant select on addmemo to ca_itrm_group;
grant update on addmemo to ca_itrm_group;
grant delete on addmemo to ca_itrm_group;
grant insert on addmemo to ca_itrm_group;
grant select on addmemo to ca_itrm_group_ams;





-- name=addtext,
CREATE TABLE  addtext  (
	 domainid   int  NOT NULL ,
	 adid   NUMBER  NOT NULL ,
	 adtype   NUMBER  NOT NULL ,
	 part   NUMBER  NOT NULL ,
	 adtext   nvarchar2  (127)   NULL 
)
;
alter table addtext add  PRIMARY KEY(adid, adtype, part, domainid)
;

grant select on addtext to ca_itrm_group;
grant update on addtext to ca_itrm_group;
grant delete on addtext to ca_itrm_group;
grant insert on addtext to ca_itrm_group;
grant select on addtext to ca_itrm_group_ams;

-- @FIXME 
-- grant select on addtext to group upmuser_group;


-- name=am_approved_licenses,
CREATE TABLE   am_approved_licenses  (
	 domain_uuid   RAW(16) NOT NULL ,
	 license_uuid  RAW(16) NOT NULL ,
	 license_type  NUMBER  NULL ,
	 sw_def_uuid   RAW(16) NOT NULL ,
	 object_uuid   RAW(16) NULL ,
	 object_type   NUMBER  NULL ,
	 approved_licenses   NUMBER  NULL ,
	 creation_user   nvarchar2  (255)  NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)  NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 auto_rep_version   timestamp  NULL 
)
;  

alter table am_approved_licenses add  PRIMARY KEY(license_uuid, domain_uuid)
;

grant select on am_approved_licenses to ca_itrm_group;
grant update on am_approved_licenses to ca_itrm_group;
grant delete on am_approved_licenses to ca_itrm_group;
grant insert on am_approved_licenses to ca_itrm_group;
grant select on am_approved_licenses to ca_itrm_group_ams;


/*
ALTER TABLE am_approved_licenses ADD 
	CONSTRAINT [DF_am_approved_licenses_license_type] DEFAULT (0) FOR [license_type],
	CONSTRAINT [DF_am_approved_licenses_object_uuid] DEFAULT (null) FOR [object_uuid],
	CONSTRAINT [DF_am_approved_licenses_object_type] DEFAULT ((-1)) FOR [object_type],
	CONSTRAINT [DF_am_approved_licenses_approved_licenses] DEFAULT (0) FOR [approved_licenses]
GO

CREATE  INDEX [am_approved_licenses_idx1] ON [dbo].[am_approved_licenses]([sw_def_uuid]) ON [PRIMARY]
GO


*/


-- name=am_external_device,
CREATE TABLE   am_external_device  (
	 device_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 class_name   NVARCHAR2  (255)  NULL ,
	 label   NVARCHAR2  (255)  NULL ,
	 ipaddress   NVARCHAR2  (255)  NULL ,
	 macaddress   NVARCHAR2  (64)  NULL ,
	 auto_rep_version   DATE  NULL ,
	 last_update_user   NVARCHAR2  (255)  NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 creation_date   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (255)  NULL 
)
;  

grant select on am_external_device to ca_itrm_group;
grant update on am_external_device to ca_itrm_group;
grant delete on am_external_device to ca_itrm_group;
grant insert on am_external_device to ca_itrm_group;
grant select on am_external_device to ca_itrm_group_ams;

-- @FIXME  
--grant select on am_external_device to group upmuser_group;

 
 
/*
ALTER TABLE [dbo].[am_external_device] ADD 
	CONSTRAINT [DF__am_extern__versi__0A9D95DB] DEFAULT (0) FOR [version_number]
GO

CREATE  UNIQUE  INDEX [baseidx_am_external_device] ON [dbo].[am_external_device]([device_uuid]) ON [PRIMARY]
GO

*/

-- name=am_external_device_def,
CREATE TABLE   am_external_device_def  (
	 def_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 class_name   NVARCHAR2  (255)   NULL ,
	 reg_class   NVARCHAR2  (255)   NULL ,
	 map_class_name   NVARCHAR2  (255)   NULL ,
	 map_name   NVARCHAR2  (255)   NULL ,
	 map_area   NVARCHAR2  (255)   NULL ,
	 map_ipaddress   NVARCHAR2  (255)   NULL ,
	 map_macaddress   NVARCHAR2  (255)   NULL ,
	 auto_rep_version   DATE  NULL ,
	 last_update_user   NVARCHAR2  (64)  NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 creation_date   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (255)  NULL 
)
; 

grant select on am_external_device_def to ca_itrm_group;
grant update on am_external_device_def to ca_itrm_group;
grant delete on am_external_device_def to ca_itrm_group;
grant insert on am_external_device_def to ca_itrm_group;
grant select on am_external_device_def to ca_itrm_group_ams;

   


/*
ALTER TABLE [dbo].[am_external_device_def] ADD 
	CONSTRAINT [DF__am_extern__versi__0C85DE4D] DEFAULT (0) FOR [version_number]
GO


*/


-- name=am_link_external_device, 
CREATE TABLE   am_link_external_device  (
	 primary_uuid   RAW(16) NOT NULL ,
	 secondary_uuid   RAW(16) NOT NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 ref_count   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (255)  NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)  NULL ,
	 link_type_id   NUMBER  NULL ,
	 label   NVARCHAR2  (255)  NULL ,
	 link_uuid   RAW(16) NOT NULL ,
	 auto_rep_version   DATE  NULL 
)
;  
alter table am_link_external_device add  PRIMARY KEY(link_uuid)
;


grant select on am_link_external_device to ca_itrm_group;
grant update on am_link_external_device to ca_itrm_group;
grant delete on am_link_external_device to ca_itrm_group;
grant insert on am_link_external_device to ca_itrm_group;
grant select on am_link_external_device to ca_itrm_group_ams;

   

-- name=am_link_object_folder,
CREATE TABLE   am_link_object_folder  (
	 folder_domain_id   NUMBER  NOT NULL ,
	 folder_id   NUMBER  NOT NULL ,
	 object_domain_id   NUMBER  NOT NULL ,
	 object_id   NUMBER  NOT NULL ,
	 object_type   NUMBER  NOT NULL ,
	 object_uuid   RAW(16) NOT NULL 
)  
; 
alter table am_link_object_folder 
    add  PRIMARY KEY(folder_id, object_domain_id,object_id, object_type, object_uuid )
;
 
grant select on am_link_object_folder to ca_itrm_group;
grant update on am_link_object_folder to ca_itrm_group;
grant delete on am_link_object_folder to ca_itrm_group;
grant insert on am_link_object_folder to ca_itrm_group;
grant select on am_link_object_folder to ca_itrm_group_ams;

	




-- name=am_object_folder,

CREATE TABLE   am_object_folder  (
	 folder_domain_id   NUMBER  NOT NULL ,
	 folder_id   NUMBER  NOT NULL ,
	 folder_parent_id   NUMBER  NULL ,
	 folder_name   NVARCHAR2  (255)  NULL ,
	 object_type   NUMBER  NULL ,
	 folder_filter   NUMBER  NOT NULL ,
	 folder_id_type   NUMBER  NOT NULL 
)
;
alter table am_object_folder 
    add  PRIMARY KEY(folder_domain_id, folder_id )
;
		
grant select on am_object_folder to ca_itrm_group;
grant update on am_object_folder to ca_itrm_group;
grant delete on am_object_folder to ca_itrm_group;
grant insert on am_object_folder to ca_itrm_group;
grant select on am_object_folder to ca_itrm_group_ams;

  


-- name=amaccmap,

CREATE TABLE   amaccmap  (
	 domainid   NUMBER  NOT NULL ,
	 acid   NUMBER  NOT NULL ,
	 acsrv   varchar  (127)   NULL ,
	 acname   varchar  (127)   NULL ,
	 actype   NUMBER  NULL ,
	 acdesc   varchar  (127)   NULL ,
	 acstate   NUMBER  NULL ,
	 acrights   VARCHAR2  (1)   NULL 
) 
;

alter table amaccmap 
    add  PRIMARY KEY(acid, domainid )
; 
		
 
grant select on amaccmap to ca_itrm_group;
grant update on amaccmap to ca_itrm_group;
grant delete on amaccmap to ca_itrm_group;
grant insert on amaccmap to ca_itrm_group;
grant select on amaccmap to ca_itrm_group_ams;



-- name=amepdef,
CREATE TABLE amepdef (
	domainid NUMBER NOT NULL ,
	epid NUMBER NOT NULL ,
	eptitle NVARCHAR2 (127)  NULL ,
	eparea NUMBER NULL ,
	epevent NUMBER NULL ,
	epsev NUMBER NULL ,
	epstate NUMBER NULL ,
	epflags NUMBER NULL ,
	ephisday NUMBER NULL ,
	epid1 NUMBER NULL ,
	epid2 NUMBER NULL ,
	epid3 NUMBER NULL ,
	epid4 NUMBER NULL ,
	epjsup NVARCHAR2 (127)  NULL ,
	epvfmt NUMBER NULL ,
	policy_uuid RAW (16) NULL ,
	creation_user NVARCHAR2 (255)  NULL ,
	creation_date NUMBER NULL ,
	last_update_user NVARCHAR2 (255)  NULL ,
	last_update_date NUMBER NULL ,
	epuuid1 RAW (16) NULL ,
	epuuid2 RAW (16) NULL ,
	epuuid3 RAW (16) NULL ,
	epuuid4 RAW (16) NULL ,
	auto_rep_version DATE NULL 
)
;
alter table amepdef 
    add  PRIMARY KEY(domainid, epid )
;


grant select on amepdef to ca_itrm_group;
grant update on amepdef to ca_itrm_group;
grant delete on amepdef to ca_itrm_group;
grant insert on amepdef to ca_itrm_group;
grant select on amepdef to ca_itrm_group_ams;

 

-- name=amephis,

CREATE TABLE   amephis  (
	 domainid   NUMBER  NULL ,
	 epid   NUMBER  NULL ,
	 eparea   NUMBER  NULL ,
	 epevent   NUMBER  NULL ,
	 hdate   NUMBER  NULL ,
	 hpri   NVARCHAR2  (127)   NULL ,
	 hpritype   NUMBER  NULL ,
	 hpridid   NUMBER  NULL ,
	 hpriid   NUMBER  NULL ,
	 hsec   NVARCHAR2  (127)   NULL ,
	 hsectype   NUMBER  NULL ,
	 hsecdid   NUMBER  NULL ,
	 hsecid   NUMBER  NULL ,
	 hter   NVARCHAR2  (127)   NULL ,
	 htertype   NUMBER  NULL ,
	 hterdid   NUMBER  NULL ,
	 hterid   NUMBER  NULL ,
	 huser   NVARCHAR2  (256)   NULL ,
	 huserdid   NUMBER  NULL ,
	 huserid   NUMBER  NULL ,
	 hold   NVARCHAR2  (127)   NULL ,
	 hnew   NVARCHAR2  (127)   NULL ,
	 epvfmt   NUMBER  NULL ,
	 hpriuuid   RAW(16) NULL ,
	 hsecuuid   RAW(16) NULL ,
	 hteruuid   RAW(16) NULL 
) 
;

alter table amephis 
    add  PRIMARY KEY(domainid, epid )
;                      

 
grant select on amephis to ca_itrm_group;
grant update on amephis to ca_itrm_group;
grant delete on amephis to ca_itrm_group;
grant insert on amephis to ca_itrm_group;
grant select on amephis to ca_itrm_group_ams;



--name=amepjobs,
CREATE TABLE   amepjobs  (
	 epdomid   NUMBER  NOT NULL ,
	 epid   NUMBER  NOT NULL ,
	 epjtype   NUMBER  NOT NULL ,
	 epjorder   NUMBER  NOT NULL ,
	 epjcont   NCLOB    NULL 
) 
;
alter table amepjobs 
    add  PRIMARY KEY(epdomid, epid,epjorder,epjtype )
; 

  
grant select on amepjobs to ca_itrm_group;
grant update on amepjobs to ca_itrm_group;
grant delete on amepjobs to ca_itrm_group;
grant insert on amepjobs to ca_itrm_group;
grant select on amepjobs to ca_itrm_group_ams;

  
	
-- name=amlegacy_objects,
CREATE TABLE   amlegacy_objects  (
	 old_domain_id   NUMBER  NOT NULL ,
	 old_id   NUMBER  NOT NULL ,
	 object_type   NUMBER  NOT NULL ,
	 object_domain_id   NUMBER  NULL ,
	 object_id   NUMBER  NULL ,
	 object_uuid   RAW(16) NULL ,
	 create_date   NUMBER  NULL ,
	 modify_date   NUMBER  NULL ,
	 status   NUMBER  NULL 
) 
;

alter table amlegacy_objects 
    add  PRIMARY KEY(object_type, old_domain_id,old_id )
;
		
grant select on amlegacy_objects to ca_itrm_group;
grant update on amlegacy_objects to ca_itrm_group;
grant delete on amlegacy_objects to ca_itrm_group;
grant insert on amlegacy_objects to ca_itrm_group;
grant select on amlegacy_objects to ca_itrm_group_ams;
 

-- name=appuknow,
CREATE TABLE   appuknow  (
	 object_uuid   RAW(16) NOT NULL ,
	 filepart   NUMBER  NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 contain   NCLOB    NULL 
) 
;

alter table appuknow 
    add  PRIMARY KEY(filepart, object_uuid )
;

		
		
grant select on appuknow to ca_itrm_group;
grant update on appuknow to ca_itrm_group;
grant delete on appuknow to ca_itrm_group;
grant insert on appuknow to ca_itrm_group;
grant select on appuknow to ca_itrm_group_ams;
 

--name=audithis,
CREATE TABLE   audithis  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 exename   NVARCHAR2  (32)   NOT NULL ,
	 sttotal   NUMBER  NOT NULL ,
	 vernr   NUMBER  NOT NULL ,
	 exepath   NVARCHAR2  (127)   NULL ,
	 acid   NUMBER  NULL ,
	 stdate   NUMBER  NULL ,
	 sttime   NUMBER  NULL ,
	 ENDDATE   NUMBER  NULL ,
	 ENDTIME   NUMBER  NULL ,
	 ENDTOTAL   NUMBER  NULL 
)  
;

alter table audithis 
    add  PRIMARY KEY(exename, object_uuid, sttotal, vernr )
;
 
		
grant select on audithis to ca_itrm_group; 
grant update on audithis to ca_itrm_group;
grant delete on audithis to ca_itrm_group;
grant insert on audithis to ca_itrm_group;
grant select on audithis to ca_itrm_group_ams; 
 


-- this is part of patch 14749700
--CREATE TABLE MDBADMIN.bit_support (
--	bit_support_id raw (16) NOT NULL ,
--	"name" nvarchar2 (50),
--	creation_user nvarchar2 (64),
--	creation_date NUMBER NOT NULL 
--) 
--/

--ALTER TABLE MDBADMIN.bit_support 
--	ADD CONSTRAINT XPKbit_support PRIMARY KEY  ( bit_support_id)  
--/

--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT ca_so_r000004cf00000000 FOREIGN KEY ( manufacturer_uuid)
--	REFERENCES MDBADMIN.ca_company ( company_uuid);

--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT ca_so_r000004d800000000 FOREIGN KEY ( source_type_id)
--	REFERENCES MDBADMIN.ca_source_type ( source_type_id);

--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT ca_so_r000004e200000000 FOREIGN KEY ( software_type_id)
--	REFERENCES MDBADMIN.ca_software_type ( software_type_id);

--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT ca_so_r000004eb00000000 FOREIGN KEY ( family_sw_def_uuid)
--	REFERENCES MDBADMIN.ca_software_def ( sw_def_uuid);

--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT ca_so_r0000064300000000 FOREIGN KEY ( class_id)
--	REFERENCES MDBADMIN.ca_class_def ( class_id);

--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT ca_so_r0000065b00000000 FOREIGN KEY ( lang_code)
--	REFERENCES MDBADMIN.ca_language ( lang_code);


GRANT  SELECT, UPDATE, INSERT, DELETE ON MDBADMIN.bit_support  TO ca_itrm_group;
GRANT  SELECT ON MDBADMIN.bit_support  TO ca_itrm_group_ams;



-- name=ca_server, already created in p15000408.sql
grant select on ca_server to ca_itrm_group;
grant update on ca_server to ca_itrm_group;
grant delete on ca_server to ca_itrm_group;
grant insert on ca_server to ca_itrm_group;
grant select on ca_server to ca_itrm_group_ams;


-- name=ca_agent, already created in p15000408
grant select on ca_agent to ca_itrm_group; 
grant update on ca_agent to ca_itrm_group;
grant delete on ca_agent to ca_itrm_group;
grant insert on ca_agent to ca_itrm_group;
grant select on ca_agent to ca_itrm_group_ams; 

-- name=ca_class_ace,
CREATE TABLE   ca_class_ace  (
	 ace   NUMBER  NOT NULL ,
	 class_def_uuid   RAW(16) NOT NULL ,
	 security_profile_uuid   RAW(16) NOT NULL ,
	 "ACCESS"   NUMBER  NULL 
)  
;
alter table ca_class_ace 
    add  PRIMARY KEY(class_def_uuid,security_profile_uuid )
;


         
grant select on ca_class_ace to ca_itrm_group; 
grant update on ca_class_ace to ca_itrm_group;
grant delete on ca_class_ace to ca_itrm_group;
grant insert on ca_class_ace to ca_itrm_group;
grant select on ca_class_ace to ca_itrm_group_ams; 
 
 
 
-- name=ca_directory_details,
CREATE TABLE   ca_directory_details  (
	 directory_uuid   RAW(16) NOT NULL ,
	 directory_name   NVARCHAR2  (255)  NULL ,
	 server_name       NVARCHAR2  (255)  NULL ,
	 port_number       NUMBER  NULL ,
	 binding         NUMBER  NULL ,
	 user_name       NVARCHAR2  (255)   NULL ,
	 password        NVARCHAR2  (255)   NULL ,
	 base_dn           NVARCHAR2  (1023)   NULL ,
	 creation_user     NVARCHAR2  (255)   NULL ,
	 creation_date     NUMBER  NULL ,
	 last_update_user  NVARCHAR2  (255)   NULL ,
	 last_update_date  NUMBER  NULL ,
	 version_number    NUMBER  NULL ,
	 directory_type    NUMBER  NULL , 
	 DIR_AUTHORITIES           NVARCHAR2(1024) NULL,
	 DIR_USER_SEARCH_FILTER    NVARCHAR2(1024) NULL,
	 DIR_HARDWARE_SEARCH_FILTER    NVARCHAR2(1024) NULL,
	 DIR_MACROS                NVARCHAR2(1024) NULL
) 
;


alter table ca_directory_details 
    add  PRIMARY KEY(directory_uuid)
; 

 
grant select on ca_directory_details to ca_itrm_group;
grant update on ca_directory_details to ca_itrm_group;
grant delete on ca_directory_details to ca_itrm_group;
grant insert on ca_directory_details to ca_itrm_group;
grant select on ca_directory_details to ca_itrm_group_ams;
 



-- name=ca_directory_schema_map,
CREATE TABLE   ca_directory_schema_map  (
	 dir_schema_uuid   RAW(16) NOT NULL ,
	 dir_schema_map_name   NVARCHAR2  (255)   NULL ,
	 itrm_attrib   NVARCHAR2  (255)   NULL ,
	 dir_attrib   NVARCHAR2  (255)   NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL 
)
;

alter table ca_directory_schema_map 
    add  PRIMARY KEY(dir_schema_uuid)
; 


 
grant select on ca_directory_schema_map to ca_itrm_group;
grant update on ca_directory_schema_map to ca_itrm_group;
grant delete on ca_directory_schema_map to ca_itrm_group;
grant insert on ca_directory_schema_map to ca_itrm_group;
grant select on ca_directory_schema_map to ca_itrm_group_ams;
 


 
 
-- name=ca_engine,
CREATE TABLE   ca_engine  (
	 engine_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 label   NVARCHAR2  (255)  NULL ,
	 host_name   NVARCHAR2  (255)  NULL ,
	 description   NVARCHAR2  (255)  NULL ,
	 creation_user   NVARCHAR2  (255)  NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)  NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 dis_hw_uuid   RAW(16) NULL ,
	 auto_rep_version   DATE  NULL 
)  
;

alter table ca_engine 
    add  PRIMARY KEY(engine_uuid)
;

grant select on ca_engine to ca_itrm_group;
grant update on ca_engine to ca_itrm_group;
grant delete on ca_engine to ca_itrm_group;
grant insert on ca_engine to ca_itrm_group;
grant select on ca_engine to ca_itrm_group_ams;



-- name=ca_group_def,
CREATE TABLE   ca_group_def  (
	 group_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 eval_freq   NUMBER  NULL ,
	 last_eval_date_time   NUMBER  NULL ,
	 query_uuid   RAW(16) NULL ,
	 member_type   NUMBER  NULL ,
	 label   NVARCHAR2  (255)  NULL ,
	 evaluation_uuid   RAW(16) NULL ,
	 group_inheritance   smallint  NULL ,
	 evaluation_location   smallint  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 creation_date   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 group_flag   smallint  NULL ,
	 group_system   smallint  NULL ,
	 security_group   NUMBER  NULL ,
	 description   NVARCHAR2  (255)   NULL ,
	 auto_rep_version   DATE  NULL 
)
;
alter table ca_group_def 
    add  PRIMARY KEY(group_uuid)
;

grant select on ca_group_def to ca_itrm_group;
grant update on ca_group_def to ca_itrm_group;
grant delete on ca_group_def to ca_itrm_group;
grant insert on ca_group_def to ca_itrm_group;
grant select on ca_group_def to ca_itrm_group_ams;
 


-- name=ca_group_member,
CREATE TABLE   ca_group_member  (
	 member_uuid   RAW(16) NOT NULL ,
	 member_type   smallint  NULL ,
	 group_domain_uuid   RAW(16) NOT NULL ,
	 group_uuid   RAW(16) NOT NULL ,
	 member_domain_uuid   RAW(16) NOT NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
) 
;

alter table ca_group_member 
    add  PRIMARY KEY(group_uuid, member_uuid)
;

grant select on ca_group_member to ca_itrm_group;
grant update on ca_group_member to ca_itrm_group;
grant delete on ca_group_member to ca_itrm_group;
grant insert on ca_group_member to ca_itrm_group;
grant select on ca_group_member to ca_itrm_group_ams;
 



-- name=ca_license_def,
CREATE TABLE   ca_license_def  (
	 lic_def_uuid   RAW(16) NOT NULL ,
	 lic_key   NCLOB    NOT NULL 
) 
;

alter table ca_license_def 
    add  PRIMARY KEY(lic_def_uuid)
;


grant select on ca_license_def to ca_itrm_group;
grant update on ca_license_def to ca_itrm_group;
grant delete on ca_license_def to ca_itrm_group;
grant insert on ca_license_def to ca_itrm_group;
grant select on ca_license_def to ca_itrm_group_ams;
 





-- name=ca_link_dir_details_map,
CREATE TABLE   ca_link_dir_details_map  (
	 directory_uuid   RAW(16) NULL ,
	 dir_schema_uuid   RAW(16) NULL ,
	 dir_details_map_uuid   RAW(16) NOT NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL 
) 
;

alter table ca_link_dir_details_map 
    add  PRIMARY KEY(dir_details_map_uuid)
;
 
grant select on ca_link_dir_details_map to ca_itrm_group;
grant update on ca_link_dir_details_map to ca_itrm_group;
grant delete on ca_link_dir_details_map to ca_itrm_group;
grant insert on ca_link_dir_details_map to ca_itrm_group;
grant select on ca_link_dir_details_map to ca_itrm_group_ams;
  


-- name=ca_link_dis_user_sec_profile,
CREATE TABLE   ca_link_dis_user_sec_profile  (
	 security_profile_uuid   RAW(16) NOT NULL ,
	 user_uuid   RAW(16) NOT NULL ,
	 creation_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL 
)
;
alter table ca_link_dis_user_sec_profile 
    add  PRIMARY KEY(security_profile_uuid, user_uuid)
;
 


  
grant select on ca_link_dis_user_sec_profile to ca_itrm_group;
grant update on ca_link_dis_user_sec_profile to ca_itrm_group;
grant delete on ca_link_dis_user_sec_profile to ca_itrm_group;
grant insert on ca_link_dis_user_sec_profile to ca_itrm_group;
grant select on ca_link_dis_user_sec_profile to ca_itrm_group_ams;
  



-- name=ca_link_lic_def_domain,
CREATE TABLE   ca_link_lic_def_domain  (
	 lic_def_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL 
)
;

alter table ca_link_lic_def_domain 
    add  PRIMARY KEY(domain_uuid, lic_def_uuid)
;


 
grant select on ca_link_lic_def_domain to ca_itrm_group;
grant update on ca_link_lic_def_domain to ca_itrm_group;
grant delete on ca_link_lic_def_domain to ca_itrm_group;
grant insert on ca_link_lic_def_domain to ca_itrm_group;
grant select on ca_link_lic_def_domain to ca_itrm_group_ams;
 




-- name=ca_manager,
CREATE TABLE   ca_manager  (
	 manager_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NULL ,
	 label   NVARCHAR2  (255)  NULL ,
	 host_uuid   nchar  (36)   NULL ,
	 host_name   NVARCHAR2  (255)   NULL ,
	 description   NVARCHAR2  (255)   NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)
;  

alter table ca_manager 
    add  PRIMARY KEY(manager_uuid)
;

	 
grant select on ca_manager to ca_itrm_group;
grant update on ca_manager to ca_itrm_group;
grant delete on ca_manager to ca_itrm_group;
grant insert on ca_manager to ca_itrm_group;
grant select on ca_manager to ca_itrm_group_ams;
 

-- name=ca_manager_component,
CREATE TABLE   ca_manager_component  (
	 manager_uuid   RAW(16) NOT NULL ,
	 manager_comp_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NULL ,
	 manager_comp_id   NUMBER  NULL ,
	 manager_comp_version   NVARCHAR2  (64)   NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 disabled   NUMBER  NULL 
)  
;
alter table ca_manager_component 
    add  PRIMARY KEY(manager_comp_uuid)
;

grant select on ca_manager_component to ca_itrm_group;
grant update on ca_manager_component to ca_itrm_group;
grant delete on ca_manager_component to ca_itrm_group;
grant insert on ca_manager_component to ca_itrm_group;
grant select on ca_manager_component to ca_itrm_group_ams;
 




-- name=ca_pool_resource,
CREATE TABLE   ca_pool_resource  (
	 pool_name   NVARCHAR2  (64)   NOT NULL ,
	 state   NUMBER  NOT NULL ,
	 last_state_change   NUMBER  NOT NULL ,
	 instance   NUMBER  NOT NULL 
) 
; 
grant select on ca_pool_resource to ca_itrm_group;
grant update on ca_pool_resource to ca_itrm_group;
grant delete on ca_pool_resource to ca_itrm_group;
grant insert on ca_pool_resource to ca_itrm_group;
grant select on ca_pool_resource to ca_itrm_group_ams; 



-- name=ca_query_def,
CREATE TABLE   ca_query_def  (
	 domain_uuid   RAW(16) NOT NULL ,
	 query_uuid   RAW(16) NOT NULL ,
	 label   NVARCHAR2  (255)  NULL ,
	 query_type   NUMBER  NULL ,
	 query_cont   NCLOB    NULL ,
	 target_table   NVARCHAR2  (255)   NULL ,
	 target_type   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
) 
;
alter table ca_query_def 
    add  PRIMARY KEY(query_uuid)
;

	
grant select on ca_query_def to ca_itrm_group;
grant update on ca_query_def to ca_itrm_group;
grant delete on ca_query_def to ca_itrm_group;
grant insert on ca_query_def to ca_itrm_group;
grant select on ca_query_def to ca_itrm_group_ams;



-- name=ca_query_def_contents,
CREATE TABLE   ca_query_def_contents  (
	 domain_uuid   RAW(16) NOT NULL ,
	 query_uuid   RAW(16) NOT NULL ,
	 sequence_no   NUMBER  NOT NULL ,
	 query_cont   NCLOB   NULL ,
	 creation_user   NVARCHAR2  (255)  NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)  NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
) 
;
alter table ca_query_def_contents 
    add  PRIMARY KEY(query_uuid, sequence_no)
;


grant select on ca_query_def_contents to ca_itrm_group;
grant update on ca_query_def_contents to ca_itrm_group;
grant delete on ca_query_def_contents to ca_itrm_group;
grant insert on ca_query_def_contents to ca_itrm_group;
grant select on ca_query_def_contents to ca_itrm_group_ams;



-- name=ca_query_pre_result,
CREATE TABLE   ca_query_pre_result  (
	 pre_result_uuid   RAW(16) NOT NULL ,
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL 
) 
; 
alter table ca_query_pre_result 
    add  PRIMARY KEY(object_uuid, pre_result_uuid)
;

		

grant select on ca_query_pre_result to ca_itrm_group;
grant update on ca_query_pre_result to ca_itrm_group;
grant delete on ca_query_pre_result to ca_itrm_group;
grant insert on ca_query_pre_result to ca_itrm_group;
grant select on ca_query_pre_result to ca_itrm_group_ams;


-- name=ca_query_result,
CREATE TABLE   ca_query_result  (
	 query_uuid   RAW(16) NOT NULL ,
	 member_uuid   RAW(16) NOT NULL ,
	 member_type   NUMBER  NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 query_domain_uuid   RAW(16) NOT NULL ,
	 query_version_uuid   RAW(16) NOT NULL ,
	 member_domain_uuid   RAW(16) NOT NULL 
)  
;
alter table ca_query_result 
    add  PRIMARY KEY(member_uuid, query_uuid,query_version_uuid )
; 

grant select on ca_query_result to ca_itrm_group;
grant update on ca_query_result to ca_itrm_group;
grant delete on ca_query_result to ca_itrm_group;
grant insert on ca_query_result to ca_itrm_group;
grant select on ca_query_result to ca_itrm_group_ams;



-- name=ca_query_version,
CREATE TABLE   ca_query_version  (
	 query_version_uuid   RAW(16) NOT NULL ,
	 query_uuid   RAW(16) NOT NULL ,
	 label   NVARCHAR2  (255)   NOT NULL ,
	 flag   NUMBER  NULL ,
	 query_domain_uuid   RAW(16) NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 domain_list   NVARCHAR2  (2000)   NULL ,
	 query_version_domain_uuid   RAW(16) NULL 
) 
;
 
alter table ca_query_version 
    add  PRIMARY KEY(query_uuid, query_version_uuid)
;

grant select on ca_query_version to ca_itrm_group;
grant update on ca_query_version to ca_itrm_group;
grant delete on ca_query_version to ca_itrm_group;
grant insert on ca_query_version to ca_itrm_group;
grant select on ca_query_version to ca_itrm_group_ams;




 


-- name=ca_replication_conf,
CREATE TABLE   ca_replication_conf  (
	 replication_conf_uuid   RAW(16) NOT NULL ,
	 table_name   NVARCHAR2  (255)   NULL ,
	 job_uuid   RAW(16) NULL ,
	 direction   NUMBER  NULL ,
	 domain_collection   NUMBER  NULL ,
	 job_domain_id   NUMBER  NULL ,
	 job_id   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 enterprise_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 replication_order   NUMBER  NOT NULL ,
	 primary_keys   NVARCHAR2  (255)   NULL ,
	 replication_column_filter   NVARCHAR2  (255)   NULL ,
	 where_clause   NVARCHAR2  (255)   NULL ,
	 unlink_where_clause   NVARCHAR2  (255)   NULL 
)
;
alter table ca_replication_conf 
    add  PRIMARY KEY(replication_conf_uuid)
;


grant select on ca_replication_conf to ca_itrm_group;
grant update on ca_replication_conf to ca_itrm_group;
grant delete on ca_replication_conf to ca_itrm_group;
grant insert on ca_replication_conf to ca_itrm_group;
grant select on ca_replication_conf to ca_itrm_group_ams;


-- name=ca_replication_history,
CREATE TABLE   ca_replication_history  (
	 primary_uuid   RAW(16) NULL ,
	 secondary_uuid   RAW(16) NULL ,
	 lng1   NUMBER  NULL ,
	 lng2   NUMBER  NULL ,
	 lng3   NUMBER  NULL ,
	 lng4   NUMBER  NULL ,
	 table_name   NVARCHAR2  (255)   NULL ,
	 action   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
) 
;

 
grant select on ca_replication_history to ca_itrm_group;
grant update on ca_replication_history to ca_itrm_group;
grant delete on ca_replication_history to ca_itrm_group;
grant insert on ca_replication_history to ca_itrm_group;
grant select on ca_replication_history to ca_itrm_group_ams;




-- name=ca_replication_status,
CREATE TABLE   ca_replication_status  (
	 replication_conf_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 modified_status   RAW  (8) NULL ,
	 deleted_status   RAW  (8) NULL 
)  
;
alter table ca_replication_status 
    add  PRIMARY KEY(domain_uuid, replication_conf_uuid)
;
grant select on ca_replication_status to ca_itrm_group;
grant update on ca_replication_status to ca_itrm_group;
grant delete on ca_replication_status to ca_itrm_group;
grant insert on ca_replication_status to ca_itrm_group;
grant select on ca_replication_status to ca_itrm_group_ams;





-- name=ca_resource_pool,
CREATE TABLE   ca_resource_pool  (
	 name   NVARCHAR2  (64)   NOT NULL ,
	 max_level   NUMBER  NOT NULL ,
	 min_level   NUMBER  NOT NULL ,
	 max_idle_time   NUMBER  NOT NULL ,
	 numb_resources   NUMBER  NOT NULL ,
	 next_resource   NUMBER  NOT NULL 
)  
;


grant select on ca_resource_pool to ca_itrm_group;
grant update on ca_resource_pool to ca_itrm_group;
grant delete on ca_resource_pool to ca_itrm_group;
grant insert on ca_resource_pool to ca_itrm_group;
grant select on ca_resource_pool to ca_itrm_group_ams;




-- name=ca_security_class_def,
CREATE TABLE   ca_security_class_def  (
	 class_def_uuid   RAW(16) NOT NULL ,
	 class_type   NUMBER  NOT NULL ,
	 class_id   NUMBER  NOT NULL ,
	 creation_date   NUMBER  NULL ,
	 class_name        NVARCHAR2(255) NULL         -- dsm barracude
)  
;
alter table ca_security_class_def 
    add  PRIMARY KEY(class_def_uuid)
;
grant select on ca_security_class_def to ca_itrm_group;
grant update on ca_security_class_def to ca_itrm_group;
grant delete on ca_security_class_def to ca_itrm_group;
grant insert on ca_security_class_def to ca_itrm_group;
grant select on ca_security_class_def to ca_itrm_group_ams;

 


-- name=ca_security_profile,
CREATE TABLE   ca_security_profile  (
	 security_profile_uuid   RAW(16) NOT NULL ,
	 name   NVARCHAR2  (255)   NULL ,
	 description   NVARCHAR2  (255)   NULL ,
	 uri   NVARCHAR2  (255)   NULL ,
	 buildin_profile   NUMBER  NULL ,
	 type   NUMBER  NULL ,
	 default_ace   NUMBER  NULL, 
	 area_enabled  NUMBER NULL,        -- dsm r11.2
	 area_ace      NUMBER NULL         -- dsm r11.2
)  
;
alter table ca_security_profile 
    add  PRIMARY KEY(security_profile_uuid)
;
grant select on ca_security_profile to ca_itrm_group;
grant update on ca_security_profile to ca_itrm_group;
grant delete on ca_security_profile to ca_itrm_group;
grant insert on ca_security_profile to ca_itrm_group;
grant select on ca_security_profile to ca_itrm_group_ams;
 


 

-- name=ca_server_component,
CREATE TABLE   ca_server_component  (
	 server_comp_uuid   RAW(16) NOT NULL ,
	 server_comp_id   NUMBER  NULL ,
	 server_comp_version   NVARCHAR2  (32)   NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 version_number   NUMBER  NULL ,
	 server_uuid   RAW(16) NULL ,
	 auto_rep_version   DATE  NULL 
)  
;
alter table ca_server_component 
    add  PRIMARY KEY(server_comp_uuid)
;
grant select on ca_server_component to ca_itrm_group;
grant update on ca_server_component to ca_itrm_group;
grant delete on ca_server_component to ca_itrm_group;
grant insert on ca_server_component to ca_itrm_group;
grant select on ca_server_component to ca_itrm_group_ams;

  

-- name=ca_server_push_status,
CREATE TABLE   ca_server_push_status  (
	 server_uuid   RAW(16) NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 status   NUMBER  NULL 
)  
;
alter table ca_server_push_status 
    add  PRIMARY KEY(server_uuid, type )
;


grant select on ca_server_push_status to ca_itrm_group;
grant update on ca_server_push_status to ca_itrm_group;
grant delete on ca_server_push_status to ca_itrm_group;
grant insert on ca_server_push_status to ca_itrm_group;
grant select on ca_server_push_status to ca_itrm_group_ams;
 
		

-- name=ca_server_queue,
CREATE TABLE   ca_server_queue  (
	 queue_uuid   RAW(16) NOT NULL ,
	 type   NUMBER  NULL ,
	 action   NUMBER  NULL ,
	 uuid1   RAW(16) NULL ,
	 uuid2   RAW(16) NULL ,
	 lng1   NUMBER  NULL ,
	 lng2   NUMBER  NULL ,
	 lng3   NUMBER  NULL ,
	 lng4   NUMBER  NULL ,
	 queue_date   NUMBER  NULL ,
	 text1   NVARCHAR2  (127)   NULL ,
	 text2   NVARCHAR2  (127)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 server_uuid   RAW(16) NULL 
)  
;
alter table ca_server_queue 
    add  PRIMARY KEY(queue_uuid)
;

grant select on ca_server_queue to ca_itrm_group;
grant update on ca_server_queue to ca_itrm_group;
grant delete on ca_server_queue to ca_itrm_group;
grant insert on ca_server_queue to ca_itrm_group;
grant select on ca_server_queue to ca_itrm_group_ams;
 


-- this is part of patch 14749700
-- name=chip_set,
--CREATE TABLE   chip_set  (
--	 chip_set_id   RAW(16) NOT NULL ,
--	 name   NVARCHAR2  (50)   NULL ,
--	 creation_user   NVARCHAR2  (64)   NULL ,
--	 creation_date   NUMBER  NULL 
--)    
--/
--alter table chip_set 
--   add  PRIMARY KEY(chip_set_id)
--/
grant select on chip_set to ca_itrm_group;
grant update on chip_set to ca_itrm_group;
grant delete on chip_set to ca_itrm_group;
grant insert on chip_set to ca_itrm_group;
grant select on chip_set to ca_itrm_group_ams;
 

 

-- name=confmemo,
CREATE TABLE   confmemo  (
	 domainid   NUMBER  NOT NULL ,
	 unitid   NUMBER  NOT NULL ,
	 conftype   NUMBER  NOT NULL ,
	 confver   NUMBER  NOT NULL ,
	 auto_rep_version   DATE  NULL ,
	 contents   NCLOB    NULL 
)   
;
alter table confmemo 
    add  PRIMARY KEY(conftype,confver,domainid, unitid )
;

grant select on confmemo to ca_itrm_group;
grant update on confmemo to ca_itrm_group;
grant delete on confmemo to ca_itrm_group;
grant insert on confmemo to ca_itrm_group;
grant select on confmemo to ca_itrm_group_ams;



-- name=csm_class,
CREATE TABLE   csm_class  (
	 id   NUMBER  NOT NULL ,
	 sysclass   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (64)   NOT NULL 
)    
;
alter table csm_class 
    add  PRIMARY KEY(id)
;


grant select on csm_class to ca_itrm_group;
grant update on csm_class to ca_itrm_group;
grant delete on csm_class to ca_itrm_group;
grant insert on csm_class to ca_itrm_group;
grant select on csm_class to ca_itrm_group_ams;
 


-- name=csm_link,
CREATE TABLE   csm_link  (
	 child   NUMBER  NOT NULL ,
	 parent   NUMBER  NOT NULL 
)    
;
grant select on csm_link to ca_itrm_group;
grant update on csm_link to ca_itrm_group;
grant delete on csm_link to ca_itrm_group;
grant insert on csm_link to ca_itrm_group;
grant select on csm_link to ca_itrm_group_ams;
 

-- name=csm_object,
CREATE TABLE   csm_object  (
	 id   NUMBER  NOT NULL ,
	 flag   NUMBER  NOT NULL ,
	 uuid   RAW(16) NOT NULL ,
	 name   NVARCHAR2  (255)   NOT NULL ,
	 dname   NVARCHAR2  (255)   NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 class   NUMBER  NOT NULL 
)    
;
alter table csm_object 
    add  PRIMARY KEY(id)
;


grant select on csm_object to ca_itrm_group;
grant update on csm_object to ca_itrm_group;
grant delete on csm_object to ca_itrm_group;
grant insert on csm_object to ca_itrm_group;
grant select on csm_object to ca_itrm_group_ams;
  


-- name=csm_property,
CREATE TABLE   csm_property  (
	 id   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (64)   NOT NULL ,
	 value   NVARCHAR2  (1024)   NOT NULL ,
	 object   NUMBER  NOT NULL 
)    
;
alter table csm_property 
    add  PRIMARY KEY(id)
;

grant select on csm_property to ca_itrm_group;
grant update on csm_property to ca_itrm_group;
grant delete on csm_property to ca_itrm_group;
grant insert on csm_property to ca_itrm_group;
grant select on csm_property to ca_itrm_group_ams;




-- name=dts_dbversion,
CREATE TABLE   dts_dbversion  (
	 proplabel   NVARCHAR2  (20)   NULL ,
	 propvalue   NVARCHAR2  (10)   NULL 
)    
;

grant select on dts_dbversion to ca_itrm_group;
grant update on dts_dbversion to ca_itrm_group;
grant delete on dts_dbversion to ca_itrm_group;
grant insert on dts_dbversion to ca_itrm_group;
grant select on dts_dbversion to ca_itrm_group_ams;



-- name=dts_dtfilter,
CREATE TABLE   dts_dtfilter  (
	 object_id   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (10)   NULL ,
	 label   NVARCHAR2  (100)   NULL ,
	 description   NVARCHAR2  (150)   NULL ,
	 user_data1   NVARCHAR2  (255)   NULL ,
	 user_data2   NVARCHAR2  (255)   NULL ,
	 permanent_filter   nchar  (1)   NULL ,
	 reserved   nchar  (1)   NULL ,
	 filter_type   NVARCHAR2  (12)   NULL ,
	 filter_path   NVARCHAR2  (300)   NULL ,
	 endec_key     NVARCHAR2  (70)   NULL ,
	 endec_algid   NUMBER  NULL ,
	 filter_op   NUMBER  NULL ,
	 filter_datatype   NUMBER  NULL 
)    
;
alter table dts_dtfilter 
    add  PRIMARY KEY(object_id)
;

grant select on dts_dtfilter to ca_itrm_group;
grant update on dts_dtfilter to ca_itrm_group;
grant delete on dts_dtfilter to ca_itrm_group;
grant insert on dts_dtfilter to ca_itrm_group;
grant select on dts_dtfilter to ca_itrm_group_ams;


 

-- name=dts_dtsubscribers,
CREATE TABLE   dts_dtsubscribers  (
	 object_id   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (10)   NULL ,
	 label   NVARCHAR2  (100)   NULL ,
	 description   NVARCHAR2  (150)   NULL ,
	 user_data1   NVARCHAR2  (255)   NULL ,
	 user_data2   NVARCHAR2  (255)   NULL ,
	 agent_naddr   NVARCHAR2  (50)   NULL ,
	 agent_uuid   NVARCHAR2  (40)   NULL ,
	 update_time   NUMBER  NULL ,
	 agent_version   NVARCHAR2  (15)   NULL ,
	 agent_name   NVARCHAR2  (255)   NULL ,
	 agent_installed   nchar  (1)   NULL ,
	 nos_installed   nchar  (1)   NULL ,
	 tos_installed   nchar  (1)   NULL ,
	 sos_installed   nchar  (1)   NULL 
)    
;
alter table dts_dtsubscribers 
    add  PRIMARY KEY(object_id)
;


grant select on dts_dtsubscribers to ca_itrm_group;
grant update on dts_dtsubscribers to ca_itrm_group;
grant delete on dts_dtsubscribers to ca_itrm_group;
grant insert on dts_dtsubscribers to ca_itrm_group;
grant select on dts_dtsubscribers to ca_itrm_group_ams;



-- name=dts_dttransfer,
CREATE TABLE   dts_dttransfer  (
	 object_id   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (10)   NULL ,
	 label   NVARCHAR2  (100)   NULL ,
	 description   NVARCHAR2  (150)   NULL ,
	 user_data1   NVARCHAR2  (255)   NULL ,
	 user_data2   NVARCHAR2  (255)   NULL ,
	 max_parcel_size   NUMBER  NULL ,
	 session_retry_interval   NUMBER  NULL ,
	 start_time   NUMBER  NULL ,
	 end_time   NUMBER  NULL ,
	 restart_time   NUMBER  NULL ,
	 total_parcels   NUMBER  NULL ,
	 no_parcels_xferd   NUMBER  NULL ,
	 session_retry_limit   NUMBER  NULL ,
	 session_retry_count   NUMBER  NULL ,
	 flags   NUMBER  NULL ,
	 failure_code   NUMBER  NULL ,
	 throttle_factor   NUMBER  NULL ,
	 license_code   NUMBER  NULL ,
	 bytes_transferred   NUMBER  NULL ,
	 alternative_routes   NUMBER  NULL ,
	 alternative_routes_count   NUMBER  NULL ,
	 discreet_delivery_period   NUMBER  NULL ,
	 discreet_expiry_period   NUMBER  NULL ,
	 auto_resume   nchar  (1)   NULL ,
	 ckp_restart   nchar  (1)   NULL ,
	 commit_to_disk   nchar  (1)   NULL ,
	 direction   nchar  (1)   NULL ,
	 default_tob   nchar  (1)   NULL ,
	 output_mode   nchar  (1)   NULL ,
	 delconv   nchar  (1)   NULL ,
	 i_use_trust   nchar  (1)   NULL ,
	 r_use_trust   nchar  (1)   NULL ,
	 trusted_user   nchar  (1)   NULL ,
	 update_uuid_from_nos   nchar  (1)   NULL ,
	 input   NVARCHAR2  (255)   NULL ,
	 output   NVARCHAR2  (255)   NULL ,
	 initiator   NVARCHAR2  (50)   NULL ,
	 responder   NVARCHAR2  (50)   NULL ,
	 initiator_naddr   NVARCHAR2  (50)   NULL ,
	 responder_naddr   NVARCHAR2  (50)   NULL ,
	 originator_naddr   NVARCHAR2  (50)   NULL ,
	 initiator_sec_token   NVARCHAR2  (100)   NULL ,
	 responder_sec_token   NVARCHAR2  (100)   NULL ,
	 p2m_naddr   NVARCHAR2  (50)   NULL ,
	 originator   NVARCHAR2  (50)   NULL ,
	 owner_name   NVARCHAR2  (50)   NULL ,
	 hop_pos   NVARCHAR2  (10)   NULL ,
	 hop_file   NVARCHAR2  (45)   NULL ,
	 parent   NVARCHAR2  (10)   NULL ,
	 next_tob   NVARCHAR2  (10)   NULL ,
	 root_id   NVARCHAR2  (10)   NULL ,
	 group_id   NVARCHAR2  (10)   NULL ,
	 fanout_protocol   NVARCHAR2  (32)   NULL ,
	 p2p_protocol   NVARCHAR2  (32)   NULL ,
	 p2m_protocol   NVARCHAR2  (32)   NULL ,
	 appl_id   NVARCHAR2  (80)   NULL ,
	 state   NVARCHAR2  (20)   NULL ,
	 state_further_info   NVARCHAR2  (40)   NULL ,
	 transfer_type   NVARCHAR2  (16)   NULL ,
	 dta_id   NVARCHAR2  (18)   NULL ,
	 osname   NVARCHAR2  (16)   NULL ,
	 initiator_priority   NVARCHAR2  (10)   NULL ,
	 responder_priority   NVARCHAR2  (10)   NULL ,
	 originator_uuid   NVARCHAR2  (40)   NULL ,
	 initiator_uuid   NVARCHAR2  (40)   NULL ,
	 responder_uuid   NVARCHAR2  (40)   NULL ,
	 i_notify   nchar  (1)   NULL ,
	 r_notify   nchar  (1)   NULL ,
	 udt_mechanism   NVARCHAR2  (40)   NULL ,
	 route_resolution   nchar  (1)   NULL ,
	 udt_cam_queue_name   NVARCHAR2  (40)   NULL ,
	 udt_cam_queue_location   NVARCHAR2  (40)   NULL ,
	 responder_uasset_uuid   NVARCHAR2  (40)   NULL ,
	 initiator_uasset_uuid   NVARCHAR2  (40)   NULL ,
	 calendar   NVARCHAR2  (10)   NULL ,
	 calendar_server   NVARCHAR2  (50)   NULL ,
	 has_children   NUMBER  NULL ,
	 child_states   NVARCHAR2  (128)   NULL 
)    
;
alter table dts_dttransfer 
    add  PRIMARY KEY(object_id)
;


grant select on dts_dttransfer to ca_itrm_group;
grant update on dts_dttransfer to ca_itrm_group;
grant delete on dts_dttransfer to ca_itrm_group;
grant insert on dts_dttransfer to ca_itrm_group;
grant select on dts_dttransfer to ca_itrm_group_ams;



 

-- name=dts_dttransfergroup,
CREATE TABLE   dts_dttransfergroup  (
	 object_id   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (10)   NULL ,
	 label   NVARCHAR2  (100)   NULL ,
	 description   NVARCHAR2  (150)   NULL ,
	 user_data1   NVARCHAR2  (255)   NULL ,
	 user_data2   NVARCHAR2  (255)   NULL ,
	 start_time   NUMBER  NULL ,
	 end_time   NUMBER  NULL ,
	 restart_time   NUMBER  NULL ,
	 total_parcels   NUMBER  NULL ,
	 no_parcels_xferd   NUMBER  NULL ,
	 bytes_transferred   NUMBER  NULL ,
	 session_retry_limit   NUMBER  NULL ,
	 session_retry_interval   NUMBER  NULL ,
	 flags   NUMBER  NULL ,
	 tos_retry_limit   NUMBER  NULL ,
	 tos_retry_count   NUMBER  NULL ,
	 tos_retry_interval   NUMBER  NULL ,
	 alternative_routes   NUMBER  NULL ,
	 discreet_delivery_period   NUMBER  NULL ,
	 discreet_expiry_period   NUMBER  NULL ,
	 initiator_sec_token   NVARCHAR2  (100)   NULL ,
	 responder_sec_token   NVARCHAR2  (100)   NULL ,
	 owner_name   NVARCHAR2  (50)   NULL ,
	 sequential   nchar  (1)   NULL ,
	 propagate   nchar  (1)   NULL ,
	 ckp_restart   nchar  (1)   NULL ,
	 commit_to_disk   nchar  (1)   NULL ,
	 initiator_priority   NVARCHAR2  (10)   NULL ,
	 responder_priority   NVARCHAR2  (10)   NULL ,
	 implementation   NVARCHAR2  (40)   NULL ,
	 state   NVARCHAR2  (20)   NULL ,
	 appl_id   NVARCHAR2  (80)   NULL ,
	 originator_uuid   NVARCHAR2  (40)   NULL ,
	 multi_group_limit   NUMBER  NULL 
)    
;
alter table dts_dttransfergroup 
    add  PRIMARY KEY(object_id)
;


grant select on dts_dttransfergroup to ca_itrm_group;
grant update on dts_dttransfergroup to ca_itrm_group;
grant delete on dts_dttransfergroup to ca_itrm_group;
grant insert on dts_dttransfergroup to ca_itrm_group;
grant select on dts_dttransfergroup to ca_itrm_group_ams;
 


-- name=dts_dtversion,
CREATE TABLE   dts_dtversion  (
	 object_id   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (10)   NULL ,
	 label   NVARCHAR2  (100)   NULL ,
	 description   NVARCHAR2  (150)   NULL ,
	 user_data1   NVARCHAR2  (255)   NULL ,
	 user_data2   NVARCHAR2  (255)   NULL ,
	 version_number   NVARCHAR2  (10)   NULL 
)    
;
alter table dts_dtversion 
    add  PRIMARY KEY( object_id)
;


grant select on dts_dtversion to ca_itrm_group;
grant update on dts_dtversion to ca_itrm_group;
grant delete on dts_dtversion to ca_itrm_group;
grant insert on dts_dtversion to ca_itrm_group;
grant select on dts_dtversion to ca_itrm_group_ams;



-- name=dts_torproperties,
CREATE TABLE   dts_torproperties  (
	 object_id   NUMBER  NOT NULL ,
	 row_num   NUMBER  NOT NULL ,
	 object_data   NVARCHAR2  (255)   NULL 
)    
;
alter table dts_torproperties 
    add  PRIMARY KEY(object_id, row_num)
;
  
	
grant select on dts_torproperties to ca_itrm_group;
grant update on dts_torproperties to ca_itrm_group;
grant delete on dts_torproperties to ca_itrm_group;
grant insert on dts_torproperties to ca_itrm_group;
grant select on dts_torproperties to ca_itrm_group_ams;

  
 

-- name=eventlog,
CREATE TABLE   eventlog  (
	 "UID"   RAW(16) NOT NULL ,
	 uidparent   RAW(16) NOT NULL ,
	 strhost   varchar  (255)   NOT NULL ,
	 strviewer   VARCHAR2 (255)   NOT NULL ,
	 strremoteuser   VARCHAR2 (255)   NOT NULL ,
	 strdescription   VARCHAR2 (255)   NOT NULL ,
	 datetimestamp   DATE  NOT NULL ,
	 iduration   NUMBER  NOT NULL ,
	 ieventid   NUMBER  NOT NULL ,
	 iseverity   NUMBER  NOT NULL ,
	 iencryption   NUMBER  NOT NULL ,
	 strprotocol   VARCHAR2 (32)   NOT NULL ,
	 ireasonsessionwasclosed   NUMBER  NOT NULL ,
	 icategory   NUMBER  NOT NULL 
)    
;
alter table eventlog 
    add  PRIMARY KEY("UID")
;

grant select on eventlog to ca_itrm_group;
grant update on eventlog to ca_itrm_group;
grant delete on eventlog to ca_itrm_group;
grant insert on eventlog to ca_itrm_group;
grant select on eventlog to ca_itrm_group_ams;



-- name=filemgr,
CREATE TABLE   filemgr  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 filepart   NUMBER  NOT NULL ,
	 fdate   NUMBER  NULL ,
	 contain   NCLOB   NULL 
)    
;
alter table filemgr 
    add  PRIMARY KEY(filepart, object_uuid)
;

 
grant select on filemgr to ca_itrm_group;
grant update on filemgr to ca_itrm_group;
grant delete on filemgr to ca_itrm_group;
grant insert on filemgr to ca_itrm_group;
grant select on filemgr to ca_itrm_group_ams;




-- name=infohis,
CREATE TABLE   infohis  (
	 object_uuid   RAW(16) NOT NULL ,
	 sw_domain_uuid   RAW(16) NOT NULL ,
	 sw_def_uuid   RAW(16) NOT NULL ,
	 sttotal   NUMBER  NOT NULL ,
	 acid   NUMBER  NULL ,
	 stdate   NUMBER  NULL ,
	 sttime   NUMBER  NULL ,
	 enddate   NUMBER  NULL ,
	 endtime   NUMBER  NULL ,
	 endtotal   NUMBER  NULL ,
	 apflag   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table infohis 
    add  PRIMARY KEY(object_uuid,sttotal, sw_def_uuid )
;

 
grant select on infohis to ca_itrm_group;
grant update on infohis to ca_itrm_group;
grant delete on infohis to ca_itrm_group;
grant insert on infohis to ca_itrm_group;
grant select on infohis to ca_itrm_group_ams;
 
 


-- name=infolng,
CREATE TABLE   infolng  (
	 domainid   NUMBER  NOT NULL ,
	 unitid   NUMBER  NOT NULL ,
	 itnameid   NUMBER  NOT NULL ,
	 itprid   NUMBER  NOT NULL ,
	 itrootid   NUMBER  NULL ,
	 itrtnmid   NUMBER  NULL ,
	 itprnmid   NUMBER  NULL ,
	 itidx   NUMBER  NULL ,
	 ittype   NUMBER  NULL ,
	 itval   NUMBER  NULL ,
	 itpval   NUMBER  NULL ,
	 itdate   NUMBER  NULL ,
	 itlock   NUMBER  NULL 
)    
;
alter table infolng 
    add  PRIMARY KEY(domainid, itprid, unitid)
;

 
grant select on infolng to ca_itrm_group;
grant update on infolng to ca_itrm_group;
grant delete on infolng to ca_itrm_group;
grant insert on infolng to ca_itrm_group;
grant select on infolng to ca_itrm_group_ams;


 

-- name=infoqlt,
CREATE TABLE   infoqlt  (
	 domainid   NUMBER  NULL ,
	 itrtnmid   NUMBER  NULL ,
	 itrtname   VARCHAR2 (127)   NULL ,
	 itprnmid   NUMBER  NULL ,
	 itprname   VARCHAR2 (127)   NULL ,
	 itgrnmid   NUMBER  NULL ,
	 itgrname   VARCHAR2 (127)   NULL ,
	 itgrrwnm   VARCHAR2 (127)   NULL ,
	 itident   NUMBER  NULL ,
	 itflag   NUMBER  NULL ,
	 itnameid   NUMBER  NULL ,
	 itname   VARCHAR2 (127)   NULL ,
	 ittbl   NUMBER  NULL ,
	 ittype   NUMBER  NULL ,
	 utype   NUMBER  NULL 
)    
;

  
grant select on infoqlt to ca_itrm_group;
grant update on infoqlt to ca_itrm_group;
grant delete on infoqlt to ca_itrm_group;
grant insert on infoqlt to ca_itrm_group;
grant select on infoqlt to ca_itrm_group_ams;
 


-- name=inv_default_item,
CREATE TABLE   inv_default_item  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_parent_id   NUMBER  NOT NULL ,
	 item_name_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_type   NUMBER  NULL ,
	 item_format   NUMBER  NULL ,
	 item_value_text   NVARCHAR2  (384)  NULL ,
	 item_previous_value_text   NVARCHAR2  (384)  NULL ,
	 item_value_long   NUMBER  NULL ,
	 item_previous_value_long   NUMBER  NULL ,
	 item_value_double   float  NULL ,
	 item_previous_value_double   float  NULL ,
	 item_date   NUMBER  NULL ,
	 item_lock   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table inv_default_item 
    add  PRIMARY KEY(item_name_id, item_parent_id, object_uuid)
;

		
  
grant select on inv_default_item to ca_itrm_group;
grant update on inv_default_item to ca_itrm_group;
grant delete on inv_default_item to ca_itrm_group;
grant insert on inv_default_item to ca_itrm_group;
grant select on inv_default_item to ca_itrm_group_ams;

 


-- name=inv_default_tree,
CREATE TABLE   inv_default_tree  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 item_parent_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_indent   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_flag   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 item_name_id   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table inv_default_tree 
    add  PRIMARY KEY(item_id, object_uuid)
;

grant select on inv_default_tree to ca_itrm_group;
grant update on inv_default_tree to ca_itrm_group;
grant delete on inv_default_tree to ca_itrm_group;
grant insert on inv_default_tree to ca_itrm_group;
grant select on inv_default_tree to ca_itrm_group_ams;
  
 


-- name=inv_externaldevice_item,
CREATE TABLE   inv_externaldevice_item  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_parent_id   NUMBER  NOT NULL ,
	 item_name_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_type   NUMBER  NULL ,
	 item_format   NUMBER  NULL ,
	 item_value_text   NVARCHAR2  (384)  NULL ,
	 item_previous_value_text   NVARCHAR2  (384)  NULL ,
	 item_value_long   NUMBER  NULL ,
	 item_previous_value_long   NUMBER  NULL ,
	 item_value_double   float  NULL ,
	 item_previous_value_double   float  NULL ,
	 item_date   NUMBER  NULL ,
	 item_lock   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;

 
grant select on inv_externaldevice_item to ca_itrm_group;
grant update on inv_externaldevice_item to ca_itrm_group;
grant delete on inv_externaldevice_item to ca_itrm_group;
grant insert on inv_externaldevice_item to ca_itrm_group;
grant select on inv_externaldevice_item to ca_itrm_group_ams;
  
 


-- name=inv_externaldevice_tree,
CREATE TABLE   inv_externaldevice_tree  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_parent_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_indent   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_flag   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 item_name_id   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;

  
grant select on inv_externaldevice_tree to ca_itrm_group;
grant update on inv_externaldevice_tree to ca_itrm_group;
grant delete on inv_externaldevice_tree to ca_itrm_group;
grant insert on inv_externaldevice_tree to ca_itrm_group;
grant select on inv_externaldevice_tree to ca_itrm_group_ams;
 


-- name=inv_generalinventory_item,
CREATE TABLE   inv_generalinventory_item  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_parent_id   NUMBER  NOT NULL ,
	 item_name_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_type   NUMBER  NULL ,
	 item_format   NUMBER  NULL ,
	 item_value_text   NVARCHAR2  (384)  NULL ,
	 item_previous_value_text   NVARCHAR2  (384)  NULL ,
	 item_value_long   NUMBER  NULL ,
	 item_previous_value_long   NUMBER  NULL ,
	 item_value_double   float  NULL ,
	 item_previous_value_double   float  NULL ,
	 item_date   NUMBER  NULL ,
	 item_lock   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table inv_generalinventory_item 
    add  PRIMARY KEY(item_name_id, item_parent_id, object_uuid)
;
  
		
		
grant select on inv_generalinventory_item to ca_itrm_group;
grant update on inv_generalinventory_item to ca_itrm_group;
grant delete on inv_generalinventory_item to ca_itrm_group;
grant insert on inv_generalinventory_item to ca_itrm_group;
grant select on inv_generalinventory_item to ca_itrm_group_ams;



-- name=inv_generalinventory_tree,
CREATE TABLE   inv_generalinventory_tree  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_parent_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_indent   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_flag   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 item_name_id   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table inv_generalinventory_tree 
    add  PRIMARY KEY(item_id, object_uuid )
;


		
  
grant select on inv_generalinventory_tree to ca_itrm_group;
grant update on inv_generalinventory_tree to ca_itrm_group;
grant delete on inv_generalinventory_tree to ca_itrm_group;
grant insert on inv_generalinventory_tree to ca_itrm_group;
grant select on inv_generalinventory_tree to ca_itrm_group_ams;

  


-- name=inv_item_name_id,
CREATE TABLE   inv_item_name_id  (
	 domain_uuid   RAW(16) NOT NULL ,
	 item_name_id   NUMBER  NOT NULL ,
	 item_name   NVARCHAR2  (384)  NOT NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table inv_item_name_id 
    add  PRIMARY KEY(domain_uuid, item_name_id)
;
  
grant select on inv_item_name_id to ca_itrm_group;
grant update on inv_item_name_id to ca_itrm_group;
grant delete on inv_item_name_id to ca_itrm_group;
grant insert on inv_item_name_id to ca_itrm_group;
grant select on inv_item_name_id to ca_itrm_group_ams;
 


-- name=inv_object_tree_id,
CREATE TABLE   inv_object_tree_id  (
	 object_uuid   RAW(16) NOT NULL ,
	 tree_id   NUMBER  NULL 
)    
;
alter table inv_object_tree_id 
    add  PRIMARY KEY(object_uuid)
;
  
grant select on inv_object_tree_id to ca_itrm_group;
grant update on inv_object_tree_id to ca_itrm_group;
grant delete on inv_object_tree_id to ca_itrm_group;
grant insert on inv_object_tree_id to ca_itrm_group;
grant select on inv_object_tree_id to ca_itrm_group_ams;

 


-- name=inv_performance_item,
CREATE TABLE   inv_performance_item  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_parent_id   NUMBER  NOT NULL ,
	 item_name_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_type   NUMBER  NULL ,
	 item_format   NUMBER  NULL ,
	 item_value_text   NVARCHAR2  (384)  NULL ,
	 item_previous_value_text   NVARCHAR2  (384)  NULL ,
	 item_value_long   NUMBER  NULL ,
	 item_previous_value_long   NUMBER  NULL ,
	 item_value_double   float  NULL ,
	 item_previous_value_double   float  NULL ,
	 item_date   NUMBER  NULL ,
	 item_lock   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table inv_performance_item 
    add  PRIMARY KEY(item_name_id, item_parent_id, object_uuid)
;

grant select on inv_performance_item to ca_itrm_group;
grant update on inv_performance_item to ca_itrm_group;
grant delete on inv_performance_item to ca_itrm_group;
grant insert on inv_performance_item to ca_itrm_group;
grant select on inv_performance_item to ca_itrm_group_ams;
   
 


-- name=inv_performance_tree,
CREATE TABLE   inv_performance_tree  (
	 object_uuid   RAW(16) NOT NULL ,
	 item_id   NUMBER  NOT NULL ,
	 item_root_id   NUMBER  NULL ,
	 item_parent_id   NUMBER  NULL ,
	 item_parent_name_id   NUMBER  NULL ,
	 item_indent   NUMBER  NULL ,
	 item_index   NUMBER  NULL ,
	 item_flag   NUMBER  NULL ,
	 item_root_name_id   NUMBER  NULL ,
	 domain_uuid   RAW(16) NULL ,
	 item_name_id   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table inv_performance_tree 
    add  PRIMARY KEY(item_id, object_uuid)
;
  
grant select on inv_performance_tree to ca_itrm_group;
grant update on inv_performance_tree to ca_itrm_group;
grant delete on inv_performance_tree to ca_itrm_group;
grant insert on inv_performance_tree to ca_itrm_group;
grant select on inv_performance_tree to ca_itrm_group_ams;

  


-- name=inv_root_map,
CREATE TABLE   inv_root_map  (
	 item_root_name_id   NUMBER  NOT NULL ,
	 object_uuid   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NULL ,
	 item_id   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 object_type   NUMBER  NULL 
)    
;
alter table inv_root_map 
    add  PRIMARY KEY(item_root_name_id, object_uuid)
;
  
grant select on inv_root_map to ca_itrm_group;
grant update on inv_root_map to ca_itrm_group;
grant delete on inv_root_map to ca_itrm_group;
grant insert on inv_root_map to ca_itrm_group;
grant select on inv_root_map to ca_itrm_group_ams;
  



-- name=inv_table_map,
CREATE TABLE   inv_table_map  (
	 domain_uuid   RAW(16) NOT NULL ,
	 component_name   NVARCHAR2  (384)  NOT NULL ,
	 component_name_id   NUMBER  NOT NULL ,
	 table_name_tree   VARCHAR2 (32)   NOT NULL ,
	 table_name_item   VARCHAR2 (32)   NOT NULL ,
	 auto_rep_version   DATE  NULL,
     tbl_owner          NVARCHAR2(128) NULL 
)    
;
alter table inv_table_map 
    add  PRIMARY KEY(component_name, domain_uuid)
;
  
grant select on inv_table_map to ca_itrm_group;
grant update on inv_table_map to ca_itrm_group;
grant delete on inv_table_map to ca_itrm_group;
grant insert on inv_table_map to ca_itrm_group;
grant select on inv_table_map to ca_itrm_group_ams;
  


-- name=inv_tree_name_id,
CREATE TABLE   inv_tree_name_id  (
	 domain_uuid   RAW(16) NOT NULL ,
	 tree_name_id   NUMBER  NOT NULL ,
	 tree_name   NVARCHAR2  (384)  NOT NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table inv_tree_name_id 
    add  PRIMARY KEY(domain_uuid, tree_name_id)
;
  
grant select on inv_tree_name_id to ca_itrm_group;
grant update on inv_tree_name_id to ca_itrm_group;
grant delete on inv_tree_name_id to ca_itrm_group;
grant insert on inv_tree_name_id to ca_itrm_group;
grant select on inv_tree_name_id to ca_itrm_group_ams;
  
 


-- name=invgene,
CREATE TABLE   invgene  (
	 domainid   NUMBER  NOT NULL ,
	 unittype   NUMBER  NOT NULL ,
	 gindex   NUMBER  NOT NULL ,
	 gid   NVARCHAR2  (127)  NULL ,
	 dname   NVARCHAR2  (127)  NOT NULL ,
	 iconkey   NVARCHAR2  (20)  NULL 
)    
;
alter table invgene 
    add  PRIMARY KEY(domainid, gindex, unittype)
;
  
grant select on invgene to ca_itrm_group;
grant update on invgene to ca_itrm_group;
grant delete on invgene to ca_itrm_group;
grant insert on invgene to ca_itrm_group;
grant select on invgene to ca_itrm_group_ams;



-- name=invsetup,
CREATE TABLE   invsetup  (
	 domainid   NUMBER  NOT NULL ,
	 invid   NUMBER  NOT NULL ,
	 invname   NVARCHAR2  (127)   NULL ,
	 invfname   NVARCHAR2  (127)   NULL ,
	 invmemo   NCLOB    NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table invsetup 
    add  PRIMARY KEY(domainid, invid)
;
 
grant select on invsetup to ca_itrm_group;
grant update on invsetup to ca_itrm_group;
grant delete on invsetup to ca_itrm_group;
grant insert on invsetup to ca_itrm_group;
grant select on invsetup to ca_itrm_group_ams;
   
 


-- name=joborder,
CREATE TABLE   joborder  (
	 udomid   NUMBER  NOT NULL ,
	 unitid   NUMBER  NOT NULL ,
	 jdomid   NUMBER  NOT NULL ,
	 jobid   NUMBER  NOT NULL ,
	 joorder   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table joborder 
    add  PRIMARY KEY(jdomid, jobid, udomid, unitid)
;
  
grant select on joborder to ca_itrm_group;
grant update on joborder to ca_itrm_group;
grant delete on joborder to ca_itrm_group;
grant insert on joborder to ca_itrm_group;
grant select on joborder to ca_itrm_group_ams;



-- name=linkbck,
CREATE TABLE   linkbck  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 bckid   NUMBER  NOT NULL ,
	 bdomid   NUMBER  NOT NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table linkbck 
    add  PRIMARY KEY(bckid, bdomid, object_uuid)
;
  
grant select on linkbck to ca_itrm_group;
grant update on linkbck to ca_itrm_group;
grant delete on linkbck to ca_itrm_group;
grant insert on linkbck to ca_itrm_group;
grant select on linkbck to ca_itrm_group_ams;
 


-- name=linkjob,
CREATE TABLE   linkjob  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 jdomid   NUMBER  NOT NULL ,
	 jobid   NUMBER  NOT NULL ,
	 jostatus   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table linkjob 
    add  PRIMARY KEY(jdomid, jobid, object_uuid)
;
  
grant select on linkjob to ca_itrm_group;
grant update on linkjob to ca_itrm_group;
grant delete on linkjob to ca_itrm_group;
grant insert on linkjob to ca_itrm_group;
grant select on linkjob to ca_itrm_group_ams;
  


-- name=linkmod,
CREATE TABLE   linkmod  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 mdomid   NUMBER  NOT NULL ,
	 moid   NUMBER  NOT NULL ,
	 modtype   NUMBER  NOT NULL ,
	 mostatus   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table linkmod 
    add  PRIMARY KEY(mdomid, moid, object_uuid)
;
  
grant select on linkmod to ca_itrm_group;
grant update on linkmod to ca_itrm_group;
grant delete on linkmod to ca_itrm_group;
grant insert on linkmod to ca_itrm_group;
grant select on linkmod to ca_itrm_group_ams;
 


-- name=lockunit,
CREATE TABLE   lockunit  (
	 domainid   NUMBER  NOT NULL ,
	 server_uuid   RAW(16) NOT NULL ,
	 unitid   NUMBER  NOT NULL ,
	 status   NUMBER  NULL 
)    
;
alter table lockunit 
    add  PRIMARY KEY(domainid, server_uuid, unitid)
;
  
grant select on lockunit to ca_itrm_group;
grant update on lockunit to ca_itrm_group;
grant delete on lockunit to ca_itrm_group;
grant insert on lockunit to ca_itrm_group;
grant select on lockunit to ca_itrm_group_ams;
 


-- name=logicalrelations,
-- no supported depreciated 

-- @FIXME
-- name=mdb_checkpoint,
-- grant select on mdb_checkpoint to ca_itrm_group;
--grant update on mdb_checkpoint to ca_itrm_group;
-- grant delete on mdb_checkpoint to ca_itrm_group;
-- grant insert on mdb_checkpoint to ca_itrm_group;

-- name=mdb_patch,
-- grant select on mdb_patch to ca_itrm_group;
-- grant update on mdb_patch to ca_itrm_group;
-- grant delete on mdb_patch to ca_itrm_group;
-- grant insert on mdb_patch to ca_itrm_group;

-- name=mdb_service_pack,
-- grant select on mdb_service_pack to ca_itrm_group;
-- grant update on mdb_service_pack to ca_itrm_group;
-- grant delete on mdb_service_pack to ca_itrm_group;
-- grant insert on mdb_service_pack to ca_itrm_group;


-- name=miftypes,
CREATE TABLE   miftypes  (
	 domainid   NUMBER  NOT NULL ,
	 typeid   NUMBER  NOT NULL ,
	 mtypeid   VARCHAR2 (120)   NULL ,
	 mareaid   VARCHAR2 (120)   NULL ,
	 mnameid   VARCHAR2 (120)   NULL 
)    
;
alter table miftypes 
    add  PRIMARY KEY(domainid, typeid)
;
  
grant select on miftypes to ca_itrm_group;
grant update on miftypes to ca_itrm_group;
grant delete on miftypes to ca_itrm_group;
grant insert on miftypes to ca_itrm_group;
grant select on miftypes to ca_itrm_group_ams;
 


-- name=ncipc,
CREATE TABLE   ncipc  (
	 ipcid   NUMBER  NOT NULL ,
	 ipctype   NUMBER  NULL ,
	 ipctypex   NUMBER  NULL ,
	 adomid   NUMBER  NULL ,
	 ipcacid   NUMBER  NULL ,
	 edomid   NUMBER  NULL ,
	 ipcextid   NUMBER  NULL ,
	 sdomid   NUMBER  NULL ,
	 ipcstype   NUMBER  NULL ,
	 ipcsid   NUMBER  NULL ,
	 udomid   NUMBER  NULL ,
	 unitid   NUMBER  NULL ,
	 ipcdate   NUMBER  NULL 
)    
;
alter table ncipc 
    add  PRIMARY KEY(ipcid)
;
  
grant select on ncipc to ca_itrm_group;
grant update on ncipc to ca_itrm_group;
grant delete on ncipc to ca_itrm_group;
grant insert on ncipc to ca_itrm_group;
grant select on ncipc to ca_itrm_group_ams;


  

-- name=ncjobbin,
CREATE TABLE   ncjobbin  (
	 domainid   NUMBER  NOT NULL ,
	 jobid   NUMBER  NOT NULL ,
	 jobpart   NUMBER  NOT NULL ,
	 contents   NCLOB    NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table ncjobbin 
    add  PRIMARY KEY(domainid, jobid, jobpart)
;
 
grant select on ncjobbin to ca_itrm_group;
grant update on ncjobbin to ca_itrm_group;
grant delete on ncjobbin to ca_itrm_group;
grant insert on ncjobbin to ca_itrm_group;
grant select on ncjobbin to ca_itrm_group_ams;
  

-- name=ncjobcfg,
CREATE TABLE   ncjobcfg  (
	 domainid   NUMBER  NOT NULL ,
	 jobid   NUMBER  NOT NULL ,
	 joname   NVARCHAR2  (127)  NULL ,
	 jotype   NUMBER  NULL ,
	 jocont   NCLOB    NULL ,
	 jocmd   NVARCHAR2  (127)   NULL ,
	 joos   NUMBER  NULL ,
	 jocreate   NUMBER  NULL ,
	 jomodify   NUMBER  NULL ,
	 josdate   NUMBER  NULL ,
	 jostime   NUMBER  NULL ,
	 joedate   NUMBER  NULL ,
	 joetime   NUMBER  NULL ,
	 jofreq   NUMBER  NULL ,
	 josched   NVARCHAR2  (127)   NULL ,
	 joinst   NUMBER  NULL ,
	 joonceat   NUMBER  NULL ,
	 jooncenr   NUMBER  NULL ,
	 joflag   NUMBER  NULL ,
	 joexit   NUMBER  NULL ,
	 jddomid   NUMBER  NULL ,
	 jodepend    NUMBER  NULL ,
	 joquest   NVARCHAR2  (127)   NULL ,
	 joqforce   NUMBER  NULL ,
	 joqfdate   NUMBER  NULL ,
	 jologoff   NVARCHAR2  (127)   NULL ,
	 joremove   NUMBER  NULL ,
	 jodepfil   NVARCHAR2  (127)   NULL ,
	 jodevice   NVARCHAR2  (127)   NULL ,
	 joserv   NVARCHAR2  (127)   NULL ,
	 jodiscon   NUMBER  NULL ,
	 joiconid   NUMBER  NULL ,
	 jopartnr   NUMBER  NULL ,
	 revnr   NUMBER  NULL ,
	 userid   NUMBER  NULL ,
	 checksum   NUMBER  NULL ,
	 auto_server_version   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 job_uuid   RAW(16) NULL ,
	 job_category   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL 
)    
;
alter table ncjobcfg 
    add  PRIMARY KEY(domainid, jobid)
;
 
grant select on ncjobcfg to ca_itrm_group;
grant update on ncjobcfg to ca_itrm_group;
grant delete on ncjobcfg to ca_itrm_group;
grant insert on ncjobcfg to ca_itrm_group;
grant select on ncjobcfg to ca_itrm_group_ams;


  

-- name=nclog,
CREATE TABLE   nclog  (
	 domainid   NUMBER  NOT NULL ,
	 logid   NUMBER  NOT NULL ,
	 logtype   NUMBER  NULL ,
	 logsev   NUMBER  NULL ,
	 logname   NVARCHAR2  (127)   NULL ,
	 logrefnr   NUMBER  NULL ,
	 logdate   NUMBER  NULL ,
	 unitid   NUMBER  NULL ,
	 userid   NUMBER  NULL ,
	 logmemo   NVARCHAR2  (127)   NULL 
)    
;
alter table nclog 
    add  PRIMARY KEY(domainid, logid)
;
  
grant select on nclog to ca_itrm_group;
grant update on nclog to ca_itrm_group;
grant delete on nclog to ca_itrm_group;
grant insert on nclog to ca_itrm_group;
grant select on nclog to ca_itrm_group_ams;




-- name=ncmodbin,
CREATE TABLE   ncmodbin  (
	 mopart   NUMBER  NOT NULL ,
	 moid   NUMBER  NOT NULL ,
	 contents   NCLOB   NULL ,
	 domainid   NUMBER  NOT NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table ncmodbin 
    add  PRIMARY KEY(domainid, mopart)
;
 
grant select on ncmodbin to ca_itrm_group;
grant update on ncmodbin to ca_itrm_group;
grant delete on ncmodbin to ca_itrm_group;
grant insert on ncmodbin to ca_itrm_group;
grant select on ncmodbin to ca_itrm_group_ams;
 


-- name=ncmodcfg,
CREATE TABLE   ncmodcfg  (
	 domainid   NUMBER  NOT NULL ,
	 moid   NUMBER  NOT NULL ,
	 moname   NVARCHAR2  (127)  NOT NULL ,
	 mocont   NCLOB   NULL ,
	 mocmd   NVARCHAR2  (127)   NULL ,
	 moos   NUMBER  NULL ,
	 motype   NUMBER  NOT NULL ,
	 mocreate   NUMBER  NULL ,
	 momodify   NUMBER  NULL ,
	 mosdate   NUMBER  NULL ,
	 mostime   NUMBER  NULL ,
	 moedate   NUMBER  NULL ,
	 moetime   NUMBER  NULL ,
	 mofreq   NUMBER  NULL ,
	 mosched   NVARCHAR2  (127)   NULL ,
	 moinst   NUMBER  NULL ,
	 moonceat   NUMBER  NULL ,
	 mooncenr   NUMBER  NULL ,
	 moflag   NUMBER  NULL ,
	 jdmodid   NUMBER  NULL ,
	 modepend    NUMBER  NULL ,
	 moquest   NVARCHAR2  (127)   NULL ,
	 moqforce   NUMBER  NULL ,
	 moqfdate   NUMBER  NULL ,
	 mologoff   NVARCHAR2  (127)   NULL ,
	 moremove   NUMBER  NULL ,
	 modepfil   NVARCHAR2  (127)   NULL ,
	 modevice   NVARCHAR2  (127)   NULL ,
	 moserv   NVARCHAR2  (127)   NULL ,
	 modiscon   NUMBER  NULL ,
	 mopartnr   NUMBER  NULL ,
	 revnr   NUMBER  NULL ,
	 userid   NUMBER  NULL ,
	 checksum   NUMBER  NULL ,
	 auto_server_version   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL ,
	 job_category   NUMBER  NULL ,
	 module_uuid   RAW(16) NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL 
)    
;
alter table ncmodcfg 
    add  PRIMARY KEY(domainid, moid)
;
 
grant select on ncmodcfg to ca_itrm_group;
grant update on ncmodcfg to ca_itrm_group;
grant delete on ncmodcfg to ca_itrm_group;
grant insert on ncmodcfg to ca_itrm_group;
grant select on ncmodcfg to ca_itrm_group_ams;

  

-- name=ncovervw,
CREATE TABLE   ncovervw  (
	 domainid   NUMBER  NOT NULL ,
	 unittype   NUMBER  NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 prnmid   NUMBER  NOT NULL ,
	 idomid   NUMBER  NOT NULL ,
	 nameid   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (64)   NULL ,
	 idx   NUMBER  NULL ,
	 attrib   NUMBER  NULL ,
	 auto_rep_version   timestamp  NULL 
)    
;
alter table ncovervw 
    add  PRIMARY KEY(domainid, idomid, nameid, prnmid, unittype, type)
;
  
grant select on ncovervw to ca_itrm_group;
grant update on ncovervw to ca_itrm_group;
grant delete on ncovervw to ca_itrm_group;
grant insert on ncovervw to ca_itrm_group;
grant select on ncovervw to ca_itrm_group_ams;
  


-- name=ncprofil,  
CREATE TABLE   ncprofil  (
	 profilid   NUMBER  NOT NULL ,
	 profilln   NUMBER  NULL ,
	 profiltx   VARCHAR2 (127)   NULL 
) ;
alter table ncprofil 
    add  PRIMARY KEY(profilid)
;


grant select on ncprofil to ca_itrm_group;
grant update on ncprofil to ca_itrm_group;
grant delete on ncprofil to ca_itrm_group;
grant insert on ncprofil to ca_itrm_group;
grant select on ncprofil to ca_itrm_group_ams;


  

-- name=ncrc,
CREATE TABLE   ncrc  (
	 domainid   NUMBER  NOT NULL ,
	 rid   NUMBER  NOT NULL ,
	 typeid   NUMBER  NOT NULL ,
	 itemid   NUMBER  NOT NULL ,
	 rescont   NCLOB   NULL 
)    
;
alter table ncrc 
    add  PRIMARY KEY(domainid, itemid, rid, typeid)
;
 
grant select on ncrc to ca_itrm_group;
grant update on ncrc to ca_itrm_group;
grant delete on ncrc to ca_itrm_group;
grant insert on ncrc to ca_itrm_group;
grant select on ncrc to ca_itrm_group_ams;



-- name=nctngref,
CREATE TABLE   nctngref  (
	 domainid   NUMBER  NOT NULL ,
	 unitid   NUMBER  NOT NULL ,
	 unittype   NUMBER  NULL ,
	 search1   VARCHAR2 (64)   NULL ,
	 search2   VARCHAR2 (64)   NULL ,
	 search3   VARCHAR2 (64)   NULL ,
	 search4   NUMBER  NULL ,
	 clsname   VARCHAR2 (64)   NULL ,
	 uuid   VARCHAR2 (64)   NULL 
)    
;
alter table nctngref 
    add  PRIMARY KEY(domainid, unitid)
;
  
grant select on nctngref to ca_itrm_group;
grant update on nctngref to ca_itrm_group;
grant delete on nctngref to ca_itrm_group;
grant insert on nctngref to ca_itrm_group;
grant select on nctngref to ca_itrm_group_ams;
  


-- name=nctpldef,
CREATE TABLE   nctpldef  (
	 domainid   NUMBER  NOT NULL ,
	 tpid   NUMBER  NOT NULL ,
	 tpname   NVARCHAR2  (64)   NULL ,
	 tpfname   NVARCHAR2  (64)   NULL ,
	 tpver   NUMBER  NULL ,
	 tpuserid   NUMBER  NULL ,
	 tpdesc   NCLOB   NULL ,
	 auto_server_version   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table nctpldef 
    add  PRIMARY KEY(domainid, tpid)
;
 
grant select on nctpldef to ca_itrm_group;
grant update on nctpldef to ca_itrm_group;
grant delete on nctpldef to ca_itrm_group;
grant insert on nctpldef to ca_itrm_group;
grant select on nctpldef to ca_itrm_group_ams;
 




-- name=openunit,
CREATE TABLE   openunit  (
	 domainid   NUMBER  NOT NULL ,
	 unitid   NUMBER  NOT NULL ,
	 opunit   NUMBER  NULL ,
	 changes   NUMBER  NULL ,
	 usdomid   NUMBER  NULL ,
	 userid   NUMBER  NULL ,
	 opendate   NUMBER  NULL 
)    
;
alter table openunit 
    add  PRIMARY KEY(domainid, unitid)
;
  
grant select on openunit to ca_itrm_group;
grant update on openunit to ca_itrm_group;
grant delete on openunit to ca_itrm_group;
grant insert on openunit to ca_itrm_group;
grant select on openunit to ca_itrm_group_ams;
 
 
-- name=policonf,
CREATE TABLE   policonf  (
	 pdomid   NUMBER  NOT NULL ,
	 polid   NUMBER  NOT NULL ,
	 poltype   NUMBER  NOT NULL ,
	 qdomid   NUMBER  NULL ,
	 polqid   NUMBER  NULL ,
	 polinter   NUMBER  NULL ,
	 edomid   NUMBER  NULL ,
	 polengid   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table policonf 
    add  PRIMARY KEY(pdomid, polid, poltype)
;
  
grant select on policonf to ca_itrm_group;
grant update on policonf to ca_itrm_group;
grant delete on policonf to ca_itrm_group;
grant insert on policonf to ca_itrm_group;
grant select on policonf to ca_itrm_group_ams;
 


-- name=polidef,
CREATE TABLE   polidef  (
	 domainid   NUMBER  NOT NULL ,
	 polid   NUMBER  NOT NULL ,
	 polsev   NUMBER  NULL ,
	 polname   NVARCHAR2  (127)  NULL ,
	 polmemo   NCLOB   NULL ,
	 lrundate   NUMBER  NULL ,
	 query_uuid   RAW(16) NULL ,
	 eval_freq   NUMBER  NULL ,
	 evaluation_uuid   RAW(16) NULL ,
	 auto_rep_version   DATE  NULL ,
	 policy_uuid   RAW(16) NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 creation_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (255)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 notify_user_uuid   RAW(16) NULL 
)    
;
alter table polidef 
    add  PRIMARY KEY(domainid, polid)
;
 
grant select on polidef to ca_itrm_group;
grant update on polidef to ca_itrm_group;
grant delete on polidef to ca_itrm_group;
grant insert on polidef to ca_itrm_group;
grant select on polidef to ca_itrm_group_ams;
  


-- name=polijob,
CREATE TABLE   polijob  (
	 domainid   NUMBER  NOT NULL ,
	 polid   NUMBER  NOT NULL ,
	 polorder   NUMBER  NOT NULL ,
	 polact   NUMBER  NOT NULL ,
	 actype   NUMBER  NULL ,
	 actypeid   NUMBER  NULL ,
	 acmemo   NCLOB   NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table polijob 
    add  PRIMARY KEY(domainid, polact, polid, polorder)
;
 
grant select on polijob to ca_itrm_group;
grant update on polijob to ca_itrm_group;
grant delete on polijob to ca_itrm_group;
grant insert on polijob to ca_itrm_group;
grant select on polijob to ca_itrm_group_ams;
  

-- name=polilog,
CREATE TABLE   polilog  (
	 pdomid   NUMBER  NOT NULL ,
	 polid   NUMBER  NOT NULL ,
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 poldate   NUMBER  NULL ,
	 polsev   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table polilog 
    add  PRIMARY KEY(object_uuid, pdomid, polid)
;

grant select on polilog to ca_itrm_group;
grant update on polilog to ca_itrm_group;
grant delete on polilog to ca_itrm_group;
grant insert on polilog to ca_itrm_group;
grant select on polilog to ca_itrm_group_ams;
; 

-- name=rpauto,
CREATE TABLE   rpauto  (
	 objid   NUMBER  NOT NULL ,
	 objname   NVARCHAR2  (64)   NULL ,
	 descript   NCLOB   NULL ,
	 tplobjid   NUMBER  NULL ,
	 schobjid   NUMBER  NULL ,
	 pubobjid   NUMBER  NULL 
)    
;
alter table rpauto 
    add  PRIMARY KEY(objid)
;
 
grant select on rpauto to ca_itrm_group;
grant update on rpauto to ca_itrm_group;
grant delete on rpauto to ca_itrm_group;
grant insert on rpauto to ca_itrm_group;
grant select on rpauto to ca_itrm_group_ams;
  


-- name=rpdatcat,
CREATE TABLE   rpdatcat  (
	 catname   NVARCHAR2  (127)   NOT NULL ,
	 locid   NVARCHAR2  (3)   NOT NULL ,
	 dispname   NVARCHAR2  (127)   NOT NULL ,
	 sources   NVARCHAR2  (256)   NULL ,
	 descript   NCLOB   NULL ,
	 priority   NUMBER  NULL ,
	 status   NUMBER  NULL ,
	 type   NUMBER  NOT NULL ,
	 catdef   NCLOB   NULL 
)    
;
alter table rpdatcat 
    add  PRIMARY KEY(catname, locid)
;
 
grant select on rpdatcat to ca_itrm_group;
grant update on rpdatcat to ca_itrm_group;
grant delete on rpdatcat to ca_itrm_group;
grant insert on rpdatcat to ca_itrm_group;
grant select on rpdatcat to ca_itrm_group_ams;
  


-- name=rpdatfld,
CREATE TABLE   rpdatfld  (
	 srcid   NVARCHAR2  (64)   NOT NULL ,
	 locid   NVARCHAR2  (3)   NOT NULL ,
	 fldname   NVARCHAR2  (127)   NOT NULL ,
	 tblname   NVARCHAR2  (64)   NULL ,
	 colname   NVARCHAR2  (64)   NULL ,
	 dispname   NVARCHAR2  (127)   NOT NULL ,
	 status   NUMBER  NULL ,
	 tpltype   NUMBER  NULL ,
	 fldtype   NUMBER  NULL ,
	 datatype   NUMBER  NULL ,
	 formtype   NUMBER  NULL ,
	 flddef   NCLOB   NULL 
)    
;
alter table rpdatfld 
    add  PRIMARY KEY(fldname, locid, srcid)
;
 
grant select on rpdatfld to ca_itrm_group;
grant update on rpdatfld to ca_itrm_group;
grant delete on rpdatfld to ca_itrm_group;
grant insert on rpdatfld to ca_itrm_group;
grant select on rpdatfld to ca_itrm_group_ams;
 


-- name=rpdatqry,
CREATE TABLE   rpdatqry  (
	 srcid   NVARCHAR2  (64)   NOT NULL ,
	 locid   NVARCHAR2  (3)   NOT NULL ,
	 qryname   NVARCHAR2  (127)   NOT NULL ,
	 qryid   NUMBER  NOT NULL ,
	 dispname   NVARCHAR2  (127)   NOT NULL ,
	 descript   NCLOB   NULL ,
	 qrysql   NCLOB   NULL ,
	 qrydef   NCLOB   NULL 
)    
;
alter table rpdatqry 
    add  PRIMARY KEY(locid, qryname, srcid)
;
 
grant select on rpdatqry to ca_itrm_group;
grant update on rpdatqry to ca_itrm_group;
grant delete on rpdatqry to ca_itrm_group;
grant insert on rpdatqry to ca_itrm_group;
grant select on rpdatqry to ca_itrm_group_ams;
  


-- name=rpdatsrc,
CREATE TABLE   rpdatsrc  (
	 srcid   NVARCHAR2  (64)   NOT NULL ,
	 locid   NVARCHAR2  (3)   NOT NULL ,
	 dispname   NVARCHAR2  (127)   NOT NULL ,
	 descript   NCLOB   NULL ,
	 type   NUMBER  NULL ,
	 status   NUMBER  NULL ,
	 server   NVARCHAR2  (64)   NULL ,
	 dbname   NVARCHAR2  (64)   NULL ,
	 dsn   NVARCHAR2  (64)   NULL ,
	 srcdef   NCLOB   NULL ,
	 linkdef   NCLOB   NULL 
)    
;
alter table rpdatsrc 
    add  PRIMARY KEY(locid, srcid)
;
 
grant select on rpdatsrc to ca_itrm_group;
grant update on rpdatsrc to ca_itrm_group;
grant delete on rpdatsrc to ca_itrm_group;
grant insert on rpdatsrc to ca_itrm_group;
grant select on rpdatsrc to ca_itrm_group_ams;
  

-- name=rpdattyp,
CREATE TABLE   rpdattyp  (
	 srcid   NVARCHAR2  (64)   NOT NULL ,
	 locid   NVARCHAR2  (3)   NOT NULL ,
	 typname   NVARCHAR2  (127)   NOT NULL ,
	 tpltype   NUMBER  NOT NULL ,
	 dispname   NVARCHAR2  (127)   NOT NULL ,
	 initflds   NCLOB   NULL ,
	 descript   NCLOB   NULL ,
	 typdef   NCLOB   NULL 
)    
;
alter table rpdattyp 
    add  PRIMARY KEY(locid, srcid, typname)
;
 
grant select on rpdattyp to ca_itrm_group;
grant update on rpdattyp to ca_itrm_group;
grant delete on rpdattyp to ca_itrm_group;
grant insert on rpdattyp to ca_itrm_group;
grant select on rpdattyp to ca_itrm_group_ams;
  


-- name=rpfield,
CREATE TABLE   rpfield  (
	 objid   NUMBER  NOT NULL ,
	 fieldid   NUMBER  NULL ,
	 fldindex   NUMBER  NOT NULL ,
	 status   NUMBER  NULL ,
	 tpltype   NUMBER  NULL ,
	 fldtype   NUMBER  NULL ,
	 fielddef   NCLOB   NULL 
)    
;
alter table rpfield 
    add  PRIMARY KEY(fldindex, objid)
;
 
grant select on rpfield to ca_itrm_group;
grant update on rpfield to ca_itrm_group;
grant delete on rpfield to ca_itrm_group;
grant insert on rpfield to ca_itrm_group;
grant select on rpfield to ca_itrm_group_ams;
   


-- name=rpfilter,
CREATE TABLE   rpfilter  (
	 tplid   NUMBER  NOT NULL ,
	 resid   NUMBER  NOT NULL ,
	 argid   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (127)   NULL ,
	 type   NUMBER  NULL ,
	 argspec   NCLOB   NULL 
)    
;
alter table rpfilter 
    add  PRIMARY KEY(argid, resid, tplid)
;
 
grant select on rpfilter to ca_itrm_group;
grant update on rpfilter to ca_itrm_group;
grant delete on rpfilter to ca_itrm_group;
grant insert on rpfilter to ca_itrm_group;
grant select on rpfilter to ca_itrm_group_ams;
    


-- name=rpglobal,
CREATE TABLE   rpglobal  (
	 keyname   NVARCHAR2  (64)   NOT NULL ,
	 subname   NVARCHAR2  (64)   NOT NULL ,
	 value   NCLOB   NULL 
)    
;
alter table rpglobal 
    add  PRIMARY KEY(keyname, subname)
;
 
grant select on rpglobal to ca_itrm_group;
grant update on rpglobal to ca_itrm_group;
grant delete on rpglobal to ca_itrm_group;
grant insert on rpglobal to ca_itrm_group;
grant select on rpglobal to ca_itrm_group_ams;
 


-- name=rpipc,
CREATE TABLE   rpipc  (
	 ipcid   NUMBER  NOT NULL ,
	 sid   NUMBER  NULL ,
	 objid   NUMBER  NULL ,
	 notify   NUMBER  NULL ,
	 lparam1   NUMBER  NULL ,
	 lparam2   NUMBER  NULL 
)    
;
alter table rpipc 
    add  PRIMARY KEY(ipcid)
;
  
grant select on rpipc to ca_itrm_group;
grant update on rpipc to ca_itrm_group;
grant delete on rpipc to ca_itrm_group;
grant insert on rpipc to ca_itrm_group;
grant select on rpipc to ca_itrm_group_ams;
 


-- name=rppub,
CREATE TABLE   rppub  (
	 objid   NUMBER  NOT NULL ,
	 genset   NCLOB   NULL ,
	 expset   NCLOB   NULL ,
	 saveset   NCLOB   NULL ,
	 expspec   NCLOB   NULL 
)    
;
alter table rppub 
    add  PRIMARY KEY(objid)
;
 
grant select on rppub to ca_itrm_group;
grant update on rppub to ca_itrm_group;
grant delete on rppub to ca_itrm_group;
grant insert on rppub to ca_itrm_group;
grant select on rppub to ca_itrm_group_ams;
 


-- name=rpresult,
CREATE TABLE   rpresult  (
	 tplid   NUMBER  NOT NULL ,
	 tplsubid   NUMBER  NOT NULL ,
	 resid   NUMBER  NOT NULL ,
	 tblname   NVARCHAR2  (64)   NULL ,
	 dispname   NVARCHAR2  (64)   NULL ,
	 filter   NUMBER  NULL ,
	 status   NUMBER  NULL ,
	 resspec   NCLOB   NULL ,
	 created   NUMBER  NULL ,
	 createby   NVARCHAR2  (64)   NULL 
)    
;
alter table rpresult 
    add  PRIMARY KEY(resid, tplid, tplsubid)
;
 
grant select on rpresult to ca_itrm_group;
grant update on rpresult to ca_itrm_group;
grant delete on rpresult to ca_itrm_group;
grant insert on rpresult to ca_itrm_group;
grant select on rpresult to ca_itrm_group_ams;
  


-- name=rpstats,
CREATE TABLE   rpstats  (
	 tplid   NUMBER  NOT NULL ,
	 runcount   NUMBER  NULL ,
	 runtoday   NUMBER  NULL ,
	 lastrun   NUMBER  NULL ,
	 lasttime   NUMBER  NULL ,
	 lastuser   NVARCHAR2  (64)   NULL ,
	 avtime   NUMBER  NULL 
)    
;
alter table rpstats 
    add  PRIMARY KEY(tplid)
;
  
grant select on rpstats to ca_itrm_group;
grant update on rpstats to ca_itrm_group;
grant delete on rpstats to ca_itrm_group;
grant insert on rpstats to ca_itrm_group;
grant select on rpstats to ca_itrm_group_ams;

   

-- name=rptables,
CREATE TABLE   rptables  (
	 tblname   NVARCHAR2  (64)   NOT NULL ,
	 type   NUMBER  NULL ,
	 tplid   NUMBER  NULL ,
	 subid   NUMBER  NULL ,
	 created   NUMBER  NULL ,
	 createby   NVARCHAR2  (64)   NULL ,
	 status   NUMBER  NULL 
)    
;
alter table rptables 
    add  PRIMARY KEY(tblname)
;
  
grant select on rptables to ca_itrm_group;
grant update on rptables to ca_itrm_group;
grant delete on rptables to ca_itrm_group;
grant insert on rptables to ca_itrm_group;
grant select on rptables to ca_itrm_group_ams;
 


-- name=rptpl,
CREATE TABLE   rptpl  (
	 objid   NUMBER  NOT NULL ,
	 objname   NVARCHAR2  (64)   NULL ,
	 descript   NCLOB   NULL ,
	 status   NUMBER  NULL ,
	 tpltype   NUMBER  NULL ,
	 tplspec   NCLOB   NULL 
)    
;
alter table rptpl 
    add  PRIMARY KEY(objid)
;
 
grant select on rptpl to ca_itrm_group;
grant update on rptpl to ca_itrm_group;
grant delete on rptpl to ca_itrm_group;
grant insert on rptpl to ca_itrm_group;
grant select on rptpl to ca_itrm_group_ams;
  


-- name=rptree,
CREATE TABLE   rptree  (
	 object_uuid   RAW(16) NOT NULL ,
	 root   NUMBER  NOT NULL ,
	 ownerid   NUMBER  NOT NULL ,
	 objid   NUMBER  NOT NULL ,
	 objname   NVARCHAR2  (64)   NULL ,
	 descript   NCLOB   NULL ,
	 status   NUMBER  NULL ,
	 creation_date   NUMBER  NULL ,
	 creation_user   NVARCHAR2  (64)   NULL ,
	 last_update_date   NUMBER  NULL ,
	 last_update_user   NVARCHAR2  (64)   NULL ,
	 type   NUMBER  NULL 
)    
;
alter table rptree 
    add  PRIMARY KEY(object_uuid)
;
 
grant select on rptree to ca_itrm_group;
grant update on rptree to ca_itrm_group;
grant delete on rptree to ca_itrm_group;
grant insert on rptree to ca_itrm_group;
grant select on rptree to ca_itrm_group_ams;
  


-- name=rpview,
CREATE TABLE   rpview  (
	 tplid   NUMBER  NOT NULL ,
	 viewid   NUMBER  NOT NULL ,
	 field1   NVARCHAR2  (127)   NULL ,
	 field2   NVARCHAR2  (127)   NULL ,
	 field3   NVARCHAR2  (127)   NULL ,
	 field4   NVARCHAR2  (127)   NULL ,
	 settings   NCLOB   NULL 
)    
;
alter table rpview 
    add  PRIMARY KEY(tplid, viewid)
;
 
grant select on rpview to ca_itrm_group;
grant update on rpview to ca_itrm_group;
grant delete on rpview to ca_itrm_group;
grant insert on rpview to ca_itrm_group;
grant select on rpview to ca_itrm_group_ams;
  


-- name=signature_os_group,
--CREATE TABLE   signature_os_group  (
--	 signature_os_group_id   RAW(16) NOT NULL ,
--	 name   NVARCHAR2  (20)   NOT NULL ,
--	 creation_user   NVARCHAR2  (64)   NOT NULL ,
--	 creation_date   NUMBER  NOT NULL 
--)    
--/
--alter table signature_os_group 
--    add  PRIMARY KEY(signature_os_group_id)
--/

grant select on signature_os_group to ca_itrm_group;
grant update on signature_os_group to ca_itrm_group;
grant delete on signature_os_group to ca_itrm_group;
grant insert on signature_os_group to ca_itrm_group;
grant select on signature_os_group to ca_itrm_group_ams;



-- name=snapmain,
CREATE TABLE   snapmain  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 snapmain   VARCHAR2 (80)   NOT NULL ,
	 snappart   NUMBER  NOT NULL ,
	 snapmemo   NCLOB   NULL 
)    
;
alter table snapmain 
    add  PRIMARY KEY(object_uuid, snapmain, snappart)
;
 
grant select on snapmain to ca_itrm_group;
grant update on snapmain to ca_itrm_group;
grant delete on snapmain to ca_itrm_group;
grant insert on snapmain to ca_itrm_group;
grant select on snapmain to ca_itrm_group_ams;
 



-- name=snapmemo,
CREATE TABLE   snapmemo  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 snappart   NUMBER  NOT NULL ,
	 snapmemo   NCLOB   NULL 
)    
;
alter table snapmemo 
    add  PRIMARY KEY(object_uuid, snappart)
;
 
grant select on snapmemo to ca_itrm_group;
grant update on snapmemo to ca_itrm_group;
grant delete on snapmemo to ca_itrm_group;
grant insert on snapmemo to ca_itrm_group;
grant select on snapmemo to ca_itrm_group_ams;


  

-- name=statjob,
CREATE TABLE   statjob  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 jdomid   NUMBER  NOT NULL ,
	 jobid   NUMBER  NOT NULL ,
	 status   NUMBER  NULL ,
	 stcount   NUMBER  NULL ,
	 stqcount   NUMBER  NULL ,
	 stdate   NUMBER  NULL ,
	 stelapse   NUMBER  NULL ,
	 sttext   NVARCHAR2  (127)   NULL ,
	 strev   NUMBER  NULL ,
	 stflag   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table statjob 
    add  PRIMARY KEY(jdomid, jobid, object_uuid)
;
  
grant select on statjob to ca_itrm_group;
grant update on statjob to ca_itrm_group;
grant delete on statjob to ca_itrm_group;
grant insert on statjob to ca_itrm_group;
grant select on statjob to ca_itrm_group_ams;
 


-- name=statjobm,
CREATE TABLE   statjobm  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 jdomid   NUMBER  NOT NULL ,
	 jobid   NUMBER  NOT NULL ,
	 statpart   NUMBER  NOT NULL ,
	 stattext   NCLOB   NULL 
)    
;
alter table statjobm 
    add  PRIMARY KEY(jdomid, jobid, object_uuid, statpart)
;
 
grant select on statjobm to ca_itrm_group;
grant update on statjobm to ca_itrm_group;
grant delete on statjobm to ca_itrm_group;
grant insert on statjobm to ca_itrm_group;
grant select on statjobm to ca_itrm_group_ams;
  


-- name=statmod,
CREATE TABLE   statmod  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 mdomid   NUMBER  NOT NULL ,
	 moid   NUMBER  NOT NULL ,
	 status   NUMBER  NULL ,
	 stcount   NUMBER  NULL ,
	 stqcount   NUMBER  NULL ,
	 stdate   NUMBER  NULL ,
	 stelapse   NUMBER  NULL ,
	 sttext   NVARCHAR2  (127)   NULL ,
	 strev   NUMBER  NULL ,
	 stflag   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table statmod 
    add  PRIMARY KEY(mdomid, moid, object_uuid)
;
  
grant select on statmod to ca_itrm_group;
grant update on statmod to ca_itrm_group;
grant delete on statmod to ca_itrm_group;
grant insert on statmod to ca_itrm_group;
grant select on statmod to ca_itrm_group_ams;
  


-- name=statmodm,
CREATE TABLE   statmodm  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_type   NUMBER  NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 mdomid   NUMBER  NOT NULL ,
	 moid   NUMBER  NOT NULL ,
	 statpart   NUMBER  NOT NULL ,
	 stattext   NCLOB   NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table statmodm 
    add  PRIMARY KEY(mdomid, moid, object_uuid, statpart)
;
   
grant select on statmodm to ca_itrm_group;
grant update on statmodm to ca_itrm_group;
grant delete on statmodm to ca_itrm_group;
grant insert on statmodm to ca_itrm_group;
grant select on statmodm to ca_itrm_group_ams;
  





-- name=tng_adminstatus,
CREATE TABLE   tng_adminstatus  (
	 admin_status   NUMBER   NOT NULL ,    -- IDENTITY (1, 1)
	 admin_text   VARCHAR2 (255)   NOT NULL 
)    
;
alter table tng_adminstatus 
    add  PRIMARY KEY(admin_status)
;
  
grant select on tng_adminstatus to ca_itrm_group;
grant update on tng_adminstatus to ca_itrm_group;
grant delete on tng_adminstatus to ca_itrm_group;
grant insert on tng_adminstatus to ca_itrm_group;
grant select on tng_adminstatus to ca_itrm_group_ams;
  



-- name=tng_class_ext,
CREATE TABLE   tng_class_ext  (
	 class_id   NUMBER  NOT NULL ,
	 name   VARCHAR2 (30)   NOT NULL ,
	 datatype   VARCHAR2 (20)   NOT NULL ,
	 length   NUMBER  NOT NULL ,
	 property_group   VARCHAR2 (10)   NULL ,
	 string   VARCHAR2 (255)   NULL 
)    
;
alter table tng_class_ext 
    add  PRIMARY KEY(class_id, name)
;
  
grant select on tng_class_ext to ca_itrm_group;
grant update on tng_class_ext to ca_itrm_group;
grant delete on tng_class_ext to ca_itrm_group;
grant insert on tng_class_ext to ca_itrm_group;
grant select on tng_class_ext to ca_itrm_group_ams;

   

-- name=tng_interface_type,
CREATE TABLE   tng_interface_type  (
	 interface_type   NUMBER  NOT NULL ,
	 description   VARCHAR2 (35)   NULL 
)    
;

  
grant select on tng_interface_type to ca_itrm_group;
grant update on tng_interface_type to ca_itrm_group;
grant delete on tng_interface_type to ca_itrm_group;
grant insert on tng_interface_type to ca_itrm_group;
grant select on tng_interface_type to ca_itrm_group_ams;
  



-- name=tng_managedobject,
CREATE TABLE   tng_managedobject  (
	 uuid   RAW(16) NOT NULL ,
	 name   VARCHAR2 (200)   NOT NULL ,
	 label   VARCHAR2 (255)   NULL ,
	 address   VARCHAR2 (255)   NULL ,
	 address_type   NUMBER  NULL ,
	 class_name   VARCHAR2 (30)   NOT NULL ,
	 interface_type   NUMBER  NULL ,
	 autoarrange_type   NUMBER  NULL ,
	 hidden   SMALLINT  NULL ,
	 propagate_status   SMALLINT  NULL ,
	 status_no   NUMBER  NULL ,
	 severity   NUMBER  NULL ,
	 tng_delete_flag   NUMBER  NULL ,
	 posted   SMALLINT  NULL ,
	 acknowledge   SMALLINT  NULL ,
	 ip_address_hex   RAW  (4) NULL ,
	 mac_address   VARCHAR2 (12)   NULL ,
	 subnet_mask   RAW  (4) NULL ,
	 date_ins   DATE  NULL ,
	 date_modify   DATE  NULL ,
	 alarmset_name   VARCHAR2 (40)   NULL ,
	 code_page   NUMBER  NULL ,
	 admin_status   NUMBER  NULL ,
	 dsm_server   VARCHAR2 (60)   NULL ,
	 propagated_status_no   NUMBER  NULL ,
	 propagated_sev   NUMBER  NULL ,
	 dsm_address   VARCHAR2 (16)   NULL ,
	 license_machine_type   VARCHAR2 (64)   NULL ,
	 create_bpv   SMALLINT  NULL ,
	 override_imagelarge   VARCHAR2 (64)   NULL ,
	 override_imagesmall   VARCHAR2 (64)   NULL ,
	 override_imagedecal   VARCHAR2 (64)   NULL ,
	 override_imagetintbool   SMALLINT  NULL ,
	 override_model   VARCHAR2 (64)   NULL ,
	 background_image   VARCHAR2 (64)   NULL ,
	 weight   NUMBER  NULL ,
	 reserved   VARCHAR2 (32)   NULL ,
	 weighted_severity   NUMBER  NULL ,
	 max_sev   NUMBER  NULL ,
	 user_reclass   NUMBER  NULL ,
	 asset_uuid   RAW(16) NULL ,
	 source_repository   VARCHAR2 (60)   NULL ,
	 dnsname   VARCHAR2 (255)   NULL ,
	 last_seen_time   DATE  NULL ,
	 amsserver   VARCHAR2 (60)   NULL ,
	 emserver   VARCHAR2 (60)   NULL 
)    
;

  
grant select on tng_managedobject to ca_itrm_group;
grant update on tng_managedobject to ca_itrm_group;
grant delete on tng_managedobject to ca_itrm_group;
grant insert on tng_managedobject to ca_itrm_group;
grant select on tng_managedobject to ca_itrm_group_ams;


-- name=tng_status,
CREATE TABLE   tng_status  (
	 status_text   VARCHAR2 (255)   NOT NULL ,
	 status_no   NUMBER   NOT NULL     -- IDENTITY (0, 1) 
)    
;
alter table tng_status 
    add  PRIMARY KEY(status_text)
;
  
grant select on tng_status to ca_itrm_group;
grant update on tng_status to ca_itrm_group;
grant delete on tng_status to ca_itrm_group;
grant insert on tng_status to ca_itrm_group;
grant select on tng_status to ca_itrm_group_ams;
 



-- name=tplmemo,
CREATE TABLE   tplmemo  (
	 domainid   NUMBER  NOT NULL ,
	 tpid   NUMBER  NOT NULL ,
	 tpver   NUMBER  NOT NULL ,
	 tpcont   NCLOB   NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table tplmemo 
    add  PRIMARY KEY(domainid, tpid, tpver)
;
 
grant select on tplmemo to ca_itrm_group;
grant update on tplmemo to ca_itrm_group;
grant delete on tplmemo to ca_itrm_group;
grant insert on tplmemo to ca_itrm_group;
grant select on tplmemo to ca_itrm_group_ams;
 


-- name=unitsec,
CREATE TABLE   unitsec  (
	 object_uuid   RAW(16) NOT NULL ,
	 object_domain_uuid   RAW(16) NULL ,
	 object_type   NUMBER  NULL ,
	 link_uuid   RAW(16) NOT NULL ,
	 link_domain_uuid   RAW(16) NULL ,
	 link_type   NUMBER  NULL ,
	 type   NUMBER  NOT NULL ,
	 typex   NUMBER  NOT NULL ,
	 rflag   NUMBER  NULL 
)    
;
alter table unitsec 
    add  PRIMARY KEY(link_uuid, object_uuid, type, typex)
;
  
grant select on unitsec to ca_itrm_group;
grant update on unitsec to ca_itrm_group;
grant delete on unitsec to ca_itrm_group;
grant insert on unitsec to ca_itrm_group;
grant select on unitsec to ca_itrm_group_ams;
  


-- name=unittype,
CREATE TABLE   unittype  (
	 domainid   NUMBER  NOT NULL ,
	 unittype   NUMBER  NOT NULL ,
	 unitname   NVARCHAR2  (127)   NULL ,
	 unitconf   NCLOB   NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table unittype 
    add  PRIMARY KEY(domainid, unittype)
;
 
grant select on unittype to ca_itrm_group;
grant update on unittype to ca_itrm_group;
grant delete on unittype to ca_itrm_group;
grant insert on unittype to ca_itrm_group;
grant select on unittype to ca_itrm_group_ams;
 



-- name=urc_ab_computer,
CREATE TABLE   urc_ab_computer  (
	 "UID"   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 host_name   NVARCHAR2  (255)   NOT NULL ,
	 host_uuid   char  (36)   NULL ,
	 connection_information   RAW  (510) NOT NULL ,
	 auto_rep_version   DATE  NULL ,
	 securityproviders   RAW  (2) NULL ,
	 label   NVARCHAR2  (255)  NULL 
)    
;
alter table urc_ab_computer 
    add  PRIMARY KEY(domain_uuid, "UID")
;
  
grant select on urc_ab_computer to ca_itrm_group;
grant update on urc_ab_computer to ca_itrm_group;
grant delete on urc_ab_computer to ca_itrm_group;
grant insert on urc_ab_computer to ca_itrm_group;
grant select on urc_ab_computer to ca_itrm_group_ams;
  

-- name=urc_ab_group_def,
CREATE TABLE   urc_ab_group_def  (
	 "UID"   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 label   NVARCHAR2  (255)  NULL ,
	 description   NVARCHAR2  (255)   NULL ,
	 sub_root_item   RAW  (1) NOT NULL ,
	 inheritance   RAW  (1) NOT NULL ,
	 update_children   RAW  (1) NOT NULL ,
	 update_viewer_version   NUMBER  NULL ,
	 auto_rep_version   DATE  NULL 
)    
;
alter table urc_ab_group_def 
    add  PRIMARY KEY("UID")
;
  
grant select on urc_ab_group_def to ca_itrm_group;
grant update on urc_ab_group_def to ca_itrm_group;
grant delete on urc_ab_group_def to ca_itrm_group;
grant insert on urc_ab_group_def to ca_itrm_group;
grant select on urc_ab_group_def to ca_itrm_group_ams;
  

-- name=urc_ab_group_member,
CREATE TABLE   urc_ab_group_member  (
	 member_uuid   RAW(16) NOT NULL ,
	 group_uuid   RAW(16) NOT NULL ,
	 group_domain_uuid   RAW(16) NOT NULL ,
	 member_domain_uuid   RAW(16) NOT NULL ,
	 auto_rep_version   DATE  NULL ,
	 member_type   NUMBER  NULL 
)    
;
alter table urc_ab_group_member 
    add  PRIMARY KEY(group_uuid, member_uuid)
;
  
grant select on urc_ab_group_member to ca_itrm_group;
grant update on urc_ab_group_member to ca_itrm_group;
grant delete on urc_ab_group_member to ca_itrm_group;
grant insert on urc_ab_group_member to ca_itrm_group;
grant select on urc_ab_group_member to ca_itrm_group_ams;
  


-- name=urc_ab_permission,
CREATE TABLE   urc_ab_permission  (
	 "UID"   RAW(16) NOT NULL ,
	 domain_uuid   RAW(16) NOT NULL ,
	 uidaddressbook   RAW(16) NOT NULL ,
	 strobjectidentifier   NVARCHAR2  (255)   NOT NULL ,
	 strpermissions   NVARCHAR2  (15)   NOT NULL ,
	 view_flag   RAW  (1) NOT NULL ,
	 is_deleted   RAW  (1) NOT NULL ,
	 original_uuid   RAW(16) NOT NULL ,
	 auto_rep_version   DATE  NULL ,
	 is_user   RAW  (1) NOT NULL ,
	 is_domain   RAW  (1) NOT NULL ,
	 user_rid   NVARCHAR2  (10)   NOT NULL 
)    
;
alter table urc_ab_permission 
    add  PRIMARY KEY("UID")
;
  
grant select on urc_ab_permission to ca_itrm_group;
grant update on urc_ab_permission to ca_itrm_group;
grant delete on urc_ab_permission to ca_itrm_group;
grant insert on urc_ab_permission to ca_itrm_group;
grant select on urc_ab_permission to ca_itrm_group_ams;
  

-- name=urc_active_session,
CREATE TABLE   urc_active_session  (
	 "UID"   RAW(16) NOT NULL ,
	 uidparent   RAW(16) NOT NULL ,
	 strhost   NVARCHAR2  (64)   NOT NULL ,
	 uidhost   RAW(16) NOT NULL ,
	 uidsession   RAW(16) NOT NULL ,
	 strviewer   NVARCHAR2  (64)   NOT NULL ,
	 datesessionstarted   NUMBER  NOT NULL ,
	 iduration   NUMBER  NOT NULL ,
	 strremoteuser   NVARCHAR2  (255)   NOT NULL ,
	 strstatus   NVARCHAR2  (64)   NOT NULL ,
	 strdescription   NVARCHAR2  (255)   NOT NULL ,
	 iseverity   NUMBER  NOT NULL ,
	 iencryption   NUMBER  NOT NULL ,
	 strprotocol   NVARCHAR2  (32)   NOT NULL ,
	 icategory   NUMBER  NOT NULL ,
	 ieventid   NUMBER  NOT NULL ,
	 ireasonsessionwasclosed   NUMBER  NOT NULL ,
	 ifailsafe     NUMBER  NOT NULL, 
	 host_uuid     CHAR(26)        NULL
)    
;
alter table urc_active_session 
    add  PRIMARY KEY("UID")
;
  
grant select on urc_active_session to ca_itrm_group;
grant update on urc_active_session to ca_itrm_group;
grant delete on urc_active_session to ca_itrm_group;
grant insert on urc_active_session to ca_itrm_group;
grant select on urc_active_session to ca_itrm_group_ams;
 


-- name=urc_computer,
CREATE TABLE   urc_computer  (
	 "UID"   RAW(16) NOT NULL ,
	 streamaddress   RAW  (510) NOT NULL ,
	 strcamaddress   NVARCHAR2  (64)   NOT NULL ,
	 uidconfigpolicy   RAW(16) NOT NULL ,
	 iinheritconfiguration   NUMBER  NOT NULL ,
	 datelastaccess   NUMBER  NOT NULL ,
	 istatus   NUMBER  NOT NULL ,
	 uidlastparent   RAW(16) NOT NULL ,
	 datelastevent   NUMBER  NOT NULL ,
	 dateconfigpolicy   NUMBER  NOT NULL ,
	 strversion   NVARCHAR2  (64)   NOT NULL 
)    
;
alter table urc_computer 
    add  PRIMARY KEY("UID")
;
  
grant select on urc_computer to ca_itrm_group;
grant update on urc_computer to ca_itrm_group;
grant delete on urc_computer to ca_itrm_group;
grant insert on urc_computer to ca_itrm_group;
grant select on urc_computer to ca_itrm_group_ams;
 

-- name=urc_local_server,
CREATE TABLE   urc_local_server  (
	 "UID"   RAW(16) NOT NULL ,
	 uidparent   RAW(16) NOT NULL ,
	 strname   NVARCHAR2  (64)   NOT NULL ,
	 strpath   NVARCHAR2  (255)   NOT NULL ,
	 straddress   NVARCHAR2  (255)   NOT NULL ,
	 iisroot   NUMBER  NOT NULL ,
	 uidconfigpolicy   RAW(16) NOT NULL ,
	 strdescription   NVARCHAR2  (255)   NOT NULL ,
	 dateconfigpolicy   NUMBER  NOT NULL ,
	 iinheritconfiguration   NUMBER  NOT NULL ,
	 ipropagatechanges   NUMBER  NOT NULL ,
	 ageofeventstopurge   NUMBER  NOT NULL ,
	 datetopurgeevents   NUMBER  NOT NULL ,
	 ageofsessionstopurge   NUMBER  NOT NULL ,
	 datetopurgesessions   NUMBER  NOT NULL ,
	 nexteventpurge   NUMBER  NOT NULL ,
	 nextsessionpurge   NUMBER  NOT NULL ,
	 periodtopurgeevents   NUMBER  NOT NULL ,
	 periodtopurgesessions   NUMBER  NOT NULL 
)    
;
alter table urc_local_server 
    add  PRIMARY KEY("UID")
;
  
grant select on urc_local_server to ca_itrm_group;
grant update on urc_local_server to ca_itrm_group;
grant delete on urc_local_server to ca_itrm_group;
grant insert on urc_local_server to ca_itrm_group;
grant select on urc_local_server to ca_itrm_group_ams;
  


-- name=urc_schema_version,
CREATE TABLE   urc_schema_version  (
	 "UID"   RAW(16) NOT NULL ,
	 uidparent   RAW(16) NOT NULL ,
	 iversion   NUMBER  NOT NULL 
)    
;
alter table urc_schema_version 
    add  PRIMARY KEY("UID")
;
  
grant select on urc_schema_version to ca_itrm_group;
grant update on urc_schema_version to ca_itrm_group;
grant delete on urc_schema_version to ca_itrm_group;
grant insert on urc_schema_version to ca_itrm_group;
grant select on urc_schema_version to ca_itrm_group_ams;
  

-- name=usd_activity,
CREATE TABLE   usd_activity  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 ordernumb   NUMBER  NOT NULL ,
	 actproc   RAW(16) NULL ,
	 instproc   RAW(16) NULL ,
	 state   NUMBER  NOT NULL ,
	 startflag   NUMBER  NOT NULL ,
	 activationtime   NUMBER  NOT NULL ,
	 creationtime   NUMBER  NOT NULL ,
	 giveuptime   NUMBER  NOT NULL ,
	 compfold   RAW(16) NULL ,
	 execmode   NUMBER  NOT NULL ,
	 jobname   NVARCHAR2  (255)  NOT NULL ,
	 promptmsg   NVARCHAR2  (255)   NOT NULL ,
	 promptto   NUMBER  NOT NULL ,
	 userparams   NVARCHAR2  (255)   NOT NULL ,
	 jobbanner   NVARCHAR2  (65)   NOT NULL ,
	 okcnt   NUMBER  NOT NULL ,
	 activecnt   NUMBER  NOT NULL ,
	 errorcnt   NUMBER  NOT NULL ,
	 mask   NUMBER  NOT NULL ,
	 opmask   NUMBER  NOT NULL ,
	 bootbefore   NUMBER  NOT NULL ,
	 bootafter   NUMBER  NOT NULL ,
	 targetmask   NUMBER  NOT NULL ,
	 dtsstate   NUMBER  NOT NULL ,
	 deliverytime   NUMBER  NOT NULL ,
	 cause   NUMBER  NOT NULL ,
	 renewstate   NUMBER  NOT NULL ,
	 waitingcnt   NUMBER  NOT NULL ,
	 waitingrenewcnt   NUMBER  NOT NULL ,
	 activerenewcnt   NUMBER  NOT NULL ,
	 okrenewcnt   NUMBER  NOT NULL ,
	 errorrenewcnt   NUMBER  NOT NULL ,
	 permmask   NUMBER  NOT NULL ,
	 calendar   NVARCHAR2  (33)   NULL ,
	 errorcause   NVARCHAR2  (255)   NULL 
)    
;
alter table usd_activity 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_activity to ca_itrm_group;
grant update on usd_activity to ca_itrm_group;
grant delete on usd_activity to ca_itrm_group;
grant insert on usd_activity to ca_itrm_group;
grant select on usd_activity to ca_itrm_group_ams;
 



-- name=usd_actproc,
CREATE TABLE   usd_actproc  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 itemname   NVARCHAR2  (129)  NOT NULL ,
	 itemversion   NVARCHAR2  (129)   NOT NULL ,
	 apesos   NUMBER  NOT NULL ,
	 subpathentered   NVARCHAR2  (255)   NOT NULL ,
	 filedby   NUMBER  NOT NULL ,
	 activatedby   NUMBER  NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 creationdate   NUMBER  NOT NULL ,
	 creationtime   NUMBER  NOT NULL ,
	 changedate   NUMBER  NOT NULL ,
	 changetime   NUMBER  NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 task   NUMBER  NOT NULL ,
	 subpath   NVARCHAR2  (255)   NOT NULL ,
	 proctorun   NVARCHAR2  (255)   NOT NULL ,
	 includedproc   NUMBER  NOT NULL ,
	 rsw   RAW(16) NOT NULL ,
	 volume   RAW(16) NULL ,
	 bootflags   NUMBER  NOT NULL ,
	 mask   NUMBER  NOT NULL ,
	 opmask   NUMBER  NOT NULL ,
	 bootbefore   NUMBER  NOT NULL ,
	 bootafter   NUMBER  NOT NULL ,
	 mgmtmask   NUMBER  NOT NULL ,
	 procparameter   NCLOB   NULL ,
	 query   RAW(16) NOT NULL 
)    
;
alter table usd_actproc 
    add  PRIMARY KEY(objectid)
;
 
grant select on usd_actproc to ca_itrm_group;
grant update on usd_actproc to ca_itrm_group;
grant delete on usd_actproc to ca_itrm_group;
grant insert on usd_actproc to ca_itrm_group;
grant select on usd_actproc to ca_itrm_group_ams;
  


-- name=usd_apdep,
CREATE TABLE   usd_apdep  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 rswname   NVARCHAR2  (129)   NOT NULL ,
	 rswversion   NVARCHAR2  (129)   NOT NULL ,
	 apname   NVARCHAR2  (129)   NOT NULL ,
	 apversion   NVARCHAR2  (129)   NOT NULL ,
	 filedby   NUMBER  NOT NULL ,
	 ap   RAW(16) NULL ,
	 depap   RAW(16) NULL ,
	 ordernumber   NUMBER  NOT NULL 
)    
;
alter table usd_apdep 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_apdep to ca_itrm_group;
grant update on usd_apdep to ca_itrm_group;
grant delete on usd_apdep to ca_itrm_group;
grant insert on usd_apdep to ca_itrm_group;
grant select on usd_apdep to ca_itrm_group_ams;
  



-- name=usd_applic,
CREATE TABLE   usd_applic  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 target   RAW(16) NOT NULL ,
	 actproc   RAW(16) NOT NULL ,
	 activity   RAW(16) NULL ,
	 installation   RAW(16) NULL ,
	 status   NUMBER  NOT NULL ,
	 errorcause   NUMBER  NOT NULL ,
	 errorparam   NVARCHAR2  (255)   NOT NULL ,
	 creationtime   NUMBER  NOT NULL ,
	 activationtime   NUMBER  NOT NULL ,
	 completiontime   NUMBER  NOT NULL ,
	 administrator   NVARCHAR2  (129)  NOT NULL ,
	 applicationid   NVARCHAR2  (129)   NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 task   RAW  (4) NOT NULL ,
	 percentsent   NUMBER  NOT NULL ,
	 retentiontime   NUMBER  NOT NULL ,
	 renewstatus   NUMBER  NOT NULL ,
	 firstrenew   RAW(16) NULL ,
	 nextrenew   RAW(16) NULL ,
	 applicationgroup   RAW(16) NULL ,
	 userparams   NVARCHAR2  (255)   NOT NULL ,
	 uuid   NVARCHAR2  (37)   NOT NULL ,
	 racassoc   RAW(16) NULL ,
	 uninstallstate   NUMBER  NOT NULL ,
	 permmask   NUMBER  NOT NULL ,
	 starttime   NUMBER  NOT NULL ,
	 uuid2   NVARCHAR2  (37)   NOT NULL 
)    
;
alter table usd_applic 
    add  PRIMARY KEY(objectid)
;

grant select on usd_applic to ca_itrm_group;
grant update on usd_applic to ca_itrm_group;
grant delete on usd_applic to ca_itrm_group;
grant insert on usd_applic to ca_itrm_group;
grant select on usd_applic to ca_itrm_group_ams;
  


-- name=usd_carrier,
CREATE TABLE   usd_carrier  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 boundto   RAW(16) NULL ,
	 status   NUMBER  NOT NULL ,
	 transferid   NVARCHAR2  (33)   NOT NULL ,
	 transferdir   NVARCHAR2  (255)   NOT NULL ,
	 destination   NVARCHAR2  (255)   NOT NULL ,
	 transfertime   NUMBER  NOT NULL ,
	 containername   NVARCHAR2  (255)   NOT NULL 
)    
;
alter table usd_carrier 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_carrier to ca_itrm_group;
grant update on usd_carrier to ca_itrm_group;
grant delete on usd_carrier to ca_itrm_group;
grant insert on usd_carrier to ca_itrm_group;
grant select on usd_carrier to ca_itrm_group_ams;
  


-- name=usd_cc,
CREATE TABLE   usd_cc  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 boundto   RAW(16) NULL ,
	 diststatus   NUMBER  NOT NULL ,
	 overalljobstatus   NUMBER  NOT NULL ,
	 numberofparameters   NUMBER  NOT NULL ,
	 failure   RAW  (129) NOT NULL ,
	 creationdate   NUMBER  NOT NULL ,
	 creationtime   NUMBER  NOT NULL ,
	 cont   RAW(16) NULL 
)    
;
alter table usd_cc 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_cc to ca_itrm_group;
grant update on usd_cc to ca_itrm_group;
grant delete on usd_cc to ca_itrm_group;
grant insert on usd_cc to ca_itrm_group;
grant select on usd_cc to ca_itrm_group_ams;
 

-- name=usd_class_version,
CREATE TABLE   usd_class_version  (
	 name   char  (32)   NOT NULL ,
	 bucket_number   NUMBER  NOT NULL ,
	 bucket_count   NUMBER  NOT NULL ,
	 insert_version   NUMBER  NOT NULL ,
	 modify_version   NUMBER  NOT NULL 
)    
;

  
grant select on usd_class_version to ca_itrm_group;
grant update on usd_class_version to ca_itrm_group;
grant delete on usd_class_version to ca_itrm_group;
grant insert on usd_class_version to ca_itrm_group;
grant select on usd_class_version to ca_itrm_group_ams;
  

-- name=usd_cmp_grp,
CREATE TABLE   usd_cmp_grp  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 qtask   RAW(16) NOT NULL ,
	 aux   RAW(16) NOT NULL ,
	 aux2   RAW(16) NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 attributes   RAW  (4) NOT NULL ,
	 name   NVARCHAR2  (129)   NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 credate   NUMBER  NOT NULL ,
	 cretime   NUMBER  NOT NULL ,
	 chdate   NUMBER  NOT NULL ,
	 chtime   NUMBER  NOT NULL ,
	 propflag   NUMBER  NOT NULL ,
	 qcalendar   NVARCHAR2  (129)   NOT NULL ,
	 qevalrate   NUMBER  NOT NULL ,
	 qnextevaldate   NUMBER  NOT NULL ,
	 qnextevaltime   NUMBER  NOT NULL ,
	 qevaldate   NUMBER  NOT NULL ,
	 qevaltime   NUMBER  NOT NULL ,
	 qtemplfold   RAW(16) NOT NULL ,
	 qtype   NUMBER  NOT NULL ,
	 state   NUMBER  NOT NULL ,
	 seal   NUMBER  NOT NULL ,
	 var   NUMBER  NOT NULL ,
	 auxtext0   NVARCHAR2  (128)   NULL ,
	 auxtext1   NVARCHAR2  (128)   NULL ,
	 auxtext2   NVARCHAR2  (128)   NULL ,
	 auxtext3   NVARCHAR2  (128)   NULL ,
	 queryid   RAW(16) NULL 
)    
;
alter table usd_cmp_grp 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_cmp_grp to ca_itrm_group;
grant update on usd_cmp_grp to ca_itrm_group;
grant delete on usd_cmp_grp to ca_itrm_group;
grant insert on usd_cmp_grp to ca_itrm_group;
grant select on usd_cmp_grp to ca_itrm_group_ams;
  


-- name=usd_cont,
CREATE TABLE   usd_cont  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 name   NVARCHAR2  (129)   NOT NULL ,
	 overallstatus   NUMBER  NOT NULL ,
	 sendid   RAW(16) NOT NULL ,
	 containerpath   NVARCHAR2  (255)   NOT NULL ,
	 distlistpath   NVARCHAR2  (255)   NOT NULL ,
	 distlisttype   NUMBER  NOT NULL ,
	 distdate   NUMBER  NOT NULL ,
	 disttime   NUMBER  NOT NULL ,
	 credate   NUMBER  NOT NULL ,
	 cretime   NUMBER  NOT NULL ,
	 ahdinfo   NVARCHAR2  (128)   NOT NULL,
	 priority  NUMBER  default 5 NOT NULL
)    
;
alter table usd_cont 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_cont to ca_itrm_group;
grant update on usd_cont to ca_itrm_group;
grant delete on usd_cont to ca_itrm_group;
grant insert on usd_cont to ca_itrm_group;
grant select on usd_cont to ca_itrm_group_ams;
  


-- name=usd_contfold,
CREATE TABLE   usd_contfold  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 qtask   RAW(16) NOT NULL ,
	 aux   RAW(16) NOT NULL ,
	 aux2   RAW(16) NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 attributes   RAW  (4) NOT NULL ,
	 name   NVARCHAR2  (129)   NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 credate   NUMBER  NOT NULL ,
	 cretime   NUMBER  NOT NULL ,
	 chdate   NUMBER  NOT NULL ,
	 chtime   NUMBER  NOT NULL ,
	 propflag   NUMBER  NOT NULL ,
	 qcalendar   NVARCHAR2  (129)   NOT NULL ,
	 qevalrate   NUMBER  NOT NULL ,
	 qnextevaldate   NUMBER  NOT NULL ,
	 qnextevaltime   NUMBER  NOT NULL ,
	 qevaldate   NUMBER  NOT NULL ,
	 qevaltime   NUMBER  NOT NULL ,
	 qtemplfold   RAW(16) NOT NULL ,
	 qtype   NUMBER  NOT NULL ,
	 state   NUMBER  NOT NULL ,
	 seal   NUMBER  NOT NULL ,
	 var   NUMBER  NOT NULL ,
	 auxtext0   NVARCHAR2  (128)   NULL ,
	 auxtext1   NVARCHAR2  (128)   NULL ,
	 auxtext2   NVARCHAR2  (128)   NULL ,
	 auxtext3   NVARCHAR2  (128)   NULL ,
	 queryid   RAW(16) NULL 
)    
;
alter table usd_contfold 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_contfold to ca_itrm_group;
grant update on usd_contfold to ca_itrm_group;
grant delete on usd_contfold to ca_itrm_group;
grant insert on usd_contfold to ca_itrm_group;
grant select on usd_contfold to ca_itrm_group_ams;
  

-- name=usd_distap,
CREATE TABLE   usd_distap  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 distributiondate   NUMBER  NOT NULL ,
	 distributiontime   NUMBER  NOT NULL ,
	 ape   RAW(16) NULL ,
	 distsw   RAW(16) NULL 
)    
;
alter table usd_distap 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_distap to ca_itrm_group;
grant update on usd_distap to ca_itrm_group;
grant delete on usd_distap to ca_itrm_group;
grant insert on usd_distap to ca_itrm_group;
grant select on usd_distap to ca_itrm_group_ams;
  


-- name=usd_distsw,
CREATE TABLE   usd_distsw  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 distributiondate   NUMBER  NOT NULL ,
	 distributiontime   NUMBER  NOT NULL ,
	 numberofinstallations   NUMBER  NOT NULL ,
	 numberofinstsfound   NUMBER  NOT NULL ,
	 numberofinstslocally   NUMBER  NOT NULL ,
	 filedby   NUMBER  NOT NULL ,
	 rsw   RAW(16) NULL ,
	 localsite   RAW(16) NULL 
)    
;
alter table usd_distsw 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_distsw to ca_itrm_group;
grant update on usd_distsw to ca_itrm_group;
grant delete on usd_distsw to ca_itrm_group;
grant insert on usd_distsw to ca_itrm_group;
grant select on usd_distsw to ca_itrm_group_ams;
  

-- name=usd_disttempl,
CREATE TABLE   usd_disttempl  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 disttime   NUMBER  NOT NULL ,
	 number_of_violators   NUMBER  NOT NULL ,
	 number_of_members   NUMBER  NOT NULL ,
	 last_eval_time   NUMBER  NOT NULL ,
	 template   RAW(16) NOT NULL ,
	 domain   RAW(16) NOT NULL 
)    
;
alter table usd_disttempl 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_disttempl to ca_itrm_group;
grant update on usd_disttempl to ca_itrm_group;
grant delete on usd_disttempl to ca_itrm_group;
grant insert on usd_disttempl to ca_itrm_group;
grant select on usd_disttempl to ca_itrm_group_ams;
  

-- name=usd_fio,
CREATE TABLE   usd_fio  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 finame   NVARCHAR2  (255)   NOT NULL ,
	 fienviron   NVARCHAR2  (255)   NOT NULL ,
	 creationdate   NUMBER  NOT NULL ,
	 creationtime   NUMBER  NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 assoc   NUMBER  NOT NULL 
)    
;
alter table usd_fio 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_fio to ca_itrm_group;
grant update on usd_fio to ca_itrm_group;
grant delete on usd_fio to ca_itrm_group;
grant insert on usd_fio to ca_itrm_group;
grant select on usd_fio to ca_itrm_group_ams;
 


-- name=usd_fitem,
CREATE TABLE   usd_fitem  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 fetchdate   NUMBER  NOT NULL ,
	 fetchtime   NUMBER  NOT NULL ,
	 fipath   NVARCHAR2  (255)   NOT NULL ,
	 copied   NUMBER  NOT NULL ,
	 localsite   RAW(16) NULL ,
	 fio   RAW(16) NULL 
)    
;
alter table usd_fitem 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_fitem to ca_itrm_group;
grant update on usd_fitem to ca_itrm_group;
grant delete on usd_fitem to ca_itrm_group;
grant insert on usd_fitem to ca_itrm_group;
grant select on usd_fitem to ca_itrm_group_ams;
 

-- name=usd_jcappgr,
CREATE TABLE   usd_jcappgr  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 jobcontview   RAW(16) NULL ,
	 jobtarget   RAW(16) NULL ,
	 jobstatus   NUMBER  NOT NULL ,
	 renewedjobstatus   NUMBER  NOT NULL ,
	 okcnt   NUMBER  NOT NULL ,
	 activecnt   NUMBER  NOT NULL ,
	 errorcnt   NUMBER  NOT NULL ,
	 waitingcnt   NUMBER  NOT NULL ,
	 okrenewcnt   NUMBER  NOT NULL ,
	 activerenewcnt   NUMBER  NOT NULL ,
	 waitingrenewcnt   NUMBER  NOT NULL ,
	 errorrenewcnt   NUMBER  NOT NULL ,
	 permmask   NUMBER  NOT NULL 
)    
;
alter table usd_jcappgr 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_jcappgr to ca_itrm_group;
grant update on usd_jcappgr to ca_itrm_group;
grant delete on usd_jcappgr to ca_itrm_group;
grant insert on usd_jcappgr to ca_itrm_group;
grant select on usd_jcappgr to ca_itrm_group_ams;
  

-- name=usd_jcview,
CREATE TABLE   usd_jcview  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 jobcont   RAW(16) NULL ,
	 type   NUMBER  NOT NULL ,
	 waitingcnt   NUMBER  NOT NULL ,
	 activecnt   NUMBER  NOT NULL ,
	 errorcnt   NUMBER  NOT NULL ,
	 okcnt   NUMBER  NOT NULL ,
	 waitingrenewcnt   NUMBER  NOT NULL ,
	 activerenewcnt   NUMBER  NOT NULL ,
	 errorrenewcnt   NUMBER  NOT NULL ,
	 okrenewcnt   NUMBER  NOT NULL 
)    
;
alter table usd_jcview 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_jcview to ca_itrm_group;
grant update on usd_jcview to ca_itrm_group;
grant delete on usd_jcview to ca_itrm_group;
grant insert on usd_jcview to ca_itrm_group;
grant select on usd_jcview to ca_itrm_group_ams;
  


-- name=usd_job_cont,
CREATE TABLE   usd_job_cont  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 qtask   RAW(16) NOT NULL ,
	 aux   RAW(16) NOT NULL ,
	 aux2   RAW(16) NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 attributes   RAW  (4) NOT NULL ,
	 name   NVARCHAR2  (129)  NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 credate   NUMBER  NOT NULL ,
	 cretime   NUMBER  NOT NULL ,
	 chdate   NUMBER  NOT NULL ,
	 chtime   NUMBER  NOT NULL ,
	 propflag   NUMBER  NOT NULL ,
	 qcalendar   NVARCHAR2  (129)   NOT NULL ,
	 qevalrate   NUMBER  NOT NULL ,
	 qnextevaldate   NUMBER  NOT NULL ,
	 qnextevaltime   NUMBER  NOT NULL ,
	 qevaldate   NUMBER  NOT NULL ,
	 qevaltime   NUMBER  NOT NULL ,
	 qtemplfold   RAW(16) NOT NULL ,
	 qtype   NUMBER  NOT NULL ,
	 state   NUMBER  NOT NULL ,
	 seal   NUMBER  NOT NULL ,
	 var   NUMBER  NOT NULL ,
	 auxtext0   NVARCHAR2  (128)   NULL ,
	 auxtext1   NVARCHAR2  (128)   NULL ,
	 auxtext2   NVARCHAR2  (128)   NULL ,
	 auxtext3   NVARCHAR2  (128)   NULL ,
	 queryid   RAW(16) NULL ,
	 dts_state   NUMBER  NULL ,
	 priority      NUMBER  default 5 NOT NULL
)    
;
alter table usd_job_cont 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_job_cont to ca_itrm_group;
grant update on usd_job_cont to ca_itrm_group;
grant delete on usd_job_cont to ca_itrm_group;
grant insert on usd_job_cont to ca_itrm_group;
grant select on usd_job_cont to ca_itrm_group_ams;

  

-- name=usd_link_act_cmp,
CREATE TABLE   usd_link_act_cmp  (
	 act   RAW(16) NOT NULL ,
	 comp   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_act_cmp 
    add  PRIMARY KEY(act, comp)
;
  
grant select on usd_link_act_cmp to ca_itrm_group;
grant update on usd_link_act_cmp to ca_itrm_group;
grant delete on usd_link_act_cmp to ca_itrm_group;
grant insert on usd_link_act_cmp to ca_itrm_group;
grant select on usd_link_act_cmp to ca_itrm_group_ams;


-- name=usd_link_act_grp,
CREATE TABLE   usd_link_act_grp  (
	 act   RAW(16) NOT NULL ,
	 grp   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_act_grp 
    add  PRIMARY KEY(act, grp)
;
  
grant select on usd_link_act_grp to ca_itrm_group;
grant update on usd_link_act_grp to ca_itrm_group;
grant delete on usd_link_act_grp to ca_itrm_group;
grant insert on usd_link_act_grp to ca_itrm_group;
grant select on usd_link_act_grp to ca_itrm_group_ams;

  



-- name=usd_link_act_inst,
CREATE TABLE   usd_link_act_inst  (
	 activity   RAW(16) NOT NULL ,
	 installation   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_act_inst 
    add  PRIMARY KEY(activity, installation)
;
  
grant select on usd_link_act_inst to ca_itrm_group;
grant update on usd_link_act_inst to ca_itrm_group;
grant delete on usd_link_act_inst to ca_itrm_group;
grant insert on usd_link_act_inst to ca_itrm_group;
grant select on usd_link_act_inst to ca_itrm_group_ams;
  



-- name=usd_link_cfold_cont,
CREATE TABLE   usd_link_cfold_cont  (
	 contfold   RAW(16) NOT NULL ,
	 cont   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_cfold_cont 
    add  PRIMARY KEY(cont, contfold)
;
  
grant select on usd_link_cfold_cont to ca_itrm_group;
grant update on usd_link_cfold_cont to ca_itrm_group;
grant delete on usd_link_cfold_cont to ca_itrm_group;
grant insert on usd_link_cfold_cont to ca_itrm_group;
grant select on usd_link_cfold_cont to ca_itrm_group_ams;
  


-- name=usd_link_cmpgrp,
CREATE TABLE   usd_link_cmpgrp  (
	 grpparent   RAW(16) NOT NULL ,
	 grpchild   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_cmpgrp 
    add  PRIMARY KEY(grpchild, grpparent)
;
  
grant select on usd_link_cmpgrp to ca_itrm_group;
grant update on usd_link_cmpgrp to ca_itrm_group;
grant delete on usd_link_cmpgrp to ca_itrm_group;
grant insert on usd_link_cmpgrp to ca_itrm_group;
grant select on usd_link_cmpgrp to ca_itrm_group_ams;
 



-- name=usd_link_contfold,
CREATE TABLE   usd_link_contfold  (
	 cfold_parent   RAW(16) NOT NULL ,
	 cfold_child   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_contfold 
    add  PRIMARY KEY(cfold_child, cfold_parent)
;
  
grant select on usd_link_contfold to ca_itrm_group;
grant update on usd_link_contfold to ca_itrm_group;
grant delete on usd_link_contfold to ca_itrm_group;
grant insert on usd_link_contfold to ca_itrm_group;
grant select on usd_link_contfold to ca_itrm_group_ams;
  

-- name=usd_link_grp_cmp,
CREATE TABLE   usd_link_grp_cmp  (
	 grp   RAW(16) NOT NULL ,
	 comp   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_grp_cmp 
    add  PRIMARY KEY(comp, grp)
;
  
grant select on usd_link_grp_cmp to ca_itrm_group;
grant update on usd_link_grp_cmp to ca_itrm_group;
grant delete on usd_link_grp_cmp to ca_itrm_group;
grant insert on usd_link_grp_cmp to ca_itrm_group;
grant select on usd_link_grp_cmp to ca_itrm_group_ams;
  

-- name=usd_link_grp_proc,
CREATE TABLE   usd_link_grp_proc  (
	 procgrp   RAW(16) NOT NULL ,
	 ap   RAW(16) NOT NULL ,
	 "ORDER"   NUMBER  NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_grp_proc 
    add  PRIMARY KEY(ap, procgrp)
;
  
grant select on usd_link_grp_proc to ca_itrm_group;
grant update on usd_link_grp_proc to ca_itrm_group;
grant delete on usd_link_grp_proc to ca_itrm_group;
grant insert on usd_link_grp_proc to ca_itrm_group;
grant select on usd_link_grp_proc to ca_itrm_group_ams;
  

-- name=usd_link_jc,
CREATE TABLE   usd_link_jc  (
	 jcparent   RAW(16) NOT NULL ,
	 jcchild   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_jc 
    add  PRIMARY KEY(jcchild, jcparent)
;
  
grant select on usd_link_jc to ca_itrm_group;
grant update on usd_link_jc to ca_itrm_group;
grant delete on usd_link_jc to ca_itrm_group;
grant insert on usd_link_jc to ca_itrm_group;
grant select on usd_link_jc to ca_itrm_group_ams;
  


-- name=usd_link_jc_act,
CREATE TABLE   usd_link_jc_act  (
	 jcont   RAW(16) NOT NULL ,
	 activity   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_jc_act 
    add  PRIMARY KEY(activity, jcont)
;
  
grant select on usd_link_jc_act to ca_itrm_group;
grant update on usd_link_jc_act to ca_itrm_group;
grant delete on usd_link_jc_act to ca_itrm_group;
grant insert on usd_link_jc_act to ca_itrm_group;
grant select on usd_link_jc_act to ca_itrm_group_ams;
  


-- name=usd_link_jc_srv,
CREATE TABLE   usd_link_jc_srv  (
	 jcont   RAW(16) NOT NULL ,
	 server   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_jc_srv 
    add  PRIMARY KEY(jcont, server)
;
  
grant select on usd_link_jc_srv to ca_itrm_group;
grant update on usd_link_jc_srv to ca_itrm_group;
grant delete on usd_link_jc_srv to ca_itrm_group;
grant insert on usd_link_jc_srv to ca_itrm_group;
grant select on usd_link_jc_srv to ca_itrm_group_ams;
  


-- name=usd_link_swg_sw,
CREATE TABLE   usd_link_swg_sw  (
	 swg   RAW(16) NOT NULL ,
	 sw   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_swg_sw 
    add  PRIMARY KEY(sw, swg)
;
  
grant select on usd_link_swg_sw to ca_itrm_group;
grant update on usd_link_swg_sw to ca_itrm_group;
grant delete on usd_link_swg_sw to ca_itrm_group;
grant insert on usd_link_swg_sw to ca_itrm_group;
grant select on usd_link_swg_sw to ca_itrm_group_ams;




-- name=usd_link_swgrp,
CREATE TABLE   usd_link_swgrp  (
	 grpparent   RAW(16) NOT NULL ,
	 grpchild   RAW(16) NOT NULL ,
	 time_secs   NUMBER  NOT NULL 
)    
;
alter table usd_link_swgrp 
    add  PRIMARY KEY(grpchild, grpparent)
;
  
grant select on usd_link_swgrp to ca_itrm_group;
grant update on usd_link_swgrp to ca_itrm_group;
grant delete on usd_link_swgrp to ca_itrm_group;
grant insert on usd_link_swgrp to ca_itrm_group;
grant select on usd_link_swgrp to ca_itrm_group_ams;

 

-- name=usd_order,
CREATE TABLE   usd_order  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 operand   RAW(16) NOT NULL ,
	 miscitem   RAW(16) NOT NULL ,
	 sequenceno   NUMBER  NOT NULL ,
	 activationdate   NUMBER  NOT NULL ,
	 activationtime   NUMBER  NOT NULL ,
	 creationdate   NUMBER  NOT NULL ,
	 creationtime   NUMBER  NOT NULL ,
	 cont   RAW(16) NULL 
)    
;
alter table usd_order 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_order to ca_itrm_group;
grant update on usd_order to ca_itrm_group;
grant delete on usd_order to ca_itrm_group;
grant insert on usd_order to ca_itrm_group;
grant select on usd_order to ca_itrm_group_ams;
  


-- name=usd_rsw,
CREATE TABLE   usd_rsw  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 packagesize   NUMBER  NOT NULL ,
	 packagetype   NUMBER  NOT NULL ,
	 itemname   NVARCHAR2  (129)  NOT NULL ,
	 itemversion   NVARCHAR2  (129)  NOT NULL ,
	 itemtype   NUMBER  NOT NULL ,
	 sourcemedium   NUMBER  NOT NULL ,
	 productname   NVARCHAR2  (129)  NOT NULL ,
	 productversion   NVARCHAR2  (129)   NOT NULL ,
	 filedby   NUMBER  NOT NULL ,
	 supplier   NVARCHAR2  (255)   NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 creationdate   NUMBER  NOT NULL ,
	 creationtime   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 changedate   NUMBER  NOT NULL ,
	 changetime   NUMBER  NOT NULL ,
	 reportevents   NUMBER  NOT NULL ,
	 activationproc   NUMBER  NOT NULL ,
	 recnotification   NUMBER  NOT NULL ,
	 singlemediasourcepath   NVARCHAR2  (255)   NOT NULL ,
	 singlemediasourcepathentered   NVARCHAR2  (255)   NOT NULL ,
	 basedon   RAW(16) NULL ,
	 deliverproc   RAW(16) NULL ,
	 undeliverproc   RAW(16) NULL ,
	 archtime   NUMBER  NOT NULL ,
	 addsize   NUMBER  NOT NULL ,
	 archpath   NVARCHAR2  (255)   NULL ,
	 archby   NVARCHAR2  (129)   NULL ,
	 archcomment   NVARCHAR2  (255)   NULL ,
	 archflag   NUMBER  NOT NULL ,
	 flags   NUMBER  NOT NULL ,
	 crc32   NUMBER  NOT NULL ,
	 software_def   RAW(16) NULL 
)    
;
alter table usd_rsw 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_rsw to ca_itrm_group;
grant update on usd_rsw to ca_itrm_group;
grant delete on usd_rsw to ca_itrm_group;
grant insert on usd_rsw to ca_itrm_group;
grant select on usd_rsw to ca_itrm_group_ams;
  


-- name=usd_swfold,
CREATE TABLE   usd_swfold  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 creation_user   NVARCHAR2  (255)   NULL ,
	 qtask   RAW(16) NOT NULL ,
	 aux   RAW(16) NOT NULL ,
	 aux2   RAW(16) NOT NULL ,
	 type   NUMBER  NOT NULL ,
	 attributes   RAW  (4) NOT NULL ,
	 name   NVARCHAR2  (129)  NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 credate   NUMBER  NOT NULL ,
	 cretime   NUMBER  NOT NULL ,
	 chdate   NUMBER  NOT NULL ,
	 chtime   NUMBER  NOT NULL ,
	 propflag   NUMBER  NOT NULL ,
	 qcalendar   NVARCHAR2  (129)   NOT NULL ,
	 qevalrate   NUMBER  NOT NULL ,
	 qnextevaldate   NUMBER  NOT NULL ,
	 qnextevaltime   NUMBER  NOT NULL ,
	 qevaldate   NUMBER  NOT NULL ,
	 qevaltime   NUMBER  NOT NULL ,
	 qtemplfold   RAW(16) NOT NULL ,
	 qtype   NUMBER  NOT NULL ,
	 state   NUMBER  NOT NULL ,
	 seal   NUMBER  NOT NULL ,
	 var   NUMBER  NOT NULL ,
	 auxtext0   NVARCHAR2  (128)   NULL ,
	 auxtext1   NVARCHAR2  (128)   NULL ,
	 auxtext2   NVARCHAR2  (128)   NULL ,
	 auxtext3   NVARCHAR2  (128)   NULL ,
	 queryid   RAW(16) NULL ,
	 security_group   NUMBER  NOT NULL 
)    
;
alter table usd_swfold 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_swfold to ca_itrm_group;
grant update on usd_swfold to ca_itrm_group;
grant delete on usd_swfold to ca_itrm_group;
grant insert on usd_swfold to ca_itrm_group;
grant select on usd_swfold to ca_itrm_group_ams;
  


-- name=usd_target,
CREATE TABLE   usd_target  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 managementtype   NUMBER  NOT NULL ,
	 state   NUMBER  NOT NULL ,
	 calendar   NVARCHAR2  (33)  NOT NULL ,
	 download_method   NUMBER  NOT NULL ,
	 locks   NUMBER  NOT NULL 
)    
;
alter table usd_target 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_target to ca_itrm_group;
grant update on usd_target to ca_itrm_group;
grant delete on usd_target to ca_itrm_group;
grant insert on usd_target to ca_itrm_group;
grant select on usd_target to ca_itrm_group_ams;
  


-- name=usd_task,
CREATE TABLE   usd_task  (
	 objectid          RAW(16) NOT NULL ,
	 version         NUMBER  NOT NULL ,
	 referredentity    RAW(16) NOT NULL ,
	 tasktype          NUMBER  NOT NULL ,
	 taskstate         NUMBER  NOT NULL ,
	 creationtime      NUMBER  NOT NULL ,
	 activationtime    NUMBER  NOT NULL ,
	 transactiontime   NUMBER  NOT NULL ,
	 runningstate      NUMBER  NOT NULL ,
	 runcounter        NUMBER  NOT NULL ,
	 lasteventmsgtime  NUMBER  NOT NULL ,
	 noofmsgparameters NUMBER  NOT NULL ,
	 lasteventmsgid    NUMBER  NOT NULL ,
	 eventmsgparams    NVARCHAR2(1023)   NOT NULL,
     priority          NUMBER   default 5 NOT NULL
)    
;
alter table usd_task 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_task to ca_itrm_group;
grant update on usd_task to ca_itrm_group;
grant delete on usd_task to ca_itrm_group;
grant insert on usd_task to ca_itrm_group;
grant select on usd_task to ca_itrm_group_ams;
 
 
  
-- name=usd_volume,
CREATE TABLE   usd_volume  (
	 objectid   RAW(16) NOT NULL ,
	 version   NUMBER  NOT NULL ,
	 name   NVARCHAR2  (129)   NOT NULL ,
	 "COMMENT"   NVARCHAR2  (255)   NOT NULL ,
	 "NUMBER"   NUMBER  NOT NULL ,
	 rsw   RAW(16) NULL 
)    
;
alter table usd_volume 
    add  PRIMARY KEY(objectid)
;
  
grant select on usd_volume to ca_itrm_group;
grant update on usd_volume to ca_itrm_group;
grant delete on usd_volume to ca_itrm_group;
grant insert on usd_volume to ca_itrm_group;
grant select on usd_volume to ca_itrm_group_ams;

  

-- name=ols_area_ace
CREATE TABLE ols_area_ace (
	    object_def_uuid    RAW(16) NOT NULL,
		object_type       NUMBER NULL,
		area_ace          NUMBER default -1 NOT NULL ,
		area_mask         NUMBER default -1 NULL ,
		security_level    NUMBER default 0 NULL ,
		creation_user     NVARCHAR2(255)  NULL
)
;

alter table ols_area_ace 
    add  PRIMARY KEY(OBJECT_DEF_UUID)
;

grant select on ols_area_ace to ca_itrm_group;
grant update on ols_area_ace to ca_itrm_group;
grant delete on ols_area_ace to ca_itrm_group;
grant insert on ols_area_ace to ca_itrm_group;
grant select on ols_area_ace to ca_itrm_group_ams;

  

-- name=ols_area_def	
CREATE TABLE ols_area_def(
			area_uuid    RAW(16) NOT NULL,
			area_id      NUMBER  NOT NULL,
			label        NVARCHAR2(255) NOT NULL,
			description  NVARCHAR2(255) NULL,
			creation_user    NVARCHAR2(255) NULL,
			creation_date    NUMBER NULL,
			last_update_user NVARCHAR2(255) NULL,
			last_update_date NUMBER NULL
)
;
	
        
alter table ols_area_def 
    add  PRIMARY KEY(area_uuid)
;

grant select on ols_area_def to ca_itrm_group;
grant update on ols_area_def to ca_itrm_group;
grant delete on ols_area_def to ca_itrm_group;
grant insert on ols_area_def to ca_itrm_group;
grant select on ols_area_def to ca_itrm_group_ams;



-- name=ols_mapping,
CREATE TABLE ols_mapping (
            uuid                 RAW(16) NOT NULL,
			target_sec_class_id  NUMBER NOT NULL,
			source_type          NUMBER NOT NULL,
			source_tbl_name      NVARCHAR2(255) NOT NULL,
			source_clmn_name     NVARCHAR2(255) NOT NULL
)
;


alter table ols_mapping 
    add  PRIMARY KEY(uuid)
;



grant select on ols_mapping to ca_itrm_group;
grant update on ols_mapping to ca_itrm_group;
grant delete on ols_mapping to ca_itrm_group;
grant insert on ols_mapping to ca_itrm_group;
grant select on ols_mapping to ca_itrm_group_ams;



-- drop table ca_object_ace
-- /
-- CREATE TABLE ca_object_ace (
--         object_def_uuid       RAW(16) NOT NULL,
--         security_profile_uuid RAW(16) NOT NULL,
-- 		ace                   NUMBER NULL,
-- 		"ACCESS"              NUMBER NOT NULL,
--         security_level        NUMBER NOT NULL , 
-- 		object_type           NUMBER NULL	
-- )
-- /
-- 
-- alter table ca_object_ace 
--     add  PRIMARY KEY(object_def_uuid, security_profile_uuid)
-- /
alter table ca_object_ace rename column access_num to "ACCESS"
;


grant select on ca_object_ace to ca_itrm_group;
grant update on ca_object_ace to ca_itrm_group;
grant delete on ca_object_ace to ca_itrm_group;
grant insert on ca_object_ace to ca_itrm_group;
grant select on ca_object_ace to ca_itrm_group_ams;



-- drop table ca_group_ace;
-- CREATE TABLE ca_group_ace (
--        group_def_uuid       RAW(16) NOT NULL,
--        security_profile_uuid RAW(16) NOT NULL,
--        ace                  NUMBER NOT NULL,
--        "ACCESS"               NUMBER NOT NULL,
--        enable_inheritance   NUMBER NOT NULL,
--        object_type          NUMBER DEFAULT 1005 NULL,
--        security_level       NUMBER default 0 NOT NULL 
-- );
-- 
-- CREATE INDEX x1ca_group_ace ON ca_group_ace
-- (
--        security_profile_uuid          ASC
-- )  tablespace &2;
-- 
-- 
-- ALTER TABLE ca_group_ace
--        ADD CONSTRAINT XPKca_group_ace PRIMARY KEY (group_def_uuid, 
--               security_profile_uuid);
-- 
alter table ca_group_ace rename column access_num to "ACCESS"; 

CREATE TABLE MDBADMIN.ca_synchronization_conf(
		  synchronization_conf_uuid 	RAW(16) NOT NULL,
		  table_name 					NVARCHAR2(255),
		  job_uuid 						RAW(16) NULL,
		  direction 					NUMBER NULL,
		  domain_collection 			NUMBER NULL,
		  job_domain_id 				NUMBER NULL,
		  job_id 						NUMBER NULL,
		  creation_user 				NVARCHAR2(255),
		  creation_date 				NUMBER NULL,
		  last_update_user 				NVARCHAR2(255),
		  last_update_date 				NUMBER NULL,
		  version_number 				NUMBER DEFAULT 0 NULL,
		  enterprise_uuid 				RAW(16) NOT NULL,
		  domain_uuid 					RAW(16) NOT NULL,
		  synchronization_order 		NUMBER NOT NULL,
		  primary_keys 					NVARCHAR2(255),
		  synchronization_column_filter	NVARCHAR2(255),
		  where_clause 					NVARCHAR2(255),
		  unlink_where_clause 			NVARCHAR2(255)
)
;
show errors 


alter table MDBADMIN.ca_synchronization_conf 
	add  CONSTRAINT XPKca_synchronization_conf PRIMARY KEY(synchronization_conf_uuid ) 
;
show errors 

grant select on MDBADMIN.ca_synchronization_conf to ca_itrm_group;
grant update on MDBADMIN.ca_synchronization_conf to ca_itrm_group;
grant delete on MDBADMIN.ca_synchronization_conf to ca_itrm_group;
grant insert on MDBADMIN.ca_synchronization_conf to ca_itrm_group;
grant select on MDBADMIN.ca_synchronization_conf to ca_itrm_group_ams;

 
 
 
CREATE TABLE MDBADMIN.ca_synchronization_history(
		  primary_uuid 		RAW(16) NULL,
		  secondary_uuid 	RAW(16) NULL,
		  lng1 				NUMBER NULL,
		  lng2 				NUMBER NULL,
		  lng3 				NUMBER NULL,
		  lng4 				NUMBER NULL,
		  table_name 		NVARCHAR2(255),
		  action 			NUMBER NULL,
		  auto_rep_version 	timestamp NULL
)
; 
 
--alter table ca_synchronization_history add  PRIMARY KEY()
--/

grant select on MDBADMIN.ca_synchronization_history to ca_itrm_group;
grant update on MDBADMIN.ca_synchronization_history to ca_itrm_group;
grant delete on MDBADMIN.ca_synchronization_history to ca_itrm_group;
grant insert on MDBADMIN.ca_synchronization_history to ca_itrm_group;
grant select on MDBADMIN.ca_synchronization_history to ca_itrm_group_ams;

 
 
 
CREATE TABLE MDBADMIN.ca_synchronization_status(
		  synchronization_conf_uuid 	RAW(16) NOT NULL,
		  domain_uuid 					RAW(16) NOT NULL,
		  modified_status 				RAW(8) NULL,
		  deleted_status 				RAW(8) NULL,
		  extlstat						NUMBER NULL
)
;


alter table MDBADMIN.ca_synchronization_status 
	add  CONSTRAINT XPKca_synchronization_status PRIMARY KEY( synchronization_conf_uuid, domain_uuid)
;

grant select on MDBADMIN.ca_synchronization_status to ca_itrm_group;
grant update on MDBADMIN.ca_synchronization_status to ca_itrm_group;
grant delete on MDBADMIN.ca_synchronization_status to ca_itrm_group;
grant insert on MDBADMIN.ca_synchronization_status to ca_itrm_group;
grant select on MDBADMIN.ca_synchronization_status to ca_itrm_group_ams;





--   of table creation----





WHENEVER SQLERROR CONTINUE;

-- *******************************************************
-- adding missing columns, special extensions only
--
-- *******************************************************

/*
 * update of Asset Collector MDb CRs
 *
 */  
-- object ace table
alter table inv_root_map 
    add trustlevel int /* constraint inv_root_map_tl*/  default ((5));

alter table inv_root_map 
    add origin nvarchar2(64);

alter table ca_agent 
    add trustlevel  int /* constraint ca_agent_tl */ default ((5));

alter table ca_agent 
    add origin nvarchar2(64);

alter table ca_discovered_hardware 
    add external_host_key nvarchar2(64);

 
--CREATE NONCLUSTERED INDEX ca_disc_hardware_idx_07 ON ca_discovered_hardware (external_host_key)


alter table ca_discovered_software 
    add trustlevel int /* constraint ca_discovered_software_tl*/ default ((5));

alter table ca_discovered_software 
    add origin nvarchar2(64);

alter table ca_discovered_software 
    add def_source_type_id int /*constraint ca_discovered_software_dsid */ default ((0));


alter table ca_discovered_software 
    add dis_source_type_id int /* constraint ca_discovered_software_dstid */ default ((0));



-- end of asset collector MDB CR






-- ****************************************************
-- adding missing indexes
-- ****************************************************

-- BEGIN fix  12584
create unique index DISHW_UNIQUE01 on CA_DISCOVERED_HARDWARE (domain_uuid, host_uuid) tablespace &2;
;
-- END fix  12584

-- BEGIN fix 12637
-- modify discovered user
alter table ca_discovered_user 
modify last_update_user NVARCHAR2(255)
;

alter table ca_discovered_user 
modify creation_user NVARCHAR2(255)
;


-- modify discovered hardware

alter table ca_discovered_hardware
modify last_update_user NVARCHAR2(255)
;

alter table ca_discovered_hardware
modify creation_user NVARCHAR2(255)
;

-- END fix 12637



-- ****************************************************
-- adding foreign key constraints
-- ****************************************************
ALTER TABLE AMEPHIS 
    ADD CONSTRAINT FK01_amephis
     FOREIGN KEY (EPID, domainid) REFERENCES AMEPDEF (EPID, domainid)    
;  


--ALTER TABLE CA_AGENT
--       ADD CONSTRAINT FK01_CA_AGENT
--              FOREIGN KEY (SERVER_UUID) REFERENCES CA_SERVER (SERVER_UUID)
--;  

alter table CA_CLASS_ACE
    add constraint FK01_CA_CLASS_ACE
        foreign key (CLASS_DEF_UUID)	 References CA_SECURITY_CLASS_DEF (CLASS_DEF_UUID)
;

alter table ca_class_ace
    add constraint fk02_ca_class_ace
        foreign key (SECURITY_PROFILE_UUID)	 References ca_security_profile (SECURITY_PROFILE_UUID)
;

 
alter table ca_engine
    add constraint fk02_ca_engine
        foreign key (DIS_HW_UUID)	 References ca_discovered_hardware (DIS_HW_UUID)
;

alter table ca_group_def
    add constraint fk01_ca_group_def
        foreign key (evaluation_uuid)	 References ca_engine (ENGINE_UUID)
;

alter table ca_group_def
    add constraint fk02_ca_group_def
        foreign key (query_uuid)	 References ca_query_def (QUERY_UUID)
;


alter table ca_group_member
    add constraint fk01_ca_group_member
        foreign key (group_uuid)	 References ca_group_def (GROUP_UUID)
;


alter table ca_link_dir_details_map
    add constraint fk01_link_dir_details_map
        foreign key (directory_uuid)	 References ca_directory_details (DIRECTORY_UUID)
;


alter table ca_link_dir_details_map
    add constraint fk02_link_dir_details_map
        foreign key (dir_schema_uuid)	 References ca_directory_schema_map (DIR_SCHEMA_UUID)
;

alter table ca_link_dis_user_sec_profile
    add constraint fk01_lnk_dis_usr_sp
        foreign key (user_uuid)	 References ca_discovered_user (user_uuid)
;


alter table ca_link_dis_user_sec_profile
    add constraint fk02_lnk_dis_usr_sp
        foreign key (security_profile_uuid)	 References ca_security_profile (security_profile_uuid)
;


alter table ca_link_lic_def_domain
    add constraint fk01_lnk_lic_def_domain
        foreign key (lic_def_uuid)	 References ca_license_def (lic_def_uuid)
;


alter table ca_link_lic_def_domain
    add constraint fk02_lnk_lic_def_domain
        foreign key (domain_uuid)	 References ca_n_tier (domain_uuid)
;

alter table ca_manager_component
    add constraint fk01_ca_manager_component
        foreign key (manager_uuid)	 References ca_manager (manager_uuid)
;

-- this is part of patch 14749700
--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT fk01_ca_software_def FOREIGN KEY ( bit_support_id)
--	REFERENCES MDBADMIN.bit_support ( bit_support_id)
--/

-- this is part of patch 14749700
--ALTER TABLE MDBADMIN.ca_software_def ADD 
--	CONSTRAINT fk02_ca_software_def FOREIGN KEY ( chip_set_id)
--	REFERENCES MDBADMIN.chip_set ( chip_set_id)
--/

alter table ca_query_result
    add constraint fk01_ca_query_result
        foreign key (query_uuid)	 References ca_query_def (query_uuid)
;


alter table ca_query_result
    add constraint fk02_ca_query_result
        foreign key (query_version_uuid, query_uuid)	 References ca_query_version (query_version_uuid, query_uuid)
;

alter table ca_query_version
    add constraint fk01_ca_query_version
        foreign key (query_uuid)	 References ca_query_def (query_uuid)
;


alter table ca_replication_status
    add constraint fk01_ca_rep_status
        foreign key (replication_conf_uuid)	 References ca_replication_conf (replication_conf_uuid)
;

alter table ca_server
    add constraint fk01_ca_server
        foreign key (dis_hw_uuid)	 References ca_discovered_hardware (dis_hw_uuid)
;

alter table ca_server_component
    add constraint fk01_ca_server_component
        foreign key (server_uuid)	 References ca_server (server_uuid)
;


alter table ca_server_push_status
    add constraint fk01_srv_push_status
        foreign key (server_uuid)	 References ca_server (server_uuid)
;


alter table ca_server_queue
    add constraint fk01_ca_server_queue
        foreign key (server_uuid)	 References ca_server (server_uuid)
;


alter table urc_computer
    add constraint fk01_urc_computer
        foreign key ("UID")	 References ca_discovered_hardware (dis_hw_uuid)
;



/*
alter table xxx
    add constraint fk01_xxx
        foreign key (xxxx)	 References xxxx (xxxx)
;
*/



-- 15948117 (B)


CREATE OR REPLACE VIEW ca_coapi_agent_view_v2
AS
SELECT
dhw.label AS agv_label,
dhw.creation_user AS agv_creation_user,
dhw.creation_date AS agv_creation_date,
dhw.last_update_user AS agv_last_update_user,
dhw.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_discovered_hardware dhw, ca_n_tier dom, 
ca_agent ag, ca_server srv 
WHERE 
ag.server_uuid(+) = srv.server_uuid and
(ag.object_uuid = dhw.dis_hw_uuid) AND (dhw.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
usr.label AS agv_label,
usr.creation_user AS agv_creation_user,
usr.creation_date AS agv_creation_date,
usr.last_update_user AS agv_last_update_user,
usr.last_update_date AS agv_last_update_date,
N'' AS agv_network_address,
N'' AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
'' AS dhw_host_uuid,
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
usr.label AS usr_label,
usr.domain_uuid AS usr_domain_uuid,
usr.user_uuid AS usr_user_uuid, 
usr.user_name AS usr_user_name, 
usr.usage_list AS usr_usage_list,
usr.uri AS usr_uri,
usr.creation_user AS usr_creation_user,
usr.creation_date AS usr_creation_date,
usr.last_update_date AS usr_last_update_date,
usr.last_update_user AS usr_last_update_user,
usr.version_number AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM  ca_group_member grm, ca_discovered_user usr, ca_n_tier dom,
 ca_agent ag, ca_server srv  
WHERE 
ag.server_uuid(+) = srv.server_uuid and
(ag.object_uuid = usr.user_uuid) AND (usr.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
cu.label AS agv_label,
cu.creation_user AS agv_creation_user,
cu.creation_date AS agv_creation_date,
cu.last_update_user AS agv_last_update_user,
cu.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
cu.label AS cu_label,
cu.link_dis_hw_user_uuid AS cu_link_dis_hw_user_uuid,
cu.dis_hw_uuid AS cu_dis_hw_uuid,
cu.user_uuid AS cu_user_uuid,
cu.ref_count AS cu_ref_count,
cu.usage_list AS cu_usage_list,
cu.creation_user AS cu_creation_user,
cu.creation_date AS cu_creation_date,
cu.last_update_user AS cu_last_update_user,
cu.last_update_date AS cu_last_update_date,
cu.version_number AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_link_dis_hw_user cu, ca_discovered_hardware dhw, ca_n_tier dom,
ca_agent  ag, ca_server srv 
WHERE ag.server_uuid(+) = srv.server_uuid and 
(ag.object_uuid = cu.link_dis_hw_user_uuid) AND 
(cu.dis_hw_uuid=dhw.dis_hw_uuid) AND
(dhw.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
exa.label AS agv_label,
exa.creation_user AS agv_creation_user,
exa.creation_date AS agv_creation_date,
exa.last_update_user AS agv_last_update_user,
exa.last_update_date AS agv_last_update_date,
exa.ipaddress AS agv_network_address,
exa.macaddress AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
'' AS dhw_host_uuid,
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
exa.label AS exa_label,
exa.device_uuid AS exa_device_uuid,
exa.domain_uuid AS exa_domain_uuid, 
exa.class_name AS exa_class_name,
exa.ipaddress AS exa_ipaddress,
exa.macaddress AS exa_macaddress,
exa.last_update_user AS exa_last_update_user,
exa.last_update_date AS exa_last_update_date,
exa.creation_date AS exa_creation_date,
exa.creation_user AS exa_creation_user,
exa.version_number AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, am_external_device exa, ca_n_tier dom, 
ca_agent ag, ca_server srv
WHERE ag.server_uuid(+) = srv.server_uuid and
 (ag.object_uuid = exa.device_uuid) AND (exa.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid);

grant select on ca_coapi_agent_view_v2 to ca_itrm_group;
grant select on ca_coapi_agent_view_v2 to ca_itrm_group_ams;

/*
 -- @FIXME
grant select on ca_coapi_agent_view_v2 to  upmuser_group*/



CREATE OR REPLACE VIEW ca_coapi_agent_view_nodom_v2
AS
SELECT
dhw.label AS agv_label,
dhw.creation_user AS agv_creation_user,
dhw.creation_date AS agv_creation_date,
dhw.last_update_user AS agv_last_update_user,
dhw.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_discovered_hardware dhw,
ca_agent ag, ca_server srv 
WHERE 
ag.server_uuid(+) = srv.server_uuid and
(ag.object_uuid = dhw.dis_hw_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
usr.label AS agv_label,
usr.creation_user AS agv_creation_user,
usr.creation_date AS agv_creation_date,
usr.last_update_user AS agv_last_update_user,
usr.last_update_date AS agv_last_update_date,
N'' AS agv_network_address,
N'' AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
''  AS dhw_host_uuid,  
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
usr.label AS usr_label,
usr.domain_uuid AS usr_domain_uuid,
usr.user_uuid AS usr_user_uuid, 
usr.user_name AS usr_user_name, 
usr.usage_list AS usr_usage_list,
usr.uri AS usr_uri,
usr.creation_user AS usr_creation_user,
usr.creation_date AS usr_creation_date,
usr.last_update_date AS usr_last_update_date,
usr.last_update_user AS usr_last_update_user,
usr.version_number AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM  ca_group_member grm, ca_discovered_user usr, 
ca_agent ag, ca_server srv 
WHERE 
ag.server_uuid(+) = srv.server_uuid and
(ag.object_uuid = usr.user_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
cu.label AS agv_label,
cu.creation_user AS agv_creation_user,
cu.creation_date AS agv_creation_date,
cu.last_update_user AS agv_last_update_user,
cu.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
cu.label AS cu_label,
cu.link_dis_hw_user_uuid AS cu_link_dis_hw_user_uuid,
cu.dis_hw_uuid AS cu_dis_hw_uuid,
cu.user_uuid AS cu_user_uuid,
cu.ref_count AS cu_ref_count,
cu.usage_list AS cu_usage_list,
cu.creation_user AS cu_creation_user,
cu.creation_date AS cu_creation_date,
cu.last_update_user AS cu_last_update_user,
cu.last_update_date AS cu_last_update_date,
cu.version_number AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_link_dis_hw_user cu, ca_discovered_hardware dhw,
ca_agent ag, ca_server srv  
WHERE
ag.server_uuid(+) = srv.server_uuid and
 (ag.object_uuid = cu.link_dis_hw_user_uuid) AND 
(cu.dis_hw_uuid=dhw.dis_hw_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
exa.label AS agv_label,
exa.creation_user AS agv_creation_user,
exa.creation_date AS agv_creation_date,
exa.last_update_user AS agv_last_update_user,
exa.last_update_date AS agv_last_update_date,
exa.ipaddress AS agv_network_address,
exa.macaddress AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
srv.host_name AS srv_host_name,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
'' AS dhw_host_uuid,  
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
exa.label AS exa_label,
exa.device_uuid AS exa_device_uuid,
exa.domain_uuid AS exa_domain_uuid, 
exa.class_name AS exa_class_name,
exa.ipaddress AS exa_ipaddress,
exa.macaddress AS exa_macaddress,
exa.last_update_user AS exa_last_update_user,
exa.last_update_date AS exa_last_update_date,
exa.creation_date AS exa_creation_date,
exa.creation_user AS exa_creation_user,
exa.version_number AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, am_external_device exa,
ca_agent  ag , ca_server  srv  
WHERE 
ag.server_uuid(+) = srv.server_uuid and
(ag.object_uuid = exa.device_uuid) AND (grm.member_uuid=ag.object_uuid);

grant select on ca_coapi_agent_view_nodom_v2 to  ca_itrm_group;
grant select on ca_coapi_agent_view_nodom_v2 to  ca_itrm_group_ams;


CREATE OR REPLACE VIEW ca_coapi_agent_view_nosrv_v2
AS
SELECT
dhw.label AS agv_label,
dhw.creation_user AS agv_creation_user,
dhw.creation_date AS agv_creation_date,
dhw.last_update_user AS agv_last_update_user,
dhw.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_discovered_hardware dhw, ca_n_tier dom, ca_agent ag
WHERE (ag.object_uuid = dhw.dis_hw_uuid) AND (dhw.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
usr.label AS agv_label,
usr.creation_user AS agv_creation_user,
usr.creation_date AS agv_creation_date,
usr.last_update_user AS agv_last_update_user,
usr.last_update_date AS agv_last_update_date,
N'' AS agv_network_address,
N'' AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
''  AS dhw_host_uuid,  
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
usr.label AS usr_label,
usr.domain_uuid AS usr_domain_uuid,
usr.user_uuid AS usr_user_uuid, 
usr.user_name AS usr_user_name, 
usr.usage_list AS usr_usage_list,
usr.uri AS usr_uri,
usr.creation_user AS usr_creation_user,
usr.creation_date AS usr_creation_date,
usr.last_update_date AS usr_last_update_date,
usr.last_update_user AS usr_last_update_user,
usr.version_number AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM  ca_group_member grm, ca_discovered_user usr, ca_n_tier dom, ca_agent ag
WHERE (ag.object_uuid = usr.user_uuid) AND (usr.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
cu.label AS agv_label,
cu.creation_user AS agv_creation_user,
cu.creation_date AS agv_creation_date,
cu.last_update_user AS agv_last_update_user,
cu.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
cu.label AS cu_label,
cu.link_dis_hw_user_uuid AS cu_link_dis_hw_user_uuid,
cu.dis_hw_uuid AS cu_dis_hw_uuid,
cu.user_uuid AS cu_user_uuid,
cu.ref_count AS cu_ref_count,
cu.usage_list AS cu_usage_list,
cu.creation_user AS cu_creation_user,
cu.creation_date AS cu_creation_date,
cu.last_update_user AS cu_last_update_user,
cu.last_update_date AS cu_last_update_date,
cu.version_number AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_link_dis_hw_user cu, ca_discovered_hardware dhw, ca_n_tier dom, ca_agent ag
WHERE (ag.object_uuid = cu.link_dis_hw_user_uuid) AND 
(cu.dis_hw_uuid=dhw.dis_hw_uuid) AND
(dhw.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
exa.label AS agv_label,
exa.creation_user AS agv_creation_user,
exa.creation_date AS agv_creation_date,
exa.last_update_user AS agv_last_update_user,
exa.last_update_date AS agv_last_update_date,
exa.ipaddress AS agv_network_address,
exa.macaddress AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dom.label AS dom_label,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
'' AS dhw_host_uuid,      
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
exa.label AS exa_label,
exa.device_uuid AS exa_device_uuid,
exa.domain_uuid AS exa_domain_uuid, 
exa.class_name AS exa_class_name,
exa.ipaddress AS exa_ipaddress,
exa.macaddress AS exa_macaddress,
exa.last_update_user AS exa_last_update_user,
exa.last_update_date AS exa_last_update_date,
exa.creation_date AS exa_creation_date,
exa.creation_user AS exa_creation_user,
exa.version_number AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, am_external_device exa, ca_n_tier dom, ca_agent ag
WHERE (ag.object_uuid = exa.device_uuid) AND (exa.domain_uuid=dom.domain_uuid) AND (grm.member_uuid=ag.object_uuid)
;

grant select on ca_coapi_agent_view_nosrv_v2 to  ca_itrm_group;
grant select on ca_coapi_agent_view_nosrv_v2 to  ca_itrm_group_ams;


CREATE OR REPLACE VIEW  coapi_agent_view_nodomsrv_v2     -- ca_coapi_agent_view_nodomsrv_v2
AS
SELECT
dhw.label AS agv_label,
dhw.creation_user AS agv_creation_user,
dhw.creation_date AS agv_creation_date,
dhw.last_update_user AS agv_last_update_user,
dhw.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_discovered_hardware dhw, ca_agent ag
WHERE (ag.object_uuid = dhw.dis_hw_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
usr.label AS agv_label,
usr.creation_user AS agv_creation_user,
usr.creation_date AS agv_creation_date,
usr.last_update_user AS agv_last_update_user,
usr.last_update_date AS agv_last_update_date,
N'' AS agv_network_address,
N'' AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
'' AS dhw_host_uuid,        
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
usr.label AS usr_label,
usr.domain_uuid AS usr_domain_uuid,
usr.user_uuid AS usr_user_uuid, 
usr.user_name AS usr_user_name, 
usr.usage_list AS usr_usage_list,
usr.uri AS usr_uri,
usr.creation_user AS usr_creation_user,
usr.creation_date AS usr_creation_date,
usr.last_update_date AS usr_last_update_date,
usr.last_update_user AS usr_last_update_user,
usr.version_number AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM  ca_group_member grm, ca_discovered_user usr, ca_agent ag
WHERE (ag.object_uuid = usr.user_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
cu.label AS agv_label,
cu.creation_user AS agv_creation_user,
cu.creation_date AS agv_creation_date,
cu.last_update_user AS agv_last_update_user,
cu.last_update_date AS agv_last_update_date,
dhw.primary_network_address AS agv_network_address,
dhw.primary_mac_address AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
dhw.label AS dhw_label,
dhw.domain_uuid AS dhw_domain_uuid,
dhw.dis_hw_uuid AS dhw_dis_hw_uuid, 
dhw.asset_source_uuid AS dhw_asset_source_uuid, 
dhw.host_name AS dhw_host_name,
dhw.primary_network_address AS dhw_primary_network_address,
dhw.serial_number AS dhw_serial_number,
dhw.disc_serial_number AS dhw_disc_serial_number,
dhw.primary_mac_address AS dhw_primary_mac_address,
dhw.asset_tag AS dhw_asset_tag,
dhw.host_uuid AS dhw_host_uuid,
dhw.class_id AS dhw_class_id,
dhw.usage_list AS dhw_usage_list,
dhw.uri AS dhw_uri,
dhw.system_id AS dhw_system_id,
dhw.vendor_name AS dhw_vendor_name,
dhw.external_host_key AS dhw_external_host_key,
dhw.creation_user AS dhw_creation_user,
dhw.creation_date AS dhw_creation_date,
dhw.last_update_date AS dhw_last_update_date,
dhw.last_update_user AS dhw_last_update_user,
dhw.version_number AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
cu.label AS cu_label,
cu.link_dis_hw_user_uuid AS cu_link_dis_hw_user_uuid,
cu.dis_hw_uuid AS cu_dis_hw_uuid,
cu.user_uuid AS cu_user_uuid,
cu.ref_count AS cu_ref_count,
cu.usage_list AS cu_usage_list,
cu.creation_user AS cu_creation_user,
cu.creation_date AS cu_creation_date,
cu.last_update_user AS cu_last_update_user,
cu.last_update_date AS cu_last_update_date,
cu.version_number AS cu_version_number,
N'' AS exa_label,
/*RAW(0) */ NULL AS exa_device_uuid,
/*RAW(0) */ NULL AS exa_domain_uuid, 
N'' AS exa_class_name,
N'' AS exa_ipaddress,
N'' AS exa_macaddress,
N'' AS exa_last_update_user,
NULL AS exa_last_update_date,
NULL AS exa_creation_date,
N'' AS exa_creation_user,
NULL AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, ca_link_dis_hw_user cu, ca_discovered_hardware dhw, ca_agent ag
WHERE (ag.object_uuid = cu.link_dis_hw_user_uuid) AND 
(cu.dis_hw_uuid=dhw.dis_hw_uuid) AND (grm.member_uuid=ag.object_uuid)
UNION
SELECT
exa.label AS agv_label,
exa.creation_user AS agv_creation_user,
exa.creation_date AS agv_creation_date,
exa.last_update_user AS agv_last_update_user,
exa.last_update_date AS agv_last_update_date,
exa.ipaddress AS agv_network_address,
exa.macaddress AS agv_mac_address,
ag.object_uuid AS ag_object_uuid, 
ag.domain_id AS ag_domain_id,
ag.server_uuid AS ag_server_uuid,
ag.boot_server_uuid AS ag_boot_server_uuid,
ag.unit_id AS ag_unit_id,
ag.last_run_date AS ag_last_run_date,
ag.agent_type AS ag_agent_type,
ag.agent_lock AS ag_agent_lock,
ag.agent_name AS ag_agent_name,
ag.agent_file_id AS ag_agent_file_id,
ag.agent_area AS ag_agent_area,
ag.agent_version AS ag_agent_version,
ag.description AS ag_description,
ag.prev_manager AS ag_prev_manager,
ag.ip_address AS ag_ip_address,
ag.registration_type AS ag_registration_type,
ag.proc_os_id AS ag_proc_os_id,
ag.class_id AS ag_class_id,
ag.origin AS ag_origin,
ag.trustlevel AS ag_trustlevel,
ag.derived_status_am AS ag_derived_status_am,
ag.derived_status_sd AS ag_derived_status_sd,
ag.derived_status_rc AS ag_derived_status_rc,
ag.derived_status_babld AS ag_derived_status_babld,
ag.user_def1 AS ag_user_def1,
ag.user_def2 AS ag_user_def2,
ag.user_def3 AS ag_user_def3,
ag.user_def4 AS ag_user_def4,
ag.creation_user AS ag_creation_user,
ag.creation_date AS ag_creation_date,
ag.last_update_date AS ag_last_update_date,
ag.last_update_user AS ag_last_update_user,
ag.version_number AS ag_version_number,
N'' AS dhw_label,
/*RAW(0) */ NULL AS dhw_domain_uuid,
/*RAW(0) */ NULL AS dhw_dis_hw_uuid, 
/*RAW(0) */ NULL AS dhw_asset_source_uuid, 
N'' AS dhw_host_name,
N'' AS dhw_primary_network_address,
N'' AS dhw_serial_number,
N'' AS dhw_disc_serial_number,
N'' AS dhw_primary_mac_address,
N'' AS dhw_asset_tag,
'' AS dhw_host_uuid,      
NULL AS dhw_class_id,
/*RAW(0) */ NULL AS dhw_usage_list,
N'' AS dhw_uri,
N'' AS dhw_system_id,
N'' AS dhw_vendor_name,
N'' AS dhw_external_host_key,
N'' AS dhw_creation_user,
NULL AS dhw_creation_date,
NULL AS dhw_last_update_date,
N'' AS dhw_last_update_user,
NULL AS dhw_version_number,
N'' AS usr_label,
/*RAW(0) */ NULL AS usr_domain_uuid,
/*RAW(0) */ NULL AS usr_user_uuid, 
N'' AS usr_user_name, 
/*RAW(0) */ NULL AS usr_usage_list,
N'' AS usr_uri,
N'' AS usr_creation_user,
NULL AS usr_creation_date,
NULL AS usr_last_update_date,
N'' AS usr_last_update_user,
NULL AS usr_version_number,
N'' AS cu_label,
/*RAW(0) */ NULL AS cu_link_dis_hw_user_uuid,
/*RAW(0) */ NULL AS cu_dis_hw_uuid,
/*RAW(0) */ NULL AS cu_user_uuid,
NULL AS cu_ref_count,
/*RAW(0) */ NULL AS cu_usage_list,
N'' AS cu_creation_user,
NULL AS cu_creation_date,
N'' AS cu_last_update_user,
NULL AS cu_last_update_date,
NULL AS cu_version_number,
exa.label AS exa_label,
exa.device_uuid AS exa_device_uuid,
exa.domain_uuid AS exa_domain_uuid, 
exa.class_name AS exa_class_name,
exa.ipaddress AS exa_ipaddress,
exa.macaddress AS exa_macaddress,
exa.last_update_user AS exa_last_update_user,
exa.last_update_date AS exa_last_update_date,
exa.creation_date AS exa_creation_date,
exa.creation_user AS exa_creation_user,
exa.version_number AS exa_version_number,
grm.group_uuid as group_uuid
FROM ca_group_member grm, am_external_device exa, ca_agent ag
WHERE (ag.object_uuid = exa.device_uuid) AND (grm.member_uuid=ag.object_uuid);


grant select on coapi_agent_view_nodomsrv_v2 to ca_itrm_group;
grant select on coapi_agent_view_nodomsrv_v2 to ca_itrm_group_ams;



-- 15948117 (C)

-- copyright Ca 2007
--
-- product 
--      Desktop and server Management 
--
-- purpose
--  install procedures and triggers to check integrity
--      
--  Scope
--      
--
-- FIXME
--  
--
--
-- Caveats:
--    
--
--
-- ****************************************************************************

-- ****************************************************************************
-- HISTORY:
/*  
    4 april 2007, jaere01
    the following items are removed - not longre needed, replace by a
     unique index which is part of the TABLE installtion script    
    trigger r_i_dis_hw_host_uuid
    trigger r_u_dis_hw_host_uuid
    procedure p_iu_dis_hw_host_uuid

*/
-- ****************************************************************************



/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of the 
 * version number 
 *********************************************************
 *********************************************************
 */



/*
 ***********************************************
 check the version number of an entity
*/

CREATE OR REPLACE PROCEDURE "MDBADMIN"."P_INTEGRITY_VERSION_NUMBER" (
    old_verno IN NUMBER,    /* old version number */
    new_verno IN NUMBER     /* new version number */
    )

AS
    E_9001 EXCEPTION;

BEGIN

    if ( new_verno <= old_verno)
    then
        RAISE E_9001;

    end if;
    
    EXCEPTION
        WHEN E_9001 THEN 
        BEGIN   
            RAISE_APPLICATION_ERROR (-20000, 'Error 9001: update error, new version number less than the old version number');
        END; 
END;
/


grant execute on  p_integrity_version_number to ca_itrm_group;
;
grant execute on  p_integrity_version_number to ca_itrm_group_ams;
;




/*
 ***********************************************
 trigger on update on ca_query_def_contents
*/

CREATE OR REPLACE TRIGGER "MDBADMIN".R_UPD_VERNO_CA_QUERY_DEF_CONT
AFTER UPDATE of version_number ON "MDBADMIN"."CA_QUERY_DEF_CONTENTS" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number(:old.version_number , :new.version_number ) ;
END;
/



/*
 ***********************************************
 trigger on update on am_approved_licenses
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_approved_licenses
AFTER UPDATE of version_number ON "MDBADMIN"."AM_APPROVED_LICENSES" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/


/*
 ***********************************************
 trigger on update on computer
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_dis_hw
AFTER UPDATE of version_number ON "MDBADMIN"."CA_DISCOVERED_HARDWARE" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/



/*
 ***********************************************
 trigger on update on am_link_external_device
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_am_lnk_ext_dev
AFTER UPDATE of version_number ON "MDBADMIN"."AM_LINK_EXTERNAL_DEVICE" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/





/*
 ***********************************************
 trigger on update on ca_agent
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_agent
AFTER UPDATE of version_number ON "MDBADMIN"."CA_AGENT" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_directory_schema_map
*/

CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_dir_schema_map
AFTER UPDATE of version_number ON "MDBADMIN"."CA_DIRECTORY_SCHEMA_MAP" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_discovered_software
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_dis_sw
AFTER UPDATE of version_number ON "MDBADMIN"."CA_DISCOVERED_SOFTWARE" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_discovered_user
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_dis_user
AFTER UPDATE of version_number ON "MDBADMIN"."CA_DISCOVERED_USER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_engine
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_engine
AFTER UPDATE of version_number ON "MDBADMIN"."CA_ENGINE" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_group_def
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_group_def
AFTER UPDATE of version_number ON "MDBADMIN"."CA_GROUP_DEF" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_group_member
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_group_member
AFTER UPDATE of version_number ON "MDBADMIN"."CA_GROUP_MEMBER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_link_dir_details_map
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_lnk_dir_dtls_map
AFTER UPDATE of version_number ON "MDBADMIN"."CA_LINK_DIR_DETAILS_MAP" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/





/*
 ***********************************************
 trigger on update on ca_link_dis_hw
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_lnk_dis_hw
AFTER UPDATE of version_number ON "MDBADMIN"."CA_LINK_DIS_HW" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_link_dis_hw_user
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_lnk_dis_hw_user
AFTER UPDATE of version_number ON "MDBADMIN"."CA_LINK_DIS_HW_USER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/



/*
 ***********************************************
 trigger on update on ca_link_dis_user_sec_profile
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_lnk_dis_usr_secp
AFTER UPDATE of version_number ON "MDBADMIN"."CA_LINK_DIS_USER_SEC_PROFILE" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/



/*
 ***********************************************
 trigger on update on ca_link_object_owner
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_lnk_object_owner
AFTER UPDATE of version_number ON "MDBADMIN"."CA_LINK_OBJECT_OWNER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_link_sw_def
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_lnk_sw_def
AFTER UPDATE of version_number ON "MDBADMIN"."CA_LINK_SW_DEF" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/


/*
 ***********************************************
 trigger on update on ca_manager
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_manager
AFTER UPDATE of version_number ON "MDBADMIN"."CA_MANAGER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/






/*
 ***********************************************
 trigger on update on ca_manager_component
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_manager_component
AFTER UPDATE of version_number ON "MDBADMIN"."CA_MANAGER_COMPONENT" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_n_tier
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_n_tier
AFTER UPDATE of version_number ON "MDBADMIN"."CA_N_TIER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_query_def
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_query_def
AFTER UPDATE of version_number ON "MDBADMIN"."CA_QUERY_DEF" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_query_result
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_query_result
AFTER UPDATE of version_number ON "MDBADMIN"."CA_QUERY_RESULT" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/





/*
 ***********************************************
 trigger on update on ca_directory_schema_map
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_query_version
AFTER UPDATE of version_number ON "MDBADMIN"."CA_QUERY_VERSION" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/



/*
 ***********************************************
 trigger on update on ca_replication_conf
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_replic_conf
AFTER UPDATE of version_number ON "MDBADMIN"."CA_REPLICATION_CONF" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_server
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_server
AFTER UPDATE of version_number ON "MDBADMIN"."CA_SERVER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/




/*
 ***********************************************
 trigger on update on ca_server_component
*/
CREATE OR REPLACE TRIGGER "MDBADMIN".r_upd_verno_server_component
AFTER UPDATE of version_number ON "MDBADMIN"."CA_SERVER_COMPONENT" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
    
FOR EACH ROW
BEGIN
    p_integrity_version_number (:old.version_number , :new.version_number ) ;
END;
/



/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of groups
 *********************************************************
 *********************************************************
 */

/*
 ***********************************************
 delete all entries of the ca_group_meber tabel if 
 a ca_group_def object is deleted
 
 @param old_group_uuid group uuid of deleted group
*/
CREATE OR REPLACE PROCEDURE "MDBADMIN"."P_INTEGRITY_D_GROUP_DEF" (
    old_groupid IN  ca_group_def.group_uuid%TYPE
)
AS
BEGIN
    delete from ca_group_member where group_uuid = old_groupid;
    delete from ca_group_member where member_uuid = old_groupid;
    delete from ca_agent where object_uuid = old_groupid and agent_type = 0;
END; 
/


grant execute on  p_integrity_d_group_def to  ca_itrm_group;
;
grant execute on  p_integrity_d_group_def to  ca_itrm_group_ams;
;

/*
 ***********************************************
 trigger on delete on ca_group_def
*/



CREATE OR REPLACE TRIGGER "MDBADMIN".R_DEL_GROUP_DEF 
AFTER DELETE ON "MDBADMIN"."CA_GROUP_DEF" 
REFERENCING 
    OLD AS OLD 
FOR EACH ROW 
BEGIN
    p_integrity_d_group_def (:old.group_uuid);
END;
/




/*
 ***********************************************
 delete following entities if a ca_server enntity
 is delete
   ca_server_component 
   ca_server_push_status
 ca_agent will be updated in case server is referenced  
 
 @param old_server_uuid  deleted server 
*/


CREATE OR REPLACE procedure "MDBADMIN".P_INTEGRITY_D_SERVER(
	old_server_uuid IN ca_server.server_uuid%TYPE	
	)
AS

begin

 delete from ca_server_component where server_uuid = old_server_uuid;
 delete from ca_server_push_status where server_uuid = old_server_uuid;
 
 update ca_agent set server_uuid = null where server_uuid = old_server_uuid;
 update ca_agent_component set server_uuid = null where server_uuid = old_server_uuid;
 
end;
/


grant execute on p_integrity_d_server to  ca_itrm_group;
;
grant execute on p_integrity_d_server to  ca_itrm_group_ams;
;

/*
 ***********************************************
 trigger on delete on ca_server
*/

CREATE OR REPLACE TRIGGER "MDBADMIN".R_DEL_SERVER 
AFTER DELETE ON "MDBADMIN"."CA_SERVER" 
REFERENCING 
    OLD AS OLD 
    NEW AS NEW 
FOR EACH ROW 
BEGIN
    p_integrity_d_server(:old.server_uuid);
END;
/


/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of agent
 *********************************************************
 *********************************************************
 */

/*
 ***********************************************
 delete all entries of the ca_agent table if 
 a ca_agent_component object is deleted
 
 @param old_object_uuid deletd agent Uuid 
*/

CREATE OR REPLACE procedure  p_integrity_d_agent(
	old_object_uuid IN ca_agent.object_uuid%TYPE	
	)
AS

begin

  delete from ca_agent_component where object_uuid = old_object_uuid;
end;
/


grant execute on p_integrity_d_agent to ca_itrm_group;
;
grant execute on p_integrity_d_agent to ca_itrm_group_ams;
;


/*
 ***********************************************
 trigger on delete on ca_agent
*/
CREATE OR REPLACE trigger r_del_agent
	after delete  on ca_agent
	REFERENCING 
        OLD AS OLD
	FOR EACH ROW
BEGIN
	p_integrity_d_agent(:old.object_uuid);
END;
/





/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of manager
 *********************************************************
 *********************************************************
 */

/*
 ***********************************************
 delete all entries of the ca_manager table if 
 a ca_manager_component object is deleted
 
 @param old_manager_uuid deleted manager uuid
*/

CREATE OR REPLACE procedure  p_integrity_d_manager(
	old_manager_uuid IN ca_manager.manager_uuid%TYPE
	)
AS

begin

  delete from ca_manager_component where manager_uuid = old_manager_uuid;
end;
/


grant execute on  p_integrity_d_manager to ca_itrm_group;
;
grant execute on  p_integrity_d_manager to ca_itrm_group_ams;
;


/*
 ***********************************************
 trigger on delete on ca_agent
*/
create or replace trigger r_del_manager
	after delete  on ca_manager
    REFERENCING 
        OLD AS OLD
    FOR EACH ROW
BEGIN
    p_integrity_d_manager (:old.manager_uuid);
END;
/


/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of query
 *********************************************************
 *********************************************************
 */
/*
 ***********************************************
 delete all entries of the ca_query_version, 
 ca_query_result table if 
 a ca_query_def object is deleted
*/
create or replace procedure  p_integrity_d_query_def(
	old_query_uuid IN ca_query_def.query_uuid%TYPE 	/* old query uuid */
	)
AS

begin

  delete from ca_query_version where query_uuid = old_query_uuid;
  delete from ca_query_result where query_uuid = old_query_uuid;
end;
/


grant execute on  p_integrity_d_query_def to ca_itrm_group;
;
grant execute on  p_integrity_d_query_def to ca_itrm_group_ams;
;


/*
 ***********************************************
 trigger on delete on ca_query_def
*/
create or replace trigger r_del_query
	after delete  on CA_QUERY_DEF
	REFERENCING OLD AS old
	FOR EACH ROW
BEGIN
	p_integrity_d_query_def(:old.query_uuid);
END;
/



/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of engine
 *********************************************************
 *********************************************************
 */

/*
 ***********************************************
 handle deletion of an ca_engine
 */
create or replace procedure  p_integrity_d_engine(
	old_engine_uuid IN ca_engine.engine_uuid%TYPE 	/* old engine uuid */
	)
AS

begin
   update ca_group_def set evaluation_uuid = null 
             where evaluation_uuid = old_engine_uuid;
end ;
/




grant execute on p_integrity_d_engine to ca_itrm_group;
;
grant execute on p_integrity_d_engine to ca_itrm_group_ams;
;




/*
 ***********************************************
 trigger on delete on ca_engine
*/
create or replace trigger r_del_engine
	after delete  on CA_ENGINE
	REFERENCING OLD AS old
	FOR EACH ROW
BEGIN
	p_integrity_d_engine(:old.engine_uuid);
END;
/



/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of directory 
 * integration tables
 *********************************************************
 *********************************************************
 */

/*
 ***********************************************
 handle deletion of ca_directory_details
 */
create or replace procedure  p_integrity_d_dir_details(
	old_directory_uuid IN ca_link_dir_details_map.directory_uuid%TYPE 	
	)
AS

begin
   delete from ca_link_dir_details_map  where directory_uuid = old_directory_uuid;
end ;
/




grant execute on  p_integrity_d_dir_details to ca_itrm_group;
;
grant execute on  p_integrity_d_dir_details to ca_itrm_group_ams;
;




/*
 ***********************************************
 trigger on delete on ca_directory_details
*/
create or replace trigger r_del_directory_details
	after delete  on CA_DIRECTORY_DETAILS
	REFERENCING OLD AS old
	FOR EACH ROW
BEGIN
	p_integrity_d_dir_details(:old.directory_uuid);
END;
/



/*
 ***********************************************
 handle deletion of ca_directory_schema_map
 */
create or replace procedure  p_integrity_d_dir_schema_map(
	old_dir_schema_uuid IN ca_link_dir_details_map.dir_schema_uuid%TYPE	
	)
AS

begin
   delete from ca_link_dir_details_map  where dir_schema_uuid = old_dir_schema_uuid;
end ;
/



grant execute on  p_integrity_d_dir_schema_map to ca_itrm_group;
;
grant execute on  p_integrity_d_dir_schema_map to ca_itrm_group_ams;
;


/*
 ***********************************************
 trigger on delete on ca_directory_schema_map
*/
create or replace trigger r_del_dir_schema_map
	after delete  on ca_directory_schema_map
	REFERENCING OLD AS old
	FOR EACH ROW
BEGIN
	p_integrity_d_dir_schema_map(:old.dir_schema_uuid);
END;
/



/*
 *********************************************************
 *********************************************************
 * Procedures and rules to manage integrity of ca_proc_os
 *********************************************************
 *********************************************************
 */

/*
 ***********************************************
 handle deletion of an ca_proc_os
 */
create or replace procedure  p_integrity_d_proc_os(
	old_proc_os_id IN NUMBER		/* old proc_s id */
	)
AS
 
	agncnt  NUMBER;
	row_not_found exception;
	PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */

begin
   
   select count(*) 
   into agncnt
   from ca_agent where proc_os_id = old_proc_os_id;
  
	if ( agncnt != 0 )
	then
	   RAISE_APPLICATION_ERROR (-20000, 'Error 9002: proc_os can''t be deleted because one or more agent objects still exists for this OS');
	end if;
  
  EXCEPTION
    WHEN row_not_found 
	THEN return;
  
end;
/




grant execute on  p_integrity_d_proc_os to ca_itrm_group;
;
grant execute on  p_integrity_d_proc_os to ca_itrm_group_ams;
;


/*
 ***********************************************
 trigger on delete on ca_proc_os
*/

create or replace trigger r_del_proc_os
	after delete  on ca_proc_os
	REFERENCING OLD AS old
	FOR EACH ROW
BEGIN
    p_integrity_d_proc_os(:old.proc_os_id);
END;
/




/**
 * integrity of copmponent registration
 *
 */  


/*
 *********************************************************
 *********************************************************
 * integrity rules for replication
 *********************************************************
 *********************************************************
 */


/*
 ************************************************
 * manage  software signature
 */
create or replace procedure  p_sp_ssf_versionupdate
AS
 
	incr NUMBER;
	row_not_found exception;
	PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */
BEGIN 

	select set_val_lng 
		into incr 
		from ca_settings where set_id=5;
		
	IF (incr=0)
    THEN
		update ca_settings set set_val_lng=set_val_lng+1 where set_id=4;
		update ca_settings set set_val_lng=set_val_lng+1 where set_id=6;
		update ca_settings set set_val_lng=1 where set_id=5;
	END IF;

	EXCEPTION
		WHEN row_not_found 
		THEN return;
end;
/




grant execute on  p_sp_ssf_versionupdate to ca_itrm_group;
;
grant execute on  p_sp_ssf_versionupdate to ca_itrm_group_ams;
;



/*
 ************************************************
 * update or insert into ca_software_signature
 */

create or replace trigger r_ssf_versionupdate 
	after insert OR update  on ca_software_signature
	REFERENCING OLD AS old
	FOR EACH ROW 
	
Begin 
		 p_sp_ssf_versionupdate;
END;
/



/* ************** 10970 begin ************************************* */

create or replace trigger r_ssf_versionupdate_def
    after insert OR update  on ca_software_def
    FOR EACH ROW
BEGIN
    p_sp_ssf_versionupdate;
END;
/




create or replace trigger r_ssf_versionupdate_link
    after insert OR update on ca_link_sw_def
    FOR EACH ROW
BEGIN
     p_sp_ssf_versionupdate;
END;
/




/* ************** 10970 end ************************************* */

/*
 *********************************************************
 *********************************************************
 * integrity group membership
 *********************************************************
 *********************************************************
 */

/*
 ************************************************
 * manage  group members
 * a group can not be a member of itself 
 */

create or replace procedure  p_iu_group_member
( member_uuid IN ca_group_member.member_uuid%TYPE,
  group_uuid IN ca_group_member.group_uuid%TYPE
)

AS
    E_9003 EXCEPTION;
BEGIN 
		
	if (member_uuid = group_uuid) 
	then
	   raise E_9003;
	
    end if;
  
EXCEPTION
    WHEN E_9003 THEN
    BEGIN
        RAISE_APPLICATION_ERROR ( -20000, 'Error 9003: insert/update error, member_uuid must be not equal the group_uuid');
    END;
        
        
end;
/




grant execute on  p_iu_group_member to ca_itrm_group;
;
grant execute on  p_iu_group_member to ca_itrm_group_ams;
;



/*
 ************************************************
 * update or insert group membership
 */
create or replace trigger r_iu_group_member
	after insert OR  update on ca_group_member
	REFERENCING NEW AS new
	FOR EACH ROW
BEGIN
		 p_iu_group_member(:new.member_uuid, :new.group_uuid);
END;
/




/*
 *********************************************************
 *********************************************************
 * integrity discovered hardware
 *********************************************************
 *********************************************************
 */

/*
 ************************************************
 * handle deletion of a ca_discovered_hardware entity
 */
create or replace procedure   p_d_discovered_hardware ( 
	dishw_uuid IN ca_discovered_hardware.dis_hw_uuid%TYPE
 ) 
AS
 
	cnt        NUMBER; 
	row_not_found exception;
	PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */
	
BEGIN 
	/* check if there is any agent record*/
	Declare
		row_not_found exception;
		PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */
	begin
		select count(*) 
			into cnt 
			from ca_agent 
			where object_uuid = dishw_uuid; 
		EXCEPTION
			WHEN row_not_found 
			THEN cnt := 0;
	end;
	if (cnt != 0) 
	then 
        raise_application_error (-20000, 'Error 9004: deletion denied, ca_agent object still exists');
	end if; 
	
	/* check if there is any server record*/
	Declare
		row_not_found exception;
		PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */
	begin
		select count(*) 
			into cnt 
			from ca_server  
			where dis_hw_uuid = dishw_uuid; 
		EXCEPTION
			WHEN row_not_found 
			THEN cnt := 0;
	end;
	if (cnt != 0) 
	then 
        raise_application_error (-20000, 'Error 9004: deletion denied, ca_server object still exists');
	end if; 
	
	
	delete from ca_discovered_hardware_network where dis_hw_uuid = dishw_uuid; 
	
	
	update ca_engine set dis_hw_uuid=NULL where dis_hw_uuid = dishw_uuid; 
	
	/* bug fix 1406 
  	delete from ca_link_dis_hw WHERE primary_dis_hw_uuid = dishw_uuid;
  	delete from ca_link_dis_hw WHERE secondary_dis_hw_uuid = dishw_uuid;
  	*/
  	delete from ca_link_dis_hw 
        WHERE primary_dis_hw_uuid = dishw_uuid 
            or secondary_dis_hw_uuid = dishw_uuid;

	delete 
		from "MDBADMIN".AM_LINK_EXTERNAL_DEVICE
		WHERE secondary_uuid = dishw_uuid;
		
    
end;
/




grant execute on p_d_discovered_hardware to ca_itrm_group;
;
grant execute on p_d_discovered_hardware to ca_itrm_group_ams;
;


/**
 * * trigger to kickoff  the deletion procedure  when a computer is deleted
 */ 
create or replace trigger  r_d_discovered_hardware 
	after delete on ca_discovered_hardware 
	REFERENCING 
	   OLD AS old
	FOR EACH ROW
BEGIN
	p_d_discovered_hardware	(:old.dis_hw_uuid );
	
END;
/




/*
 *********************************************************
 *********************************************************
 * integrity discovered user
 *********************************************************
 *********************************************************
 */

/*
 ************************************************
 * handle deletion of a ca_discovered_user entity
 */
create or replace procedure  p_d_discovered_user
(   usr_uuid IN ca_discovered_user.user_uuid%TYPE
)

AS

	cnt    NUMBER;
	row_not_found exception;
	PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */
    	
BEGIN 

	select 	count(*)
	into cnt
	from ca_agent
	where object_uuid = usr_uuid;
	
	if (cnt != 0) 
	then
       raise_application_error (-20000, 'Error 9005: deletion denied, ca_agent object still exists');
    end if;
   
	delete from "MDBADMIN".AM_LINK_EXTERNAL_DEVICE
		WHERE secondary_uuid = usr_uuid;

	EXCEPTION
		WHEN row_not_found 
		THEN return;
    
end;
/




grant execute on  p_d_discovered_user to ca_itrm_group;
;
grant execute on  p_d_discovered_user to ca_itrm_group_ams;
;



/*
 ************************************************
 * delete ca_discovered user
 */

create or replace trigger r_d_discovered_user
	after delete on ca_discovered_user
	REFERENCING 
	   OLD AS old
	FOR EACH ROW
BEGIN
	 p_d_discovered_user(:old.user_uuid);
END;
/




/*
 *********************************************************
 *********************************************************
 * integrity computer  user
 *********************************************************
 *********************************************************
 */

/*
 ************************************************
 * handle update/insert computer user
 */

create or replace procedure  p_iu_computer_user
(   usr_uuid   IN ca_link_dis_hw_user.user_uuid%TYPE,
	dishw_uuid IN ca_link_dis_hw_user.dis_hw_uuid%TYPE
)

AS
	
	cnt    NUMBER;
	row_not_found exception;
	PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */
    	
BEGIN 

	select 	count(*)
	into cnt
	from ca_discovered_user  u, ca_discovered_hardware  c
	where       c.dis_hw_uuid = dishw_uuid 
			and u.user_uuid = usr_uuid
			and c.domain_uuid = u.domain_uuid;
	if ( cnt = 0)
	then
			-- we will never come here
			raise_application_error ( -20000, 'Error 9010: insert/update denied, different domain_uuid for user and computer');
	end if;
	
	EXCEPTION
		WHEN row_not_found THEN
		BEGIN
			raise_application_error ( -20000, 'Error 9010: insert/update denied, different domain_uuid for user and computer');
		END;        

end;
/




grant execute on  p_iu_computer_user to ca_itrm_group;
;
grant execute on  p_iu_computer_user to ca_itrm_group_ams;
;

/*
 ************************************************
 * insert/update computer user
 */
create or replace trigger r_iu_computer_user
	after insert OR update on ca_link_dis_hw_user
    REFERENCING
        NEW AS new
    FOR EACH ROW
BEGIN	
    p_iu_computer_user(:new.user_uuid, :new.dis_hw_uuid);
	
END;
/





/*
 ************************************
 * procedure to
 * check uri of a discovered_user object
 */

--drop index dis_user_unique_uri;
create unique index dis_user_unique_uri on ca_discovered_user
    (uri,
     domain_uuid,
     case user_type 
            when 1 			then 200 
            when 2 			then 200 
            else user_type 	end		);


-- remove the old ugly triggers, if they exist from an earlier test
--drop trigger r_u_dis_user_uri_check;
--drop trigger r_i_dis_user_uri_check;
--drop procedure   p_iu_dis_user_uri_check;

-- create or replace procedure   p_iu_dis_user_uri_check( 
-- 	olduri IN ca_discovered_user.uri%TYPE,
-- 	newuri IN ca_discovered_user.uri%TYPE,
-- 	dom_uuid IN ca_discovered_user.domain_uuid%TYPE
-- )
-- as 
--  
--    nr 		NUMBER;
--    E_9007   EXCEPTION;
-- begin
-- 
--     if ( newuri IS NULL )
--     then
--     	return;
--     end if;
-- 
--     select count(*) into nr
-- 	from ca_discovered_user
-- 	where uri = newuri 
--             and (user_type = 1 or user_type = 2) 
--             and domain_uuid = dom_uuid;
-- 
--       
--       if (nr > 1) then
--         raise E_9007;
--          
--       end if;
-- EXCEPTION
--     WHEN E_9007 THEN
--     BEGIN
--         raise_application_error( -20000, 'Error 9007: uri for discovered user not unique: ' || TO_CHAR(nr) );
--     END;
--          
-- end;
-- /
-- 
-- 
-- 
-- grant execute on  p_iu_dis_user_uri_check to ca_itrm_group;
-- /
-- 
-- 
-- 
-- /*
--  ************************************
--  * trigger: new discovered_user to check uri
--  */
-- 
-- 
-- create or replace trigger r_i_dis_user_uri_check 
--     after insert on ca_discovered_user
--     REFERENCING
--         NEW AS new
--     FOR EACH ROW
-- BEGIN
--     p_iu_dis_user_uri_check(null, :new.uri, :new.domain_uuid);
--     
-- END;
-- /
-- 

/*
 ************************************
 * trigger: update discovered_user to
 * check uri
 */

-- create or replace trigger r_u_dis_user_uri_check 
--     after update OF uri on ca_discovered_user
--     REFERENCING
--         OLD AS old
--         NEW AS NEW
--     FOR EACH ROW
-- BEGIN
--     p_iu_dis_user_uri_check(:old.uri, :new.uri, :new.domain_uuid);
--     
-- END;
-- /
-- 
-- 

/*
 ************************************
 * procedure: check if  host_uuid   of a computer
 * is unqiue
 *
 */

-- remove the old ugly triggers, if they exist from an earlier test
--drop trigger r_i_dis_hw_host_uuid;
--drop trigger r_u_dis_hw_host_uuid; 
--drop procedure   p_iu_dis_hw_host_uuid;



--drop index dis_hardware_unique_uuid;
create unique index dis_hardware_unique_uuid on ca_discovered_hardware
    (host_uuid,
     domain_uuid
            );

--create or replace procedure   p_iu_dis_hw_host_uuid( 
--    newuuid  IN ca_discovered_hardware.host_uuid%TYPE,
--	dom_uuid IN ca_discovered_hardware.domain_uuid%TYPE
--)
--as 
-- 
--   nr 		NUMBER;
--   row_not_found exception;
--   PRAGMA EXCEPTION_INIT(row_not_found,100); /* 100 means -1403 */
--   
--begin
--	
--
--    if ( newuuid IS NULL )
--    then
--	       return;
--    end if;
--
--    select count(*) 
--		into nr 
--		from ca_discovered_hardware
--		where host_uuid = newuuid and domain_uuid = dom_uuid;
--
--    if (nr > 1) 
--    then
--        raise_application_error( -20000,  'Error 9008: host_uuid for discovered hardware not unique: ');
--    end if;
--
--	EXCEPTION 
--		when row_not_found
--			then return;
--END;
--/
--
--
--
--
--grant execute on  p_iu_dis_hw_host_uuid to ca_itrm_group;
--/
--
--
--
--
--/*
-- ************************************
-- trigger : check host_uuid  of new computer
-- */
--
--create or replace trigger r_i_dis_hw_host_uuid 
--    after insert on ca_discovered_hardware
--    REFERENCING
--        NEW AS new
--    FOR EACH ROW
--BEGIN
--    p_iu_dis_hw_host_uuid(:new.host_uuid, :new.domain_uuid);
--    
--END;
--/
--
--
--
--
--
--/*
-- ************************************
-- trigger: update computer host_uuid
-- */
-- 
--
--create or replace trigger r_u_dis_hw_host_uuid 
--    after update OF host_uuid on ca_discovered_hardware
--    REFERENCING 
--        NEW as new
--    FOR EACH ROW
--BEGIN
--    p_iu_dis_hw_host_uuid(:new.host_uuid, :new.domain_uuid);
--END;
--/
--




/*
 *********************************************************
 *********************************************************
 * integrity ca_category_def
 *********************************************************
 *********************************************************
 */


/*
 *******************************************************
 after delete on ca_category_def
 	delete link entries in ca_category_member
 bug fix 1512
 *******************************************************
 */

create or replace procedure p_d_link_category_def( 
	uuid IN ca_category_def.category_uuid%TYPE
) 
AS
 
	cnt number; 
BEGIN 

	delete from ca_category_member WHERE category_uuid = uuid;

end;
/



grant execute on  p_d_link_category_def to ca_itrm_group;
;
grant execute on  p_d_link_category_def to ca_itrm_group_ams;
;




/**
 * trigger to kickoff  the deletion procedure for categories
 */ 


create or replace trigger  r_d_links_category_def
	after delete on ca_category_def
	REFERENCING
	   OLD as old
	FOR EACH ROW
BEGIN
	p_d_link_category_def(:old.category_uuid );
END;
/






/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15948117, systimestamp, 1, 4, 'Star 15948117 (MODIFIED v5): ORACLE SYNCH PATCH' );

COMMIT;

EXIT SUCCESS;
